@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -22,7 +22,7 @@
  *
  * When writing the doxygen documentation for a class, one should follow those steps:
  *
- * 1/ Remove the /// @cond DOXYGEN_HIDDEN condition on top of the header and the /// @endcond tag at the bottom.
+ * 1/ Remove the @cond DOXYGEN_HIDDEN condition on top of the header and the @endcond tag at the bottom.
  *   If you are adding a new class to Tulip and didn't write the documentation yet, you should add those tags until the documentation is written.
  * 2/ Every class should belong to a doxygen group. This means that a @ingroup declaration must be added before the class @brief tag.
  * 3/ A doxygen group is identified by a single-word identifier (first word after the @defgroup declaration). What follows in the  @defgroup declaration is the pretty name that will appear into the final HTML document.
@@ -31,8 +31,6 @@
  * 5/ Please remember that code comments should NEVER begin with /** (use /* instead) in order to exclude them from doxygen.
  */
 
-#define DOXYGEN // Used to separate licence from groups definitions
-
 /**
  * @mainpage Welcome to Tulip's documentation.
  * You can jump right in with \ref graph_display/graph_display.cpp "one of our code examples", or browse the documentation by module.
