@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -82,6 +82,14 @@ public:
   typename tlp::StoredType<typename Tnode::RealType>::ReturnedConstValue
   getNodeValue(const node n) const;
 
+  /**
+   * @brief overloading of operator[] to get a node value
+   **/
+  const typename tlp::StoredType<typename Tnode::RealType>::ReturnedConstValue
+  operator[](node n) const {
+    return getNodeValue(n);
+  }
+
   /**
    * @brief Returns the value associated to the edge e in this property.
    * If there is no value, it returns the default edge value.
@@ -93,6 +101,13 @@ public:
   typename tlp::StoredType<typename Tedge::RealType>::ReturnedConstValue
   getEdgeValue(const edge e) const;
 
+  /**
+   * @brief overloading of operator[] to get an edge value
+   **/
+  typename tlp::StoredType<typename Tedge::RealType>::ReturnedConstValue operator[](edge e) const {
+    return getEdgeValue(e);
+  }
+
   /**
    * Returns an iterator through all nodes belonging to g
    * whose associated value is equal to val.
@@ -121,6 +136,56 @@ public:
   setNodeValue(const node n,
                typename tlp::StoredType<typename Tnode::RealType>::ReturnedConstValue v);
 
+  /**
+   * @brief inner class used to overload the operator[] to set a node value
+   **/
+  class nodeValueRef {
+  protected:
+    AbstractProperty *_prop;
+    node _n;
+
+  public:
+    constexpr nodeValueRef(AbstractProperty *prop, node n) : _prop(prop), _n(n) {}
+
+    typename tlp::StoredType<typename Tnode::RealType>::ReturnedConstValue getValue() const {
+      return _prop->getNodeValue(_n);
+    }
+
+    /**
+     * @brief overloading of operator= to assign a node value
+     * which allow to write: prop[n] = val
+     **/
+    nodeValueRef &
+    operator=(typename tlp::StoredType<typename Tnode::RealType>::ReturnedConstValue val) noexcept {
+      _prop->setNodeValue(_n, val);
+      return *this;
+    }
+
+    /**
+     * @brief overloading of operator= to assign a node value
+     * which allow to write: prop1[n] = prop2[m]
+     **/
+    nodeValueRef &operator=(const nodeValueRef &ref) noexcept {
+      _prop->setNodeValue(_n, ref.getValue());
+      return *this;
+    }
+
+    /**
+     * @brief overloading of value type conversion operator
+     * which allow to write: if (prop[n])
+     **/
+    operator typename tlp::StoredType<typename Tnode::RealType>::ReturnedConstValue() {
+      return getValue();
+    }
+  };
+
+  /**
+   * @brief overloading of operator[] to set a node value
+   **/
+  constexpr nodeValueRef operator[](node n) {
+    return nodeValueRef(this, n);
+  }
+
   /**
    * @brief Set the value of an edge and notify the observers of a modification.
    *
@@ -131,6 +196,56 @@ public:
   setEdgeValue(const edge e,
                typename tlp::StoredType<typename Tedge::RealType>::ReturnedConstValue v);
 
+  /**
+   * @brief inner class used to overload the operator[] to set an edge value
+   **/
+  class edgeValueRef {
+  protected:
+    AbstractProperty *_prop;
+    edge _e;
+
+  public:
+    constexpr edgeValueRef(AbstractProperty *prop, edge e) : _prop(prop), _e(e) {}
+
+    typename tlp::StoredType<typename Tedge::RealType>::ReturnedConstValue getValue() const {
+      return _prop->getEdgeValue(_e);
+    }
+
+    /**
+     * @brief overloading of operator= to assign an edge value
+     * which allow to write: prop[n] = val
+     **/
+    edgeValueRef &
+    operator=(typename tlp::StoredType<typename Tedge::RealType>::ReturnedConstValue val) noexcept {
+      _prop->setEdgeValue(_e, val);
+      return *this;
+    }
+
+    /**
+     * @brief overloading of operator= to assign an edge value
+     * which allow to write: prop1[e1] = prop2[e2]
+     **/
+    edgeValueRef &operator=(const edgeValueRef &ref) noexcept {
+      _prop->setEdgeValue(_e, ref.getValue());
+      return *this;
+    }
+
+    /**
+     * @brief overloading of value type conversion operator
+     * which allow to write: if (prop[e])
+     **/
+    operator typename tlp::StoredType<typename Tedge::RealType>::ReturnedConstValue() {
+      return getValue();
+    }
+  };
+
+  /**
+   * @brief overloading of operator[] to set an edge value
+   **/
+  constexpr edgeValueRef operator[](edge e) {
+    return edgeValueRef(this, e);
+  }
+
   /**
    * @brief Sets the value of all nodes and notify the observers.
    * All previous values are lost and the given value is assigned as the default one to the future
@@ -552,6 +667,7 @@ template <typename vectType, typename eltType, typename propType = VectorPropert
 class TLP_SCOPE AbstractVectorProperty : public AbstractProperty<vectType, vectType, propType> {
 public:
   AbstractVectorProperty(Graph *, const std::string &name = "");
+  using AbstractProperty<vectType, vectType, propType>::operator=;
 
   // 5 methods inherited from VectorPropertyInterface
   bool tokenize(const std::string &str, std::vector<std::string> &vect, char openChar = '(',
