@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -123,7 +123,7 @@ public:
    * @param gradient if set to true, color scale is a gradient
    *
    */
-  virtual void setColorScale(const std::vector<Color> colors, const bool gradient = true);
+  virtual void setColorScale(const std::vector<Color> &colors, const bool gradient = true);
 
   /**
    * @brief Adds a color to the color scale at specific position.
@@ -202,6 +202,14 @@ public:
     return (gradient == cs.gradient) && (colorMap == cs.colorMap);
   }
 
+  /**
+   * @brief Tests color scale difference with another one.
+   *
+   */
+  bool operator!=(const ColorScale &cs) const {
+    return (gradient != cs.gradient) || (colorMap != cs.colorMap);
+  }
+
   /**
    * @brief Tests color scale equality with a regular one defined by a vector of colors.
    *
