@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -21,13 +21,14 @@
 #ifndef TEST_LISTENER
 #define TEST_LISTENER
 
-#include <unordered_map>
+#include <tulip/tuliphash.h>
 
-#include <tulip/Graph.h>
 #include <tulip/Observable.h>
 
 namespace tlp {
 
+class Graph;
+
 class ConnectedTestListener : public Observable {
 public:
   // override of Observable::treatEvent to remove the cached result for a graph if it is modified.
@@ -36,7 +37,7 @@ public:
   /**
    * @brief Stored results for graphs. When a graph is updated, its entry is removed from the map.
    **/
-  std::unordered_map<const Graph *, bool> resultsBuffer;
+  tlp_hash_map<const Graph *, bool> resultsBuffer;
 };
 
 } // namespace tlp
