@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -20,8 +20,8 @@
 #ifndef _TULIPREFLECT
 #define _TULIPREFLECT
 
-#include <unordered_map>
 #include <tulip/tulipconf.h>
+#include <tulip/tuliphash.h>
 #include <tulip/StlIterator.h>
 
 #include <string>
@@ -114,8 +114,14 @@ class DataSet;
 struct DataTypeSerializer {
   // the readable type name the serializer is designed for
   std::string outputTypeName;
-  DataTypeSerializer(const std::string &otn) : outputTypeName(otn) {}
+  // the current graph
+  Graph *graph;
+  DataTypeSerializer(const std::string &otn) : outputTypeName(otn), graph(nullptr) {}
   virtual ~DataTypeSerializer() {}
+  // set the current graph if needed
+  void setGraph(Graph *g) {
+    graph = g;
+  }
   // return a copy of this
   virtual DataTypeSerializer *clone() const = 0;
   // write the DataType embedded value into the output stream
@@ -164,15 +170,15 @@ class DataTypeSerializerContainer {
 
 public:
   ~DataTypeSerializerContainer() {
-    std::unordered_map<std::string, DataTypeSerializer *>::iterator it = tnTodts.begin();
+    tlp_hash_map<std::string, DataTypeSerializer *>::iterator it = tnTodts.begin();
 
     for (; it != tnTodts.end(); ++it) {
       delete it->second;
     }
   }
 
-  std::unordered_map<std::string, DataTypeSerializer *> tnTodts;
-  std::unordered_map<std::string, DataTypeSerializer *> otnTodts;
+  tlp_hash_map<std::string, DataTypeSerializer *> tnTodts;
+  tlp_hash_map<std::string, DataTypeSerializer *> otnTodts;
 };
 ///@endcond
 
@@ -189,6 +195,14 @@ public:
 class TLP_SCOPE DataSet {
   // Internal list of key-value pairs.
   std::list<std::pair<std::string, DataType *>> data;
+
+  // list of deprecated properties
+  std::list<std::pair<std::string, std::string>> *deprecated;
+  // add a deprecated property name for compatibility management
+  void addDeprecated(const std::string &oldName, const std::string &usedName);
+  // return the property to be used
+  const std::string &getUsedName(const std::string &oldName) const;
+
   /* management of data serialization
       two hashmap to retrieve data serializer from their
       type names and output type names
@@ -198,7 +212,7 @@ class TLP_SCOPE DataSet {
   static void registerDataTypeSerializer(const std::string &typeName, DataTypeSerializer *dts);
 
 public:
-  DataSet() {}
+  DataSet() : deprecated(nullptr) {}
   DataSet(const DataSet &set);
   ~DataSet();
 
@@ -219,6 +233,19 @@ public:
   template <typename T>
   bool get(const std::string &key, T &value) const;
 
+  /**
+   * @brief Returns the stored value associated with the given key or the deprecated version of the
+   *key The stored value is a copy of the original value that was set. If there is no value
+   *associated with both keys, the input value is left untouched.
+   *
+   * @param key The key with which the data we want to retrieve is associated.
+   * @param oldKey The deprecated version of the key.
+   * @param value A variable which will be overwritten with the value to retrieve.
+   * @return bool Whether there is a value associated with one of the keys or not.
+   **/
+  template <typename T>
+  bool getDeprecated(const std::string &key, const std::string &oldKey, T &value) const;
+
   /**
    * @brief Returns the stored value, and deletes the stored copy.
    * If no value is found, nothing is deleted.
@@ -241,6 +268,18 @@ public:
   template <typename T>
   void set(const std::string &key, const T &value);
 
+  /**
+   * @brief Stores a copy of the given param, associated with a key and a deprected version of the
+   *key The value must have a well-formed copy constructor.
+   *
+   * @param key The key which can be used to retrieve the data.
+   * @param oldKey The deprecated version of the key.
+   * @param value The data to store.
+   * @return void
+   **/
+  template <typename T>
+  void setDeprecated(const std::string &key, const std::string &deprecatedKey, const T &value);
+
   /**
    * @brief Returns the mangled name of a type.
    *.
