@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -46,7 +46,7 @@ struct edge {
   /**
    * @brief edge creates an invalid edge.
    */
-  edge() : id(UINT_MAX) {}
+  constexpr edge() : id(UINT_MAX) {}
 
   /**
    * @brief edge Create an edge of given identifier.
