@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -45,6 +45,7 @@ public:
   GraphImpl();
   ~GraphImpl() override;
   void clear() override;
+  static Graph *newGraph();
   //=========================================================================
   inline bool isElement(const node n) const override {
     return storage.isElement(n);
