@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -21,10 +21,7 @@
 #ifndef _TLPGRAPHMEASEURE_H
 #define _TLPGRAPHMEASEURE_H
 
-#include <set>
-
 #include <tulip/Node.h>
-#include <tulip/MutableContainer.h>
 #include <tulip/StaticProperty.h>
 #include <tulip/GraphTools.h>
 
@@ -51,28 +48,14 @@ TLP_SCOPE double averageClusteringCoefficient(const Graph *);
  * assign to each node its local clustering coefficient
  * that is the proportion of edges between the nodes within its neighbourhood
  * divided by the number of edges that could possibly exist between them.
- * This quantifies how close its neighbors are to being a clique.
- * see http://en.wikipedia.org/wiki/Clustering_coefficient for more details
- * WARNING: this function is deprecated
- */
-TLP_SCOPE _DEPRECATED void clusteringCoefficient(const Graph *g, MutableContainer<double> &result,
-                                                 unsigned int maxDepth = 1);
-/*
- * assign to each node its local clustering coefficient
- * that is the proportion of edges between the nodes within its neighbourhood
- * divided by the number of edges that could possibly exist between them.
- * This quantifies how close its neighbors are to being a clique.
- * see http://en.wikipedia.org/wiki/Clustering_coefficient for more details
+ * This quantifies how close the node and its neighbors are close to a clique.
+ * see http://en.wikipedia.org/wiki/Clustering_coefficient for more details or
+ * the paper: D. J. Watts and S. H. Strogatz.
+ * Collective dynamics of "small-world" networks.
+ * Nature 393, 440 (1998) doi: https://doi.org/10.1038/30918\">10.1038/30918.
  */
 TLP_SCOPE void clusteringCoefficient(const Graph *g, tlp::NodeStaticProperty<double> &result,
-                                     unsigned int maxDepth = 1);
-/*
- * assign to each node of a Directed Acyclic Graph a level such that
- * if the edge e(u,v) exists level(u) < level(v) the algorithm ensure that
- * the number of level used is minimal.
- * WARNING: this function is deprecated
- */
-TLP_SCOPE _DEPRECATED void dagLevel(const Graph *graph, MutableContainer<unsigned int> &level);
+                                     _DEPRECATED unsigned int maxDepth = 1);
 /*
  * assign to each node of a graph its (in/ou/inout) degree.
  * The weighted degree of a node is the sum of weights of
@@ -98,16 +81,6 @@ TLP_SCOPE void dagLevel(const Graph *graph, tlp::NodeStaticProperty<unsigned int
 TLP_SCOPE unsigned int maxDegree(const Graph *);
 // return the minimum value of the degree of the graph's nodes
 TLP_SCOPE unsigned int minDegree(const Graph *);
-/*
- * compute the maximum distance from n to all the other nodes of graph
- * and store it into distance, (stored value is UINT_MAX for non connected nodes),
- * if direction is set to UNDIRECTED use undirected graph, DIRECTED use directed graph
- * and INV_DIRECTED use reverse directed graph (ie. all edges are reversed)
- * all the edge's weight is set to 1. (it uses a bfs thus the complexity is o(m), m = |E|).
- */
-TLP_SCOPE _DEPRECATED unsigned int maxDistance(const Graph *graph, const node n,
-                                               MutableContainer<unsigned int> &distance,
-                                               EDGE_TYPE direction = UNDIRECTED);
 /*
  * compute the maximum distance from the n (graph->nodes[nPos]) to all the other nodes of graph
  * and store it into distance, (stored value is UINT_MAX for non connected nodes),
