@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -31,9 +31,11 @@
 namespace tlp {
 
 ///@cond DOXYGEN_HIDDEN
+#ifndef NDEBUG
 extern TLP_SCOPE void incrNumIterators();
 extern TLP_SCOPE void decrNumIterators();
 extern TLP_SCOPE int getNumIterators();
+#endif
 ///@endcond
 
 /**
