@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -25,6 +25,7 @@
 #include <list>
 #include <vector>
 #include <unordered_map>
+#include <utility>
 
 #include <tulip/Edge.h>
 #include <tulip/MutableContainer.h>
@@ -52,7 +53,6 @@ private:
   void restore();
   edge edgeReversal(edge e);
   void makeBidirected(Graph *sG);
-  void swapNode(node &n1, node &n2);
   void findTerminalNodes(Graph *sG, node n, std::list<node> &listOfComponents,
                          std::map<node, std::list<node>> &terminalNodes);
   bool findObstruction(Graph *sG, node n, std::list<node> &terminalNodes);
@@ -194,7 +194,7 @@ private:
   MutableContainer<int> largestNeighbor;
 
   //   // for each node u in T,
-  //   // label_b[u] = max{largest_neighbor[v] : v is a descendat of u in T_u}
+  //   // label_b[u] = max{largest_neighbor[v] : v is a descendant of u in T_u}
   //   // where T_u is the subtree of T rooted at u;
   //   //node_map<int> labelB;
   MutableContainer<int> labelB;
