@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -26,8 +26,8 @@
 
 #include <tulip/tulipconf.h>
 #include <tulip/Observable.h>
-//#include <tulip/Node.h>
 #include <tulip/Edge.h>
+#include <tulip/TlpTools.h>
 
 namespace tlp {
 
@@ -124,12 +124,33 @@ public:
   virtual PropertyInterface *clonePrototype(Graph *graph, const std::string &name) const = 0;
 
   /**
-   * @brief Gets a string describing the type of the property (e.g. "graph", "double", "layout",
-   * "string", "integer", "color", "size").
+   * @brief Gets a string describing the type of the property value (e.g. "graph", "double",
+   * "layout", "string", "integer", "color", "size").
    * @return The name of this property's type.
    */
   virtual const std::string &getTypename() const = 0;
 
+  /**
+   * @brief Gets a string giving the name of a the PropertyInterface subclass
+   * (e.g "tlp::BooleanProperty", "tlp::DoubleProperty", ...)
+   * @return The subclass name.
+   */
+  virtual const std::string &getCppClassName() const = 0;
+
+///@cond DOXYGEN_HIDDEN
+// the following macro gives a generic definition of getCppClassName()
+// it is used when declaring PropertyInterface subclasses
+#define DEFINE_GET_CPP_CLASS_NAME                                                                  \
+  const std::string &getCppClassName() const override {                                            \
+    static std::string className;                                                                  \
+    if (className.empty()) {                                                                       \
+      std::string dcn(demangleClassName(typeid(this).name(), false));                              \
+      className = dcn.substr(0, dcn.find(' '));                                                    \
+    }                                                                                              \
+    return className;                                                                              \
+  }
+  ///@endcond
+
   /**
    * @brief Gets the name of the property (e.g. viewLayout).
    * @return The name of this property.
@@ -174,19 +195,12 @@ public:
   }
 
   /**
-   * @brief Gets a string representation of the node default value.
+   * @brief Gets a string representation of the node value.
    * @param n The node to get the value of.
-   * @return A string representation of the node default value.
+   * @return A string representation of the node value.
    */
   virtual std::string getNodeStringValue(const node n) const = 0;
 
-  /**
-   * @brief Gets a string representation of the edge default value.
-   * @param e The edge to get the value of.
-   * @return A string representation of the edge default value.
-   */
-  virtual std::string getEdgeStringValue(const edge e) const = 0;
-
   /**
    * @brief Sets a new value on the node, represented by the string parameter.
    * @param n The node on which to set the new value.
@@ -196,6 +210,69 @@ public:
    */
   virtual bool setNodeStringValue(const node n, const std::string &value) = 0;
 
+  /**
+   * @brief inner class used to overload the operator[] to set a node string value
+   **/
+  class nodeStringValueRef {
+  protected:
+    PropertyInterface *_prop;
+    node _n;
+
+  public:
+    constexpr nodeStringValueRef(PropertyInterface *prop, node n) : _prop(prop), _n(n) {}
+
+    std::string getStringValue() const {
+      return _prop->getNodeStringValue(_n);
+    }
+
+    /**
+     * @brief overloading of operator= to assign a node string value
+     * which allows to write: prop[n] = strval
+     **/
+    nodeStringValueRef &operator=(std::string val) noexcept {
+      _prop->setNodeStringValue(_n, val);
+      return *this;
+    }
+
+    /**
+     * @brief overloading of operator= to assign a node string value
+     * which allows to write: prop1[n] = prop2[m]
+     **/
+    nodeStringValueRef &operator=(const nodeStringValueRef &ref) noexcept {
+      _prop->setNodeStringValue(_n, ref.getStringValue());
+      return *this;
+    }
+
+    /**
+     * @brief overloading of operator==
+     * which allows to write: prop1[n] == prop2[m]
+     **/
+    bool operator==(std::string str) noexcept {
+      return _prop->getNodeStringValue(_n) == str;
+    }
+
+    /**
+     * @brief overloading of std::string conversion operator
+     **/
+    operator std::string() {
+      return getStringValue();
+    }
+  };
+
+  /**
+   * @brief overloading of operator[] to set a node string value
+   **/
+  constexpr nodeStringValueRef operator[](node n) {
+    return nodeStringValueRef(this, n);
+  }
+
+  /**
+   * @brief Gets a string representation of the edge value.
+   * @param e The edge to get the value of.
+   * @return A string representation of the edge value.
+   */
+  virtual std::string getEdgeStringValue(const edge e) const = 0;
+
   /**
    * @brief Sets a new value on the edge, represented by the string parameter.
    * @param e The edge on which to set value on.
@@ -205,6 +282,69 @@ public:
    */
   virtual bool setEdgeStringValue(const edge e, const std::string &value) = 0;
 
+  /**
+   * @brief inner class used to overload the operator[] to set an edge string value
+   **/
+  class edgeStringValueRef {
+  protected:
+    PropertyInterface *_prop;
+    edge _e;
+
+  public:
+    constexpr edgeStringValueRef(PropertyInterface *prop, edge e) : _prop(prop), _e(e) {}
+
+    std::string getStringValue() const {
+      return _prop->getEdgeStringValue(_e);
+    }
+
+    /**
+     * @brief overloading of operator= to assign a edge string value
+     * which allows to write: prop[e] = strval
+     **/
+    edgeStringValueRef &operator=(std::string val) noexcept {
+      _prop->setEdgeStringValue(_e, val);
+      return *this;
+    }
+
+    /**
+     * @brief overloading of operator= to assign a edge string value
+     * which allows to write: prop1[e1] = prop2[e2]
+     **/
+    edgeStringValueRef &operator=(const edgeStringValueRef &ref) noexcept {
+      _prop->setEdgeStringValue(_e, ref.getStringValue());
+      return *this;
+    }
+
+    /**
+     * @brief overloading of operator==
+     * which allows to write: prop1[e1] == prop2[e2]
+     **/
+    bool operator==(std::string str) noexcept {
+      return _prop->getEdgeStringValue(_e) == str;
+    }
+
+    /**
+     * @brief overloading of std::string conversion operator
+     **/
+    operator std::string() {
+      return getStringValue();
+    }
+  };
+
+  /**
+   * @brief overloading of operator[] to set a edge string value value
+   **/
+  constexpr edgeStringValueRef operator[](edge e) {
+    return edgeStringValueRef(this, e);
+  }
+
+  /**
+   * @brief overloading of operator[] to get the edge string value
+   **/
+  std::string operator[](edge e) const {
+    return getEdgeStringValue(e);
+  }
+
   /**
    * @brief Gets a string representation of the node default value.
    * @return A string representation of the node default value.
@@ -596,7 +736,7 @@ public:
    * @param vect An output vector containing the string elements
    * @param openChar an optional character opening the list of elements. Default value is '('; when
    * set to '\0' it indicates that there is no opening character.
-   * @param sepChar an optional character separing the elements of the list. Default value is ','.
+   * @param sepChar an optional character separating the elements of the list. Default value is ','.
    * @param closeChar an optional character closing the list of elements. Default value is ')'; when
    * set to '\0' it indicates that there is no opening character.
    * @return Whether the string was a correct representation for this property's type.
@@ -630,7 +770,7 @@ public:
    * @param value A string listing the elements of the vector to set on the node.
    * @param openChar an optional character opening the list of elements. Default value is '('; when
    * set to '\0' it indicates that there is no opening character.
-   * @param sepChar an optional character separing the elements of the list. Default value is ','.
+   * @param sepChar an optional character separating the elements of the list. Default value is ','.
    * @param closeChar an optional character closing the list of elements. Default value is ')'; when
    * set to '\0' it indicates that there is no opening character.
    * @return Whether the string was a correct representation for this property's type. If not, the
@@ -646,7 +786,7 @@ public:
    * @param value A string listing the elements of the vector to set on the edge.
    * @param openChar an optional character opening the list of elements. Default value is '('; when
    * set to '\0' it indicates that there is no opening character.
-   * @param sepChar an optional character separing the elements of the list. Default value is ','.
+   * @param sepChar an optional character separating the elements of the list. Default value is ','.
    * @param closeChar an optional character closing the list of elements. Default value is ')'; when
    * set to '\0' it indicates that there is no opening character.
    * @return Whether the string was a correct representation for this property's type. If not, the
