@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -23,7 +23,7 @@
 
 #include <set>
 #include <vector>
-#include <sstream>
+#include <iostream>
 #include <tulip/StoredType.h>
 #include <tulip/Coord.h>
 #include <tulip/Size.h>
