@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -158,7 +158,7 @@ public:
       else {
         bool find = false;
 
-        if (entities.size() > 0) {
+        if (!entities.empty()) {
           result.push_back(entities[0]);
           find = true;
         }
