@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -18,7 +18,6 @@
  */
 ///@cond DOXYGEN_HIDDEN
 
-#ifndef DOXYGEN_NOTFOR_DEVEL
 #ifndef _TLPSTLFUNCTIONS_H
 #define _TLPSTLFUNCTIONS_H
 
@@ -33,14 +32,14 @@ struct edge;
  */
 class LessByMetric {
 public:
-  LessByMetric(DoubleProperty *metric):metric(metric) {}
-  bool operator() (node n1,node n2);
-  bool operator() (edge e1,edge e2);
+  LessByMetric(DoubleProperty *metric) : metric(metric) {}
+  bool operator()(node n1, node n2);
+  bool operator()(edge e1, edge e2);
+
 private:
   DoubleProperty *metric;
 };
-
-}
+} // namespace tlp
 #endif
-#endif // DOXYGEN_NOTFOR_DEVEL
+
 ///@endcond
