@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -36,13 +36,14 @@ typedef AbstractProperty<tlp::StringType, tlp::StringType> AbstractStringPropert
 class TLP_SCOPE StringProperty : public AbstractStringProperty {
 public:
   StringProperty(Graph *g, const std::string &n = "");
-
+  using AbstractStringProperty::operator=;
   // redefinition of some PropertyInterface methods
   PropertyInterface *clonePrototype(Graph *, const std::string &) const override;
   static const std::string propertyTypename;
   const std::string &getTypename() const override {
     return propertyTypename;
   }
+  DEFINE_GET_CPP_CLASS_NAME;
   // the value size of a StringVectorProperty is not fixed
   unsigned int nodeValueSize() const override {
     return 0;
@@ -63,13 +64,14 @@ class TLP_SCOPE StringVectorProperty
 public:
   StringVectorProperty(Graph *g, const std::string &n = "")
       : AbstractVectorProperty<StringVectorType, tlp::StringType>(g, n) {}
-
+  using AbstractVectorProperty<tlp::StringVectorType, tlp::StringType>::operator=;
   // redefinition of some PropertyInterface methods
   PropertyInterface *clonePrototype(Graph *, const std::string &) const override;
   static const std::string propertyTypename;
   const std::string &getTypename() const override {
     return propertyTypename;
   }
+  DEFINE_GET_CPP_CLASS_NAME;
   // the value size of a StringVectorProperty is not fixed
   unsigned int nodeValueSize() const override {
     return 0;
