@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -35,6 +35,8 @@
 #define OS_ARCHITECTURE "x86_64"
 #elif defined(__i386__) || defined(_M_IX86)
 #define OS_ARCHITECTURE "x86"
+#elif defined(__arm64__)
+#define OS_ARCHITECTURE "arm64"
 #else
 #define OS_ARCHITECTURE "other"
 #endif
