@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -132,7 +132,7 @@ struct TLPTokenParser {
             slashMode = false;
             break;
           }
-
+          [[fallthrough]];
         default:
           if (!slashMode)
             val.str += ch;
@@ -397,7 +397,7 @@ struct TLPParser {
     ess << "Error when parsing '" << value.c_str() << "' at line " << tokenParser->curLine + 1;
 
     if (errno)
-      ess << std::endl << strerror(errno);
+      ess << std::endl << tlp::getStrError();
     else if (!errorMsg.empty())
       ess << std::endl << errorMsg;
 
