@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -97,9 +97,6 @@ public:
    *graph->getRoot()->delNode()).
    **/
   static void cleanComputedTree(Graph *graph, Graph *tree);
-
-private:
-  static bool isFreeTree(const Graph *graph, node curRoot);
 };
 } // namespace tlp
 #endif
