@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -16,29 +16,22 @@
  * See the GNU General Public License for more details.
  *
  */
-///@cond DOXYGEN_HIDDEN
-
 
 #ifndef TULIP_TRICONNECTEDTEST_H
 #define TULIP_TRICONNECTEDTEST_H
 
-#include <tulip/tuliphash.h>
-#include <tulip/Observable.h>
-#include <tulip/Graph.h>
+#include <tulip/tulipconf.h>
 
 namespace tlp {
 
+class Graph;
+
 /**
  * @ingroup Checks
- * @brief Provides functions to test if a graph is Triconnected.
+ * @brief Provides functions to test if a graph is triconnected.
  **/
-class TLP_SCOPE TriconnectedTest : private Observable {
+class TLP_SCOPE TriconnectedTest {
 public:
-
-  /**
-   * Returns true if the graph is triconnected (i.e. a connected graph such that deleting any two nodes (and incident edges)
-   * results in a graph that is still connected), false otherwise.
-   */
   /**
    * @brief Checks if the graph is triconnected.
    * Creates a clone sugraph in which to operate, then iterates over the nodes, and deletes them.
@@ -50,25 +43,6 @@ public:
    * @return bool True if the graph is triconnected, false otherwise.
    **/
   static bool isTriconnected(Graph *graph);
-
-private:
-  TriconnectedTest();
-
-  bool compute(tlp::Graph* graph);
-  // override Observable::treatEvent
-  void treatEvent(const Event&);
-
-  /**
-   * @brief Singleton instance of this class.
-   **/
-  static TriconnectedTest * instance;
-  /**
-   * @brief Stored results for graphs. When a graph is updated, its entry is removed from the hashmap.
-   **/
-  TLP_HASH_MAP<const Graph*, bool> resultsBuffer;
 };
-
-
-}
+} // namespace tlp
 #endif
-///@endcond
