@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -24,7 +24,6 @@
 
 #include <list>
 #include <string>
-#include <typeinfo>
 #include <tulip/tulipconf.h>
 
 namespace tlp {
