@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -149,7 +149,7 @@ public:
  *
  * It is used by WithParameter to store parameters.
  * Each parameter is identified by a name, has a default value, a value, a help string, and a
- *boolean indicating whether it is mandatory or optional.
+ * Boolean indicating whether it is mandatory or optional.
  **/
 struct TLP_SCOPE ParameterDescriptionList {
 
@@ -188,6 +188,14 @@ struct TLP_SCOPE ParameterDescriptionList {
     parameters.push_back(newParameter);
   }
 
+  /**
+   * @brief remove an existing parameter from the list.
+   *
+   * @param parameterName The name of the parameter.
+   * @return void
+   **/
+  void remove(const std::string &parameterName);
+
   /**
    * @brief Retrieves an Iterator on the parameters.
    *
@@ -212,6 +220,14 @@ struct TLP_SCOPE ParameterDescriptionList {
    **/
   void setDefaultValue(const std::string &parameterName, const std::string &value);
 
+  /**
+   * @brief retrieves the direction of a parameter.
+   *
+   * @param parameterName The name of the parameter to retrieve the direction of.
+   * @return The direction of the parameter
+   **/
+  ParameterDirection getDirection(const std::string &parameterName) const;
+
   /**
    * @brief Sets the direction of a parameter.
    *
@@ -270,20 +286,6 @@ private:
   std::vector<ParameterDescription> parameters;
 };
 
-#define HTML_HELP_OPEN()                                                                           \
-  "<!DOCTYPE html><html><head>\
-<style type=\"text/css\">.body { font-family: \"Segoe UI\", Candara, \"Bitstream Vera Sans\", \"DejaVu Sans\", \"Bitstream Vera Sans\", \"Trebuchet MS\", Verdana, \"Verdana Ref\", sans-serif; }\
-    .paramtable { width: 100%; border: 0px; border-bottom: 1px solid #C9C9C9; padding: 5px; }\
-    .help { font-style: italic; font-size: 90%; }\
-    .b { padding-left: 5px; }</style>\
-</head><body><table border=\"0\" class=\"paramtable\">"
-
-#define HTML_HELP_DEF(A, B) "<tr><td><b>" A "</b><td class=\"b\">" B "</td></tr>"
-
-#define HTML_HELP_BODY() "</table><p class=\"help\">"
-
-#define HTML_HELP_CLOSE() "</p></body></html>"
-
 /**
  * @ingroup Plugins
  * @brief This class describes parameters on a plug-in.
@@ -305,7 +307,10 @@ struct TLP_SCOPE WithParameter {
   /**
    * @brief Adds an IN parameter to the plug-in.
    *
-   * @param name The name of the parameter to add.
+   * @param name The name of the parameter to add. Three name prefixes have special meanings:
+   *'anyfile::' means that the parameter identifies a file, 'file::' means that the parameter
+   *identifies an already existing file, 'dir::' means that the parameter identifies an alreay
+   *existing directory.
    * @param help A description of the parameter, that will be displayed to the user. Defaults to "".
    * @param defaultValue The default value the parameter should take, to be the initial value in the
    *GUI. Defaults to "".
@@ -324,7 +329,10 @@ struct TLP_SCOPE WithParameter {
   /**
    * @brief Adds an OUT parameter to the plug-in.
    *
-   * @param name The name of the parameter to add.
+   * @param name The name of the parameter to add. Three name prefixes have special meanings:
+   *'anyfile::' means that the parameter identifies a file, 'file::' means that the parameter
+   *identifies an already existing file, 'dir::' means that the parameter identifies an alreay
+   *existing directory.
    * @param help A description of the parameter, that will be displayed to the user. Defaults to "".
    * @param defaultValue The default value the parameter should take, to be the initial value in the
    *GUI. Defaults to "".
@@ -343,7 +351,10 @@ struct TLP_SCOPE WithParameter {
   /**
    * @brief Adds an INOUT parameter to the plug-in.
    *
-   * @param name The name of the parameter to add.
+   * @param name The name of the parameter to add. Three name prefixes have special meaning:
+   *'anyfile::' means that the parameter identifies a file, 'file::' means that the parameter
+   *identifies an already existing file, 'dir::' means taht the parameter identifies an alreay
+   *existing directory.
    * @param help A description of the parameter, that will be displayed to the user. Defaults to "".
    * @param defaultValue The default value the parameter should take, to be the initial value in the
    *GUI. Defaults to "".
@@ -372,6 +383,12 @@ protected:
    * @brief The internal structure storing the parameters.
    **/
   ParameterDescriptionList parameters;
+  /**
+   * @brief remove an existing parameter
+   **/
+  void removeParameter(const std::string &name) {
+    parameters.remove(name);
+  }
 };
 } // namespace tlp
 #endif
