@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -48,7 +48,7 @@ public:
    * @param filename The file to parse.
    * @return void
    **/
-  void parse(std::string filename);
+  void parse(const std::string &filename);
   void parse(const unsigned char *data, int length);
 
   virtual void parseNull();
@@ -65,6 +65,7 @@ public:
 
   bool parsingSucceeded() const;
   std::string errorMessage() const;
+  static std::string yajlVersion();
 
 protected:
   tlp::PluginProgress *_progress;
