@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -180,17 +180,6 @@ inline double log1p(double x) {
 #define TLP_PYTHON_SCOPE
 #endif
 
-#ifdef _WIN32
-#ifdef DLL_TULIP_OGDF
-#define TLP_OGDF_SCOPE __declspec(dllexport)
-#else
-#define TLP_OGDF_SCOPE __declspec(dllimport)
-#endif
-#endif
-#ifndef TLP_OGDF_SCOPE
-#define TLP_OGDF_SCOPE
-#endif
-
 #include <ostream>
 
 namespace tlp {
