@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -17,9 +17,6 @@
  *
  */
 
-#include <utility>
-#include <limits>
-
 #include <tulip/BoundingBox.h>
 
 #define THIS_INITED (memcmp(this, &_invalidBB, sizeof(_invalidBB)) != 0)
