@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -48,7 +48,7 @@ ColorScale &ColorScale::operator=(const ColorScale &scale) {
 
 ColorScale::~ColorScale() {}
 
-void ColorScale::setColorScale(const std::vector<Color> colors, const bool gradientV) {
+void ColorScale::setColorScale(const std::vector<Color> &colors, const bool gradientV) {
   gradient = gradientV;
   colorMap.clear();
 
@@ -98,7 +98,7 @@ void ColorScale::setColorAtPos(const float pos, const Color &color) {
 }
 
 Color ColorScale::getColorAtPos(const float pos) const {
-  if (colorMap.size() == 0) {
+  if (colorMap.empty()) {
     return Color(255, 255, 255, 255);
   } else {
     Color startColor;
