@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -20,7 +20,6 @@
 #include <tulip/ConnectedTest.h>
 #include <tulip/ConnectedTestListener.h>
 #include <tulip/Graph.h>
-#include <tulip/MutableContainer.h>
 #include <tulip/StaticProperty.h>
 
 using namespace std;
@@ -60,22 +59,25 @@ static bool connectedTest(const Graph *const graph) {
   if (graph->isEmpty())
     return true;
 
-  NodeStaticProperty<bool> visited(graph);
-  visited.setAll(false);
+  NodeStaticProperty<bool> visited(graph, false);
   unsigned int count = connectedTest(graph, graph->getOneNode(), visited);
   return (count == graph->numberOfNodes());
 }
 #endif
 //=================================================================
 bool ConnectedTest::isConnected(const tlp::Graph *const graph) {
-  if (instance.resultsBuffer.find(graph) != instance.resultsBuffer.end())
-    return instance.resultsBuffer[graph];
+  auto it = instance.resultsBuffer.find(graph);
+  if (it != instance.resultsBuffer.end())
+    return it->second;
 
   if (graph->isEmpty())
     return true;
 
-  NodeStaticProperty<bool> visited(graph);
-  visited.setAll(false);
+  // trees are connected graphs with the minimum number of edges
+  if (graph->numberOfEdges() < graph->numberOfNodes() - 1)
+    return false;
+
+  NodeStaticProperty<bool> visited(graph, false);
   unsigned int count = connectedTest(graph, graph->getOneNode(), visited);
   bool result = (count == graph->numberOfNodes());
   graph->addListener(instance);
@@ -98,6 +100,10 @@ unsigned int ConnectedTest::numberOfConnectedComponents(const tlp::Graph *const
   if (graph->isEmpty())
     return 0u;
 
+  // trees are the minimally connected graphs
+  if (graph->numberOfNodes() == graph->numberOfEdges() + 1)
+    return 1u;
+
   graph->removeListener(instance);
   vector<node> toLink;
   connect(graph, toLink);
@@ -115,8 +121,7 @@ unsigned int ConnectedTest::numberOfConnectedComponents(const tlp::Graph *const
 //======================================================================
 void ConnectedTest::computeConnectedComponents(const tlp::Graph *graph,
                                                vector<vector<node>> &components) {
-  NodeStaticProperty<bool> visited(graph);
-  visited.setAll(false);
+  NodeStaticProperty<bool> visited(graph, false);
   // do a bfs traversal for each node
   TLP_MAP_NODES_AND_INDICES(graph, [&](node n, unsigned int i) {
     // check if curNode has been already visited
@@ -149,6 +154,9 @@ void ConnectedTest::computeConnectedComponents(const tlp::Graph *graph,
           }
         }
       }
+      // stop if graph is connected
+      if (i == 0 && (component.size() == graph->numberOfNodes()))
+        return;
     }
   });
 }
@@ -163,8 +171,7 @@ void ConnectedTest::connect(const tlp::Graph *const graph, vector<node> &toLink)
   if (graph->isEmpty())
     return;
 
-  NodeStaticProperty<bool> visited(graph);
-  visited.setAll(false);
+  NodeStaticProperty<bool> visited(graph, false);
 
   TLP_MAP_NODES_AND_INDICES(graph, [&](node n, unsigned int i) {
     if (!visited[i]) {
