@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -24,8 +24,6 @@
 #include <tulip/BooleanProperty.h>
 #include <tulip/ConvexHull.h>
 
-#include <climits>
-
 using namespace std;
 using namespace tlp;
 
@@ -136,7 +134,7 @@ pair<Coord, Coord> tlp::computeBoundingRadius(const Graph *graph, const LayoutPr
   if (layout->hasNonDefaultValuatedEdges()) {
     for (auto e : graph->edges()) {
       if (selection == nullptr || selection->getEdgeValue(e)) {
-        for (const auto coord : layout->getEdgeValue(e)) {
+        for (const auto &coord : layout->getEdgeValue(e)) {
           double curRad = (coord - centre).norm();
 
           if (curRad > maxRad) {
