@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -25,7 +25,6 @@
 #include <tulip/GraphImpl.h>
 #include <tulip/ConcatIterator.h>
 #include <tulip/GraphTools.h>
-#include <tulip/TlpTools.h>
 
 using namespace std;
 using namespace tlp;
@@ -45,9 +44,10 @@ GraphAbstract::GraphAbstract(Graph *supergraph, unsigned int sgId)
 }
 //=========================================================================
 GraphAbstract::~GraphAbstract() {
+  // notify destruction
+  observableDeleted();
 
   for (Graph *sg : subgraphs) {
-
     // avoid double free
     // in a push context, a 'deleted' graph (see delSubGraph)
     // may still have a non empty list of subgraphs
@@ -222,9 +222,11 @@ bool GraphAbstract::isDescendantGraph(const Graph *g) const {
 }
 //=========================================================================
 Graph *GraphAbstract::getSubGraph(unsigned int sgId) const {
-  for (auto sg : subgraphs) {
-    if (sg->getId() == sgId)
-      return sg;
+  if (sgId) { // 0 is for root graph
+    for (auto sg : subgraphs) {
+      if (sg->getId() == sgId)
+        return sg;
+    }
   }
 
   return nullptr;
@@ -240,14 +242,16 @@ Graph *GraphAbstract::getSubGraph(const std::string &name) const {
 }
 //=========================================================================
 Graph *GraphAbstract::getDescendantGraph(unsigned int sgId) const {
-  Graph *sg = getSubGraph(sgId);
+  if (sgId) { // 0 is for root graph
+    Graph *sg = getSubGraph(sgId);
 
-  if (sg)
-    return sg;
-
-  for (auto sg : subgraphs) {
-    if ((sg = sg->getDescendantGraph(sgId)))
+    if (sg)
       return sg;
+
+    for (auto cur : subgraphs) {
+      if ((sg = cur->getDescendantGraph(sgId)))
+        return sg;
+    }
   }
 
   return nullptr;
@@ -259,8 +263,8 @@ Graph *GraphAbstract::getDescendantGraph(const string &name) const {
   if (sg)
     return sg;
 
-  for (auto sg : subgraphs) {
-    if ((sg = sg->getDescendantGraph(name)))
+  for (auto cur : subgraphs) {
+    if ((sg = cur->getDescendantGraph(name)))
       return sg;
   }
 
@@ -269,7 +273,7 @@ Graph *GraphAbstract::getDescendantGraph(const string &name) const {
 //=========================================================================
 node GraphAbstract::getOneNode() const {
   const std::vector<node> &vNodes = nodes();
-  return (vNodes.size() > 0) ? vNodes[0] : node();
+  return (!vNodes.empty()) ? vNodes[0] : node();
 }
 //=========================================================================
 node GraphAbstract::getRandomNode() const {
@@ -283,7 +287,7 @@ node GraphAbstract::getRandomNode() const {
 //=========================================================================
 edge GraphAbstract::getOneEdge() const {
   const std::vector<edge> &vEdges = edges();
-  return (vEdges.size() > 0) ? vEdges[0] : edge();
+  return (!vEdges.empty()) ? vEdges[0] : edge();
 }
 //=========================================================================
 edge GraphAbstract::getRandomEdge() const {
