@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -18,9 +18,8 @@
  */
 #include <deque>
 #include <stack>
-#include <climits>
 
-#include <unordered_map>
+#include <unordered_set>
 #include <tulip/GraphMeasure.h>
 #include <tulip/Graph.h>
 #include <tulip/GraphParallelTools.h>
@@ -29,19 +28,6 @@
 using namespace std;
 using namespace tlp;
 
-//================================================================
-unsigned int tlp::maxDistance(const Graph *graph, const node n,
-                              MutableContainer<unsigned int> &distance, EDGE_TYPE direction) {
-  distance.setAll(UINT_MAX);
-
-  tlp::NodeStaticProperty<unsigned int> dist(graph);
-  unsigned int result = tlp::maxDistance(graph, graph->nodePos(n), dist, direction);
-
-  for (auto n : graph->nodes())
-    distance.set(n, dist[n]);
-
-  return result;
-}
 //================================================================
 unsigned int tlp::maxDistance(const Graph *graph, unsigned int nPos,
                               tlp::NodeStaticProperty<unsigned int> &distance,
@@ -76,8 +62,7 @@ double tlp::maxDistance(const Graph *graph, const unsigned int nPos,
                         tlp::NodeStaticProperty<double> &distance,
                         const NumericProperty *const weights, EDGE_TYPE direction) {
   if (!weights) {
-    NodeStaticProperty<unsigned int> dist_int(graph);
-    dist_int.setAll(0);
+    NodeStaticProperty<unsigned int> dist_int(graph, 0);
     unsigned int res = maxDistance(graph, nPos, dist_int, direction);
     for (auto n : graph->getNodes()) {
       distance[n] = double(dist_int[n]);
@@ -139,14 +124,14 @@ double tlp::averagePathLength(const Graph *graph) {
 //================================================================
 double tlp::averageClusteringCoefficient(const Graph *graph) {
   tlp::NodeStaticProperty<double> clusters(graph);
-  tlp::clusteringCoefficient(graph, clusters, UINT_MAX);
-  unsigned int nbNodes = graph->numberOfNodes();
+  tlp::clusteringCoefficient(graph, clusters);
+
   double sum = 0;
+  for (auto v : clusters) {
+    sum += v;
+  }
 
-  for (unsigned int i = 0; i < nbNodes; ++i)
-    sum += clusters[i];
-
-  return sum / nbNodes;
+  return sum / graph->numberOfNodes();
 }
 //================================================================
 unsigned int tlp::maxDegree(const Graph *graph) {
@@ -163,56 +148,30 @@ unsigned int tlp::minDegree(const Graph *graph) {
   return mindeg;
 }
 //=================================================
-void tlp::clusteringCoefficient(const Graph *graph, MutableContainer<double> &clusters,
-                                unsigned int maxDepth) {
-  tlp::NodeStaticProperty<double> vClusters(graph);
-  tlp::clusteringCoefficient(graph, vClusters, maxDepth);
-
-  TLP_MAP_NODES_AND_INDICES(graph,
-                            [&](node n, unsigned int i) { clusters.set(n.id, vClusters[i]); });
-}
-//=================================================
 void tlp::clusteringCoefficient(const Graph *graph, tlp::NodeStaticProperty<double> &clusters,
-                                unsigned int maxDepth) {
+                                unsigned int) {
 
   TLP_MAP_NODES_AND_INDICES(graph, [&](node n, unsigned int i) {
-    std::unordered_map<node, bool> reachables;
-    markReachableNodes(graph, n, reachables, maxDepth);
-    double nbEdge = 0; // e(N_v)*2$
-
-    std::unordered_map<node, bool>::const_iterator itr = reachables.begin();
-    std::unordered_map<node, bool>::const_iterator ite = reachables.end();
-
-    while (itr != ite) {
-      node itn = itr->first;
-
-      for (auto e : graph->getInOutEdges(itn)) {
-        auto eEnds = graph->ends(e);
-
-        if ((reachables.find(eEnds.first) != ite) && (reachables.find(eEnds.second) != ite)) {
-          ++nbEdge;
-        }
-      }
-
-      ++itr;
+    vector<node> reachables;
+    for (node nei : graph->getInOutNodes(n)) {
+      reachables.push_back(nei);
     }
 
-    double nNode = reachables.size(); //$|N_v|$
+    unsigned nbEdgesN(0);
+    auto itr = reachables.end();
+    for (auto i = reachables.begin(); i != itr - 1; ++i) {
+      for (auto j = i + 1; j != itr; ++j) {
+        if (graph->hasEdge(*i, *j, false)) {
+          ++nbEdgesN;
+        }
+      }
+    }
 
-    if (reachables.size() > 1) {
-      //$e(N_v)/(\frac{k*(k-1)}{2}}$
-      clusters[i] = nbEdge / (nNode * (nNode - 1));
-    } else
-      clusters[i] = 0;
+    double nbEdge(graph->deg(n) + nbEdgesN);
+    double nNode = reachables.size() + 1;
+    clusters[i] = nbEdge / ((nNode * (nNode - 1)) / 2);
   });
 }
-//==================================================
-void tlp::dagLevel(const Graph *graph, MutableContainer<unsigned int> &level) {
-  tlp::NodeStaticProperty<unsigned int> tmp(graph);
-  dagLevel(graph, tmp);
-  TLP_MAP_NODES_AND_INDICES(graph, [&](node n, unsigned int i) { level.set(n.id, tmp[i]); });
-}
-
 //==================================================
 void tlp::dagLevel(const Graph *graph, tlp::NodeStaticProperty<unsigned int> &level) {
   tlp::NodeStaticProperty<unsigned int> totreat(graph);
