@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -310,9 +310,6 @@ void GraphStorage::setEnds(const edge e, const node newSrc, const node newTgt) {
   if (src == newSrc && tgt == newTgt)
     return;
 
-  node nSrc = newSrc;
-  node nTgt = newTgt;
-
   if (newSrc.isValid() && src != newSrc) {
     assert(isElement(newSrc));
     eEnds.first = newSrc;
@@ -322,16 +319,14 @@ void GraphStorage::setEnds(const edge e, const node newSrc, const node newTgt) {
     nCtnr.outDegree += 1;
     nCtnr.edges.push_back(e);
     removeFromNodeData(sCtnr, e);
-  } else
-    nSrc = src;
+  }
 
   if (newTgt.isValid() && tgt != newTgt) {
     assert(isElement(newTgt));
     eEnds.second = newTgt;
     nodeData[newTgt.id].edges.push_back(e);
     removeFromNodeData(nodeData[tgt.id], e);
-  } else
-    nTgt = tgt;
+  }
 }
 //=======================================================
 /**
