@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -60,7 +60,7 @@ void GraphUpdatesRecorder::treatEvent(const Event &ev) {
       addNode(graph, gEvt->getNode());
       break;
 
-    case GraphEvent::TLP_DEL_NODE:
+    case GraphEvent::TLP_BEFORE_DEL_NODE:
       delNode(graph, gEvt->getNode());
       break;
 
@@ -68,7 +68,7 @@ void GraphUpdatesRecorder::treatEvent(const Event &ev) {
       addEdge(graph, gEvt->getEdge());
       break;
 
-    case GraphEvent::TLP_DEL_EDGE:
+    case GraphEvent::TLP_BEFORE_DEL_EDGE:
       delEdge(graph, gEvt->getEdge());
       break;
 
@@ -123,7 +123,7 @@ void GraphUpdatesRecorder::treatEvent(const Event &ev) {
 
     case GraphEvent::TLP_REMOVE_ATTRIBUTE:
       removeAttribute(graph, gEvt->getAttributeName());
-
+      [[fallthrough]];
     default:
       break;
     }
@@ -160,7 +160,7 @@ void GraphUpdatesRecorder::treatEvent(const Event &ev) {
 // delete the objects collected as to be deleted
 void GraphUpdatesRecorder::deleteDeletedObjects() {
 
-  std::unordered_map<Graph *, set<PropertyInterface *>> &propertiesToDelete =
+  tlp_hash_map<Graph *, set<PropertyInterface *>> &propertiesToDelete =
       updatesReverted ? addedProperties : deletedProperties;
 
   std::list<std::pair<Graph *, Graph *>> &subGraphsToDelete =
@@ -185,8 +185,7 @@ void GraphUpdatesRecorder::deleteDeletedObjects() {
 }
 
 // clean up all the MutableContainers
-void GraphUpdatesRecorder::deleteValues(
-    std::unordered_map<PropertyInterface *, RecordedValues> &values) {
+void GraphUpdatesRecorder::deleteValues(tlp_hash_map<PropertyInterface *, RecordedValues> &values) {
   for (auto &itv : values) {
     delete itv.second.values;
 
@@ -200,9 +199,9 @@ void GraphUpdatesRecorder::deleteValues(
   values.clear();
 }
 
-// delete all the DataMem referenced by a std::unordered_map
+// delete all the DataMem referenced by a tlp_hash_map
 void GraphUpdatesRecorder::deleteDefaultValues(
-    std::unordered_map<PropertyInterface *, DataMem *> &values) {
+    tlp_hash_map<PropertyInterface *, DataMem *> &values) {
   for (auto &itv : values) {
     delete itv.second;
   }
@@ -210,26 +209,26 @@ void GraphUpdatesRecorder::deleteDefaultValues(
   values.clear();
 }
 
-void GraphUpdatesRecorder::recordEdgeContainer(
-    std::unordered_map<node, std::vector<edge>> &containers, GraphImpl *g, node n, edge e) {
+void GraphUpdatesRecorder::recordEdgeContainer(tlp_hash_map<node, std::vector<edge>> &containers,
+                                               GraphImpl *g, node n, edge e, bool loop) {
   if (containers.find(n) == containers.end()) {
     auto itAdj = containers.emplace(n, g->storage.adj(n)).first;
     // if we got a valid edge, this means that we must record
     // the node adjacencies before that edge was added (see addEdge)
     if (e.isValid()) {
       // as the edge is the last added
-      // it must be at the last adj position
+      // it must be at the last adj position (two last if loop)
       auto &adj = itAdj->second;
-      auto size = adj.size() - 1;
+      auto size = adj.size() - (loop ? 2 : 1);
       assert(e == adj[size]);
       adj.resize(size);
     }
   }
 }
 
-void GraphUpdatesRecorder::recordEdgeContainer(
-    std::unordered_map<node, std::vector<edge>> &containers, GraphImpl *g, node n,
-    const vector<edge> &gEdges, unsigned int nbAdded) {
+void GraphUpdatesRecorder::recordEdgeContainer(tlp_hash_map<node, std::vector<edge>> &containers,
+                                               GraphImpl *g, node n, const vector<edge> &gEdges,
+                                               unsigned int nbAdded) {
   if (containers.find(n) == containers.end()) {
     auto &adj = containers.emplace(n, g->storage.adj(n)).first->second;
     // we must ensure that the last edges added in gEdges
@@ -244,6 +243,9 @@ void GraphUpdatesRecorder::recordEdgeContainer(
         --nbAdded;
         if (e == gEdges[--lastAdded]) {
           ++adjAdded;
+          // check for loop
+          if (i && (e == adj[i - 1]))
+            ++adjAdded, --i;
           break;
         }
       }
@@ -256,7 +258,7 @@ void GraphUpdatesRecorder::recordEdgeContainer(
 }
 
 void GraphUpdatesRecorder::removeFromEdgeContainer(
-    std::unordered_map<node, std::vector<edge>> &containers, edge e, node n) {
+    tlp_hash_map<node, std::vector<edge>> &containers, edge e, node n) {
   const auto itAdj = containers.find(n);
 
   if (itAdj != containers.end()) {
@@ -612,7 +614,7 @@ void GraphUpdatesRecorder::doUpdates(GraphImpl *g, bool undo) {
 
   Observable::holdObservers();
   // loop on propsToDel
-  std::unordered_map<Graph *, set<PropertyInterface *>> &propsToDel =
+  tlp_hash_map<Graph *, set<PropertyInterface *>> &propsToDel =
       undo ? addedProperties : deletedProperties;
 
   for (const auto &itpg : propsToDel) {
@@ -664,7 +666,7 @@ void GraphUpdatesRecorder::doUpdates(GraphImpl *g, bool undo) {
   }
 
   // loop on nodesToDel
-  std::unordered_map<Graph *, std::unordered_set<node>> &nodesToDel =
+  tlp_hash_map<Graph *, std::unordered_set<node>> &nodesToDel =
       undo ? graphAddedNodes : graphDeletedNodes;
 
   for (const auto &itgn : nodesToDel) {
@@ -684,8 +686,7 @@ void GraphUpdatesRecorder::doUpdates(GraphImpl *g, bool undo) {
     // notify its addition
     g->notifyBeforeAddSubGraph(sg);
     // restore sg as subgraph of g
-    if (undo)
-      g->setSubGraphToKeep(sg);
+    g->setSubGraphToKeep(sg);
     g->restoreSubGraph(sg);
 
     // and sg subgraphs are no longer subgraphs of g
@@ -699,7 +700,7 @@ void GraphUpdatesRecorder::doUpdates(GraphImpl *g, bool undo) {
   }
 
   // loop on nodesToAdd
-  std::unordered_map<Graph *, unordered_set<node>> &nodesToAdd =
+  tlp_hash_map<Graph *, unordered_set<node>> &nodesToAdd =
       undo ? graphDeletedNodes : graphAddedNodes;
 
   for (const auto &itgn : nodesToAdd) {
@@ -724,8 +725,8 @@ void GraphUpdatesRecorder::doUpdates(GraphImpl *g, bool undo) {
   }
 
   // loop on edgesEnds
-  std::unordered_map<edge, pair<node, node>> &updatedEdgesEnds = undo ? oldEdgesEnds : newEdgesEnds;
-  std::unordered_map<edge, pair<node, node>>::const_iterator itee = updatedEdgesEnds.begin();
+  tlp_hash_map<edge, pair<node, node>> &updatedEdgesEnds = undo ? oldEdgesEnds : newEdgesEnds;
+  tlp_hash_map<edge, pair<node, node>>::const_iterator itee = updatedEdgesEnds.begin();
 
   while (itee != updatedEdgesEnds.end()) {
     g->setEnds(itee->first, itee->second.first, itee->second.second);
@@ -733,7 +734,7 @@ void GraphUpdatesRecorder::doUpdates(GraphImpl *g, bool undo) {
   }
 
   // loop on containers
-  std::unordered_map<node, std::vector<edge>> &containers = undo ? oldContainers : newContainers;
+  tlp_hash_map<node, std::vector<edge>> &containers = undo ? oldContainers : newContainers;
   for (auto itc = containers.begin(); itc != containers.end(); ++itc) {
     node n(itc->first);
     // n may have been deleted as a previously added node
@@ -743,8 +744,7 @@ void GraphUpdatesRecorder::doUpdates(GraphImpl *g, bool undo) {
 
   // loop on edgesToAdd
   std::map<Graph *, unordered_set<edge>> &edgesToAdd = undo ? graphDeletedEdges : graphAddedEdges;
-  std::unordered_map<edge, std::pair<node, node>> &edgesEnds =
-      undo ? deletedEdgesEnds : addedEdgesEnds;
+  tlp_hash_map<edge, std::pair<node, node>> &edgesEnds = undo ? deletedEdgesEnds : addedEdgesEnds;
 
   for (auto itge = edgesToAdd.begin(); itge != edgesToAdd.end(); ++itge) {
     Graph *g = itge->first;
@@ -764,7 +764,7 @@ void GraphUpdatesRecorder::doUpdates(GraphImpl *g, bool undo) {
   }
 
   // loop on propsToAdd
-  std::unordered_map<Graph *, set<PropertyInterface *>> &propsToAdd =
+  tlp_hash_map<Graph *, set<PropertyInterface *>> &propsToAdd =
       undo ? deletedProperties : addedProperties;
 
   for (const auto &itpg : propsToAdd) {
@@ -787,7 +787,7 @@ void GraphUpdatesRecorder::doUpdates(GraphImpl *g, bool undo) {
   }
 
   // loop on nodeDefaultValues
-  std::unordered_map<PropertyInterface *, DataMem *> &nodeDefaultValues =
+  tlp_hash_map<PropertyInterface *, DataMem *> &nodeDefaultValues =
       undo ? oldNodeDefaultValues : newNodeDefaultValues;
 
   for (const auto &itdv : nodeDefaultValues) {
@@ -796,7 +796,7 @@ void GraphUpdatesRecorder::doUpdates(GraphImpl *g, bool undo) {
   }
 
   // loop on edgeDefaultValues
-  std::unordered_map<PropertyInterface *, DataMem *> &edgeDefaultValues =
+  tlp_hash_map<PropertyInterface *, DataMem *> &edgeDefaultValues =
       undo ? oldEdgeDefaultValues : newEdgeDefaultValues;
 
   for (const auto &itdv : edgeDefaultValues) {
@@ -805,7 +805,7 @@ void GraphUpdatesRecorder::doUpdates(GraphImpl *g, bool undo) {
   }
 
   // loop on recorded values
-  std::unordered_map<PropertyInterface *, RecordedValues> &rvalues = undo ? oldValues : newValues;
+  tlp_hash_map<PropertyInterface *, RecordedValues> &rvalues = undo ? oldValues : newValues;
 
   for (const auto &itrv : rvalues) {
     PropertyInterface *prop = itrv.first;
@@ -829,7 +829,7 @@ void GraphUpdatesRecorder::doUpdates(GraphImpl *g, bool undo) {
   }
 
   // loop on attribute values to restore
-  std::unordered_map<Graph *, DataSet> &attValues = undo ? oldAttributeValues : newAttributeValues;
+  tlp_hash_map<Graph *, DataSet> &attValues = undo ? oldAttributeValues : newAttributeValues;
 
   for (const auto &itav : attValues) {
     Graph *g = itav.first;
@@ -984,8 +984,10 @@ void GraphUpdatesRecorder::addEdge(Graph *g, edge e) {
     auto eEnds = g->ends(e);
     addedEdgesEnds.emplace(e, eEnds);
     // record source & target old adjacencies
-    recordEdgeContainer(oldContainers, static_cast<GraphImpl *>(g), eEnds.first, e);
-    recordEdgeContainer(oldContainers, static_cast<GraphImpl *>(g), eEnds.second, e);
+    bool loop = eEnds.first == eEnds.second;
+    recordEdgeContainer(oldContainers, static_cast<GraphImpl *>(g), eEnds.first, e, loop);
+    if (!loop)
+      recordEdgeContainer(oldContainers, static_cast<GraphImpl *>(g), eEnds.second, e);
   }
 
   // we need to backup properties values of the newly added edge
