@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -18,12 +18,13 @@
  */
 
 #include <tulip/Ordering.h>
+#ifndef NDEBUG
 #include <tulip/BiconnectedTest.h>
+#endif
 #include <tulip/PlanarConMap.h>
 
 #include <cassert>
-#include <cstdlib>
-
+#
 using namespace std;
 using namespace tlp;
 
@@ -147,8 +148,8 @@ void Ordering::updateContourLeftRight(node pred, node n, edge e, node last) {
  * update is_selectable_visited and is_selectable
  */
 void Ordering::updateNewSelectableNodes(node node_f, node no_tmp2, edge, node node_last,
-                                        vector<Face> v_faces, bool one_face, bool was_visited,
-                                        bool selection_face) {
+                                        const vector<Face> &v_faces, bool one_face,
+                                        bool was_visited, bool selection_face) {
   MutableContainer<bool> tried;
   tried.setAll(false);
   node n = node_f;
@@ -245,7 +246,7 @@ void Ordering::updateNewSelectableNodes(node node_f, node no_tmp2, edge, node no
 /**
  * update is_selectable_visted_face and is_selectable_face
  */
-void Ordering::updateSelectableFaces(vector<Face> v_faces) {
+void Ordering::updateSelectableFaces(const vector<Face> &v_faces) {
   Face derniere = Gp->getFaceContaining(v1[0], v1[1]);
 
   for (unsigned int m = 0; m < v_faces.size(); ++m) {
@@ -483,18 +484,17 @@ void Ordering::minMarkedf() {
  * that can be induce (in the graph) on face f starting
  * at point n and in counter-clockwise
  */
-node Ordering::getLastOfQ(Face f, node pred, node n, edge e) {
+node Ordering::getLastOfQ(Face f, node pred, node /*n*/, edge e) {
   vector<node> q;
   edge e_tmp = e;
   node tmp = pred;
-  node tmp2 = n;
   bool done = false;
   e_tmp = Gp->succCycleEdge(e_tmp, tmp);
 
   while (!Gp->containEdge(f, e_tmp))
     e_tmp = Gp->succCycleEdge(e_tmp, tmp);
 
-  tmp2 = Gp->opposite(e_tmp, tmp);
+  node tmp2 = Gp->opposite(e_tmp, tmp);
   q.push_back(tmp);
 
   while (!done) {
@@ -522,18 +522,17 @@ node Ordering::getLastOfQ(Face f, node pred, node n, edge e) {
  * that can be induce (in the graph) on face f starting
  * at point n and in clockwise
  */
-node Ordering::getLastOfP(Face f, node pred, node n, edge e) {
+node Ordering::getLastOfP(Face f, node pred, node /*n*/, edge e) {
   vector<node> p;
   edge e_tmp = e;
   node tmp = pred;
-  node tmp2 = n;
   bool done = false;
   e_tmp = Gp->predCycleEdge(e_tmp, tmp);
 
   while (!Gp->containEdge(f, e_tmp))
     e_tmp = Gp->predCycleEdge(e_tmp, tmp);
 
-  tmp2 = Gp->opposite(e_tmp, tmp);
+  node tmp2 = Gp->opposite(e_tmp, tmp);
   p.push_back(tmp);
 
   while (!done) {
@@ -559,7 +558,7 @@ node Ordering::getLastOfP(Face f, node pred, node n, edge e) {
 /**
  * return the longest path of degree 2 on face fn from node fn[from]
  */
-vector<node> Ordering::getPathFrom(vector<node> fn, int from) {
+vector<node> Ordering::getPathFrom(const vector<node> &fn, int from) {
   vector<node> res;
   int i = from;
   int l = fn.size();
@@ -591,8 +590,8 @@ void Ordering::augment(Face f, node pred, node n, node pred_last, node last, int
   vector<Face> newFaces;
   Face newFace;
   node no_selectable;
-  node tmp, tmp2, l_tmp, l_tmp2;
-  edge e_tmp, e_ltmp;
+  node tmp, tmp2;
+  edge e_tmp;
   bool was_last_face = (f == Gp->getFaceContaining(v1[0], v1[1]));
 
   n_pred = pred;
@@ -795,7 +794,7 @@ void Ordering::augment(Face f, node pred, node n, node pred_last, node last, int
 /**
  * select node n and update members
  */
-void Ordering::selectAndUpdate(node n) {
+void Ordering::selectAndUpdateNode(node n) {
 
   // update visitedNodes, contour, is_selectable and is_selectable_visited
   visitedNodes.set(n.id, false);
@@ -1079,7 +1078,7 @@ void Ordering::selectAndUpdate(node n) {
 /**
  * select face f and update members
  */
-void Ordering::selectAndUpdate(Face f) {
+void Ordering::selectAndUpdateFace(Face f) {
   int compteur = 0;
   node n;
   node pred;
@@ -1358,8 +1357,7 @@ Ordering::Ordering(PlanarConMap *G, PluginProgress *pluginProgress, int minProgr
     Iterator<unsigned int> *itn = is_selectable_visited.findAll(true);
 
     while (itn->hasNext()) {
-      n = node(itn->next());
-      selectAndUpdate(n);
+      selectAndUpdateNode(node(itn->next()));
 
       if (Gp->nbFaces() <= 2)
         break;
@@ -1377,8 +1375,7 @@ Ordering::Ordering(PlanarConMap *G, PluginProgress *pluginProgress, int minProgr
     bool selVisitedFace = false;
 
     for (unsigned int faceId : is_selectable_visited_face.findAll(true)) {
-      Face f = Face(faceId);
-      selectAndUpdate(f);
+      selectAndUpdateFace(Face(faceId));
       selVisitedFace = true;
       break;
     }
@@ -1389,9 +1386,8 @@ Ordering::Ordering(PlanarConMap *G, PluginProgress *pluginProgress, int minProgr
 
     if (!selVisitedFace) {
       for (unsigned int id : is_selectable.findAll(true)) {
-        n = node(id);
         selNode = true;
-        selectAndUpdate(n);
+        selectAndUpdateNode(node(id));
         break;
       }
     }
@@ -1403,8 +1399,7 @@ Ordering::Ordering(PlanarConMap *G, PluginProgress *pluginProgress, int minProgr
     if (!selNode && !selVisitedFace) {
 
       for (unsigned int faceId : is_selectable_face.findAll(true)) {
-        Face f(faceId);
-        selectAndUpdate(f);
+        selectAndUpdateFace(Face(faceId));
         selFace = true;
         break;
       }
@@ -1478,7 +1473,7 @@ Ordering::Ordering(PlanarConMap *G, PluginProgress *pluginProgress, int minProgr
 /**
  * initialize v1
  */
-void Ordering::init_v1(vector<node> fn) {
+void Ordering::init_v1(const vector<node> &fn) {
   int l = fn.size();
   int i = 0;
   int cpt2 = 0;
@@ -1489,8 +1484,8 @@ void Ordering::init_v1(vector<node> fn) {
   }
 
   if (cpt2 == l)
-    for (int i = l / 2; i > 0; --i)
-      v1.push_back(fn[i]);
+    for (int j = l / 2; j > 0; --j)
+      v1.push_back(fn[j]);
   else {
     cpt2 = 1;
     v1.push_back(fn[i]);
