@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -34,7 +34,7 @@ public:
   /**
    * @brief Stored results for graphs. When a graph is updated, its entry is removed from the map.
    **/
-  std::unordered_map<const Graph *, bool> resultsBuffer;
+  tlp_hash_map<const Graph *, bool> resultsBuffer;
 };
 
 void PlanarityTestListener::treatEvent(const Event &evt) {
@@ -43,12 +43,13 @@ void PlanarityTestListener::treatEvent(const Event &evt) {
   if (gEvt) {
     Graph *graph = gEvt->getGraph();
 
+    auto it = resultsBuffer.find(graph);
     switch (gEvt->getType()) {
-    case GraphEvent::TLP_DEL_EDGE:
-    case GraphEvent::TLP_DEL_NODE:
+    case GraphEvent::TLP_AFTER_DEL_EDGE:
+    case GraphEvent::TLP_AFTER_DEL_NODE:
 
-      if (resultsBuffer.find(graph) != resultsBuffer.end())
-        if (resultsBuffer[graph])
+      if (it != resultsBuffer.end())
+        if (it->second)
           return;
 
       graph->removeListener(this);
@@ -57,8 +58,8 @@ void PlanarityTestListener::treatEvent(const Event &evt) {
 
     case GraphEvent::TLP_ADD_EDGE:
 
-      if (resultsBuffer.find(graph) != resultsBuffer.end())
-        if (!resultsBuffer[graph])
+      if (it != resultsBuffer.end())
+        if (it->second == false)
           return;
 
       graph->removeListener(this);
