@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -57,7 +57,7 @@ bool PlanarityTestImpl::isPlanar(bool embedsg) {
     findTerminalNodes(sg, n1, listOfComponents, terminalNodes);
 
     for (auto comp : listOfComponents) {
-      if (terminalNodes[comp].size() > 0) {
+      if (!terminalNodes[comp].empty()) {
         // creates a new c-node to represent current component;
         //  tlp::warning() << "  *terminal nodes for w = " << dfsPosNum.get(n1.id) << ":\n";
         //  tlp::warning() << "    in component (" << dfsPosNum.get(comp.id) << "): ";
@@ -225,9 +225,9 @@ void PlanarityTestImpl::findTerminalNodes(Graph *sG, node n, list<node> &listOfC
       }
 
       while (!S.empty()) {
-        node target = S.front();
+        node tgt = S.front();
         S.pop_front();
-        componentOf[target] = componentOf[parent.get(target.id)];
+        componentOf[tgt] = componentOf[parent.get(tgt.id)];
       }
 
       // did we find a terminal node?
@@ -394,8 +394,8 @@ bool PlanarityTestImpl::findObstruction(Graph *sG, node n, list<node> &terminalN
 
           if (mm == t1 || mm == t2) {
             if (mm == t2) {
-              swapNode(t1, t2); // makes t1 == t12;
-              swapNode(t12, t22);
+              std::swap(t1, t2); // makes t1 == t12;
+              std::swap(t12, t22);
             }
           } else
             mm = NULL_NODE;
