@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -240,12 +240,6 @@ void PlanarityTestImpl::preProcessing(Graph *g) {
     }
 }
 //=================================================================
-void PlanarityTestImpl::swapNode(node &n1, node &n2) {
-  node tmp = n1;
-  n1 = n2;
-  n2 = tmp;
-}
-//=================================================================
 bool PlanarityTestImpl::isCNode(node n) {
   return (n.isValid() && (dfsPosNum.get(n.id) < 0));
 }
@@ -474,7 +468,7 @@ node PlanarityTestImpl::lcaBetween(node n1, node n2, const MutableContainer<node
   }
 
   if (dfsPosNum.get(n1.id) > dfsPosNum.get(n2.id))
-    swapNode(n1, n2);
+    std::swap(n1, n2);
 
   list<node> nl;
 
@@ -541,7 +535,7 @@ void PlanarityTestImpl::calculateNewRBC(Graph *, node newCNode, node n, list<nod
     }
 
     if (dfsPosNum.get(aux1.id) > dfsPosNum.get(aux2.id))
-      swapNode(t1, t2);
+      std::swap(t1, t2);
 
     m = lcaBetweenTermNodes(t1, t2);
     node t12 = lastPNode(t1, m), t22 = lastPNode(t2, m);
@@ -794,15 +788,7 @@ BmdLink<node> *PlanarityTestImpl::searchRBC(int dir, BmdLink<node> *it, node n,
     return it;
 
   BmdLink<node> *prev = it;
-  BmdLink<node> *aux1 = it->prev();
-  BmdLink<node> *aux2 = it->succ();
-
-  if (dir == 1) {
-    // leda_swap(aux1, aux2);
-    BmdLink<node> *tmp = aux1;
-    aux1 = aux2;
-    aux2 = tmp;
-  }
+  BmdLink<node> *aux1 = (dir == 1) ? it->succ() : it->prev();
 
   it = aux1;
   node u = it->getData();
