@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -16,7 +16,6 @@
  * See the GNU General Public License for more details.
  *
  */
-#include <iostream>
 #include <tulip/PropertyInterface.h>
 #include <tulip/Graph.h>
 
