@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -19,20 +19,24 @@
 
 #include <tulip/PropertyTypes.h>
 #include <tulip/Graph.h>
+#include <tulip/PropertiesCollection.h>
 #include <tulip/StringCollection.h>
+#include <tulip/TulipException.h>
 
-#include <stdint.h>
+#include <climits>
+#include <cfloat>
+#include <cstdint>
 
 using namespace std;
 using namespace tlp;
 
 // GraphType
 GraphType::RealType GraphType::undefinedValue() {
-  return 0;
+  return nullptr;
 }
 
 GraphType::RealType GraphType::defaultValue() {
-  return 0;
+  return nullptr;
 }
 
 void GraphType::write(ostream &oss, const RealType &v) {
@@ -42,17 +46,17 @@ void GraphType::write(ostream &oss, const RealType &v) {
 
 void GraphType::writeb(ostream &oss, const RealType &v) {
   unsigned int id = v ? v->getId() : 0;
-  oss.write((char *) &id, sizeof(id));
+  oss.write(reinterpret_cast<const char *>(&id), sizeof(id));
 }
 
-bool GraphType::read(istream& iss, RealType& v) {
+bool GraphType::read(istream &iss, RealType &v) {
   uintptr_t lv = 0;
   bool ok = bool(iss >> lv);
 
   if (ok)
-    v = (RealType) lv;
+    v = reinterpret_cast<RealType>(lv);
   else
-    v = 0;
+    v = nullptr;
 
   return ok;
 }
@@ -66,35 +70,39 @@ bool GraphType::readb(istream &, RealType &) {
 }
 
 // EdgeSetType
-void EdgeSetType::write(ostream& os, const RealType & v ) {
+void EdgeSetType::write(ostream &os, const RealType &v) {
   os << '(';
   set<edge>::const_iterator it;
 
-  for(it = v.begin() ; it != v.end() ; ++it)
-    os << (*it).id << ' ';
+  for (it = v.begin(); it != v.end(); ++it) {
+    if (it != v.begin())
+      os << ' ';
+    os << (*it).id;
+  }
 
   os << ')';
 }
 
-void EdgeSetType::writeb(ostream& oss, const RealType & v ) {
+void EdgeSetType::writeb(ostream &oss, const RealType &v) {
   unsigned int vSize = v.size();
   // write the size of the set
-  oss.write((char *) &vSize, sizeof(vSize));
+  oss.write(reinterpret_cast<const char *>(&vSize), sizeof(vSize));
 
   set<edge>::const_iterator it;
 
   // loop to write the edges
-  for(it = v.begin() ; it != v.end() ; ++it)
-    oss.write((char *) &(it->id), sizeof(unsigned int));
+  for (it = v.begin(); it != v.end(); ++it)
+    oss.write(reinterpret_cast<const char *>(&(it->id)), sizeof(unsigned int));
 }
 
-bool EdgeSetType::read(istream& is, RealType & v) {
+bool EdgeSetType::read(istream &is, RealType &v) {
   v.clear();
-  char c  = ' ';
+  char c = ' ';
   bool ok;
 
   // go to first '('
-  while((ok = bool(is >> c)) && isspace(c)) {}
+  while ((ok = bool(is >> c)) && isspace(c)) {
+  }
 
   // for compatibility with older version (3.0)
   if (!ok)
@@ -105,44 +113,45 @@ bool EdgeSetType::read(istream& is, RealType & v) {
 
   edge e;
 
-  for( ;; ) {
-    if( !(is >> c) )
+  for (;;) {
+    if (!(is >> c))
       return false;
 
-    if (isspace(c)) continue;
+    if (isspace(c))
+      continue;
 
-    if( c == ')' )
+    if (c == ')')
       return true;
 
     is.unget();
 
-    if( !(is >> e.id) )
+    if (!(is >> e.id))
       return false;
 
-    v.insert( e );
+    v.insert(e);
   }
 }
 
-bool EdgeSetType::readb(istream& iss, RealType & s) {
+bool EdgeSetType::readb(istream &iss, RealType &s) {
   s.clear();
 
   unsigned int size;
 
   // get the set size
-  if (!bool(iss.read((char *) &size, sizeof(unsigned int))))
+  if (!bool(iss.read(reinterpret_cast<char *>(&size), sizeof(unsigned int))))
     return false;
 
   // use a vector to get the edges
   vector<edge> v;
   v.resize(size);
-  edge* data = v.data();
+  edge *data = v.data();
 
   // get the edges in one read
-  if (!bool(iss.read((char *) v.data(), size * sizeof(unsigned int))))
+  if (!bool(iss.read(reinterpret_cast<char *>(v.data()), size * sizeof(unsigned int))))
     return false;
 
   // insert edges in the set
-  while(size) {
+  while (size) {
     s.insert(*data);
     ++data;
     --size;
@@ -160,13 +169,14 @@ double DoubleType::defaultValue() {
   return 0;
 }
 
-// add support for inf and -inf
-bool DoubleType::read(istream& iss, double& v) {
+// add support for inf, -inf and nan
+bool DoubleType::read(istream &iss, double &v) {
   char c;
   char sign = 0;
 
   // go to first non space char
-  while((iss >> c) && isspace(c)) {}
+  while ((iss >> c) && isspace(c)) {
+  }
 
   if (c == '-' || c == '+') {
     sign = c;
@@ -177,8 +187,7 @@ bool DoubleType::read(istream& iss, double& v) {
 
   if (c == 'i') {
     // should be inf
-    if (!(iss >> c) || (c != 'n') ||
-        !(iss >> c) || (c != 'f'))
+    if (!(iss >> c) || (c != 'n') || !(iss >> c) || (c != 'f'))
       return false;
 
     if (sign == '-')
@@ -187,12 +196,21 @@ bool DoubleType::read(istream& iss, double& v) {
       v = numeric_limits<double>::infinity();
 
     return true;
-  }
-  else {
-    iss.unget();
+  } else {
+    if (c == 'n') {
+      // should be nan
+      if (!(iss >> c) || (c != 'a') || !(iss >> c) || (c != 'n'))
+        return false;
 
-    if (sign)
+      v = std::numeric_limits<double>::quiet_NaN();
+
+      return true;
+    } else {
       iss.unget();
+
+      if (sign)
+        iss.unget();
+    }
   }
 
   return bool(iss >> v);
@@ -207,6 +225,52 @@ float FloatType::defaultValue() {
   return 0;
 }
 
+// add support for inf, -inf and nan
+bool FloatType::read(istream &iss, float &v) {
+  char c;
+  char sign = 0;
+
+  // go to first non space char
+  while ((iss >> c) && isspace(c)) {
+  }
+
+  if (c == '-' || c == '+') {
+    sign = c;
+
+    if (!(iss >> c))
+      return false;
+  }
+
+  if (c == 'i') {
+    // should be inf
+    if (!(iss >> c) || (c != 'n') || !(iss >> c) || (c != 'f'))
+      return false;
+
+    if (sign == '-')
+      v = -numeric_limits<float>::infinity();
+    else
+      v = numeric_limits<float>::infinity();
+
+    return true;
+  } else {
+    if (c == 'n') {
+      // should be nan
+      if (!(iss >> c) || (c != 'a') || !(iss >> c) || (c != 'n'))
+        return false;
+
+      v = std::numeric_limits<float>::quiet_NaN();
+      return true;
+    } else {
+      iss.unget();
+
+      if (sign)
+        iss.unget();
+    }
+  }
+
+  return bool(iss >> v);
+}
+
 // IntegerType
 int IntegerType::undefinedValue() {
   return INT_MIN;
@@ -243,17 +307,18 @@ bool BooleanType::defaultValue() {
   return false;
 }
 
-void BooleanType::write(ostream& os, const RealType &v) {
+void BooleanType::write(ostream &os, const RealType &v) {
   if (v)
     os << "true";
   else
     os << "false";
 }
 
-bool BooleanType::read(istream& is, RealType & v, bool untilEnd) {
+bool BooleanType::read(istream &is, RealType &v, bool untilEnd) {
   char c = ' ';
 
-  while((is >> c) && isspace(c)) {}
+  while ((is >> c) && isspace(c)) {
+  }
 
   c = ::tolower(c);
 
@@ -262,23 +327,19 @@ bool BooleanType::read(istream& is, RealType & v, bool untilEnd) {
   if (c == 't') {
     s.append("true");
     v = true;
-  }
-  else if (c == 'f') {
+  } else if (c == 'f') {
     s.append("false");
     v = false;
-  }
-  else if(c == '1') {
+  } else if (c == '1') {
     s.append("1");
     v = true;
-  }
-  else if (c == '0') {
+  } else if (c == '0') {
     s.append("0");
     v = false;
-  }
-  else
+  } else
     return false;
 
-  for(unsigned int i = 1; i < s.size(); ++i) {
+  for (unsigned int i = 1; i < s.size(); ++i) {
     if (!(is >> c))
       return false;
 
@@ -290,8 +351,8 @@ bool BooleanType::read(istream& is, RealType & v, bool untilEnd) {
 
   if (untilEnd) {
     // check if there is only space char until the end
-    for(;;) {
-      if( !(is >> c) )
+    for (;;) {
+      if (!(is >> c))
         return true;
 
       if (!isspace(c))
@@ -302,17 +363,16 @@ bool BooleanType::read(istream& is, RealType & v, bool untilEnd) {
   return true;
 }
 
-bool BooleanType::fromString(RealType &v, const std::string &s,
-                             bool untilEnd) {
+bool BooleanType::fromString(RealType &v, const std::string &s, bool untilEnd) {
   std::istringstream iss(s);
   return read(iss, v, untilEnd);
 }
 
 // BooleanVectorType
-void BooleanVectorType::write(ostream& os, const RealType & v) {
+void BooleanVectorType::write(ostream &os, const RealType &v) {
   os << '(';
 
-  for( unsigned int i = 0 ; i < v.size() ; i++ ) {
+  for (unsigned int i = 0; i < v.size(); i++) {
     if (i)
       os << ", ";
 
@@ -322,57 +382,56 @@ void BooleanVectorType::write(ostream& os, const RealType & v) {
   os << ')';
 }
 
-void BooleanVectorType::writeb(ostream& oss, const RealType & v) {
+void BooleanVectorType::writeb(ostream &oss, const RealType &v) {
   unsigned int vSize = v.size();
   // write the size of the vector
-  oss.write((char *) &vSize, sizeof(vSize));
+  oss.write(reinterpret_cast<const char *>(&vSize), sizeof(vSize));
 
   vector<char> vc;
   vc.resize(vSize);
 
-  // loop to write boolean as char
-  char* data = vc.data();
+  // loop to write Boolean as char
+  char *data = vc.data();
 
-  for(unsigned int i = 0; i < vSize; ++i, ++data) {
+  for (unsigned int i = 0; i < vSize; ++i, ++data) {
     *data = v[i] ? 1 : 0;
   }
 
   oss.write(vc.data(), vSize);
 }
 
-bool BooleanVectorType::read(istream& is,  RealType & v, char openChar,
-                             char sepChar, char closeChar) {
+bool BooleanVectorType::read(istream &is, RealType &v, char openChar, char sepChar,
+                             char closeChar) {
   v.clear();
 
-  char c =' ';
+  char c = ' ';
   bool firstVal = true;
 
   // go to first non space char
-  while((is >> c) && isspace(c)) {}
+  while ((is >> c) && isspace(c)) {
+  }
 
   if (openChar) {
     if (c != openChar)
       return false;
-  }
-  else
+  } else
     is.unget();
 
-  for(;;) {
-    if( !(is >> c) )
+  for (;;) {
+    if (!(is >> c))
       return !closeChar;
 
     if (isspace(c))
       continue;
 
-    if(c == closeChar) {
+    if (c == closeChar) {
       return true;
     }
 
     if (c == sepChar) {
       if (firstVal)
         return false;
-    }
-    else
+    } else
       is.unget();
 
     bool val;
@@ -385,23 +444,86 @@ bool BooleanVectorType::read(istream& is,  RealType & v, char openChar,
   }
 }
 
-bool BooleanVectorType::readb(istream& iss, RealType & v) {
+bool BooleanVectorType::read(const std::vector<std::string> &vs, RealType &v) {
+  v.clear();
+  v.reserve(vs.size());
+
+  for (const std::string &s : vs) {
+    bool val;
+    std::istringstream is(s);
+    if (!BooleanType::read(is, val))
+      return false;
+
+    v.push_back(val);
+  }
+  return true;
+}
+
+bool BooleanVectorType::tokenize(const std::string &s, std::vector<std::string> &v, char openChar,
+                                 char sepChar, char closeChar) {
+  v.clear();
+
+  std::istringstream is(s);
+  char c = ' ';
+  bool firstVal = true;
+
+  // go to first non space char
+  while ((is >> c) && isspace(c)) {
+  }
+
+  if (openChar) {
+    if (c != openChar)
+      return false;
+  } else
+    is.unget();
+
+  for (;;) {
+    if (!(is >> c))
+      return !closeChar;
+
+    if (isspace(c))
+      continue;
+
+    if (c == closeChar) {
+      return true;
+    }
+
+    if (c == sepChar) {
+      if (firstVal)
+        return false;
+    } else
+      is.unget();
+
+    bool val;
+
+    auto pos = is.tellg();
+    if (!BooleanType::read(is, val))
+      return false;
+
+    v.push_back(s.substr(pos, is.tellg() - pos));
+    firstVal = false;
+  }
+}
+
+bool BooleanVectorType::readb(istream &iss, RealType &v) {
   unsigned int vSize = v.size();
 
   // read the size of the vector
-  if (!iss.read((char *) &vSize, sizeof(vSize)))
+  if (!iss.read(reinterpret_cast<char *>(&vSize), sizeof(vSize)))
     return false;
 
   vector<char> vc;
   vc.resize(vSize);
 
-  // loop to write boolean as char
-  char* data = vc.data();
+  // loop to write Boolean as char
+  char *data = vc.data();
 
   if (!bool(iss.read(data, vSize)))
     return false;
 
-  for(unsigned int i = 0; i < vSize; ++i, ++data) {
+  v.resize(vSize);
+
+  for (unsigned int i = 0; i < vSize; ++i, ++data) {
     v[i] = *data ? true : false;
   }
 
@@ -409,16 +531,16 @@ bool BooleanVectorType::readb(istream& iss, RealType & v) {
 }
 
 // LineType
-bool LineType::read(istream& is, RealType& v, char openChar,
-                    char sepChar, char closeChar) {
+bool LineType::read(istream &is, RealType &v, char openChar, char sepChar, char closeChar) {
   v.clear();
 
-  char c =' ';
+  char c = ' ';
   bool firstVal = true;
   bool dbqFound = false;
 
   // go to first non space char
-  while((is >> c) && isspace(c)) {}
+  while ((is >> c) && isspace(c)) {
+  }
 
   // value may have been enclosed by double quotes
   if (c == '"') {
@@ -426,27 +548,28 @@ bool LineType::read(istream& is, RealType& v, char openChar,
     dbqFound = true;
 
     // skip space chars
-    while((is >> c) && isspace(c)) {}
+    while ((is >> c) && isspace(c)) {
+    }
   }
 
   if (openChar) {
     if (c != openChar)
       return false;
-  }
-  else
+  } else
     is.unget();
 
-  for(;;) {
-    if( !(is >> c) )
+  for (;;) {
+    if (!(is >> c))
       return !closeChar;
 
     if (isspace(c))
       continue;
 
-    if(c == closeChar) {
+    if (c == closeChar) {
       if (dbqFound) {
         // expect it is the next non space char
-        while((is >> c) && isspace(c)) {}
+        while ((is >> c) && isspace(c)) {
+        }
 
         if (c != '"')
           return false;
@@ -464,9 +587,8 @@ bool LineType::read(istream& is, RealType& v, char openChar,
       if (!PointType::read(is, val))
         return false;
 
-      v.push_back(val);
-    }
-    else {
+      v.push_back(std::move(val));
+    } else {
       // , is not required between coords
       is.unget();
       Coord val;
@@ -474,7 +596,7 @@ bool LineType::read(istream& is, RealType& v, char openChar,
       if (!PointType::read(is, val))
         return false;
 
-      v.push_back(val);
+      v.push_back(std::move(val));
       firstVal = false;
     }
   }
@@ -483,7 +605,7 @@ bool LineType::read(istream& is, RealType& v, char openChar,
 // PointType
 Coord PointType::undefinedValue() {
   Coord tmp;
-  tmp.set(-FLT_MAX,-FLT_MAX,-FLT_MAX);
+  tmp.set(-FLT_MAX, -FLT_MAX, -FLT_MAX);
   return tmp;
 }
 
@@ -491,13 +613,17 @@ Coord PointType::defaultValue() {
   return Coord(0, 0, 0);
 }
 
-bool PointType::read(istream& is, RealType & v) {
+bool PointType::read(istream &is, RealType &v) {
   // value may have been enclosed by double quotes
   char c = ' ';
   bool ok;
 
   // skip spaces
-  while((ok = bool(is >> c)) && isspace(c)) {}
+  while ((ok = bool(is >> c)) && isspace(c)) {
+  }
+
+  if (!ok)
+    return false;
 
   bool dbqFound = false;
 
@@ -507,41 +633,81 @@ bool PointType::read(istream& is, RealType & v) {
   else
     is.unget();
 
-  ok = bool(is >> v);
+  // skip spaces
+  while (bool(is >> c) && isspace(c)) {
+  }
 
-  if (ok && dbqFound) {
-    // look for the close double quote
-    ok = bool(is >> c);
+  if (c != '(')
+    return false;
 
-    if (c != '"')
+  for (unsigned int i = 0; i < 3; ++i) {
+    if (i > 0) {
+      // skip spaces
+      while ((ok = bool(is >> c)) && isspace(c)) {
+      }
+
+      if (!ok || c != ',')
+        return false;
+    }
+
+    // skip spaces
+    while ((ok = bool(is >> c)) && isspace(c)) {
+    }
+
+    if (!ok)
+      return false;
+
+    is.unget();
+
+    bool done = FloatType::read(is, v[i]);
+
+    if (!done)
       return false;
   }
 
-  return ok;
+  // skip spaces
+  while ((ok = bool(is >> c)) && isspace(c)) {
+  }
+
+  if (!ok && c != ')')
+    return false;
+
+  if (dbqFound) {
+    // look for the close double quote
+    ok = bool(is >> c);
+
+    return (ok && c == '"');
+  }
+
+  return true;
 }
 
-bool PointType::fromString( RealType & v, const string & s ) {
+bool PointType::fromString(RealType &v, const string &s) {
   istringstream iss(s);
-  return bool(iss >> v);
+  return read(iss, v);
 }
 
 //
 // SizeType
 Size SizeType::undefinedValue() {
-  return Size(-FLT_MAX,-FLT_MAX,-FLT_MAX);
+  return Size(-FLT_MAX, -FLT_MAX, -FLT_MAX);
 }
 
 Size SizeType::defaultValue() {
-  return Size(1,1,0);
+  return Size(1, 1, 0);
 }
 
-bool SizeType::read(istream& is, RealType & v) {
+bool SizeType::read(istream &is, RealType &v) {
   // value may have been enclosed by double quotes
   char c = ' ';
   bool ok;
 
   // skip spaces
-  while((ok = bool(is >> c)) && isspace(c)) {}
+  while ((ok = bool(is >> c)) && isspace(c)) {
+  }
+
+  if (!ok)
+    return false;
 
   bool dbqFound = false;
 
@@ -564,7 +730,7 @@ bool SizeType::read(istream& is, RealType & v) {
   return ok;
 }
 
-bool SizeType::fromString( RealType & v, const string & s ) {
+bool SizeType::fromString(RealType &v, const string &s) {
   istringstream iss(s);
   return bool(iss >> v);
 }
@@ -578,11 +744,11 @@ string StringType::defaultValue() {
   return string("");
 }
 
-void StringType::write(ostream& os, const RealType & v, char openCloseChar) {
+void StringType::write(ostream &os, const RealType &v, char openCloseChar) {
   if (openCloseChar)
     os << openCloseChar;
 
-  for(char* str = (char *) v.c_str(); *str; ++str) {
+  for (char *str = const_cast<char *>(v.c_str()); *str; ++str) {
     char c = *str;
 
     if (c == '\\' || c == '"')
@@ -595,25 +761,25 @@ void StringType::write(ostream& os, const RealType & v, char openCloseChar) {
     os << openCloseChar;
 }
 
-void StringType::writeb(ostream& os, const RealType & str) {
+void StringType::writeb(ostream &os, const RealType &str) {
   // write size of str
   unsigned int size = str.size();
-  os.write((char *) &size, sizeof(size));
+  os.write(reinterpret_cast<const char *>(&size), sizeof(size));
 
   // then write c_str()
-  os.write((char *) str.c_str(), size);
+  os.write(str.c_str(), size);
 }
 
-string StringType::toString( const RealType & v ) {
+string StringType::toString(const RealType &v) {
   return v;
 }
 
-bool StringType::read(istream& is, RealType & v, char openChar,
-                      char closeChar) {
-  char c= ' ';
+bool StringType::read(istream &is, RealType &v, char openChar, char closeChar) {
+  char c = ' ';
 
   // go to first non space char
-  while((is >> c) && isspace(c)) {}
+  while ((is >> c) && isspace(c)) {
+  }
 
   // ensure space chars are not skipped
   // in the string to extract
@@ -628,8 +794,8 @@ bool StringType::read(istream& is, RealType & v, char openChar,
   bool bslashFound = false;
   string str;
 
-  for(;;) {
-    if ( !(is >> c) ) {
+  for (;;) {
+    if (!(is >> c)) {
       if (!openChar || !closeChar)
         break;
 
@@ -639,8 +805,7 @@ bool StringType::read(istream& is, RealType & v, char openChar,
     if (bslashFound) {
       str.push_back(c);
       bslashFound = false;
-    }
-    else {
+    } else {
       if (c == '\\')
         bslashFound = true;
       else {
@@ -656,34 +821,34 @@ bool StringType::read(istream& is, RealType & v, char openChar,
   std::size_t found = str.find_last_not_of(" \t\f\v\n\r");
 
   if (found != std::string::npos)
-    str.erase(found+1);
+    str.erase(found + 1);
 
   v = str;
   return true;
 }
 
-bool StringType::readb(istream& iss, RealType & str) {
+bool StringType::readb(istream &iss, RealType &str) {
   // read size of str
   unsigned int size;
 
-  if (!bool(iss.read((char *)&size, sizeof(size))))
+  if (!bool(iss.read(reinterpret_cast<char *>(&size), sizeof(size))))
     return false;
 
   // then read chars
   str.resize(size);
-  return bool(iss.read((char *) str.c_str(), size));
+  return bool(iss.read(const_cast<char *>(str.c_str()), size));
 }
 
-bool StringType::fromString( RealType & v, const string & s ) {
+bool StringType::fromString(RealType &v, const string &s) {
   v = s;
   return true;
 }
 
 // StringVectorType
-void StringVectorType::write(ostream& os, const RealType & v) {
+void StringVectorType::write(ostream &os, const RealType &v) {
   os << '(';
 
-  for( unsigned int i = 0 ; i < v.size() ; i++ ) {
+  for (unsigned int i = 0; i < v.size(); i++) {
     if (i)
       os << ", ";
 
@@ -693,43 +858,42 @@ void StringVectorType::write(ostream& os, const RealType & v) {
   os << ')';
 }
 
-void StringVectorType::writeb(ostream& os, const RealType & v) {
+void StringVectorType::writeb(ostream &os, const RealType &v) {
   // write size of vector
   unsigned int size = v.size();
-  os.write((char *) &size, sizeof(size));
+  os.write(reinterpret_cast<const char *>(&size), sizeof(size));
 
   // loop to write strings
-  for(unsigned int i = 0; i < size; ++i)
+  for (unsigned int i = 0; i < size; ++i)
     StringType::writeb(os, v[i]);
 }
 
-bool StringVectorType::read(istream& is, RealType & v, char openChar,
-                            char sepChar, char closeChar) {
+bool StringVectorType::read(istream &is, RealType &v, char openChar, char sepChar, char closeChar) {
   v.clear();
   char c = ' ';
 
   // go to first non space char
-  while((is >> c) && isspace(c)) {}
+  while ((is >> c) && isspace(c)) {
+  }
 
   if (openChar) {
     if (c != openChar)
       return false;
-  }
-  else
+  } else
     is.unget();
 
   is.unsetf(ios_base::skipws);
   bool firstVal = true;
   bool sepFound = false;
 
-  for( ;; ) {
-    if( !(is >> c) )
+  for (;;) {
+    if (!(is >> c))
       return (!sepFound && !closeChar);
 
     if (isspace(c))
       continue;
 
-    if( c == closeChar) {
+    if (c == closeChar) {
       if (!closeChar || sepFound)
         return false;
 
@@ -741,17 +905,15 @@ bool StringVectorType::read(istream& is, RealType & v, char openChar,
         return false;
 
       sepFound = true;
-    }
-    else {
+    } else {
       if ((firstVal || sepFound) && (!openChar || c == '"')) {
         string str;
         is.unget();
 
-        if (!(openChar ? StringType::read(is, str) :
-              StringType::read(is, str, '\0', sepChar)))
+        if (!(openChar ? StringType::read(is, str) : StringType::read(is, str, '\0', sepChar)))
           return false;
 
-        v.push_back(str);
+        v.push_back(std::move(str));
 
         if (!openChar)
           // last read char was sepChar
@@ -759,24 +921,23 @@ bool StringVectorType::read(istream& is, RealType & v, char openChar,
 
         firstVal = false;
         sepFound = false;
-      }
-      else
+      } else
         return false;
     }
   }
 }
 
-bool StringVectorType::readb(istream& iss, RealType & v) {
+bool StringVectorType::readb(istream &iss, RealType &v) {
   // read size of vector
   unsigned int size;
 
-  if (!bool(iss.read((char *) &size, sizeof(size))))
+  if (!bool(iss.read(reinterpret_cast<char *>(&size), sizeof(size))))
     return false;
 
   v.resize(size);
 
   // loop to read strings
-  for(unsigned int i = 0; i < size; ++i) {
+  for (unsigned int i = 0; i < size; ++i) {
     if (!StringType::readb(iss, v[i]))
       return false;
   }
@@ -786,27 +947,28 @@ bool StringVectorType::readb(istream& iss, RealType & v) {
 
 // ColorType
 Color ColorType::undefinedValue() {
-  return Color(255,255,255,255);
+  return Color(255, 255, 255, 255);
 }
 
-void ColorType::write(ostream& os, const RealType & v) {
+void ColorType::write(ostream &os, const RealType &v) {
   // add double quotes to ensure compatibility in gui tests
   os << '"' << v << '"';
 }
 
-string ColorType::toString( const RealType & v ) {
+string ColorType::toString(const RealType &v) {
   ostringstream oss;
   oss << v;
   return oss.str();
 }
 
-bool ColorType::read(istream& is, RealType & v) {
+bool ColorType::read(istream &is, RealType &v) {
   // value may have been enclosed by double quotes
   char c = ' ';
   bool ok;
 
   // skip spaces
-  while((ok = bool(is >> c)) && isspace(c)) {}
+  while ((ok = bool(is >> c)) && isspace(c)) {
+  }
 
   bool dbqFound = false;
 
@@ -829,28 +991,28 @@ bool ColorType::read(istream& is, RealType & v) {
   return ok;
 }
 
-bool ColorType::fromString( RealType & v, const string & s ) {
+bool ColorType::fromString(RealType &v, const string &s) {
   istringstream iss(s);
   return bool(iss >> v);
 }
 
 // some special serializers
-struct DataSetTypeSerializer :public TypedDataSerializer<DataSet> {
-  DataSetTypeSerializer():TypedDataSerializer<DataSet>("DataSet") {}
+struct DataSetTypeSerializer : public TypedDataSerializer<DataSet> {
+  DataSetTypeSerializer() : TypedDataSerializer<DataSet>("DataSet") {}
 
-  DataTypeSerializer* clone() const {
+  DataTypeSerializer *clone() const override {
     return new DataSetTypeSerializer();
   }
 
-  void write(ostream& os, const DataSet& ds) {
+  void write(ostream &os, const DataSet &ds) override {
     DataSet::write(os, ds);
   }
 
-  bool read(istream& is, DataSet& ds) {
+  bool read(istream &is, DataSet &ds) override {
     return DataSet::read(is, ds);
   }
 
-  bool setData(tlp::DataSet&, const string&, const string&) {
+  bool setData(tlp::DataSet &, const string &, const string &) override {
     // no sense
     return false;
   }
@@ -861,57 +1023,57 @@ struct NodeTypeSerializer : public TypedDataSerializer<node> {
 
   KnownTypeSerializer<UnsignedIntegerType> *uintSerializer;
 
-  NodeTypeSerializer():TypedDataSerializer<node>("node") {
+  NodeTypeSerializer() : TypedDataSerializer<node>("node") {
     uintSerializer = new KnownTypeSerializer<UnsignedIntegerType>("");
   }
 
-  ~NodeTypeSerializer() {
+  ~NodeTypeSerializer() override {
     delete uintSerializer;
   }
 
-  DataTypeSerializer* clone() const {
+  DataTypeSerializer *clone() const override {
     return new NodeTypeSerializer();
   }
 
-  void write(ostream& os, const node& n) {
+  void write(ostream &os, const node &n) override {
     uintSerializer->write(os, n.id);
   }
 
-  bool read(istream& is, node& n) {
+  bool read(istream &is, node &n) override {
     return uintSerializer->read(is, n.id);
   }
 
-  bool setData(tlp::DataSet&, const string&, const string&) {
+  bool setData(tlp::DataSet &, const string &, const string &) override {
     // no sense
     return false;
   }
 };
 
-struct NodeVectorTypeSerializer : public TypedDataSerializer<vector<node> > {
+struct NodeVectorTypeSerializer : public TypedDataSerializer<vector<node>> {
 
   KnownTypeSerializer<UnsignedIntegerVectorType> *uintVecSerializer;
 
-  NodeVectorTypeSerializer():TypedDataSerializer<vector<node> >("nodes") {
+  NodeVectorTypeSerializer() : TypedDataSerializer<vector<node>>("nodes") {
     uintVecSerializer = new KnownTypeSerializer<UnsignedIntegerVectorType>("");
   }
 
-  ~NodeVectorTypeSerializer() {
+  ~NodeVectorTypeSerializer() override {
     delete uintVecSerializer;
   }
 
-  DataTypeSerializer* clone() const {
+  DataTypeSerializer *clone() const override {
     return new NodeVectorTypeSerializer();
   }
 
-  void write(ostream& os, const vector<node>& vn) {
+  void write(ostream &os, const vector<node> &vn) override {
     uintVecSerializer->write(os, reinterpret_cast<const vector<unsigned int> &>(vn));
   }
 
-  bool read(istream& is, vector<node>& vn) {
+  bool read(istream &is, vector<node> &vn) override {
     return uintVecSerializer->read(is, reinterpret_cast<vector<unsigned int> &>(vn));
   }
 
-  bool setData(tlp::DataSet&, const string&, const string&) {
+  bool setData(tlp::DataSet &, const string &, const string &) override {
     // no sense
     return false;
   }
@@ -921,75 +1083,112 @@ struct EdgeTypeSerializer : public TypedDataSerializer<edge> {
 
   KnownTypeSerializer<UnsignedIntegerType> *uintSerializer;
 
-  EdgeTypeSerializer():TypedDataSerializer<edge>("edge") {
+  EdgeTypeSerializer() : TypedDataSerializer<edge>("edge") {
     uintSerializer = new KnownTypeSerializer<UnsignedIntegerType>("");
   }
 
-  ~EdgeTypeSerializer() {
+  ~EdgeTypeSerializer() override {
     delete uintSerializer;
   }
 
-  DataTypeSerializer* clone() const {
+  DataTypeSerializer *clone() const override {
     return new EdgeTypeSerializer();
   }
 
-  void write(ostream& os, const edge& e) {
+  void write(ostream &os, const edge &e) override {
     uintSerializer->write(os, e.id);
   }
 
-  bool read(istream& is, edge& e) {
+  bool read(istream &is, edge &e) override {
     return uintSerializer->read(is, e.id);
   }
 
-  bool setData(tlp::DataSet&, const string&, const string&) {
+  bool setData(tlp::DataSet &, const string &, const string &) override {
     // no sense
     return false;
   }
 };
 
-struct EdgeVectorTypeSerializer : public TypedDataSerializer<vector<edge> > {
+struct EdgeVectorTypeSerializer : public TypedDataSerializer<vector<edge>> {
 
   KnownTypeSerializer<UnsignedIntegerVectorType> *uintVecSerializer;
 
-  EdgeVectorTypeSerializer():TypedDataSerializer<vector<edge> >("edges") {
+  EdgeVectorTypeSerializer() : TypedDataSerializer<vector<edge>>("edges") {
     uintVecSerializer = new KnownTypeSerializer<UnsignedIntegerVectorType>("");
   }
 
-  ~EdgeVectorTypeSerializer() {
+  ~EdgeVectorTypeSerializer() override {
     delete uintVecSerializer;
   }
 
-  DataTypeSerializer* clone() const {
+  DataTypeSerializer *clone() const override {
     return new EdgeVectorTypeSerializer();
   }
 
-  void write(ostream& os, const vector<edge>& ve) {
+  void write(ostream &os, const vector<edge> &ve) override {
     uintVecSerializer->write(os, reinterpret_cast<const vector<unsigned int> &>(ve));
   }
 
-  bool read(istream& is, vector<edge>& ve) {
+  bool read(istream &is, vector<edge> &ve) override {
     return uintVecSerializer->read(is, reinterpret_cast<vector<unsigned int> &>(ve));
   }
 
-  bool setData(tlp::DataSet&, const string&, const string&) {
+  bool setData(tlp::DataSet &, const string &, const string &) override {
     // no sense
     return false;
   }
-
 };
 
-struct StringCollectionSerializer :public TypedDataSerializer<StringCollection> {
-  StringCollectionSerializer():TypedDataSerializer<StringCollection>("StringCollection") {}
+struct PropertiesCollectionSerializer : public TypedDataSerializer<PropertiesCollection> {
+  PropertiesCollectionSerializer()
+      : TypedDataSerializer<PropertiesCollection>("PropertiesCollection") {}
 
-  DataTypeSerializer* clone() const {
+  DataTypeSerializer *clone() const override {
+    return new PropertiesCollectionSerializer();
+  }
+
+  // called when writing a tlp file, which should never happen
+  void write(ostream &, const PropertiesCollection &) override {
+    throw TulipException("PropertiesCollectionSerializer::write is not implemented");
+  }
+
+  // called when reading a tlp file, which should never happen
+  bool read(istream &, PropertiesCollection &) override {
+    throw TulipException("PropertiesCollectionSerializer::read is not implemented");
+  }
+
+  std::string toString(const DataType *data) override {
+    auto &selected = static_cast<PropertiesCollection *>(data->value)->getSelected();
+    ostringstream oss;
+    oss << '"';
+    for (size_t i = 0; i < selected.size(); ++i) {
+      if (i)
+        oss << ", ";
+      oss << selected[i];
+    }
+    oss << '"';
+    return oss.str();
+  }
+
+  bool setData(tlp::DataSet &dts, const string &prop, const string &) override {
+    PropertiesCollection col(graph);
+    dts.set(prop, col);
+    return true;
+  }
+};
+
+struct StringCollectionSerializer : public TypedDataSerializer<StringCollection> {
+  StringCollectionSerializer() : TypedDataSerializer<StringCollection>("StringCollection") {}
+
+  DataTypeSerializer *clone() const override {
     return new StringCollectionSerializer();
   }
 
-  void write(ostream& os, const StringCollection& sc) {
+  void write(ostream &os, const StringCollection &sc) override {
     os << '"';
     std::vector<std::string> values = sc.getValues();
 
-    for(unsigned int i = 0; i < values.size(); ++i) {
+    for (unsigned int i = 0; i < values.size(); ++i) {
       if (i)
         os << ';';
 
@@ -999,69 +1198,65 @@ struct StringCollectionSerializer :public TypedDataSerializer<StringCollection>
     os << '"';
   }
 
-  bool read(istream& is, StringCollection& sc) {
+  bool read(istream &is, StringCollection &sc) override {
     char c = ' ';
 
     // go to first '"'
-    while((is >> c) && isspace(c)) {}
+    while ((is >> c) && isspace(c)) {
+    }
 
     if (c != '"')
       return false;
 
     string str;
 
-    for( ;; ) {
-      if( !(is >> c) )
+    for (;;) {
+      if (!(is >> c))
         return false;
 
-      if( c == '"' ) {
-        sc.push_back(str);
+      if (c == '"') {
+        sc.push_back(std::move(str));
         return true;
       }
 
       if (c == ';') {
-        sc.push_back(str);
+        sc.push_back(std::move(str));
         str.clear();
-      }
-      else
+      } else
         str.push_back(c);
     }
   }
 
-  std::string toString(const DataType *data) {
-    return ((StringCollection *) data->value)->getCurrentString();
+  std::string toString(const DataType *data) override {
+    return std::string("\"") + static_cast<StringCollection *>(data->value)->getCurrentString() +
+           '"';
+    ;
   }
 
-  bool setData(tlp::DataSet& dts, const string& prop, const string& val) {
-    StringCollection col;
-
-    string::size_type lastPos = val.find_first_not_of(";");
-    string::size_type pos = val.find_first_of(";", lastPos);
-
-    while (string::npos != pos || string::npos != lastPos) {
-      col.push_back(val.substr(lastPos, pos - lastPos));
-      lastPos = val.find_first_not_of(";", pos);
-      pos = val.find_first_of(";", lastPos);
-    }
-
+  bool setData(tlp::DataSet &dts, const string &prop, const string &val) override {
+    StringCollection col(val);
     dts.set(prop, col);
-
     return true;
   }
 };
 
 void tlp::initTypeSerializers() {
-  DataSet::registerDataTypeSerializer<EdgeSetType::RealType>(KnownTypeSerializer<EdgeSetType>("edgeset"));
+  DataSet::registerDataTypeSerializer<EdgeSetType::RealType>(
+      KnownTypeSerializer<EdgeSetType>("edgeset"));
 
-  DataSet::registerDataTypeSerializer<DoubleType::RealType>(KnownTypeSerializer<DoubleType>("double"));
+  DataSet::registerDataTypeSerializer<DoubleType::RealType>(
+      KnownTypeSerializer<DoubleType>("double"));
 
   DataSet::registerDataTypeSerializer<FloatType::RealType>(KnownTypeSerializer<FloatType>("float"));
 
-  DataSet::registerDataTypeSerializer<BooleanType::RealType>(KnownTypeSerializer<BooleanType>("bool"));
+  DataSet::registerDataTypeSerializer<BooleanType::RealType>(
+      KnownTypeSerializer<BooleanType>("bool"));
 
-  DataSet::registerDataTypeSerializer<IntegerType::RealType>(KnownTypeSerializer<IntegerType>("int"));
+  DataSet::registerDataTypeSerializer<IntegerType::RealType>(
+      KnownTypeSerializer<IntegerType>("int"));
 
-  DataSet::registerDataTypeSerializer<UnsignedIntegerType::RealType>(KnownTypeSerializer<UnsignedIntegerType>("uint"));
+  DataSet::registerDataTypeSerializer<UnsignedIntegerType::RealType>(
+      KnownTypeSerializer<UnsignedIntegerType>("uint"));
 
   DataSet::registerDataTypeSerializer<LongType::RealType>(KnownTypeSerializer<LongType>("long"));
 
@@ -1069,30 +1264,38 @@ void tlp::initTypeSerializers() {
 
   DataSet::registerDataTypeSerializer<PointType::RealType>(KnownTypeSerializer<PointType>("coord"));
 
-  DataSet::registerDataTypeSerializer<StringType::RealType>(KnownTypeSerializer<StringType>("string"));
+  DataSet::registerDataTypeSerializer<StringType::RealType>(
+      KnownTypeSerializer<StringType>("string"));
 
-  DataSet::registerDataTypeSerializer<DoubleVectorType::RealType>(KnownTypeSerializer<DoubleVectorType>("doublevector"));
+  DataSet::registerDataTypeSerializer<DoubleVectorType::RealType>(
+      KnownTypeSerializer<DoubleVectorType>("doublevector"));
 
-  DataSet::registerDataTypeSerializer<BooleanVectorType::RealType>(KnownTypeSerializer<BooleanVectorType>("boolvector"));
+  DataSet::registerDataTypeSerializer<BooleanVectorType::RealType>(
+      KnownTypeSerializer<BooleanVectorType>("boolvector"));
 
-  DataSet::registerDataTypeSerializer<IntegerVectorType::RealType>(KnownTypeSerializer<IntegerVectorType>("intvector"));
+  DataSet::registerDataTypeSerializer<IntegerVectorType::RealType>(
+      KnownTypeSerializer<IntegerVectorType>("intvector"));
 
-  DataSet::registerDataTypeSerializer<ColorVectorType::RealType>(KnownTypeSerializer<ColorVectorType>("colorvector"));
+  DataSet::registerDataTypeSerializer<ColorVectorType::RealType>(
+      KnownTypeSerializer<ColorVectorType>("colorvector"));
 
-  DataSet::registerDataTypeSerializer<LineType::RealType>(KnownTypeSerializer<LineType>("coordvector"));
+  DataSet::registerDataTypeSerializer<LineType::RealType>(
+      KnownTypeSerializer<LineType>("coordvector"));
 
-  DataSet::registerDataTypeSerializer<StringVectorType::RealType>(KnownTypeSerializer<StringVectorType>("stringvector"));
+  DataSet::registerDataTypeSerializer<StringVectorType::RealType>(
+      KnownTypeSerializer<StringVectorType>("stringvector"));
 
   DataSet::registerDataTypeSerializer<DataSet>(DataSetTypeSerializer());
 
   DataSet::registerDataTypeSerializer<node>(NodeTypeSerializer());
 
-  DataSet::registerDataTypeSerializer<vector<node> >(NodeVectorTypeSerializer());
+  DataSet::registerDataTypeSerializer<vector<node>>(NodeVectorTypeSerializer());
 
   DataSet::registerDataTypeSerializer<edge>(EdgeTypeSerializer());
 
-  DataSet::registerDataTypeSerializer<vector<edge> >(EdgeVectorTypeSerializer());
+  DataSet::registerDataTypeSerializer<vector<edge>>(EdgeVectorTypeSerializer());
 
   DataSet::registerDataTypeSerializer<StringCollection>(StringCollectionSerializer());
 
+  DataSet::registerDataTypeSerializer<PropertiesCollection>(PropertiesCollectionSerializer());
 }
