@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -17,6 +17,7 @@
  *
  */
 #include <algorithm>
+#include <tulip/tuliphash.h>
 
 #include <tulip/TLPBExportImport.h>
 #include <tulip/TlpTools.h>
@@ -28,6 +29,23 @@ PLUGIN(TLPBExport)
 using namespace tlp;
 using namespace std;
 
+// used to reindex the hierarchy to be saved with consecutive ids
+static unsigned int getExportedId(Graph *g = nullptr) {
+  static unsigned int nextExportedId = 0;
+  static tlp_hash_map<Graph *, unsigned int> ids;
+  if (g == nullptr) {
+    // reset
+    nextExportedId = 0;
+    ids.clear();
+    return 0;
+  }
+  auto it = ids.find(g);
+  if (it != ids.end())
+    return it->second;
+  ids[g] = nextExportedId;
+  return nextExportedId++;
+}
+
 //================================================================================
 void TLPBExport::getSubGraphs(Graph *g, vector<Graph *> &vsg) {
   // get subgraphs in a vector
@@ -41,34 +59,34 @@ void TLPBExport::writeAttributes(ostream &os, Graph *g) {
   const DataSet &attributes = g->getAttributes();
 
   if (!attributes.empty()) {
+
     // If nodes and edges are stored as graph attributes
     // we need to update their ids before serializing them
     // as nodes and edges have been reindexed
-
     for (const pair<string, DataType *> &attribute : attributes.getValues()) {
       if (attribute.second->getTypeName() == string(typeid(node).name())) {
         node *n = static_cast<node *>(attribute.second->value);
-        n->id = getNode(*n).id;
+        n->id = exportedNode(*n).id;
       } else if (attribute.second->getTypeName() == string(typeid(edge).name())) {
         edge *e = static_cast<edge *>(attribute.second->value);
-        e->id = getEdge(*e).id;
+        e->id = exportedEdge(*e).id;
       } else if (attribute.second->getTypeName() == string(typeid(vector<node>).name())) {
         vector<node> *vn = static_cast<vector<node> *>(attribute.second->value);
 
         for (size_t i = 0; i < vn->size(); ++i) {
-          (*vn)[i].id = getNode((*vn)[i]).id;
+          (*vn)[i].id = exportedNode((*vn)[i]).id;
         }
       } else if (attribute.second->getTypeName() == string(typeid(vector<edge>).name())) {
         vector<edge> *ve = static_cast<vector<edge> *>(attribute.second->value);
 
         for (size_t i = 0; i < ve->size(); ++i) {
-          (*ve)[i].id = getEdge((*ve)[i]).id;
+          (*ve)[i].id = exportedEdge((*ve)[i]).id;
         }
       }
     }
   }
 
-  unsigned int id = g->getSuperGraph() == g ? 0 : g->getId();
+  unsigned int id = getExportedId(g);
   // write graph id
   os.write(reinterpret_cast<const char *>(&id), sizeof(id));
   // write graph attributes
@@ -79,11 +97,6 @@ void TLPBExport::writeAttributes(ostream &os, Graph *g) {
 //================================================================================
 bool TLPBExport::exportGraph(std::ostream &os) {
 
-  // change graph parent in hierarchy temporarily to itself as
-  // it will be the new root of the exported hierarchy
-  Graph *superGraph = graph->getSuperGraph();
-  graph->setSuperGraph(graph);
-
   // header
   TLPBHeader header(graph->numberOfNodes(), graph->numberOfEdges());
   // write header
@@ -96,8 +109,8 @@ bool TLPBExport::exportGraph(std::ostream &os) {
     unsigned int edgesToWrite = 0, nbWrittenEdges = 0;
     for (auto e : graph->edges()) {
       std::pair<node, node> ends = graph->ends(e);
-      ends.first = getNode(ends.first);
-      ends.second = getNode(ends.second);
+      ends.first = exportedNode(ends.first);
+      ends.second = exportedNode(ends.second);
       vEdges[edgesToWrite] = std::move(ends);
 
       if (++edgesToWrite == MAX_EDGES_TO_WRITE) {
@@ -129,14 +142,13 @@ bool TLPBExport::exportGraph(std::ostream &os) {
     // write nb subgraphs
     os.write(reinterpret_cast<const char *>(&numSubGraphs), sizeof(numSubGraphs));
 
+    // initialize graph hierarchy ids
+    getExportedId();
     for (unsigned int i = 0; i < numSubGraphs; ++i) {
       Graph *sg = vSubGraphs[i];
-      unsigned int parentId = sg->getSuperGraph()->getId();
+      unsigned int parentId = getExportedId(sg->getSuperGraph());
 
-      if (parentId == graph->getId())
-        parentId = 0;
-
-      std::pair<unsigned int, unsigned int> ids(sg->getId(), parentId);
+      std::pair<unsigned int, unsigned int> ids(getExportedId(sg), parentId);
       // write ids
       os.write(reinterpret_cast<const char *>(&ids), sizeof(ids));
       // loop to write sg nodes ranges
@@ -147,7 +159,7 @@ bool TLPBExport::exportGraph(std::ostream &os) {
         std::vector<node> sgNodes(nbNodes);
 
         for (unsigned int j = 0; j < nbNodes; ++j)
-          sgNodes[j] = getNode(nodes[j]);
+          sgNodes[j] = exportedNode(nodes[j]);
 
         std::sort(sgNodes.begin(), sgNodes.end());
 
@@ -214,7 +226,7 @@ bool TLPBExport::exportGraph(std::ostream &os) {
         std::vector<edge> sgEdges(nbEdges);
 
         for (unsigned int j = 0; j < nbEdges; ++j)
-          sgEdges[j] = getEdge(edges[j]);
+          sgEdges[j] = exportedEdge(edges[j]);
 
         std::sort(sgEdges.begin(), sgEdges.end());
 
@@ -312,10 +324,7 @@ bool TLPBExport::exportGraph(std::ostream &os) {
       os.write(reinterpret_cast<const char *>(&size), sizeof(size));
       os.write(reinterpret_cast<const char *>(nameOrType.data()), size);
       // write graph id
-      unsigned int propGraphId = prop->getGraph()->getId();
-
-      if (i < numGraphProperties || propGraphId == graph->getId())
-        propGraphId = 0;
+      unsigned int propGraphId = (i < numGraphProperties) ? 0 : getExportedId(prop->getGraph());
 
       os.write(reinterpret_cast<const char *>(&propGraphId), sizeof(propGraphId));
       // special treament for pathnames view properties
@@ -382,14 +391,13 @@ bool TLPBExport::exportGraph(std::ostream &os) {
 
         // loop on nodes
         unsigned int nbValues = 0;
-        // when exporting the GraphProperty, if the exported graph
-        // is not the root graph we will have to check if the node pointed
+        // when exporting the GraphProperty
+        // we will have to check if the node pointed
         // subgraph is a descendant graph of this graph
-        bool checkForDescendantGraph =
-            propGraphId && (prop->getTypename() == GraphProperty::propertyTypename);
+        bool checkForMetaGraph = prop->getTypename() == GraphProperty::propertyTypename;
         for (auto n : prop->getNonDefaultValuatedNodes(propGraphId ? nullptr : graph)) {
           // write current node reindexed id
-          size = getNode(n).id;
+          size = exportedNode(n).id;
           s.write(reinterpret_cast<const char *>(&size), sizeof(size));
 
           if (pnViewProp && !TulipBitmapDir.empty()) { // viewFont || viewTexture
@@ -400,13 +408,13 @@ bool TLPBExport::exportGraph(std::ostream &os) {
               sVal.replace(pos, TulipBitmapDir.size(), "TulipBitmapDir/");
 
             StringType::writeb(s, sVal);
-          } else if (checkForDescendantGraph) {
+          } else if (checkForMetaGraph) {
             string tmp = prop->getNodeStringValue(n);
             unsigned int id = strtoul(tmp.c_str(), nullptr, 10);
-
+            auto sg = graph->getDescendantGraph(id);
             // record a null value if the node pointed subgraph
             // is not a descendant of the currently exported graph
-            UnsignedIntegerType::writeb(s, graph->getDescendantGraph(id) ? id : 0);
+            UnsignedIntegerType::writeb(s, sg ? getExportedId(sg) : 0);
           } else
             prop->writeNodeValue(s, n);
 
@@ -483,7 +491,7 @@ bool TLPBExport::exportGraph(std::ostream &os) {
         // loop on edges
         unsigned int nbValues = 0;
         for (auto e : prop->getNonDefaultValuatedEdges(propGraphId ? nullptr : graph)) {
-          size = getEdge(e).id;
+          size = exportedEdge(e).id;
           s.write(reinterpret_cast<const char *>(&size), sizeof(size));
 
           if (isGraphProperty) {
@@ -495,7 +503,7 @@ bool TLPBExport::exportGraph(std::ostream &os) {
               // reindex only embedded edges belonging to the exported graph
               if (!graph->isElement(eEdge))
                 continue;
-              edge rEdge = getEdge(eEdge);
+              edge rEdge = exportedEdge(eEdge);
               rEdges.insert(rEdge);
             }
 
@@ -558,6 +566,5 @@ bool TLPBExport::exportGraph(std::ostream &os) {
   for (unsigned int i = 0; i < numSubGraphs; ++i)
     writeAttributes(os, vSubGraphs[i]);
 
-  graph->setSuperGraph(superGraph);
   return true;
 }
