@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -22,31 +22,38 @@
 #include <cstring>
 #include <ctime>
 #include <string>
-#include <sstream>
+#include <iostream>
 #include <clocale>
 #include <cerrno>
 #include <random>
 #include <chrono>
 
 #ifndef _WIN32
+#include <sys/stat.h>
 #include <unistd.h>
+#include <gzstream.h>
 #endif
 
 #ifdef _WIN32
 #include <windows.h>
 #include <utf8.h>
+// msys2 build hack
+#ifndef __CRT__NO_INLINE
+#define __CRT__NO_INLINE
+#define UNDEF__CRT__NO_INLINE
+#endif
+#include <gzstream.h>
+#ifdef UNDEF__CRT__NO_INLINE
+#undef __CRT__NO_INLINE
+#endif
 #ifdef _MSC_VER
 #include <dbghelp.h>
 #endif
-#ifdef __GLIBCXX__
-#include <ext/stdio_filebuf.h>
-#endif
 #else
 #include <dirent.h>
 #include <dlfcn.h>
 #endif
 
-#include <gzstream.h>
 #include <tulip/TulipException.h>
 #include <tulip/TlpTools.h>
 #include <tulip/Plugin.h>
@@ -57,9 +64,7 @@
 using namespace std;
 using namespace tlp;
 
-#ifndef __EMSCRIPTEN__
 static const char *TULIP_PLUGINS_PATH_VARIABLE = "TLP_PLUGINS_PATH";
-#endif
 
 // the relative path (a string), from the install dir
 // of the directory where the tulip libraries are installed
@@ -91,7 +96,6 @@ const char tlp::PATH_DELIMITER = ';';
 const char tlp::PATH_DELIMITER = ':';
 #endif
 
-#ifndef __EMSCRIPTEN__
 // A function that retrieves the Tulip libraries directory based on
 // the path of the loaded shared library libtulip-core-X.Y.[dll, so, dylib]
 extern "C" {
@@ -154,11 +158,9 @@ static void checkDirectory(std::string dir, bool tlpDirSet, bool throwEx) {
   if (dir[dir.length() - 1] == '/')
     dir.erase(dir.length() - 1);
 
-  tlp_stat_t infoEntry;
-
-  if (statPath(dir, &infoEntry) != 0) {
+  if (!pathExist(dir)) {
     std::stringstream ess;
-    ess << "Error - " << dir << ":" << std::endl << strerror(errno) << std::endl;
+    ess << "Error - " << dir << ":" << std::endl << getStrError() << std::endl;
     if (tlpDirSet)
       ess << std::endl << "Check your TLP_DIR environment variable";
     if (throwEx)
@@ -251,8 +253,7 @@ void tlp::initTulipLib(const char *appDirPath) {
 #ifndef _WIN32
   // special case for Debian when Tulip install prefix is /usr
   // as libraries are installed in <prefix>/lib/<arch>
-  tlp_stat_t statInfo;
-  if (statPath(curDir, &statInfo) != 0) {
+  if (!pathExist(curDir)) {
     pos = TulipLibDir.rfind("/", pos - 1);
     curDir = TulipLibDir.substr(0, pos + 1) + "share/tulip/";
   }
@@ -311,16 +312,6 @@ std::string tlp::demangleClassName(const char *className, bool hideTlp) {
 #error define symbols demangling function
 #endif
 
-#else // __EMSCRIPTEN__
-
-void initTulipLib(const char *) {}
-
-std::string tlp::demangleClassName(const char *className, bool) {
-  return std::string(className);
-}
-
-#endif // __EMSCRIPTEN__
-
 //=========================================================
 std::istream *tlp::getIgzstream(const std::string &name, int open_mode) {
 #if defined(WIN32) && ZLIB_VERNUM >= 0x1270
@@ -346,14 +337,12 @@ std::ostream *tlp::getOgzstream(const std::string &name, int open_mode) {
 //=========================================================
 
 static unsigned int randomSeed = UINT_MAX;
-// uniformly-distributed integer random number generator that produces non-deterministic random
-// numbers
-static std::random_device rd;
 // Mersenne Twister pseudo-random generator of 32-bit numbers
 static std::mt19937 mt;
 
 void tlp::setSeedOfRandomSequence(unsigned int seed) {
   randomSeed = seed;
+  tlp::initRandomSequence();
 }
 
 unsigned int tlp::getSeedOfRandomSequence() {
@@ -361,15 +350,8 @@ unsigned int tlp::getSeedOfRandomSequence() {
 }
 
 void tlp::initRandomSequence() {
-  // init seed from random sequence with std::random_device
   if (randomSeed == UINT_MAX) {
-#ifndef __MINGW32__
-    mt.seed(rd());
-#else
-    // std::random_device implementation is deterministic in MinGW so initialize seed with current
-    // time (microsecond precision)
-    mt.seed(uint(std::chrono::high_resolution_clock::now().time_since_epoch().count()));
-#endif
+    mt.seed(std::chrono::high_resolution_clock::now().time_since_epoch().count());
   } else {
     mt.seed(randomSeed);
   }
@@ -403,127 +385,32 @@ double tlp::randomDouble(double max) {
 
 //=========================================================
 
-int tlp::statPath(const std::string &pathname, tlp_stat_t *buf) {
+bool tlp::pathExist(const std::string &pathname) {
 #ifndef WIN32
-  return stat(pathname.c_str(), buf);
+  struct stat info;
+  return stat(pathname.c_str(), &info) == 0;
 #else
+  struct _stat info;
   std::wstring utf16pathname;
   utf8::utf8to16(pathname.begin(), pathname.end(), std::back_inserter(utf16pathname));
-  return _wstat(utf16pathname.c_str(), buf);
+  return _wstat(utf16pathname.c_str(), &info) == 0;
 #endif
 }
 
 //=========================================================
 
-#if defined(WIN32) && defined(__GLIBCXX__)
-// function to get the string representation of the bitwise combination of std::ios_base::openmode
-// flags
-static std::wstring openmodeToWString(std::ios_base::openmode mode) {
-  std::wstring ret;
-  bool testb = (mode & std::ios_base::binary) == std::ios_base::binary;
-  bool testi = (mode & std::ios_base::in) == std::ios_base::in;
-  bool testo = (mode & std::ios_base::out) == std::ios_base::out;
-  bool testt = (mode & std::ios_base::trunc) == std::ios_base::trunc;
-  bool testa = (mode & std::ios_base::app) == std::ios_base::app;
-
-  if (!testi && testo && !testt && !testa)
-    ret = L"w";
-
-  if (!testi && testo && !testt && testa)
-    ret = L"a";
-
-  if (!testi && testo && testt && !testa)
-    ret = L"w";
-
-  if (testi && !testo && !testt && !testa)
-    ret = L"r";
-
-  if (testi && testo && !testt && !testa)
-    ret = L"r+";
-
-  if (testi && testo && testt && !testa)
-    ret = L"w+";
-
-  if (testb)
-    ret += L"b";
-
-  return ret;
-}
-
-// class to open a file for reading whose path contains non ascii characters (MinGW only)
-class wifilestream : public std::istream {
-public:
-  wifilestream(const std::wstring &wfilename, std::ios_base::openmode mode)
-      : fp(nullptr), buffer(nullptr) {
-    fp = _wfopen(wfilename.c_str(), openmodeToWString(mode).c_str());
-
-    if (fp) {
-      buffer = new __gnu_cxx::stdio_filebuf<char>(fp, mode);
-    }
-
-    init(buffer);
-  }
-  ~wifilestream() {
-    delete buffer;
-
-    if (fp) {
-      fclose(fp);
-    }
-  }
-
-private:
-  FILE *fp;
-  __gnu_cxx::stdio_filebuf<char> *buffer;
-};
-
-// class to open a file for writing whose path contains non ascii characters (MinGW only)
-class wofilestream : public std::ostream {
-public:
-  wofilestream(const std::wstring &wfilename, std::ios_base::openmode open_mode)
-      : fp(nullptr), buffer(nullptr) {
-    fp = _wfopen(wfilename.c_str(), openmodeToWString(open_mode).c_str());
-
-    if (fp) {
-      buffer = new __gnu_cxx::stdio_filebuf<char>(fp, open_mode);
-    }
-
-    init(buffer);
-  }
-  ~wofilestream() {
-    delete buffer;
-
-    if (fp) {
-      fclose(fp);
-    }
-  }
-
-private:
-  FILE *fp;
-  __gnu_cxx::stdio_filebuf<char> *buffer;
-};
-#endif
-
 //=========================================================
 
 std::istream *tlp::getInputFileStream(const std::string &filename, std::ios_base::openmode mode) {
-#ifndef WIN32
-  // On Linux and Mac OS, UTF-8 encoded paths are supported by std::ifstream
-  return new std::ifstream(filename.c_str(), mode);
-#else
+#ifdef WIN32
   // On Windows, the path name (possibly containing non ascii characters) has to be converted to
   // UTF-16 in order to open a stream
   std::wstring utf16filename;
   utf8::utf8to16(filename.begin(), filename.end(), std::back_inserter(utf16filename));
-#ifdef __GLIBCXX__
-  // With MinGW, it's a little bit tricky to get an input stream
-  return new wifilestream(utf16filename, mode);
-#elif defined(_MSC_VER)
-  // Visual Studio has wide char version of std::ifstream
   return new std::ifstream(utf16filename.c_str(), mode);
 #else
-  // Fallback
-  return new std::ifstream(filename.c_str(), mode);
-#endif
+  // On Linux and Mac OS, UTF-8 encoded paths are supported by std::ofstream
+  return new std::ifstream(filename, mode);
 #endif
 }
 
@@ -531,25 +418,30 @@ std::istream *tlp::getInputFileStream(const std::string &filename, std::ios_base
 
 std::ostream *tlp::getOutputFileStream(const std::string &filename,
                                        std::ios_base::openmode open_mode) {
-#ifndef WIN32
-  // On Linux and Mac OS, UTF-8 encoded paths are supported by std::ofstream
-  return new std::ofstream(filename.c_str(), open_mode);
-#else
+#ifdef WIN32
   // On Windows, the path name (possibly containing non ascii characters) has to be converted to
   // UTF-16 in order to open a stream
   std::wstring utf16filename;
   utf8::utf8to16(filename.begin(), filename.end(), std::back_inserter(utf16filename));
-#ifdef __GLIBCXX__
-  // With MinGW, it's a little bit tricky to get an output stream
-  return new wofilestream(utf16filename, open_mode);
-#elif defined(_MSC_VER)
-  // Visual Studio has wide char version of std::ofstream
   return new std::ofstream(utf16filename.c_str(), open_mode);
 #else
-  // Fallback
-  return new std::ofstream(filename.c_str(), open_mode);
+  // On Linux and Mac OS, UTF-8 encoded paths are supported by std::ofstream
+  return new std::ofstream(filename, open_mode);
 #endif
+}
+
+#ifndef LC_MESSAGES
+#define LC_MESSAGES LC_ALL
 #endif
+char *tlp::getStrError() {
+  // get current locale
+  auto loc = setlocale(LC_MESSAGES, nullptr);
+  // avoid message translation
+  setlocale(LC_MESSAGES, "C");
+  auto msg = strerror(errno);
+  // restore locale
+  setlocale(LC_MESSAGES, loc);
+  return msg;
 }
 
 //=========================================================
