@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -20,13 +20,10 @@
 #include <tulip/YajlFacade.h>
 #include <tulip/TlpTools.h>
 
-extern "C" {
 #include <yajl/yajl_parse.h>
 #include <yajl/yajl_gen.h>
-}
-#include <cerrno>
-#include <cstdlib>
-#include <cstring>
+#include <yajl/yajl_version.h>
+
 #include <iostream>
 #include <fstream>
 #include <sstream>
@@ -34,6 +31,11 @@ extern "C" {
 YajlParseFacade::YajlParseFacade(tlp::PluginProgress *progress)
     : _progress(progress), _parsingSucceeded(true) {}
 
+std::string YajlParseFacade::yajlVersion() {
+  return std::to_string(YAJL_MAJOR) + "." + std::to_string(YAJL_MINOR) + "." +
+         std::to_string(YAJL_MICRO);
+}
+
 static int parse_null(void *ctx) {
   YajlParseFacade *facade = static_cast<YajlParseFacade *>(ctx);
   facade->parseNull();
@@ -103,26 +105,23 @@ static int parse_end_array(void *ctx) {
   return 1;
 }
 
-void YajlParseFacade::parse(std::string filename) {
-  // check if file exists
-  tlp_stat_t infoEntry;
-  bool result = tlp::statPath(filename, &infoEntry) == 0;
+void YajlParseFacade::parse(const std::string &filename) {
+  // open a stream
+  std::istream *ifs = tlp::getInputFileStream(filename, std::ifstream::in |
+                                                            // consider file is binary
+                                                            // to avoid pb using tellg
+                                                            // on the input stream
+                                                            std::ifstream::binary);
 
-  if (!result) {
+  // check for open stream failure
+  if (ifs->fail()) {
     std::stringstream ess;
-    ess << filename.c_str() << ": " << strerror(errno);
+    ess << "Unable to open " << filename << ": " << tlp::getStrError();
     _errorMessage = ess.str();
     _parsingSucceeded = false;
     return;
   }
 
-  // open a stream
-  std::istream *ifs = tlp::getInputFileStream(filename.c_str(), std::ifstream::in |
-                                                                    // consider file is binary
-                                                                    // to avoid pb using tellg
-                                                                    // on the input stream
-                                                                    std::ifstream::binary);
-
   // get length of file:
   ifs->seekg(0, std::ios::end);
   int fileLength = ifs->tellg();
