@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -27,9 +27,11 @@
 #include <QWidget>
 
 namespace Ui {
-class AboutTulipPageData;
+class AboutTulipPageWidget;
 }
 
+class QNetworkReply;
+
 namespace tlp {
 
 /**
@@ -46,10 +48,10 @@ public:
 
 private slots:
 
-  void openUrlInBrowser(const QString &url);
+  void rssReply(QNetworkReply *);
 
 private:
-  Ui::AboutTulipPageData *_ui;
+  Ui::AboutTulipPageWidget *_ui;
 };
 } // namespace tlp
 
