@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -48,6 +48,7 @@ public:
   CSVParser *buildParser(unsigned int firstLine = 0, unsigned int lastLine = UINT_MAX) const;
 
   std::string getFile() const;
+  void clearFile();
   bool isValid() const;
   QString getSeparator() const;
   char getTextSeparator() const;
@@ -55,6 +56,7 @@ public:
   std::string getEncoding() const;
   bool invertMatrix() const;
   bool getMergeSeparator() const;
+  bool getConsiderAsString() const;
   void initWithLastOpenedFile();
   int getFirstLineIndex() const;
   void setNbIgnoredLines(int);
