@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -30,7 +30,7 @@ class WorkspacePanel;
 class DragHandle : public QLabel {
   Q_OBJECT
 public:
-  explicit DragHandle(QWidget *parent = nullptr, Qt::WindowFlags f = nullptr);
+  explicit DragHandle(QWidget *parent = nullptr, Qt::WindowFlags f = Qt::WindowFlags());
   void mousePressEvent(QMouseEvent *ev) override;
   void mouseReleaseEvent(QMouseEvent *ev) override;
   void mouseMoveEvent(QMouseEvent *ev) override;
