@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -28,8 +28,6 @@
 #include <tulip/TulipModel.h>
 #include <tulip/GraphModel.h>
 
-#include <QVector>
-
 namespace tlp {
 
 class TLP_QT_SCOPE GraphElementModel : public TulipModel {
@@ -59,7 +57,7 @@ public:
   }
 
 protected:
-  QVector<PropertyInterface *> getGraphProperties() const;
+  std::vector<PropertyInterface *> getGraphProperties() const;
 
   Graph *_graph;
   unsigned int _id;
