@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -75,6 +75,15 @@ public:
    * @brief A callback method after setView was called.
    */
   virtual void viewChanged(View *) {}
+
+  /**
+   * @brief This method is called whenever the context menu is required on the view.
+   * @param point The screen coordinates where the context menu should be displayed.
+    @return true or false whether the context menu has been shown or not
+   */
+  virtual bool showContextMenu(const QPoint & /*point*/, const QPointF & /*scenePoint*/) {
+    return false;
+  }
 };
 
 /**
@@ -166,6 +175,11 @@ public:
     */
   void push_front(InteractorComponent *component);
 
+  /**
+    @brief iterate on _components to show context menu
+    */
+  bool showContextMenu(const QPoint & /*point*/, const QPointF & /*scenePoint*/) override;
+
 public slots:
   void undoIsDone() override;
   void setView(tlp::View *view) override;
