@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -116,14 +116,13 @@ private:
   GlTriangle targetTriangle;
   GlCircle sourceCircle;
   GlComposite *circleString;
-  std::vector<SelectedEntity> select;
   bool edgeSelected;
   tlp::edge mEdge;
   node mNode;
   Coord start, end;
   std::string selectedEntity;
   bool mouseButtonPressOnEdge;
-  bool belong(Coord, Coord, Coord, GlMainWidget *);
+  bool belong(const Coord &, const Coord &, const Coord &, GlMainWidget *);
   bool haveSelection(GlMainWidget *);
   void computeSrcTgtEntities(GlMainWidget *);
   bool computeBendsCircles(GlMainWidget *);
