@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -47,7 +47,7 @@ protected:
    * @param source
    * @param dest
    */
-  virtual void addLink(const node &source, const node &dest);
+  virtual void addLink(node source, node dest);
   /**
    * @brief source gets the source node.
    * @return
