@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -26,18 +26,21 @@
 #include <QEvent>
 
 namespace tlp {
+class GlMainWidget;
 
-class TLP_QT_SCOPE MouseNodeBuilder:public InteractorComponent {
+class TLP_QT_SCOPE MouseNodeBuilder : public InteractorComponent {
 
 public:
-  MouseNodeBuilder(QEvent::Type eventType = QEvent::MouseButtonPress):_eventType(eventType) {}
-  ~MouseNodeBuilder() {}
-  bool eventFilter(QObject *, QEvent *);
-  void clear();
+  MouseNodeBuilder(QEvent::Type eventType = QEvent::MouseButtonPress)
+      : _eventType(eventType), glMainWidget(nullptr) {}
+  ~MouseNodeBuilder() override {}
+  bool eventFilter(QObject *, QEvent *) override;
+  void clear() override;
+
 private:
   QEvent::Type _eventType;
+  GlMainWidget *glMainWidget;
 };
-
-}
+} // namespace tlp
 #endif
 ///@endcond
