@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -141,7 +141,7 @@ protected:
 
   void graphChanged(tlp::Graph *) override;
 
-  void createScene(Graph *graph, DataSet dataSet);
+  void createScene(Graph *graph, const DataSet &dataSet = DataSet());
   DataSet sceneData() const;
   void loadGraphOnScene(Graph *graph);
   void useHulls(bool hasHulls);
