@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -25,6 +25,7 @@
 
 #include <QIcon>
 #include <QFont>
+#include <QWidget>
 
 #include <tulip/TulipModel.h>
 #include <tulip/TlpQtTools.h>
@@ -101,8 +102,7 @@ class PluginModel : public tlp::TulipModel {
         std::sort(pluginTree[cat][group].begin(), pluginTree[cat][group].end(), QStringCaseCmp);
 
         for (const QString &alg : pluginTree[cat][group]) {
-          const Plugin &plugin = PluginLister::pluginInformation(tlp::QStringToTlpString(alg));
-          std::string info = plugin.info();
+          std::string info = PluginLister::pluginInformation(tlp::QStringToTlpString(alg)).info();
 
           // set info only if they contain more than one word
           if (info.find(' ') != std::string::npos)
@@ -185,18 +185,21 @@ public:
       if (item->info.isEmpty())
         return item->name;
       else
-        return QString("<table><tr><td>%1</td></tr><tr><td><i>%2</i></td></tr></table>")
-            .arg(item->name + ":")
+        return QString("<table><tr><td><b>%1</b></td></tr><tr><td><i>%2</i></td></tr></table>")
+            .arg(item->name)
             .arg(item->info);
     } else if (role == Qt::FontRole && !index.parent().parent().isValid()) {
       QFont f;
+      QWidget *p = dynamic_cast<QWidget *>(QAbstractItemModel::parent());
+      if (p)
+        f = p->font();
+
       f.setBold(true);
       return f;
     } else if (role == Qt::DecorationRole && item->children.isEmpty() &&
                tlp::PluginLister::pluginExists(tlp::QStringToTlpString(item->name))) {
-      const tlp::Plugin &p =
-          tlp::PluginLister::pluginInformation(tlp::QStringToTlpString(item->name));
-      QIcon icon(tlp::tlpStringToQString(p.icon()));
+      QIcon icon(tlp::tlpStringToQString(
+          tlp::PluginLister::pluginInformation(tlp::QStringToTlpString(item->name)).icon()));
       return icon;
     }
 
