@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -52,6 +52,7 @@ public slots:
   void resetChanges();
   void applySettings();
   void dynamicFontRBToggled(bool);
+  void labelSizesRangeChanged();
 
 protected:
   bool eventFilter(QObject *, QEvent *) override;
