@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -38,12 +38,13 @@ class TLP_QT_SCOPE ShapeDialog : public QDialog {
 
   Q_OBJECT
 
+  bool _forNodes;
   Ui::ShapeDialog *_ui;
   QString _selectedShapeName;
   std::list<std::pair<QString, QPixmap>> shapes;
 
 public:
-  ShapeDialog(std::list<std::pair<QString, QPixmap>> &&nodeShapes, QWidget *parent = nullptr);
+  ShapeDialog(bool forNodes, QWidget *parent = nullptr);
   ~ShapeDialog() override;
 
   QString getSelectedShapeName() const;
@@ -54,6 +55,9 @@ public:
 
   void showEvent(QShowEvent *) override;
 
+protected:
+  bool eventFilter(QObject *, QEvent *e) override;
+
 protected slots:
   void updateShapeList();
 };
