@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -22,6 +22,7 @@
 
 #include <QColor>
 #include <QDebug>
+#include <QCursor>
 
 #include <tulip/Color.h>
 #include <tulip/tulipconf.h>
@@ -106,12 +107,10 @@ TLP_QT_SCOPE QString localPluginsPath();
  This method performs basic operations when starting a software using Tulip:
  @list
  @li It initializes the tulip library
- @li it checks plugins to be discarded and uninstalls them
  @li It loads plugins from the application path
  @endlist
  */
-extern TLP_QT_SCOPE void initTulipSoftware(PluginLoader *loader = nullptr,
-                                           bool removeDiscardedPlugins = false);
+extern TLP_QT_SCOPE void initTulipSoftware(PluginLoader *loader = nullptr);
 
 /**
  * @brief redirect tlp::debug() to qDebug()
@@ -131,6 +130,41 @@ TLP_QT_SCOPE void redirectErrorOutputToQCritical();
 TLP_QT_SCOPE void disableQtUserInput();
 
 TLP_QT_SCOPE void enableQtUserInput();
+
+/**
+ * @brief convert sql like filter into an acceptable regexp
+ */
+TLP_QT_SCOPE void convertLikeFilter(QString &filter);
+
+/**
+ * @brief associate a texture file path to a name
+ */
+TLP_QT_SCOPE void registerTextureFile(QString name, QString textureFilePath);
+
+/**
+ * @brief return the texture file path associated to a name
+ */
+TLP_QT_SCOPE QString getRegisteredTextureFile(QString name);
+
+/**
+ * @brief forget all registered texture files
+ */
+TLP_QT_SCOPE void clearRegisteredTextureFiles();
+
+/**
+ * @brief check for possible internet access waiting for time ms
+ */
+TLP_QT_SCOPE bool checkInternetAccess(unsigned int time = 1000);
+
+#define qtWhatsThisCursor Qt::PointingHandCursor
+
+#ifdef _LINUX
+// fix display of QCheckBox and QRadioButton in dark mode
+void tlpFixCBRBs(QWidget *parent);
+#else
+#define tlpFixCBRBs(arg)
+#endif
+
 } // namespace tlp
 
 // QDebug extension
@@ -151,4 +185,7 @@ inline QDebug operator<<(QDebug dbg, const std::string &s) {
   SET_TOOLTIP_WITH_CTRL_SHORTCUT(a, tt, sc);                                                       \
   a->setStatusTip(a->toolTip())
 
+// the color to display html links
+#define HTML_LINK_COLOR "#0d71f1"
+
 #endif
