@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -54,7 +54,8 @@ protected slots:
 
   void updateIconList();
 
-  void openUrlInBrowser(const QString &url);
+protected:
+  bool eventFilter(QObject *, QEvent *e) override;
 };
 } // namespace tlp
 
