@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -20,14 +20,14 @@
 #define VIEW_H
 
 #include <unordered_set>
+#include <list>
 
 #include <QObject>
-#include <QSet>
-#include <QList>
 #include <QSize>
 
 #include <tulip/tulipconf.h>
 #include <tulip/Edge.h>
+#include <tulip/Interactor.h>
 #include <tulip/Observable.h>
 #include <tulip/Plugin.h>
 
@@ -42,7 +42,6 @@ class QPoint;
 namespace tlp {
 static const std::string VIEW_CATEGORY = "Panel";
 
-class Interactor;
 class GlMainWidget;
 class ViewToolTipAndUrlManager;
 
@@ -95,13 +94,13 @@ class ViewToolTipAndUrlManager;
 class TLP_QT_SCOPE View : public QObject, public tlp::Plugin, public tlp::Observable {
   Q_OBJECT
 
-  QList<tlp::Interactor *> _interactors;
+  std::list<tlp::Interactor *> _interactors;
   tlp::Interactor *_currentInteractor;
   tlp::Graph *_graph;
   tlp::ViewToolTipAndUrlManager *_tturlManager;
   bool interactorsActivated;
 
-  QSet<tlp::Observable *> _triggers;
+  std::list<tlp::Observable *> _triggers;
   bool _displayContextMenu;
 
 public:
@@ -145,12 +144,19 @@ public:
     return false;
   }
 
+  // this method indicates if the view needs to be centered
+  // when added to a Workspace
+  // default is centered
+  virtual bool centeredWhenAddedToWorkspace() {
+    return true;
+  }
+
   /**
     @return The list of interactors installed on this view.
     The list is always the same as the one given when View::setInteractors() was called.
     @see setInteractors();
     */
-  inline const QList<Interactor *> &interactors() const {
+  inline const std::list<Interactor *> &interactors() const {
     return _interactors;
   }
 
@@ -177,17 +183,7 @@ public:
     @see View::applySettings()
     @warning This method must not instantiate configuration widgets on the fly.
     */
-  virtual QList<QWidget *> configurationWidgets() const;
-
-  /**
-   * @brief This method can be used to change the configuration widgets' style
-   * sheet. From Qt documentation: The style sheet contains a textual description of customizations
-   * to the
-   *  widget's style, as described in the Qt Style Sheets document. see
-   * http://qt-project.org/doc/qt-4.7/stylesheet.html.
-   * @return The stylesheet to use
-   */
-  virtual QString configurationWidgetsStyleSheet() const;
+  virtual std::list<QWidget *> configurationWidgets() const;
 
   /**
     @brief Backup the state of the view.
@@ -206,7 +202,7 @@ public:
     @return The list of currently registered triggers.
     @see View::addRedrawTrigger()
     */
-  QSet<tlp::Observable *> triggers() const;
+  std::list<tlp::Observable *> triggers() const;
 
   /**
     @brief reimplemented from tlp::Observable to provide the triggers mechanism.
@@ -233,8 +229,9 @@ public:
   /**
    * @brief This method is called whenever the context menu is required on the view.
    * @param point The screen coordinates where the context menu should be displayed.
+    @return true or false whether the context menu has been shown or not
    */
-  void showContextMenu(const QPoint &point, const QPointF &scenePoint);
+  bool showContextMenu(const QPoint &point, const QPointF &scenePoint);
 
   /**
    * @brief This method allows to control the display of the context menu.
@@ -275,7 +272,7 @@ public slots:
     @brief defines the list of interactors available on this View
     @note Calling this will trigger the View::interactorsInstalled() callback for custom handling.
   */
-  virtual void setInteractors(const QList<tlp::Interactor *> &);
+  virtual void setInteractors(const std::list<tlp::Interactor *> &);
 
   /**
     @brief defines the active interactor that will receive user inputs.
@@ -404,12 +401,25 @@ signals:
 
   void interactorsChanged();
 
+protected:
+  /**
+    @brief Save view state associated to the current graph
+  */
+  void saveState();
+  /**
+   @brief retrieve the view saved state associated to the graph
+   @note if there is no saved state for the graph,
+   the saved state of the nearest parent graph which have a saved state
+   will be returned or an empty DataSet if not.
+   */
+  DataSet getState(Graph *graph);
+
 protected slots:
   /**
     @brief Callback method after setInteractors() was called.
     At this point, a call to View::interactors() is considered valid.
     */
-  virtual void interactorsInstalled(const QList<tlp::Interactor *> &interactors);
+  virtual void interactorsInstalled(const std::list<tlp::Interactor *> &interactors);
 
   /**
     @brief Callback method after setCurrentInteractor() was called.
