@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -23,6 +23,8 @@
 #include <tulip/tulipconf.h>
 #include <tulip/View.h>
 
+#include <QSet>
+
 class QGraphicsItem;
 
 namespace tlp {
@@ -66,6 +68,8 @@ public:
     */
   QGraphicsView *graphicsView() const override;
 
+  virtual void graphicsViewResized(int /* width */, int /* height */) {}
+
 public slots:
   /**
     @see View::setupUi
