@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -23,9 +23,9 @@
 
 #include <QWidget>
 #include <QMap>
-#include <QVector>
 
 #include <tulip/tulipconf.h>
+#include <tulip/Graph.h>
 
 class PlaceHolderWidget;
 
@@ -41,23 +41,20 @@ namespace tlp {
 class PluginProgress;
 class View;
 class WorkspacePanel;
-class Graph;
 class GraphHierarchiesModel;
 class TulipProject;
 
 class TLP_QT_SCOPE Workspace : public QWidget {
   Q_OBJECT
 
-  Q_PROPERTY(bool bottomFrameVisible READ isBottomFrameVisible WRITE setBottomFrameVisible)
-
   Ui::Workspace *_ui;
-  QList<WorkspacePanel *> _panels;
-  int _currentPanelIndex;
+  std::vector<WorkspacePanel *> _panels;
+  unsigned int _currentPanelIndex;
   QWidget *_oldWorkspaceMode;
   WorkspacePanel *_focusedPanel;
   bool _focusedPanelHighlighting;
 
-  QMap<QWidget *, QVector<PlaceHolderWidget *>> _modeToSlots;
+  QMap<QWidget *, std::vector<PlaceHolderWidget *>> _modeToSlots;
   QMap<QWidget *, QWidget *> _modeSwitches;
   GraphHierarchiesModel *_model;
   QAbstractButton *_exposeButton;
@@ -74,9 +71,7 @@ public:
   inline bool empty() const {
     return _panels.empty();
   }
-  QList<tlp::View *> panels() const;
-
-  bool isBottomFrameVisible() const;
+  std::vector<tlp::View *> panels() const;
 
 public slots:
   void delView(tlp::View *view);
@@ -112,7 +107,6 @@ public slots:
   void writeProject(tlp::TulipProject *, QMap<tlp::Graph *, QString>, tlp::PluginProgress *);
   void readProject(tlp::TulipProject *, QMap<QString, tlp::Graph *>, tlp::PluginProgress *);
 
-  void setBottomFrameVisible(bool);
   void setPageCountLabel(QLabel *l);
 
   void redrawPanels(bool center = false);
@@ -123,11 +117,14 @@ public slots:
 
   void setGraphForFocusedPanel(tlp::Graph *);
 
+  void setFocusedPanel(WorkspacePanel *panel);
+
 signals:
   void panelFocused(tlp::View *);
   void focusedPanelSynchronized();
   void addPanelRequest(tlp::Graph *g = nullptr);
   void importGraphRequest();
+  void panelsEmpty();
 
 protected slots:
   void viewNeedsDraw();
@@ -153,10 +150,8 @@ protected:
   bool eventFilter(QObject *, QEvent *) override;
 
   QWidget *currentModeWidget() const;
-  QVector<PlaceHolderWidget *> currentModeSlots() const;
+  std::vector<PlaceHolderWidget *> currentModeSlots() const;
   unsigned int currentSlotsCount() const;
-
-  void setFocusedPanel(WorkspacePanel *panel);
 };
 } // namespace tlp
 
