@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -78,6 +78,7 @@ public slots:
   void setOverlayMode(bool);
   void setHighlightMode(bool);
   bool isGraphSynchronized() const;
+  void showConfigurationTab(QString tabName);
 
 signals:
   void drawNeeded();
