@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -151,6 +151,9 @@ QVariant GraphPropertiesModel<PROPTYPE>::data(const QModelIndex &index, int role
 
   else if (role == Qt::FontRole) {
     QFont f;
+    QWidget *p = dynamic_cast<QWidget *>(QAbstractItemModel::parent());
+    if (p)
+      f = p->font();
 
     if (!_placeholder.isEmpty() && index.row() == 0)
       f.setItalic(true);
