@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -33,6 +33,7 @@
 #include <tulip/TlpQtTools.h>
 #include <tulip/TulipMetaTypes.h>
 #include <tulip/ScientificDoubleSpinBox.h>
+#include <tulip/Perspective.h>
 
 namespace tlp {
 
@@ -60,7 +61,7 @@ QWidget *NumberEditorCreator<T>::createWidget(QWidget *parent) const {
   } else if (typeid(T).name() == typeid(tlp::UnsignedIntegerType).name()) {
     dsb->setRange(0, UINT_MAX);
   } else if (typeid(T).name() == typeid(tlp::LongType).name()) {
-    dsb->setRange(-LONG_MAX, LONG_MAX);
+    dsb->setRange(static_cast<double>(-LONG_MAX), static_cast<double>(LONG_MAX));
   } else if (typeid(T).name() == typeid(tlp::FloatType).name()) {
     dsb->setRange(-FLT_MAX, FLT_MAX);
   } else {
@@ -104,7 +105,7 @@ QVariant LineEditEditorCreator<T>::editorData(QWidget *editor, tlp::Graph *) {
   typename T::RealType val;
 
   if (T::fromString(val, strVal))
-    result.setValue<typename T::RealType>(val);
+    result.setValue(val);
 
   return result;
 }
@@ -133,7 +134,7 @@ QVariant MultiLinesEditEditorCreator<T>::editorData(QWidget *editor, tlp::Graph
   typename T::RealType val;
 
   if (T::fromString(val, strVal))
-    result.setValue<typename T::RealType>(val);
+    result.setValue(val);
 
   return result;
 }
@@ -238,7 +239,9 @@ QString PropertyEditorCreator<PROPTYPE>::displayText(const QVariant &v) const {
 
 template <typename ElementType>
 QWidget *VectorEditorCreator<ElementType>::createWidget(QWidget *) const {
-  VectorEditor *w = new VectorEditor(nullptr);
+  VectorEditor *w = new VectorEditor(
+      tlp::Perspective::instance() ? tlp::Perspective::instance()->mainWindow()->centralWidget()
+                                   : nullptr);
   w->setWindowFlags(Qt::Dialog);
   w->setWindowModality(Qt::ApplicationModal);
   return w;
