@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -20,12 +20,6 @@
 #include "tulip/CSVGraphMappingConfigurationWidget.h"
 #include "ui_CSVGraphMappingConfigurationWidget.h"
 
-#include <QComboBox>
-#include <QFormLayout>
-#include <QLabel>
-#include <QPushButton>
-#include <QLineEdit>
-
 #include <tulip/CSVGraphImport.h>
 #include <tulip/PropertyCreationDialog.h>
 #include <tulip/Graph.h>
@@ -210,7 +204,7 @@ void CSVGraphMappingConfigurationWidget::selectProperties(const QString &title,
   }
 
   if (StringsListSelectionDialog::choose(title, graphProperties, selProperties, this)) {
-    if (selProperties.size() == 0) {
+    if (selProperties.empty()) {
       selProperties.push_back("viewLabel");
       button->setText("viewLabel");
     } else {
@@ -262,7 +256,7 @@ void CSVGraphMappingConfigurationWidget::selectColumns(const QString &title,
   }
 
   if (StringsListSelectionDialog::choose(title, tmpColumns, selColumns, this)) {
-    if (selColumns.size() == 0) {
+    if (selColumns.empty()) {
       columnIds.clear();
 
       for (unsigned int i = 0; i < columns.size(); ++i) {
