@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -33,6 +33,7 @@ void ClearableLineEdit::initPixmap() {
 ClearableLineEdit::ClearableLineEdit(QWidget *parent)
     : QLineEdit(parent), _clearButtonHovered(false) {
   setMouseTracking(true);
+  setProperty("clearableLineEdit", true);
 }
 
 void ClearableLineEdit::paintEvent(QPaintEvent *ev) {
