@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -18,13 +18,11 @@
  */
 
 #include <QFileDialog>
-#include <QHeaderView>
-#include <QLinearGradient>
 #include <QPainter>
 #include <QMessageBox>
 #include <QInputDialog>
 
-#include <algorithm>
+#include <map>
 #include <vector>
 
 #include <tulip/TlpQtTools.h>
@@ -44,6 +42,9 @@ map<QString, vector<Color>> ColorScaleConfigDialog::tulipImageColorScales;
 ColorScaleConfigDialog::ColorScaleConfigDialog(const ColorScale &colorScale, QWidget *parent)
     : QDialog(parent), _ui(new Ui::ColorScaleDialog), colorScale(colorScale) {
   _ui->setupUi(this);
+  // fix display of QCheckBox and QRadioButton children
+  tlpFixCBRBs(this);
+
   _ui->colorsTable->setColumnWidth(0, _ui->colorsTable->width());
   _ui->colorsTable->horizontalHeader()->setHidden(true);
   QPalette palette;
@@ -74,6 +75,12 @@ ColorScaleConfigDialog::ColorScaleConfigDialog(const ColorScale &colorScale, QWi
   connect(_ui->globalAlphaSB, SIGNAL(valueChanged(int)), this,
           SLOT(applyGlobalAlphaToColorScale()));
 
+  // relook colorbrewer html link
+  auto txt = _ui->colorbrewerLabel->text();
+  auto pos = txt.indexOf(" href=");
+  txt.insert(pos, " style=\"color:" HTML_LINK_COLOR "\"");
+  _ui->colorbrewerLabel->setText(txt);
+
   if (tulipImageColorScales.empty()) {
     loadTulipImageColorScales();
   }
@@ -358,7 +365,7 @@ void ColorScaleConfigDialog::saveCurrentColorScale() {
   if (ok && !text.isEmpty()) {
     if (savedColorScalesList.contains(text)) {
       QString question = "There is already a color scale saved under the name " + text +
-                         ". Do you want to owerwrite it ?";
+                         ". Do you want to overwrite it?";
 
       if (QMessageBox::question(this, "Color scale saving", question,
                                 QMessageBox::Yes | QMessageBox::No,
@@ -387,7 +394,7 @@ void ColorScaleConfigDialog::deleteSavedColorScale() {
     QString savedColorScaleId = _ui->savedColorScalesList->currentItem()->text();
 
     if (QMessageBox::question(
-            this, "Color scale deleting", "Delete saved color scale " + savedColorScaleId + " ?",
+            this, "Color scale deleting", "Delete saved color scale " + savedColorScaleId + "?",
             QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes) != QMessageBox::Yes) {
       return;
     }
