@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -19,8 +19,6 @@
 
 #include "tulip/GlOverviewGraphicsItem.h"
 
-#include <QMenu>
-#include <QMessageBox>
 #include <QGraphicsSceneMouseEvent>
 #include <QPen>
 
