@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -19,10 +19,7 @@
 
 #include <tulip/GraphElementModel.h>
 #include <tulip/TulipMetaTypes.h>
-#include <QFont>
-
 #include <tulip/Graph.h>
-#include <tulip/FilterIterator.h>
 
 using namespace tlp;
 using namespace std;
@@ -91,8 +88,8 @@ Qt::ItemFlags GraphElementModel::flags(const QModelIndex &index) const {
 #endif
 }
 
-QVector<PropertyInterface *> GraphElementModel::getGraphProperties() const {
-  QVector<PropertyInterface *> properties;
+std::vector<PropertyInterface *> GraphElementModel::getGraphProperties() const {
+  std::vector<PropertyInterface *> properties;
   for (PropertyInterface *prop : _graph->getObjectProperties()) {
     auto propName = prop->getName();
     // an empty set indicates that all the properties are visible
@@ -102,7 +99,7 @@ QVector<PropertyInterface *> GraphElementModel::getGraphProperties() const {
     if (propName == "viewMetaGraph")
       continue;
 #endif
-    properties.append(prop);
+    properties.push_back(prop);
   }
   return properties;
 }
