@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -22,7 +22,6 @@
 
 #include <QIcon>
 
-#include <tulip/BooleanProperty.h>
 #include <tulip/Graph.h>
 #include <tulip/TulipMetaTypes.h>
 #include <tulip/TlpQtTools.h>
@@ -123,18 +122,18 @@ QVariant GraphModel::headerData(int section, Qt::Orientation orientation, int ro
     else if (role == TulipModel::PropertyRole)
       return QVariant::fromValue<PropertyInterface *>(prop);
     else if (role == Qt::ToolTipRole) {
-      return QString(_graph->existLocalProperty(prop->getName()) ? "local " : "inherited ")
-          .append("property \"")
+      auto defVal = isNode() ? _graph->getProperty(prop->getName())->getNodeDefaultStringValue()
+                             : _graph->getProperty(prop->getName())->getEdgeDefaultStringValue();
+      if (defVal.empty())
+        defVal = "\"\"";
+      return QString(_graph->existLocalProperty(prop->getName()) ? "Local " : "Inherited ")
+          .append("property <b>")
           .append(tlpStringToQString(prop->getName()))
-          .append("\" of type ")
+          .append("</b><br/>type: <b>")
           .append(tlpStringToQString(prop->getTypename()))
-          .append("\ndefault ")
+          .append("</b><br/>default ")
           .append(isNode() ? "node value: " : "edge value: ")
-          .append(isNode()
-                      ? tlpStringToQString(
-                            _graph->getProperty(prop->getName())->getNodeDefaultStringValue())
-                      : tlpStringToQString(
-                            _graph->getProperty(prop->getName())->getEdgeDefaultStringValue()));
+          .append(QString("<b>%1</b>").arg(defVal.c_str()));
     }
   }
 
@@ -317,11 +316,8 @@ QVariant GraphModel::nodeValue(unsigned int id, PropertyInterface *prop) {
         tlpStringToQString(static_cast<StringProperty *>(prop)->getNodeValue(n)));
   } else if (dynamic_cast<BooleanVectorProperty *>(prop) != nullptr) {
     const auto &vb = static_cast<BooleanVectorProperty *>(prop)->getNodeValue(n);
-#if (QT_VERSION < QT_VERSION_CHECK(5, 14, 0))
-    return QVariant::fromValue<QVector<bool>>(QVector<bool>::fromStdVector(vb));
-#else
+
     return QVariant::fromValue<QVector<bool>>(QVector<bool>(vb.begin(), vb.end()));
-#endif
   }
 
   STANDARD_NODE_CHECKS(GET_NODE_VALUE)
@@ -360,11 +356,8 @@ QVariant GraphModel::nodeDefaultValue(PropertyInterface *prop) {
         tlpStringToQString(static_cast<StringProperty *>(prop)->getNodeDefaultValue()));
   } else if (dynamic_cast<BooleanVectorProperty *>(prop) != nullptr) {
     const auto &vb = static_cast<BooleanVectorProperty *>(prop)->getNodeDefaultValue();
-#if (QT_VERSION < QT_VERSION_CHECK(5, 14, 0))
-    return QVariant::fromValue<QVector<bool>>(QVector<bool>::fromStdVector(vb));
-#else
+
     return QVariant::fromValue<QVector<bool>>(QVector<bool>(vb.begin(), vb.end()));
-#endif
   }
 
   STANDARD_NODE_CHECKS(GET_NODE_DEFAULT_VALUE)
@@ -539,11 +532,8 @@ QVariant GraphModel::edgeValue(unsigned int id, PropertyInterface *prop) {
         tlpStringToQString(static_cast<StringProperty *>(prop)->getEdgeValue(e)));
   } else if (dynamic_cast<BooleanVectorProperty *>(prop) != nullptr) {
     const auto &vb = static_cast<BooleanVectorProperty *>(prop)->getEdgeValue(e);
-#if (QT_VERSION < QT_VERSION_CHECK(5, 14, 0))
-    return QVariant::fromValue<QVector<bool>>(QVector<bool>::fromStdVector(vb));
-#else
+
     return QVariant::fromValue<QVector<bool>>(QVector<bool>(vb.begin(), vb.end()));
-#endif
   }
 
   STANDARD_EDGE_CHECKS(GET_EDGE_VALUE)
@@ -592,11 +582,8 @@ QVariant GraphModel::edgeDefaultValue(PropertyInterface *prop) {
         tlpStringToQString(static_cast<StringProperty *>(prop)->getEdgeDefaultValue()));
   } else if (dynamic_cast<BooleanVectorProperty *>(prop) != nullptr) {
     const auto &vb = static_cast<BooleanVectorProperty *>(prop)->getEdgeDefaultValue();
-#if (QT_VERSION < QT_VERSION_CHECK(5, 14, 0))
-    return QVariant::fromValue<QVector<bool>>(QVector<bool>::fromStdVector(vb));
-#else
+
     return QVariant::fromValue<QVector<bool>>(QVector<bool>(vb.begin(), vb.end()));
-#endif
   }
 
   STANDARD_EDGE_CHECKS(GET_EDGE_DEFAULT_VALUE)
@@ -874,11 +861,10 @@ bool GraphSortFilterProxyModel::filterAcceptsRow(int sourceRow, const QModelInde
   if (!selected)
     return false;
 
-  if (filterRegExp().isEmpty())
+  if (filterRegularExpression().pattern().isEmpty())
     return true;
-
   for (auto pi : _properties) {
-    if (graphModel->stringValue(id, pi).contains(filterRegExp()))
+    if (graphModel->stringValue(id, pi).contains(filterRegularExpression()))
       return true;
   }
 
@@ -1058,7 +1044,7 @@ void NodesGraphModel::treatEvent(const Event &ev) {
           _elementsToModify.remove(wasDeleted);
         }
       }
-    } else if (graphEv->getType() == GraphEvent::TLP_DEL_NODE) {
+    } else if (graphEv->getType() == GraphEvent::TLP_AFTER_DEL_NODE) {
       _nodesRemoved = true;
       // if the node was added then deleted before the call to Observable::unholdObservers(), remove
       // it from the elementsToModify list as no update has to be performed in the model for that
@@ -1090,7 +1076,8 @@ void NodesGraphModel::treatEvents(const std::vector<tlp::Event> &events) {
 QVariant NodesGraphModel::headerData(int section, Qt::Orientation orientation, int role) const {
   if (orientation == Qt::Vertical) {
     if (role == Qt::ToolTipRole && (section >= 0 && section < _elements.size())) {
-      return getNodeTooltip(_graph, node(_elements[section]));
+      node n(_elements[section]);
+      return getNodeTooltip(_graph, n);
     }
   }
 
@@ -1102,10 +1089,11 @@ QString NodesGraphModel::getNodeTooltip(Graph *graph, node n) {
   return QString("<b>Node #")
       .append(QString::number(n.id))
       .append(label.empty() ? "</b>" : "</b> (<b><i>" + tlpStringToQString(label) + "</i></b>)")
-      .append("\ninput degree: ")
+      .append("<br/>input degree: <b>")
       .append(QString::number(graph->indeg(n)))
-      .append("\noutput degree: ")
-      .append(QString::number(graph->outdeg(n)));
+      .append("</b><br/>output degree: <b>")
+      .append(QString::number(graph->outdeg(n)))
+      .append("</b>");
 }
 
 void EdgesGraphModel::treatEvent(const Event &ev) {
@@ -1148,7 +1136,7 @@ void EdgesGraphModel::treatEvent(const Event &ev) {
           _elementsToModify.remove(wasDeleted);
         }
       }
-    } else if (graphEv->getType() == GraphEvent::TLP_DEL_EDGE) {
+    } else if (graphEv->getType() == GraphEvent::TLP_AFTER_DEL_EDGE) {
       _edgesRemoved = true;
       // if the edge was added then deleted before the call to Observable::unholdObservers(), remove
       // it from the elementsToModify list as no update has to be performed in the model for that
@@ -1179,7 +1167,7 @@ void EdgesGraphModel::treatEvents(const std::vector<tlp::Event> &events) {
 QVariant EdgesGraphModel::headerData(int section, Qt::Orientation orientation, int role) const {
   if (orientation == Qt::Vertical) {
     if (role == Qt::ToolTipRole && (section >= 0 && section < _elements.size())) {
-      edge e = edge(_elements[section]);
+      edge e(_elements[section]);
       return getEdgeTooltip(_graph, e);
     }
   }
@@ -1197,10 +1185,10 @@ QString EdgesGraphModel::getEdgeTooltip(Graph *graph, edge e) {
   return QString("<b>Edge #")
       .append(QString::number(e.id))
       .append(label.empty() ? "</b>" : "</b> (<b><i>" + tlpStringToQString(label) + ")</b>")
-      .append("\nsource: <b>node #")
+      .append("<br/>source: <b>node #")
       .append(QString::number(extremities.first.id))
       .append(sourceLabel.empty() ? "</b>" : "</b> (" + tlpStringToQString(sourceLabel) + ")")
-      .append("\ntarget: <b>node #")
+      .append("<br/>target: <b>node #")
       .append(QString::number(extremities.second.id))
       .append(targetLabel.empty() ? "</b>" : "</b> (" + tlpStringToQString(targetLabel) + ")");
 }
