@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -20,8 +20,6 @@
 #include "tulip/GraphPropertiesSelectionWidget.h"
 #include "tulip/Graph.h"
 
-#include <algorithm>
-
 using namespace std;
 
 namespace tlp {
@@ -70,7 +68,7 @@ void GraphPropertiesSelectionWidget::initWidget() {
 bool GraphPropertiesSelectionWidget::propertySelectable(const std::string &propertyName) {
   bool selectProperty = false;
 
-  if (propertiesTypes.size() > 0) {
+  if (!propertiesTypes.empty()) {
     string propertyType = graph->getProperty(propertyName)->getTypename();
 
     if (std::find(propertiesTypes.begin(), propertiesTypes.end(), propertyType) !=
@@ -89,7 +87,8 @@ bool GraphPropertiesSelectionWidget::propertySelectable(const std::string &prope
   return selectProperty;
 }
 
-void GraphPropertiesSelectionWidget::setInputPropertiesList(vector<string> &inputPropertiesList) {
+void GraphPropertiesSelectionWidget::setInputPropertiesList(
+    const vector<string> &inputPropertiesList) {
   vector<string> inputPropertiesListFiltered;
 
   for (unsigned int i = 0; i < inputPropertiesList.size(); ++i) {
@@ -101,7 +100,8 @@ void GraphPropertiesSelectionWidget::setInputPropertiesList(vector<string> &inpu
   setUnselectedStringsList(inputPropertiesListFiltered);
 }
 
-void GraphPropertiesSelectionWidget::setOutputPropertiesList(vector<string> &outputPropertiesList) {
+void GraphPropertiesSelectionWidget::setOutputPropertiesList(
+    const vector<string> &outputPropertiesList) {
   vector<string> outputPropertiesListFiltered;
 
   for (unsigned int i = 0; i < outputPropertiesList.size(); ++i) {
