@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -16,13 +16,12 @@
  * See the GNU General Public License for more details.
  *
  */
-#include <tulip/GraphTableItemDelegate.h>
+#include <QPainter>
 
-#include <QDebug>
+#include <tulip/GraphTableItemDelegate.h>
 
 #include <tulip/GraphModel.h>
 #include <tulip/DoubleProperty.h>
-#include <tulip/TulipMetaTypes.h>
 
 using namespace tlp;
 using namespace std;
@@ -33,7 +32,7 @@ void GraphTableItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem
                                    const QModelIndex &index) const {
   PropertyInterface *pi = index.data(TulipModel::PropertyRole).value<PropertyInterface *>();
 
-  if (index.data().type() == QVariant::Double && dynamic_cast<DoubleProperty *>(pi) != nullptr) {
+  if (index.data().canConvert<double>() && dynamic_cast<DoubleProperty *>(pi) != nullptr) {
     DoubleProperty *prop = static_cast<DoubleProperty *>(pi);
     double value = index.data().value<double>();
     double min = 0, max = 0;
