@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -16,7 +16,7 @@
  * See the GNU General Public License for more details.
  *
  */
-#include <algorithm>
+#include <QWidget>
 
 #include <tulip/Interactor.h>
 #include <tulip/PluginLister.h>
@@ -25,8 +25,8 @@
 using namespace std;
 using namespace tlp;
 
-QMap<std::string, QList<std::string>> InteractorLister::_compatibilityMap =
-    QMap<std::string, QList<std::string>>();
+QMap<std::string, std::list<std::string>> InteractorLister::_compatibilityMap =
+    QMap<std::string, std::list<std::string>>();
 
 bool interactorLessThan(Interactor *a, Interactor *b) {
   return a->priority() > b->priority();
@@ -47,19 +47,18 @@ void InteractorLister::initInteractorsDependencies() {
   std::list<std::string> views(PluginLister::availablePlugins<View>());
 
   for (const std::string &viewName : views) {
-    QList<Interactor *> compatibleInteractors;
+    std::list<Interactor *> compatibleInteractors;
 
     for (auto i : interactorToName.keys()) {
       if (i->isCompatible(viewName))
-        compatibleInteractors << i;
+        compatibleInteractors.push_back(i);
     }
+    compatibleInteractors.sort(interactorLessThan);
 
-    std::sort(compatibleInteractors.begin(), compatibleInteractors.end(), interactorLessThan);
-
-    QList<string> compatibleNames;
+    std::list<string> compatibleNames;
 
     for (auto i : compatibleInteractors)
-      compatibleNames << interactorToName[i];
+      compatibleNames.push_back(interactorToName[i]);
 
     _compatibilityMap[viewName] = compatibleNames;
   }
@@ -68,6 +67,10 @@ void InteractorLister::initInteractorsDependencies() {
     delete i;
 }
 
-QList<string> InteractorLister::compatibleInteractors(const std::string &viewName) {
+std::list<string> InteractorLister::compatibleInteractors(const std::string &viewName) {
   return _compatibilityMap[viewName];
 }
+
+void Interactor::setupConfigWidget(QWidget *w) {
+  w->setObjectName("interactorConfigWidget");
+}
