@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -79,6 +79,13 @@ void InteractorComposite::setView(tlp::View *view) {
     i->setView(view);
 }
 
+bool InteractorComposite::showContextMenu(const QPoint &point, const QPointF &scenePoint) {
+  for (auto i : _components)
+    if (i->showContextMenu(point, scenePoint))
+      return true;
+  return false;
+}
+
 InteractorComposite::iterator InteractorComposite::begin() {
   return _components.begin();
 }
