@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -78,7 +78,7 @@ bool MouseEdgeBendEditor::eventFilter(QObject *widget, QEvent *e) {
   if (e->type() == QEvent::MouseButtonDblClick && qMouseEv->button() == Qt::LeftButton &&
       haveSelection(glMainWidget)) {
     _operation = NEW_OP;
-    mMouseCreate(qMouseEv->x(), qMouseEv->y(), glMainWidget);
+    mMouseCreate(qMouseEv->pos().x(), qMouseEv->pos().y(), glMainWidget);
     return true;
   }
 
@@ -89,8 +89,8 @@ bool MouseEdgeBendEditor::eventFilter(QObject *widget, QEvent *e) {
     initProxies(glMainWidget);
     bool hasSelection = haveSelection(glMainWidget);
 
-    editPosition[0] = qMouseEv->x();
-    editPosition[1] = qMouseEv->y();
+    editPosition[0] = qMouseEv->pos().x();
+    editPosition[1] = qMouseEv->pos().y();
     editPosition[2] = 0;
 
     switch (qMouseEv->buttons()) {
@@ -102,15 +102,19 @@ bool MouseEdgeBendEditor::eventFilter(QObject *widget, QEvent *e) {
         // which should intercept the event
         _operation = NONE_OP;
       } else {
-
+        vector<SelectedEntity> selectedEntities;
         bool entityIsSelected = glMainWidget->pickGlEntities(
-            int(editPosition[0]) - 3, int(editPosition[1]) - 3, 6, 6, select, layer);
+            int(editPosition[0]) - 3, int(editPosition[1]) - 3, 6, 6, selectedEntities, layer);
 
         if (!entityIsSelected) {
           // We have click outside an entity
           _operation = NONE_OP;
         } else {
-          selectedEntity = circleString->findKey(select[0].getSimpleEntity());
+          for (const auto &entity : selectedEntities) {
+            selectedEntity = circleString->findKey(entity.getSimpleEntity());
+            if (!selectedEntity.empty())
+              break;
+          }
 
           if (qMouseEv->modifiers() &
 #if defined(__APPLE__)
@@ -135,7 +139,9 @@ bool MouseEdgeBendEditor::eventFilter(QObject *widget, QEvent *e) {
       break;
     }
 
-    default: { return false; }
+    default: {
+      return false;
+    }
     }
 
     glMainWidget->redraw();
@@ -148,7 +154,7 @@ bool MouseEdgeBendEditor::eventFilter(QObject *widget, QEvent *e) {
     if (selectedEntity == "targetTriangle") {
       SelectedEntity selectedEntity;
 
-      if (glMainWidget->pickNodesEdges(qMouseEv->x(), qMouseEv->y(), selectedEntity) &&
+      if (glMainWidget->pickNodesEdges(qMouseEv->pos().x(), qMouseEv->pos().y(), selectedEntity) &&
           selectedEntity.getEntityType() == SelectedEntity::NODE_SELECTED) {
         _graph->setEnds(
             mEdge, glMainWidget->getScene()->getGlGraphComposite()->getGraph()->ends(mEdge).first,
@@ -165,7 +171,7 @@ bool MouseEdgeBendEditor::eventFilter(QObject *widget, QEvent *e) {
     } else if (selectedEntity == "sourceCircle") {
       SelectedEntity selectedEntity;
 
-      if (glMainWidget->pickNodesEdges(qMouseEv->x(), qMouseEv->y(), selectedEntity) &&
+      if (glMainWidget->pickNodesEdges(qMouseEv->pos().x(), qMouseEv->pos().y(), selectedEntity) &&
           selectedEntity.getEntityType() == SelectedEntity::NODE_SELECTED) {
         _graph->setEnds(
             mEdge, node(selectedEntity.getComplexEntityId()),
@@ -189,7 +195,7 @@ bool MouseEdgeBendEditor::eventFilter(QObject *widget, QEvent *e) {
 
   if (e->type() == QEvent::MouseButtonPress) {
     vector<SelectedEntity> selectedEntities;
-    glMainWidget->pickGlEntities(qMouseEv->x(), qMouseEv->y(), selectedEntities);
+    glMainWidget->pickGlEntities(qMouseEv->pos().x(), qMouseEv->pos().y(), selectedEntities);
 
     if (!selectedEntities.empty())
       if (selectedEntities[0].getEntityType() == SelectedEntity::SIMPLE_ENTITY_SELECTED)
@@ -201,7 +207,7 @@ bool MouseEdgeBendEditor::eventFilter(QObject *widget, QEvent *e) {
 
   if (e->type() == QEvent::MouseButtonRelease) {
     vector<SelectedEntity> selectedEntities;
-    glMainWidget->pickGlEntities(qMouseEv->x(), qMouseEv->y(), selectedEntities);
+    glMainWidget->pickGlEntities(qMouseEv->pos().x(), qMouseEv->pos().y(), selectedEntities);
 
     if (!selectedEntities.empty())
       if (selectedEntities[0].getEntityType() == SelectedEntity::SIMPLE_ENTITY_SELECTED)
@@ -219,19 +225,23 @@ bool MouseEdgeBendEditor::eventFilter(QObject *widget, QEvent *e) {
 
       switch (_operation) {
       case TRANSLATE_OP:
-        mMouseTranslate(qMouseEv->x(), qMouseEv->y(), glMainWidget);
+        mMouseTranslate(qMouseEv->pos().x(), qMouseEv->pos().y(), glMainWidget);
         return true;
 
       default:
         return false;
       }
     } else if (qMouseEv->buttons() == Qt::NoButton) {
-      SelectedEntity selectedEntity;
       GlMainWidget *g = static_cast<GlMainWidget *>(widget);
+      vector<SelectedEntity> selectedEntities;
 
-      if (g->pickNodesEdges(qMouseEv->x(), qMouseEv->y(), selectedEntity) &&
-          selectedEntity.getEntityType() == SelectedEntity::NODE_SELECTED) {
-        g->setCursor(Qt::CrossCursor);
+      if (g->pickGlEntities(qMouseEv->pos().x(), qMouseEv->pos().y(), selectedEntities)) {
+        for (const auto &entity : selectedEntities) {
+          if (!circleString->findKey(entity.getSimpleEntity()).empty()) {
+            g->setCursor(Qt::CrossCursor);
+            break;
+          }
+        }
       } else {
         g->setCursor(Qt::ArrowCursor);
       }
@@ -301,7 +311,8 @@ void MouseEdgeBendEditor::initProxies(GlMainWidget *glMainWidget) {
 }
 //========================================================================================
 // Does the point p belong to the segment [u,v]?
-bool MouseEdgeBendEditor::belong(Coord u, Coord v, Coord p, GlMainWidget *glMainWidget) {
+bool MouseEdgeBendEditor::belong(const Coord &u, const Coord &v, const Coord &p,
+                                 GlMainWidget *glMainWidget) {
   int W = glMainWidget->screenToViewport(glMainWidget->width());
   int H = glMainWidget->screenToViewport(glMainWidget->height());
   Coord m = glMainWidget->getScene()->getLayer("Main")->getCamera().worldTo2DViewport(u);
@@ -325,20 +336,11 @@ void MouseEdgeBendEditor::mMouseTranslate(int newX, int newY, GlMainWidget *glMa
       glMainWidget->screenToViewport(v0));
   v1 = glMainWidget->getScene()->getLayer("Main")->getCamera().viewportTo3DWorld(
       glMainWidget->screenToViewport(v1));
-  v1 -= v0;
 
-  if (selectedEntity == "targetTriangle") {
-    targetTriangle.translate(Coord(-glMainWidget->screenToViewport(editPosition[0] - newX),
-                                   glMainWidget->screenToViewport(editPosition[1] - newY), 0));
-    glMainWidget->draw(false);
-  } else if (selectedEntity == "sourceCircle") {
-    sourceCircle.translate(Coord(-glMainWidget->screenToViewport(editPosition[0] - newX),
-                                 glMainWidget->screenToViewport(editPosition[1] - newY), 0));
-    glMainWidget->draw(false);
-  } else {
-    int i;
-    IntegerType::fromString(i, selectedEntity);
-    coordinates[i] += v1;
+  int i;
+  if (IntegerType::fromString(i, selectedEntity)) {
+    coordinates[i] += v1 - v0;
+
     Observable::holdObservers();
 
     if (edgeSelected)
@@ -347,6 +349,15 @@ void MouseEdgeBendEditor::mMouseTranslate(int newX, int newY, GlMainWidget *glMa
       _coordsVectorProperty->setNodeValue(mNode, coordinates);
 
     Observable::unholdObservers();
+  } else {
+    if (selectedEntity == "targetTriangle") {
+      targetTriangle.translate(Coord(-glMainWidget->screenToViewport(editPosition[0] - newX),
+                                     glMainWidget->screenToViewport(editPosition[1] - newY), 0));
+    } else /* (selectedEntity == "sourceCircle") */ {
+      sourceCircle.translate(Coord(-glMainWidget->screenToViewport(editPosition[0] - newX),
+                                   glMainWidget->screenToViewport(editPosition[1] - newY), 0));
+    }
+    glMainWidget->draw(false);
   }
 
   editPosition[0] = newX;
@@ -354,9 +365,8 @@ void MouseEdgeBendEditor::mMouseTranslate(int newX, int newY, GlMainWidget *glMa
 }
 //========================================================================================
 void MouseEdgeBendEditor::mMouseDelete() {
-  if (selectedEntity != "targetTriangle" && selectedEntity != "sourceCircle") {
-    int i;
-    IntegerType::fromString(i, selectedEntity);
+  int i;
+  if (IntegerType::fromString(i, selectedEntity)) {
     vector<Coord>::iterator CoordIt = coordinates.begin();
     vector<tlp::GlCircle>::iterator circleIt = circles.begin();
     int tmp = 0;
@@ -520,7 +530,6 @@ bool MouseEdgeBendEditor::computeBendsCircles(GlMainWidget *glMainWidget) {
 
   coordinates.clear();
   circles.clear();
-  select.clear();
 
   if (circleString)
     circleString->reset(false);
