@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -17,19 +17,10 @@
  *
  */
 
-#include <QEvent>
-#include <QWheelEvent>
 #include <QPinchGesture>
-#include <QPanGesture>
 
-#include <tulip/GlNode.h>
-#include <tulip/GlMainWidget.h>
-#include <tulip/View.h>
-#include <tulip/Observable.h>
 #include <tulip/GlGraphComposite.h>
-#include <tulip/GlMainView.h>
 #include <tulip/GlBoundingBoxSceneVisitor.h>
-#include <tulip/DrawingTools.h>
 #include <tulip/QtGlSceneZoomAndPanAnimator.h>
 #include <tulip/NodeLinkDiagramComponent.h>
 #include <tulip/MouseInteractors.h>
@@ -42,16 +33,18 @@ using namespace std;
 //===============================================================
 bool MousePanNZoomNavigator::eventFilter(QObject *widget, QEvent *e) {
 // according to Qt's doc, this constant has been defined by wheel mouse vendors
-// we need it to interpret the value of QWheelEvent->delta()
+// we need it to interpret the value of QWheelEvent->angleDelta()
 #define WHEEL_DELTA 120
   GlMainWidget *g = static_cast<GlMainWidget *>(widget);
 
   if (e->type() == QEvent::Wheel) {
     QWheelEvent *we = static_cast<QWheelEvent *>(e);
 
-    if (we->orientation() == Qt::Vertical && we->modifiers() == Qt::NoModifier) {
-      g->getScene()->zoomXY(g->screenToViewport(we->delta()) / WHEEL_DELTA,
-                            g->screenToViewport(we->x()), g->screenToViewport(we->y()));
+    auto vDelta = we->angleDelta().y();
+    if (vDelta != 0 && we->modifiers() == Qt::NoModifier) {
+      auto wePos = we->position();
+      g->getScene()->zoomXY(g->screenToViewport(vDelta) / WHEEL_DELTA,
+                            g->screenToViewport(wePos.x()), g->screenToViewport(wePos.y()));
       g->draw(false);
       return true;
     }
@@ -59,7 +52,6 @@ bool MousePanNZoomNavigator::eventFilter(QObject *widget, QEvent *e) {
 
   if (e->type() == QEvent::Gesture) {
     QGestureEvent *gesture = static_cast<QGestureEvent *>(e);
-    QPointF center;
     // swipe events and pan events are never fired, known Qt bug
     /*if(gesture->gesture(Qt::SwipeGesture)) {
       QSwipeGesture* swipe = (QSwipeGesture*)gesture->gesture(Qt::SwipeGesture);
@@ -120,7 +112,6 @@ bool MousePanNZoomNavigator::eventFilter(QObject *widget, QEvent *e) {
           isGesturing = false;
         }
 
-        center = pan->delta();
         g->getScene()->translateCamera(g->screenToViewport(pan->delta().x()),
                                        -g->screenToViewport(pan->delta().y()), 0);
       }
@@ -159,7 +150,7 @@ bool MouseElementDeleter::eventFilter(QObject *widget, QEvent *e) {
       glMainWidget = static_cast<GlMainWidget *>(widget);
 
     if (e->type() == QEvent::MouseMove) {
-      if (glMainWidget->pickNodesEdges(qMouseEv->x(), qMouseEv->y(), selectedEntity)) {
+      if (glMainWidget->pickNodesEdges(qMouseEv->pos().x(), qMouseEv->pos().y(), selectedEntity)) {
         glMainWidget->setCursor(QCursor(QPixmap(":/tulip/gui/icons/i_del.png")));
       } else {
         glMainWidget->setCursor(Qt::ArrowCursor);
@@ -167,7 +158,7 @@ bool MouseElementDeleter::eventFilter(QObject *widget, QEvent *e) {
 
       return false;
     } else if (e->type() == QEvent::MouseButtonPress && qMouseEv->button() == Qt::LeftButton) {
-      if (glMainWidget->pickNodesEdges(qMouseEv->x(), qMouseEv->y(), selectedEntity)) {
+      if (glMainWidget->pickNodesEdges(qMouseEv->pos().x(), qMouseEv->pos().y(), selectedEntity)) {
         Observable::holdObservers();
         Graph *graph = glMainWidget->getScene()->getGlGraphComposite()->getInputData()->getGraph();
         // allow to undo
@@ -200,8 +191,8 @@ public:
 bool MouseRotXRotY::eventFilter(QObject *widget, QEvent *e) {
   if (e->type() == QEvent::MouseButtonPress) {
     QMouseEvent *qMouseEv = static_cast<QMouseEvent *>(e);
-    x = qMouseEv->x();
-    y = qMouseEv->y();
+    x = qMouseEv->pos().x();
+    y = qMouseEv->pos().y();
     return true;
   }
 
@@ -209,8 +200,8 @@ bool MouseRotXRotY::eventFilter(QObject *widget, QEvent *e) {
     QMouseEvent *qMouseEv = static_cast<QMouseEvent *>(e);
     GlMainWidget *glMainWidget = static_cast<GlMainWidget *>(widget);
     int deltaX, deltaY;
-    deltaX = qMouseEv->x() - x;
-    deltaY = qMouseEv->y() - y;
+    deltaX = qMouseEv->pos().x() - x;
+    deltaY = qMouseEv->pos().y() - y;
 
     if (abs(deltaX) > abs(deltaY))
       deltaY = 0;
@@ -223,8 +214,8 @@ bool MouseRotXRotY::eventFilter(QObject *widget, QEvent *e) {
     if (deltaX != 0)
       glMainWidget->getScene()->rotateCamera(0, glMainWidget->screenToViewport(deltaX), 0);
 
-    x = qMouseEv->x();
-    y = qMouseEv->y();
+    x = qMouseEv->pos().x();
+    y = qMouseEv->pos().y();
     glMainWidget->draw(false);
     return true;
   }
@@ -244,8 +235,8 @@ public:
 bool MouseZoomRotZ::eventFilter(QObject *widget, QEvent *e) {
   if (e->type() == QEvent::MouseButtonPress) {
     QMouseEvent *qMouseEv = static_cast<QMouseEvent *>(e);
-    x = qMouseEv->x();
-    y = qMouseEv->y();
+    x = qMouseEv->pos().x();
+    y = qMouseEv->pos().y();
     inRotation = false;
     inZoom = false;
     return true;
@@ -257,8 +248,8 @@ bool MouseZoomRotZ::eventFilter(QObject *widget, QEvent *e) {
     int deltaX, deltaY;
 
     if (!inRotation && !inZoom) {
-      deltaX = qMouseEv->x() - x;
-      deltaY = qMouseEv->y() - y;
+      deltaX = qMouseEv->pos().x() - x;
+      deltaY = qMouseEv->pos().y() - y;
 
       if (deltaY && abs(deltaX) >= 3 * abs(deltaY)) {
         inRotation = true;
@@ -269,22 +260,22 @@ bool MouseZoomRotZ::eventFilter(QObject *widget, QEvent *e) {
       } else {
       }
 
-      x = qMouseEv->x();
-      y = qMouseEv->y();
+      x = qMouseEv->pos().x();
+      y = qMouseEv->pos().y();
     }
 
     if (inZoom) {
       // Zoom
-      deltaY = qMouseEv->y() - y;
+      deltaY = qMouseEv->pos().y() - y;
       glMainWidget->getScene()->zoom(-glMainWidget->screenToViewport(deltaY / 2));
-      y = qMouseEv->y();
+      y = qMouseEv->pos().y();
     }
 
     if (inRotation) {
       // Rotation
-      deltaX = qMouseEv->x() - x;
+      deltaX = qMouseEv->pos().x() - x;
       glMainWidget->getScene()->rotateCamera(0, 0, glMainWidget->screenToViewport(deltaX));
-      x = qMouseEv->x();
+      x = qMouseEv->pos().x();
     }
 
     glMainWidget->draw(false);
@@ -305,8 +296,8 @@ public:
 bool MouseMove::eventFilter(QObject *widget, QEvent *e) {
   if (e->type() == QEvent::MouseButtonPress) {
     QMouseEvent *qMouseEv = static_cast<QMouseEvent *>(e);
-    x = qMouseEv->x();
-    y = qMouseEv->y();
+    x = qMouseEv->pos().x();
+    y = qMouseEv->pos().y();
     return true;
   }
 
@@ -314,17 +305,16 @@ bool MouseMove::eventFilter(QObject *widget, QEvent *e) {
     QMouseEvent *qMouseEv = static_cast<QMouseEvent *>(e);
     GlMainWidget *glMainWidget = static_cast<GlMainWidget *>(widget);
 
-    if (qMouseEv->x() != x)
-      glMainWidget->getScene()->translateCamera(glMainWidget->screenToViewport(qMouseEv->x() - x),
-                                                0, 0);
-
-    if (qMouseEv->y() != y)
-      glMainWidget->getScene()->translateCamera(
-          0, glMainWidget->screenToViewport(y - qMouseEv->y()), 0);
-
-    x = qMouseEv->x();
-    y = qMouseEv->y();
-    glMainWidget->draw(false);
+    auto dx = qMouseEv->pos().x() - x;
+    auto dy = y - qMouseEv->pos().y();
+    if (dx || dy) {
+      glMainWidget->getScene()->translateCamera(glMainWidget->screenToViewport(dx),
+                                                glMainWidget->screenToViewport(dy), 0);
+      glMainWidget->setCursor(QCursor(Qt::ClosedHandCursor));
+      glMainWidget->draw(false);
+    }
+    x = qMouseEv->pos().x();
+    y = qMouseEv->pos().y();
     return true;
   }
 
@@ -378,16 +368,21 @@ bool MouseNKeysNavigator::eventFilter(QObject *widget, QEvent *e) {
   GlMainWidget *glmainwidget = static_cast<GlMainWidget *>(widget);
   QMouseEvent *qMouseEv = static_cast<QMouseEvent *>(e);
 
-  if (e->type() == QEvent::MouseButtonDblClick && qMouseEv->button() == Qt::LeftButton) {
-    if (mouseNavigationDisabled)
-      return false;
+  // check for meta node navigation (double mouse left click)
+  // only available for NodeLinkDiagram view
+  if ((mouseNavigationEnabled && e->type() == QEvent::MouseButtonDblClick) &&
+      (qMouseEv->button() == Qt::LeftButton) &&
+      (view()->name() == NodeLinkDiagramComponent::viewName)) {
 
     Graph *graph = glmainwidget->getScene()->getGlGraphComposite()->getInputData()->getGraph();
 
-    if (qMouseEv->modifiers() != Qt::ControlModifier) {
+    if (qMouseEv->modifiers() == Qt::NoModifier ||
+        // used to ease the meta node navigation
+        qMouseEv->modifiers() == Qt::ShiftModifier) {
       vector<SelectedEntity> tmpNodes;
       vector<SelectedEntity> tmpEdges;
-      glmainwidget->pickNodesEdges(qMouseEv->x() - 1, qMouseEv->y() - 1, 3, 3, tmpNodes, tmpEdges);
+      glmainwidget->pickNodesEdges(qMouseEv->pos().x() - 1, qMouseEv->pos().y() - 1, 3, 3, tmpNodes,
+                                   tmpEdges);
       node metaNode;
       bool find = false;
 
@@ -411,7 +406,15 @@ bool MouseNKeysNavigator::eventFilter(QObject *widget, QEvent *e) {
         return false;
 
       return true;
-    } else {
+    } else if (qMouseEv->modifiers() ==
+#if defined(__APPLE__)
+                   Qt::AltModifier ||
+               qMouseEv->modifiers() == Qt::ControlModifier
+#else
+               Qt::ControlModifier
+#endif
+
+    ) {
       if (!graphHierarchy.empty() && nldc) {
         Graph *oldGraph = graphHierarchy.back();
         graphHierarchy.pop_back();
@@ -454,10 +457,7 @@ bool MouseNKeysNavigator::eventFilter(QObject *widget, QEvent *e) {
     }
   }
 
-  if (e->type() == QEvent::MouseButtonPress) {
-    if (mouseNavigationDisabled)
-      return false;
-
+  if (mouseNavigationEnabled && e->type() == QEvent::MouseButtonPress) {
     if (qMouseEv->buttons() == Qt::LeftButton) {
       oldCursor = glmainwidget->cursor();
       InteractorComponent *currentMouse;
@@ -466,17 +466,18 @@ bool MouseNKeysNavigator::eventFilter(QObject *widget, QEvent *e) {
 
       if (qMouseEv->modifiers() &
 #if defined(__APPLE__)
-          Qt::AltModifier
+              Qt::AltModifier
 #else
-          Qt::ControlModifier
+              Qt::ControlModifier
 #endif
-      )
+          && (view()->name() == NodeLinkDiagramComponent::viewName))
         currentMouse = new MouseZoomRotZ();
-      else if (qMouseEv->modifiers() & Qt::ShiftModifier)
+      else if ((qMouseEv->modifiers() & Qt::ShiftModifier) &&
+               (view()->name() == NodeLinkDiagramComponent::viewName))
         currentMouse = new MouseRotXRotY();
       else {
         currentMouse = new MouseMove();
-        glmainwidget->setCursor(QCursor(Qt::ClosedHandCursor));
+        e->accept();
       }
 
       bool result = currentMouse->eventFilter(widget, e);
@@ -489,10 +490,7 @@ bool MouseNKeysNavigator::eventFilter(QObject *widget, QEvent *e) {
     return false;
   }
 
-  if (e->type() == QEvent::MouseButtonRelease) {
-    if (mouseNavigationDisabled)
-      return false;
-
+  if (mouseNavigationEnabled && e->type() == QEvent::MouseButtonRelease) {
     glmainwidget->setCursor(oldCursor);
     delete currentSpecInteractorComponent;
     currentSpecInteractorComponent = nullptr;
@@ -582,7 +580,8 @@ bool MouseNKeysNavigator::eventFilter(QObject *widget, QEvent *e) {
 }
 
 void MouseNKeysNavigator::viewChanged(View *view) {
-  nldc = static_cast<NodeLinkDiagramComponent *>(view);
+  if (view && view->name() == NodeLinkDiagramComponent::viewName)
+    nldc = static_cast<NodeLinkDiagramComponent *>(view);
 }
 
 void MouseNKeysNavigator::clear() {}
