@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -19,28 +19,19 @@
 #include "ui_GridOptionsWidget.h"
 
 #include <QGraphicsView>
-#include <QActionGroup>
-#include <QDialog>
 #include <QMenu>
-#include <QString>
 
 #include <tulip/GlMetaNodeRenderer.h>
 #include <tulip/GlGrid.h>
 #include <tulip/DrawingTools.h>
 #include <tulip/TulipItemDelegate.h>
 #include <tulip/ParameterListModel.h>
-#include <tulip/GlMainWidget.h>
 #include <tulip/GlGraphComposite.h>
-#include <tulip/GlGraphInputData.h>
 #include <tulip/Gl2DRect.h>
 #include <tulip/GlVertexArrayManager.h>
 #include <tulip/GlOverviewGraphicsItem.h>
-#include <tulip/Interactor.h>
-#include <tulip/TulipMetaTypes.h>
 #include <tulip/QtGlSceneZoomAndPanAnimator.h>
 #include <tulip/GlCompositeHierarchyManager.h>
-#include <tulip/TlpTools.h>
-#include <tulip/TlpQtTools.h>
 #include <tulip/NodeLinkDiagramComponent.h>
 #include <tulip/GraphModel.h>
 #include <tulip/NumericProperty.h>
@@ -59,6 +50,7 @@ NodeLinkDiagramComponent::~NodeLinkDiagramComponent() {
     delete grid_ui->tableView->itemDelegate();
 
   delete grid_ui;
+  delete _gridOptions;
   delete manager;
 }
 
@@ -119,22 +111,6 @@ void NodeLinkDiagramComponent::draw() {
 }
 
 void NodeLinkDiagramComponent::setState(const tlp::DataSet &data) {
-  ParameterDescriptionList gridParameters;
-  gridParameters.add<StringCollection>("Grid mode", "", "No grid;Space divisions;Fixed size", true);
-  gridParameters.add<Size>("Grid size", "", "(1,1,1)", false);
-  gridParameters.add<Size>("Margins", "", "(0.5,0.5,0.5)", false);
-  gridParameters.add<Color>("Grid color", "", "(0,0,0,255)", false);
-  gridParameters.add<bool>("X grid", "", "true", false);
-  gridParameters.add<bool>("Y grid", "", "true", false);
-  gridParameters.add<bool>("Z grid", "", "true", false);
-  ParameterListModel *model = new ParameterListModel(gridParameters, nullptr, this);
-
-  grid_ui = new Ui::GridOptionsWidget;
-  _gridOptions = new QDialog(graphicsView());
-  grid_ui->setupUi(_gridOptions);
-  grid_ui->tableView->setModel(model);
-  grid_ui->tableView->setItemDelegate(new TulipItemDelegate(grid_ui->tableView));
-
   setOverviewVisible(true);
   setQuickAccessBarVisible(true);
   GlMainView::setState(data);
@@ -181,7 +157,7 @@ void NodeLinkDiagramComponent::initRenderingParameters(GlGraphRenderingParameter
 }
 
 //==================================================
-void NodeLinkDiagramComponent::createScene(Graph *graph, DataSet dataSet) {
+void NodeLinkDiagramComponent::createScene(Graph *graph, const DataSet &dataSet) {
   if (manager) {
     delete manager;
     manager = nullptr;
@@ -291,7 +267,7 @@ void NodeLinkDiagramComponent::loadGraphOnScene(Graph *graph) {
   GlScene *scene = getGlMainWidget()->getScene();
 
   if (!scene->getLayer("Main")) {
-    createScene(graph, DataSet());
+    createScene(graph);
     return;
   }
 
@@ -302,7 +278,7 @@ void NodeLinkDiagramComponent::loadGraphOnScene(Graph *graph) {
       static_cast<GlGraphComposite *>(scene->getLayer("Main")->findGlEntity("graph"));
 
   if (!oldGraphComposite) {
-    createScene(graph, DataSet());
+    createScene(graph);
 
     return;
   }
@@ -341,12 +317,11 @@ void NodeLinkDiagramComponent::registerTriggers() {
     return;
 
   addRedrawTrigger(getGlMainWidget()->getScene()->getGlGraphComposite()->getGraph());
-  std::set<tlp::PropertyInterface *> properties =
+  const auto &properties =
       getGlMainWidget()->getScene()->getGlGraphComposite()->getInputData()->properties();
 
-  for (std::set<tlp::PropertyInterface *>::iterator it = properties.begin(); it != properties.end();
-       ++it) {
-    addRedrawTrigger(*it);
+  for (auto prop : properties) {
+    addRedrawTrigger(prop);
   }
 }
 
@@ -360,6 +335,22 @@ void NodeLinkDiagramComponent::setZOrdering(bool f) {
 }
 
 void NodeLinkDiagramComponent::showGridControl() {
+  if (!_gridOptions) {
+    ParameterDescriptionList gridParameters;
+    gridParameters.add<StringCollection>("Grid mode", "", "No grid;Space divisions;Fixed size",
+                                         true);
+    gridParameters.add<Size>("Grid size", "", "(1,1,1)", false);
+    gridParameters.add<Size>("Margins", "", "(0.5,0.5,0.5)", false);
+    gridParameters.add<Color>("Grid color", "", "(0,0,0,255)", false);
+    gridParameters.add<bool>("X grid", "", "true", false);
+    gridParameters.add<bool>("Y grid", "", "true", false);
+    gridParameters.add<bool>("Z grid", "", "true", false);
+
+    grid_ui = new Ui::GridOptionsWidget;
+    _gridOptions = new QDialog(graphicsView());
+    grid_ui->setupUi(_gridOptions);
+    ParameterListModel::configureTableView(grid_ui->tableView, gridParameters, nullptr, this);
+  }
   if (_gridOptions->exec() == QDialog::Rejected)
     return;
 
@@ -401,7 +392,7 @@ void NodeLinkDiagramComponent::fillContextMenu(QMenu *menu, const QPointF &point
       action = selectMenu->addAction("predecessor nodes", this, SLOT(selectInNodes()));
       action->setToolTip(QString("Select the predecessors of node #") + sId);
       action = selectMenu->addAction("successor nodes", this, SLOT(selectOutNodes()));
-      action->setToolTip(QString("Select the sucessors of node #") + sId);
+      action->setToolTip(QString("Select the successors of node #") + sId);
       action = selectMenu->addAction("input edges", this, SLOT(selectInEdges()));
       action->setToolTip(QString("Select the input edges of node #") + sId);
       action = selectMenu->addAction("output edges", this, SLOT(selectOutEdges()));
@@ -431,7 +422,7 @@ void NodeLinkDiagramComponent::fillContextMenu(QMenu *menu, const QPointF &point
                          " to the current selection");
       action =
           addToSelectionMenu->addAction("successor nodes", this, SLOT(addOutNodesToSelection()));
-      action->setToolTip(QString("Add the sucessors of node #") + sId +
+      action->setToolTip(QString("Add the successors of node #") + sId +
                          " to the current selection");
       action = addToSelectionMenu->addAction("input edges", this, SLOT(addInEdgesToSelection()));
       action->setToolTip(QString("Add the input edges of node #") + sId +
@@ -468,7 +459,7 @@ void NodeLinkDiagramComponent::fillContextMenu(QMenu *menu, const QPointF &point
                          " from the current selection");
       action = removeFromSelectionMenu->addAction("successor nodes", this,
                                                   SLOT(removeOutNodesFromSelection()));
-      action->setToolTip(QString("Remove the sucessors of node #") + sId +
+      action->setToolTip(QString("Remove the successors of node #") + sId +
                          " from the current selection");
       action = removeFromSelectionMenu->addAction("input edges", this,
                                                   SLOT(removeInEdgesFromSelection()));
@@ -479,8 +470,10 @@ void NodeLinkDiagramComponent::fillContextMenu(QMenu *menu, const QPointF &point
       action->setToolTip(QString("Remove the output edges of node #") + sId +
                          " from the current selection");
       action = removeFromSelectionMenu->addAction(
-          tr("node and all its neighbour nodes (including edges)"), this,
+          "node and its neighbourhood", this,
           SLOT(removeNodeAndAllNeighbourNodesAndEdgesFromSelection()));
+      action->setToolTip(QString("Remove the node and the adjacent nodes of node #") + sId +
+                         " from the current selection");
     } else {
       action = removeFromSelectionMenu->addAction("edge", this, SLOT(removeItemFromSelection()));
       action->setToolTip(QString("Remove the edge #") + sId + " from the current selection");
