@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -17,11 +17,10 @@
  *
  */
 
+#include <tulip/Interactor.h>
 #include <tulip/NodeLinkDiagramComponentInteractor.h>
-#include <tulip/NodeLinkDiagramComponent.h>
 
 #include <QLabel>
-#include <QIcon>
 
 using namespace tlp;
 
@@ -29,6 +28,7 @@ NodeLinkDiagramComponentInteractor::NodeLinkDiagramComponentInteractor(const QSt
                                                                        const QString &text,
                                                                        unsigned int priority)
     : GLInteractorComposite(QIcon(iconPath), text), _label(new QLabel), _priority(priority) {
+  Interactor::setupConfigWidget(_label);
   _label->setWordWrap(true);
   _label->setAlignment(Qt::AlignTop);
   _label->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
