@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -19,14 +19,8 @@
 
 #include "tulip/SceneConfigWidget.h"
 
-#include <QDebug>
-#include <QMainWindow>
-#include <QApplication>
-
 #include <tulip/GlGraphComposite.h>
 #include <tulip/GlMainWidget.h>
-#include <tulip/Perspective.h>
-#include <tulip/TulipSettings.h>
 #include <tulip/GraphPropertiesModel.h>
 
 #include "ui_SceneConfigWidget.h"
@@ -38,14 +32,10 @@ SceneConfigWidget::SceneConfigWidget(QWidget *parent)
   _ui->setupUi(this);
 
   connect(_ui->dynamicFontSizeRB, SIGNAL(toggled(bool)), this, SLOT(dynamicFontRBToggled(bool)));
+  connect(_ui->labelSizesRangeSlider, SIGNAL(sliderReleased()), this,
+          SLOT(labelSizesRangeChanged()));
   _ui->selectionColorButton->setDialogTitle("Choose the color of selected nodes or edges");
   _ui->backgroundColorButton->setDialogTitle("Choose the background color");
-
-  if (Perspective::instance() != nullptr && Perspective::instance()->mainWindow() != nullptr) {
-    _ui->selectionColorButton->setDialogParent(Perspective::instance()->mainWindow());
-    _ui->backgroundColorButton->setDialogParent(Perspective::instance()->mainWindow());
-  }
-
   _ui->labelsDisabledLabel->installEventFilter(this);
   _ui->labelsNoOverlapLabel->installEventFilter(this);
   _ui->labelsShowAllLabel->installEventFilter(this);
@@ -108,7 +98,10 @@ void SceneConfigWidget::resetChanges() {
   _ui->dynamicFontSizeRB->setChecked(!renderingParameters->isLabelFixedFontSize());
   _ui->labelsDensitySlider->setValue(renderingParameters->getLabelsDensity());
   _ui->labelSizesRangeSlider->setLowerValue(renderingParameters->getMinSizeOfLabel());
+  _ui->labelsMinSize->display(_ui->labelSizesRangeSlider->minimum());
   _ui->labelSizesRangeSlider->setUpperValue(renderingParameters->getMaxSizeOfLabel());
+  _ui->labelsMaxSize->display(_ui->labelSizesRangeSlider->maximum());
+  labelSizesRangeChanged();
 
   // EDGES
   _ui->edges3DCheck->setChecked(renderingParameters->isEdge3D());
@@ -133,7 +126,6 @@ void SceneConfigWidget::resetChanges() {
   else
     _ui->centerSceneRadioButton->setChecked(true);
 
-  //  QApplication::processEvents();
   _resetting = false;
 }
 
@@ -208,3 +200,10 @@ void SceneConfigWidget::applySettings() {
 void SceneConfigWidget::dynamicFontRBToggled(bool state) {
   _ui->sizeLimitsGB->setEnabled(state);
 }
+
+void SceneConfigWidget::labelSizesRangeChanged() {
+  auto lowerSize = _ui->labelSizesRangeSlider->lowerValue();
+  auto upperSize = _ui->labelSizesRangeSlider->upperValue();
+  QString label = QString("Font size limits [%1, %2]").arg(lowerSize).arg(upperSize);
+  _ui->fontLimitsLabel->setText(label);
+}
