@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -21,10 +21,13 @@
 
 #include <QFont>
 #include <QVector>
+#include <QWidget>
 
 #include <tulip/GlScene.h>
 #include <tulip/GlGraphComposite.h>
 #include <tulip/GlSceneObserver.h>
+#include <tulip/GlComplexPolygon.h>
+#include <tulip/GlConvexGraphHull.h>
 
 using namespace tlp;
 
@@ -167,7 +170,8 @@ int SceneLayersModel::rowCount(const QModelIndex &parent) const {
 }
 
 int SceneLayersModel::columnCount(const QModelIndex &) const {
-  return 3;
+  // Name, Visible, Texture, Stencil
+  return 4;
 }
 
 QVariant SceneLayersModel::data(const QModelIndex &index, int role) const {
@@ -228,7 +232,7 @@ QVariant SceneLayersModel::data(const QModelIndex &index, int role) const {
       if (index.column() == 1)
         return (visible ? Qt::Checked : Qt::Unchecked);
 
-      if (index.column() == 2)
+      if (index.column() == 3)
         return (stencil == NO_STENCIL ? Qt::Unchecked : Qt::Checked);
     }
 
@@ -255,6 +259,10 @@ QVariant SceneLayersModel::data(const QModelIndex &index, int role) const {
 
   if (role == Qt::FontRole && layer != nullptr) {
     QFont f;
+    QWidget *p = dynamic_cast<QWidget *>(QAbstractItemModel::parent());
+    if (p)
+      f = p->font();
+
     f.setBold(true);
     return f;
   }
@@ -263,7 +271,19 @@ QVariant SceneLayersModel::data(const QModelIndex &index, int role) const {
     if (index.column() == 1)
       return (entity->isVisible() ? Qt::Checked : Qt::Unchecked);
 
-    if (index.column() == 2)
+    if (index.column() == 2) {
+      GlComplexPolygon *pl = dynamic_cast<GlComplexPolygon *>(entity);
+      if (pl)
+        return (pl->textureActivation() ? Qt::Checked : Qt::Unchecked);
+      else {
+        GlConvexGraphHullsComposite *composite =
+            dynamic_cast<GlConvexGraphHullsComposite *>(entity);
+        if (composite)
+          return (composite->hullsTextureActivation() ? Qt::Checked : Qt::Unchecked);
+      }
+    }
+
+    if (index.column() == 3)
       return (entity->getStencil() == NO_STENCIL ? Qt::Unchecked : Qt::Checked);
   }
 
@@ -339,7 +359,16 @@ bool SceneLayersModel::setData(const QModelIndex &index, const QVariant &value,
       layer->setVisible(val);
 
     entity->setVisible(val);
-  } else if (index.column() == 2)
+  } else if (index.column() == 2) {
+    GlComplexPolygon *pl = dynamic_cast<GlComplexPolygon *>(entity);
+    if (pl)
+      pl->setTextureActivation(val);
+    else {
+      GlConvexGraphHullsComposite *composite = dynamic_cast<GlConvexGraphHullsComposite *>(entity);
+      if (composite)
+        composite->setHullsTextureActivation(val);
+    }
+  } else
     entity->setStencil(val ? FULL_STENCIL : 0xFFFF);
 
   emit drawNeeded(_scene);
@@ -349,12 +378,16 @@ bool SceneLayersModel::setData(const QModelIndex &index, const QVariant &value,
 QVariant SceneLayersModel::headerData(int section, Qt::Orientation orientation, int role) const {
   if (orientation == Qt::Horizontal) {
     if (role == Qt::DisplayRole) {
-      if (section == 0)
+      switch (section) {
+      case 0:
         return "Name";
-      else if (section == 1)
+      case 1:
         return "Visible";
-      else
+      case 2:
+        return "Texture";
+      case 3:
         return "Stencil";
+      }
     }
 
     else if (role == Qt::TextAlignmentRole)
