@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -24,16 +24,18 @@
 #include <QStyle>
 #include <QVBoxLayout>
 
-#include <iostream>
-
 #include <tulip/TlpQtTools.h>
+#include <tulip/TulipSettings.h>
 
 using namespace tlp;
 
 SimplePluginProgressWidget::SimplePluginProgressWidget(QWidget *parent, Qt::WindowFlags f)
     : QWidget(parent, f), _ui(new Ui::SimplePluginProgressWidgetData),
       _lastUpdate(QTime::currentTime()), _state(tlp::TLP_CONTINUE) {
+
   _ui->setupUi(this);
+  tlpFixCBRBs(this);
+  showLogo(false);
   _ui->cancelButton->setIcon(QApplication::style()->standardIcon(QStyle::SP_DialogCancelButton));
   _ui->stopButton->setIcon(QApplication::style()->standardIcon(QStyle::SP_MediaStop));
   connect(_ui->cancelButton, SIGNAL(clicked()), this, SLOT(cancelClicked()));
@@ -102,6 +104,14 @@ void SimplePluginProgressWidget::showStops(bool showButtons) {
     setComment("Processing in progress...");
 }
 
+void SimplePluginProgressWidget::showText(bool show) {
+  _ui->progressBar->setTextVisible(show);
+}
+
+void SimplePluginProgressWidget::showLogo(bool show) {
+  _ui->logoLabel->setVisible(show);
+}
+
 ProgressState SimplePluginProgressWidget::state() const {
   return _state;
 }
@@ -139,9 +149,20 @@ void SimplePluginProgressWidget::stopClicked() {
 // ===================
 
 SimplePluginProgressDialog::SimplePluginProgressDialog(QWidget *parent)
-    : QDialog(parent, Qt::WindowTitleHint | Qt::CustomizeWindowHint), _painted(false),
-      _progress(new SimplePluginProgressWidget(this)) {
+    : QDialog(parent, Qt::WindowTitleHint | Qt::CustomizeWindowHint), _painted(false) {
   setModal(true);
+  // configure style sheet
+  QString s_sheet(R"(
+QDialog, QLabel, #SimplePluginProgressWidgetData { background-color: %BG_COLOR%; }
+QLabel { color: %FG_COLOR%; }
+)");
+
+  if (TulipSettings::isDisplayInDarkMode())
+    s_sheet.replace("%BG_COLOR%", "#323232").replace("%FG_COLOR%", "white");
+  else
+    s_sheet.replace("%BG_COLOR%", "white").replace("%FG_COLOR%", "black");
+  setStyleSheet(s_sheet);
+  _progress = new SimplePluginProgressWidget(this);
   QVBoxLayout *mainLayout = new QVBoxLayout(this);
   mainLayout->setContentsMargins(0, 0, 0, 0);
   mainLayout->addWidget(_progress);
@@ -211,6 +232,10 @@ void SimplePluginProgressDialog::showStops(bool showButtons) {
   QApplication::processEvents();
 }
 
+void SimplePluginProgressDialog::showText(bool show) {
+  _progress->showText(show);
+}
+
 ProgressState SimplePluginProgressDialog::state() const {
   return _progress->state();
 }
