@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -21,7 +21,6 @@
 #include <tulip/DoubleStringsListSelectionWidget.h>
 #include <tulip/StringsListSelectionWidget.h>
 
-#include <QLayout>
 #include <QVBoxLayout>
 
 using namespace std;
