@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -21,10 +21,6 @@
 
 #include <QHeaderView>
 #include <QStyledItemDelegate>
-#include <QPainter>
-#include <QStyleOptionViewItem>
-#include <QMouseEvent>
-#include <QTreeView>
 
 class TreeViewDelegate : public QStyledItemDelegate {
 public:
