@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -16,7 +16,6 @@
  * See the GNU General Public License for more details.
  *
  */
-#include <tulip/PropertyTypes.h>
 #include "tulip/TulipMetaTypes.h"
 #include "tulip/TlpQtTools.h"
 
@@ -121,6 +120,7 @@ tlp::DataType *TulipMetaTypes::qVariantToDataType(const QVariant &v) {
 
   CHECK_QVARIANT(ColorScale);
 
+  CHECK_QVARIANT(PropertiesCollection);
   CHECK_QVARIANT(StringCollection);
 
   CHECK_QVARIANT(QStringType::RealType);
@@ -142,8 +142,6 @@ tlp::DataType *TulipMetaTypes::qVariantToDataType(const QVariant &v) {
   if (type.compare(typeid(TYPE).name()) == 0)                                                      \
     return typedVariant<TYPE>(dm);
 
-#include <QDebug>
-
 QVariant TulipMetaTypes::dataTypeToQvariant(tlp::DataType *dm, const std::string &paramName) {
   std::string type = dm->getTypeName();
 
@@ -157,7 +155,8 @@ QVariant TulipMetaTypes::dataTypeToQvariant(tlp::DataType *dm, const std::string
     desc.absolutePath = tlpStringToQString(*static_cast<std::string *>(dm->value));
     desc.type =
         name.startsWith("dir::") ? TulipFileDescriptor::Directory : TulipFileDescriptor::File;
-    desc.mustExist = !name.startsWith("any");
+    // check if the file must exists
+    desc.mustExist = !name.startsWith("anyfile");
     return QVariant::fromValue<TulipFileDescriptor>(desc);
   }
 
@@ -178,11 +177,8 @@ QVariant TulipMetaTypes::dataTypeToQvariant(tlp::DataType *dm, const std::string
 
     if (dm)
       result = *(static_cast<tlp::BooleanVectorType::RealType *>(dm->value));
-#if (QT_VERSION < QT_VERSION_CHECK(5, 14, 0))
-    return QVariant::fromValue<QVector<bool>>(QVector<bool>::fromStdVector(result));
-#else
+
     return QVariant::fromValue<QVector<bool>>(QVector<bool>(result.begin(), result.end()));
-#endif
   }
 
   CHECK_DATATYPE(tlp::PointType::RealType);
@@ -216,6 +212,7 @@ QVariant TulipMetaTypes::dataTypeToQvariant(tlp::DataType *dm, const std::string
 
   CHECK_DATATYPE(tlp::ColorScale);
 
+  CHECK_DATATYPE(tlp::PropertiesCollection);
   CHECK_DATATYPE(tlp::StringCollection);
 
   // Qt built-in types
