@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -19,6 +19,7 @@
 #include "tulip/TulipModel.h"
 
 #include <QFont>
+#include <QWidget>
 
 using namespace tlp;
 
@@ -29,8 +30,13 @@ TulipModel::~TulipModel() {}
 QVariant TulipModel::headerData(int, Qt::Orientation orientation, int role) const {
   if (orientation == Qt::Horizontal && role == Qt::FontRole) {
     QFont f;
+    QWidget *p = dynamic_cast<QWidget *>(QAbstractItemModel::parent());
+    if (p)
+      f = p->font();
+
     f.setBold(true);
-    f.setPointSize(f.pointSize() - 1);
+    if (f.pointSize() > 1)
+      f.setPointSize(f.pointSize() - 1);
     return f;
   }
 
