@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -19,13 +19,7 @@
 
 #include <tulip/View.h>
 
-#include <QDebug>
-#include <QFile>
 #include <QGraphicsView>
-#include <QGraphicsItem>
-#include <QMenu>
-#include <QMainWindow>
-#include <QStatusBar>
 
 #include <tulip/Interactor.h>
 #include <tulip/Graph.h>
@@ -65,7 +59,7 @@ void View::toggleInteractors(const bool activate,
   }
 }
 
-void View::setInteractors(const QList<tlp::Interactor *> &inters) {
+void View::setInteractors(const std::list<tlp::Interactor *> &inters) {
   _interactors = inters;
 
   for (auto i : inters)
@@ -80,8 +74,9 @@ void View::setCurrentInteractor(tlp::Interactor *i) {
   if (_currentInteractor) {
     _currentInteractor->uninstall();
 
-    if (graphicsView() != nullptr)
-      graphicsView()->setCursor(QCursor()); // Force reset cursor when interactor is changed
+    if (graphicsView() != nullptr && i != _currentInteractor)
+      // Force cursor reset when changing interactor
+      graphicsView()->setCursor(QCursor());
   }
 
   _currentInteractor = i;
@@ -115,7 +110,11 @@ void View::fillContextMenu(QMenu *menu, edge e) {
     _tturlManager->fillContextMenu(menu, e);
 }
 
-void View::showContextMenu(const QPoint &point, const QPointF &scenePoint) {
+bool View::showContextMenu(const QPoint &point, const QPointF &scenePoint) {
+  // try to display current interactor context menu first
+  if (_currentInteractor && _currentInteractor->showContextMenu(point, scenePoint))
+    return true;
+
   if (_displayContextMenu) {
     QMenu menu;
     menu.setStyleSheet("QMenu::item:disabled {color: white; background-color: "
@@ -127,8 +126,10 @@ void View::showContextMenu(const QPoint &point, const QPointF &scenePoint) {
       Perspective::redirectStatusTipOfMenu(&menu);
       menu.move(point);
       menu.exec();
+      return true;
     }
   }
+  return false;
 }
 
 DataSet View::state() const {
@@ -151,8 +152,10 @@ Graph *View::graph() const {
   return _graph;
 }
 void View::setGraph(tlp::Graph *g) {
-  if (_graph != nullptr)
+  if (_graph != nullptr) {
     _graph->removeListener(this);
+    saveState();
+  }
 
   bool center = false;
 
@@ -166,6 +169,9 @@ void View::setGraph(tlp::Graph *g) {
   _graph = g;
 
   graphChanged(g);
+  // ensure current interactor refresh
+  if (currentInteractor())
+    setCurrentInteractor(currentInteractor());
 
   if (_graph != nullptr)
     _graph->addListener(this);
@@ -205,19 +211,11 @@ void View::treatEvent(const Event &ev) {
   }
 }
 
-QList<QWidget *> View::configurationWidgets() const {
-  return QList<QWidget *>();
+std::list<QWidget *> View::configurationWidgets() const {
+  return std::list<QWidget *>();
 }
 
-QString View::configurationWidgetsStyleSheet() const {
-  QFile css(":/tulip/gui/txt/view_configurationtab.css");
-  css.open(QIODevice::ReadOnly);
-  QString style(css.readAll());
-  css.close();
-  return style;
-}
-
-void View::interactorsInstalled(const QList<tlp::Interactor *> &) {
+void View::interactorsInstalled(const std::list<tlp::Interactor *> &) {
   emit interactorsChanged();
 }
 
@@ -228,13 +226,17 @@ void View::centerView(bool /* graphChanged */) {
 /*
   Triggers
   */
-QSet<tlp::Observable *> View::triggers() const {
+std::list<tlp::Observable *> View::triggers() const {
   return _triggers;
 }
 
 void View::removeRedrawTrigger(tlp::Observable *obs) {
-  if (_triggers.remove(obs))
+  // to be changed for C++20. remove() returns the number of element removed. Returns void with
+  // c++17
+  if (std::find(_triggers.begin(), _triggers.end(), obs) != _triggers.end()) {
+    _triggers.remove(obs);
     obs->removeObserver(this);
+  }
 }
 
 void View::emitDrawNeededSignal() {
@@ -242,10 +244,10 @@ void View::emitDrawNeededSignal() {
 }
 
 void View::addRedrawTrigger(tlp::Observable *obs) {
-  if (_triggers.contains(obs) || obs == nullptr)
+  if ((obs == nullptr) || std::find(_triggers.begin(), _triggers.end(), obs) != _triggers.end())
     return;
 
-  _triggers.insert(obs);
+  _triggers.push_back(obs);
   obs->addObserver(this);
 }
 
@@ -254,11 +256,12 @@ void View::treatEvents(const std::vector<Event> &events) {
     Event e = events[i];
 
     // ensure redraw trigger is removed from the triggers set when it is deleted
-    if (e.type() == Event::TLP_DELETE && _triggers.contains(e.sender())) {
+    if (e.type() == Event::TLP_DELETE &&
+        std::find(_triggers.begin(), _triggers.end(), e.sender()) != _triggers.end()) {
       removeRedrawTrigger(e.sender());
     }
 
-    if (_triggers.contains(e.sender())) {
+    if (std::find(_triggers.begin(), _triggers.end(), e.sender()) != _triggers.end()) {
       emit drawNeeded();
       break;
     }
@@ -275,3 +278,74 @@ void View::clearRedrawTriggers() {
 }
 
 void View::applySettings() {}
+
+// define a class to save/restore the View state associated
+// to a graph
+class ViewStatesMap : public tlp::Observable {
+  tlp_hash_map<std::string, tlp_hash_map<Graph *, DataSet>> mMap;
+
+public:
+  void saveState(const std::string &viewName, Graph *graph, const DataSet &ds) {
+    const auto it = mMap.find(viewName);
+    // register this as listener
+    if (it == mMap.cend() || (it->second.find(graph) == it->second.end()))
+      graph->addListener(this);
+    // associate state to graph
+    mMap[viewName][graph] = ds;
+  }
+
+  DataSet getState(const std::string &viewName, Graph *graph) const {
+    // get view map
+    const auto it = mMap.find(viewName);
+
+    if (it == mMap.cend())
+      return DataSet();
+
+    auto &vMap = it->second;
+    // look for a DataSet associated to graph or its nearest parent graph
+    while (true) {
+      auto itg = vMap.find(graph);
+      if (itg != vMap.cend())
+        return itg->second;
+      auto parent = graph->getSuperGraph();
+      if (graph == parent)
+        return DataSet();
+      graph = parent;
+    }
+  }
+
+  void treatEvent(const Event &ev) override {
+    // look for graph deletion
+    if (ev.type() == Event::TLP_DELETE) {
+      const GraphEvent *gEv = dynamic_cast<const GraphEvent *>(&ev);
+      if (gEv) {
+        auto graph = gEv->getGraph();
+        // remove graph entry
+        auto itm = mMap.begin();
+        for (; itm != mMap.end(); ++itm) {
+          auto itg = itm->second.begin();
+          for (; itg != itm->second.end(); ++itg) {
+            if (itg->first == graph) {
+              itm->second.erase(graph);
+              return;
+            }
+          }
+        }
+      }
+    }
+  }
+};
+
+static ViewStatesMap _viewStatesMap;
+
+void View::saveState() {
+  if (_graph) {
+    _viewStatesMap.saveState(name(), _graph, state());
+  }
+}
+
+DataSet View::getState(Graph *graph) {
+  if (graph)
+    return _viewStatesMap.getState(name(), graph);
+  return DataSet();
+}
