@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -30,9 +30,11 @@
 using namespace tlp;
 
 struct TulipGraphicsView : public QGraphicsView {
+  ViewWidget *_viewWidget;
   QGraphicsItem *_centralItem;
 
-  TulipGraphicsView() : QGraphicsView(new QGraphicsScene()), _centralItem(nullptr) {
+  TulipGraphicsView(ViewWidget *w)
+      : QGraphicsView(new QGraphicsScene()), _viewWidget(w), _centralItem(nullptr) {
     setAcceptDrops(false);
     setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
@@ -58,14 +60,10 @@ struct TulipGraphicsView : public QGraphicsView {
     else if (proxyWidget)
       proxyWidget->resize(width(), height());
 
+    _viewWidget->graphicsViewResized(width(), height());
+
     if (scene())
       scene()->update();
-
-    // Hack : send a mouse event to force redraw of the scene (otherwise artifacts was displayed
-    // when maximizing or minimizing the graphics view)
-    QMouseEvent eventModif(QEvent::MouseMove, QPoint(size().width() / 2, size().height() / 2),
-                           Qt::NoButton, Qt::NoButton, Qt::NoModifier);
-    QApplication::sendEvent(this, &eventModif);
   }
 };
 
@@ -90,7 +88,9 @@ QGraphicsView *ViewWidget::graphicsView() const {
 }
 
 void ViewWidget::setupUi() {
-  _graphicsView = new TulipGraphicsView();
+  // instantiate the graphicsView
+  // (will be deleted by the WorkspacePanel destructor)
+  _graphicsView = new TulipGraphicsView(this);
   _graphicsView->setFrameStyle(QFrame::NoFrame);
   _graphicsView->scene()->setBackgroundBrush(Qt::white);
   setupWidget();
@@ -98,8 +98,11 @@ void ViewWidget::setupUi() {
 }
 
 void ViewWidget::currentInteractorChanged(tlp::Interactor *i) {
-  if (i)
+  if (i) {
     i->install(_centralWidget);
+    // gives focus to allow keyboard interaction
+    _centralWidgetItem->setFocus(Qt::MouseFocusReason);
+  }
 }
 
 void ViewWidget::graphDeleted(Graph *parentGraph) {
