@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -90,28 +90,31 @@ public:
    * lines, 1 -> catmull rom curves, 2 -> bezier curves) and a textureName if you want
    */
   GlComplexPolygon(const std::vector<Coord> &coords, Color fcolor, int polygonEdgesType = 0,
-                   const std::string &textureName = "");
+                   const std::string &textureName = "", bool textured = true);
   /**
    * @brief Constructor with a vector of coords, a fill color, an outline color, a polygon edges
    * type(0 -> straight lines, 1 -> catmull rom curves, 2 -> bezier curves) and a textureName if you
    * want
    */
   GlComplexPolygon(const std::vector<Coord> &coords, Color fcolor, Color ocolor,
-                   int polygonEdgesType = 0, const std::string &textureName = "");
+                   int polygonEdgesType = 0, const std::string &textureName = "",
+                   bool textured = true);
   /**
    * @brief Constructor with a vector of vector of coords (the first vector of coord is the polygon
    * and others vectors are holes in polygon), a fill color, a polygon edges type(0 -> straight
    * lines, 1 -> catmull rom curves, 2 -> bezier curves) and a textureName if you want
    */
   GlComplexPolygon(const std::vector<std::vector<Coord>> &coords, Color fcolor,
-                   int polygonEdgesType = 0, const std::string &textureName = "");
+                   int polygonEdgesType = 0, const std::string &textureName = "",
+                   bool textured = true);
   /**
    * @brief Constructor with a vector of vector of coords (the first vector of coord is the polygon
    * and others vectors are holes in polygon), a fill color, an outline color a polygon edges type(0
    * -> straight lines, 1 -> catmull rom curves, 2 -> bezier curves) and a textureName if you want
    */
   GlComplexPolygon(const std::vector<std::vector<Coord>> &coords, Color fcolor, Color ocolor,
-                   int polygonEdgesType = 0, const std::string &textureName = "");
+                   int polygonEdgesType = 0, const std::string &textureName = "",
+                   bool textured = true);
 
   ~GlComplexPolygon() override {}
 
@@ -130,6 +133,11 @@ public:
    */
   void setOutlineSize(double size);
 
+  /**
+   * @brief Set if the outline is stippled or not
+   */
+  void setOutlineStippled(bool stippled);
+
   /**
    * @brief Get fill color of GlComplexPolygon
    */
@@ -188,6 +196,18 @@ public:
    */
   void setTextureName(const std::string &name);
 
+  /**
+   *  @brief indicates if texture must be applied
+   */
+  bool textureActivation() {
+    return textured;
+  }
+
+  /**
+   *  @brief set if texture must be applied
+   */
+  void setTextureActivation(bool);
+
   /**
    * @brief Draw a thick (textured) border around the polygon.
    *
@@ -253,7 +273,7 @@ protected:
   std::vector<float> verticesData;
   std::vector<unsigned int> verticesIndices;
   int currentVector;
-  bool outlined;
+  bool outlined, outlineStippled, textured;
   Color fillColor;
   Color outlineColor;
   double outlineSize;
