@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -378,24 +378,6 @@ public:
    */
   bool isEdge3D() const;
 
-  /**
-   * @brief Get the size of the border that is added to any label when using bitmap fonts.
-   *
-   * @deprecated Use getLabelsDensity instead
-   */
-  unsigned int _DEPRECATED getLabelsBorder() const;
-
-  /**
-   * @brief Get the size of label border
-   *
-   * Get the size of the border that is added to any label when
-   * using bitmap fonts. Setting this parameter to a high value
-   * enables de reduce the label density in the final drawing.
-   * Default value is set to 2 which enables readable labels.
-   * @deprecated Use setLabelsDensity instead
-   */
-  void _DEPRECATED setLabelsBorder(const unsigned int);
-
   /**
    * @brief set if Edge max size is block to node size
    */
@@ -495,8 +477,8 @@ public:
   }
 
   /**
-   * @brief This property is use to filter nodes/edges display, for a node/edge if this property is
-   * false : the node/edge will not be displayed
+   * @brief This property is use to filter nodes/edges rendering. If this property is
+   * false, the node/edge will be rendered and displayed.
    *
    * @Warning : this property will not be saved in DataSet
    */
