@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -30,20 +30,17 @@ namespace tlp {
 class TLP_GL_SCOPE GlGraphStaticData {
 
 public:
-
   static const int edgeShapesCount;
   static int edgeShapeIds[];
   static std::string labelPositionNames[];
 
   static std::string edgeShapeName(int id);
-  static int edgeShapeId(const std::string& name);
+  static int edgeShapeId(const std::string &name);
 
   static std::string labelPositionName(int id);
-  static int labelPositionId(const std::string& name);
-
+  static int labelPositionId(const std::string &name);
 };
-
-}
+} // namespace tlp
 
 #endif // Tulip_GLGRAPHSTATICDATA_H
 ///@endcond
