@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -32,20 +32,14 @@ public:
   /**
    * @brief Constructor
    */
-  GlHexagon(const Coord &position,
-            const Size &size,
-            const Color &outlineColor = Color(255, 0 , 0 , 255),
-            const Color &fillColor = Color (0, 0, 255,255),
-            bool filled = true,
-            bool outlined =true,
-            const std::string &textureName="",
-            float outlineSize=1.);
+  GlHexagon(const Coord &position, const Size &size,
+            const Color &outlineColor = Color(255, 0, 0, 255),
+            const Color &fillColor = Color(0, 0, 255, 255), bool filled = true,
+            bool outlined = true, const std::string &textureName = "", float outlineSize = 1.);
   /**
    * @brief Default empty destructor
    */
-  virtual ~GlHexagon();
-
+  ~GlHexagon() override;
 };
-
-}
+} // namespace tlp
 #endif
