@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -167,7 +167,7 @@ protected:
   LayoutProperty *layoutProperty;
   SizeProperty *sizeProperty;
   IntegerProperty *shapeProperty;
-  DoubleProperty *rotationProperty;
+  DoubleProperty *rotationProperty, *lengthRatioProperty;
   ColorProperty *colorProperty;
   ColorProperty *borderColorProperty;
   DoubleProperty *borderWidthProperty;
