@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -20,7 +20,6 @@
 #include <cstring>
 #include <GL/glew.h>
 #include <tulip/Vector.h>
-#include <tulip/TlpTools.h>
 #include <tulip/Curves.h>
 #include <tulip/GlTextureManager.h>
 #include <tulip/GlShaderProgram.h>
@@ -354,12 +353,12 @@ void buildCurvePoints(const vector<Coord> &vertices, const vector<float> &sizes,
   }
 
   if (endN != vertices[sz - 1]) {
-    inversion = computeExtrusion(vertices[sz - 2], vertices[sz - 1], endN, sizes[sizes.size() - 1],
-                                 inversion, result, true, twoPointsCurve);
+    computeExtrusion(vertices[sz - 2], vertices[sz - 1], endN, sizes[sizes.size() - 1], inversion,
+                     result, true, twoPointsCurve);
   } else {
-    inversion = computeExtrusion(vertices[sz - 2], vertices[sz - 1],
-                                 vertices[sz - 1] + (vertices[sz - 1] - vertices[sz - 2]),
-                                 sizes[sizes.size() - 1], inversion, result, true, twoPointsCurve);
+    computeExtrusion(vertices[sz - 2], vertices[sz - 1],
+                     vertices[sz - 1] + (vertices[sz - 1] - vertices[sz - 2]),
+                     sizes[sizes.size() - 1], inversion, result, true, twoPointsCurve);
   }
 }
 //==============================================
