@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -20,8 +20,6 @@
 #include <tulip/Camera.h>
 #include <tulip/GlXMLTools.h>
 
-#include <limits>
-
 using namespace std;
 
 namespace tlp {
