@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -17,10 +17,6 @@
  *
  */
 
-#include <GL/glew.h>
-
-#include <cstring>
-
 #include <tulip/GlBezierCurve.h>
 #include <tulip/GlCatmullRomCurve.h>
 #include <tulip/ParametricCurves.h>
