@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -17,8 +17,6 @@
  *
  */
 
-#include <map>
-
 #include <tulip/GlColorScale.h>
 #include <tulip/ColorScale.h>
 #include <tulip/GlPolyQuad.h>
@@ -61,7 +59,6 @@ void GlColorScale::updateDrawing() {
     colorScalePolyQuad->setOutlineWidth(2);
   }
 
-  map<float, Color> colorMap = colorScale->getColorMap();
   Coord currentMin, currentMax;
 
   for (const auto &colorMapIt : colorScale->getColorMap()) {
