@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -247,17 +247,18 @@ const int nbFloatPerVertex = 5;
 namespace tlp {
 
 GlComplexPolygon::GlComplexPolygon(const vector<Coord> &coords, Color fcolor, int polygonEdgesType,
-                                   const string &textureName)
-    : currentVector(-1), outlined(false), fillColor(fcolor), outlineSize(1),
-      textureName(textureName), textureZoom(1.) {
+                                   const string &textureName, bool textured)
+    : currentVector(-1), outlined(false), outlineStippled(false), textured(textured),
+      fillColor(fcolor), outlineSize(1), textureName(textureName), textureZoom(1.) {
   createPolygon(coords, polygonEdgesType);
   runTesselation();
 }
 //=====================================================
 GlComplexPolygon::GlComplexPolygon(const vector<Coord> &coords, Color fcolor, Color ocolor,
-                                   int polygonEdgesType, const string &textureName)
-    : currentVector(-1), outlined(true), fillColor(fcolor), outlineColor(ocolor), outlineSize(1),
-      textureName(textureName), textureZoom(1.) {
+                                   int polygonEdgesType, const string &textureName, bool textured)
+    : currentVector(-1), outlined(true), outlineStippled(false), textured(textured),
+      fillColor(fcolor), outlineColor(ocolor), outlineSize(1), textureName(textureName),
+      textureZoom(1.) {
   if (!coords.empty()) {
     createPolygon(coords, polygonEdgesType);
     runTesselation();
@@ -265,9 +266,9 @@ GlComplexPolygon::GlComplexPolygon(const vector<Coord> &coords, Color fcolor, Co
 }
 //=====================================================
 GlComplexPolygon::GlComplexPolygon(const vector<vector<Coord>> &coords, Color fcolor,
-                                   int polygonEdgesType, const string &textureName)
-    : currentVector(-1), outlined(false), fillColor(fcolor), outlineSize(1),
-      textureName(textureName), textureZoom(1.) {
+                                   int polygonEdgesType, const string &textureName, bool textured)
+    : currentVector(-1), outlined(false), outlineStippled(false), textured(textured),
+      fillColor(fcolor), outlineSize(1), textureName(textureName), textureZoom(1.) {
   for (size_t i = 0; i < coords.size(); ++i) {
     createPolygon(coords[i], polygonEdgesType);
   }
@@ -276,9 +277,10 @@ GlComplexPolygon::GlComplexPolygon(const vector<vector<Coord>> &coords, Color fc
 }
 //=====================================================
 GlComplexPolygon::GlComplexPolygon(const vector<vector<Coord>> &coords, Color fcolor, Color ocolor,
-                                   int polygonEdgesType, const string &textureName)
-    : currentVector(-1), outlined(true), fillColor(fcolor), outlineColor(ocolor), outlineSize(1),
-      textureName(textureName), textureZoom(1.) {
+                                   int polygonEdgesType, const string &textureName, bool textured)
+    : currentVector(-1), outlined(true), outlineStippled(false), textured(textured),
+      fillColor(fcolor), outlineColor(ocolor), outlineSize(1), textureName(textureName),
+      textureZoom(1.) {
   for (unsigned int i = 0; i < coords.size(); ++i) {
     createPolygon(coords[i], polygonEdgesType);
   }
@@ -332,6 +334,10 @@ void GlComplexPolygon::setOutlineSize(double size) {
   outlineSize = size;
 }
 //=====================================================
+void GlComplexPolygon::setOutlineStippled(bool stippled) {
+  outlineStippled = stippled;
+}
+//=====================================================
 string GlComplexPolygon::getTextureName() {
   return textureName;
 }
@@ -340,6 +346,11 @@ void GlComplexPolygon::setTextureName(const string &name) {
   textureName = name;
 }
 //=====================================================
+void GlComplexPolygon::setTextureActivation(bool flag) {
+  if (textured != flag)
+    textured = flag;
+}
+//=====================================================
 void GlComplexPolygon::addPoint(const Coord &point) {
   pointsIdx[currentVector].push_back(points[currentVector].size());
   points[currentVector].emplace_back(point);
@@ -377,17 +388,17 @@ void GlComplexPolygon::runTesselation() {
     const float *verts = tessGetVertices(tess);
     const int *elems = tessGetElements(tess);
     const int nelems = tessGetElementCount(tess);
-    std::unordered_map<Coord, unsigned int> vidx;
+    tlp_hash_map<Coord, unsigned int> vidx;
 
     // iterate over polygons computed by tessellation
     for (int i = 0; i < nelems; ++i) {
       std::vector<tlp::Coord> verticesTmp;
-      const int *p = &elems[i * nvp];
+      const int *poly = &elems[i * nvp];
 
-      for (int j = 0; j < nvp && p[j] != TESS_UNDEF; ++j) {
-        int idxx = p[j] * 3;
-        int idxy = p[j] * 3 + 1;
-        int idxz = p[j] * 3 + 2;
+      for (int j = 0; j < nvp && poly[j] != TESS_UNDEF; ++j) {
+        int idxx = poly[j] * 3;
+        int idxy = poly[j] * 3 + 1;
+        int idxz = poly[j] * 3 + 2;
         Coord p(verts[idxx], verts[idxy], verts[idxz]);
         verticesTmp.emplace_back(p);
 
@@ -450,7 +461,7 @@ void GlComplexPolygon::draw(float, Camera *) {
   glDisable(GL_CULL_FACE);
   glEnable(GL_COLOR_MATERIAL);
 
-  if (!textureName.empty()) {
+  if (textured && !textureName.empty()) {
     if (GlTextureManager::activateTexture(textureName))
       glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_REPEAT);
   }
@@ -468,7 +479,7 @@ void GlComplexPolygon::draw(float, Camera *) {
 
   glDisableClientState(GL_TEXTURE_COORD_ARRAY);
 
-  if (!textureName.empty()) {
+  if (textured && !textureName.empty()) {
     GlTextureManager::deactivateTexture();
   }
 
@@ -480,6 +491,10 @@ void GlComplexPolygon::draw(float, Camera *) {
 
     glLineWidth(lineWidth);
     setMaterial(outlineColor);
+    if (outlineStippled) {
+      glLineStipple(2, 0xAAAA);
+      glEnable(GL_LINE_STIPPLE);
+    }
 
     for (size_t v = 0; v < points.size(); ++v) {
       glVertexPointer(3, GL_FLOAT, 3 * sizeof(GLfloat), &points[v][0]);
