@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -16,10 +16,7 @@
  * See the GNU General Public License for more details.
  *
  */
-#include <tulip/LayoutProperty.h>
-#include <tulip/Vector.h>
 #include <tulip/GlGraphRenderingParameters.h>
-#include <tulip/TlpTools.h>
 #include <tulip/NumericProperty.h>
 
 using namespace tlp;
@@ -202,16 +199,6 @@ void GlGraphRenderingParameters::setParameters(const DataSet &data) {
     setElementOrderedDescending(b);
 }
 //====================================================
-unsigned int GlGraphRenderingParameters::getLabelsBorder() const {
-  if (_labelsDensity < 0)
-    return 100;
-  else
-    return -_labelsDensity;
-}
-void GlGraphRenderingParameters::setLabelsBorder(const unsigned int border) {
-  _labelsDensity = -int(border);
-}
-//====================================================
 bool GlGraphRenderingParameters::isViewMetaLabel() const {
   return (_viewMetaLabel);
 }
