@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -27,34 +27,23 @@
 #endif
 
 #include <tulip/GlLabel.h>
-#include <tulip/Coord.h>
-#include <tulip/LayoutProperty.h>
-#include <tulip/DoubleProperty.h>
-#include <tulip/StringProperty.h>
-#include <tulip/BooleanProperty.h>
-#include <tulip/SizeProperty.h>
-#include <tulip/IntegerProperty.h>
-#include <tulip/ColorProperty.h>
 #include <tulip/GlTools.h>
-#include <tulip/GlyphManager.h>
 #include <tulip/OcclusionTest.h>
 #include <tulip/OcclusionTest.h>
 #include <tulip/GlTextureManager.h>
 #include <tulip/GlXMLTools.h>
-#include <tulip/TlpTools.h>
 #include <tulip/TulipViewSettings.h>
-#include <tulip/ParallelTools.h>
 
 using namespace std;
 
 namespace tlp {
 
 // FTGL fonts must be cached to avoid to much memory consumption
-static std::unordered_map<std::string, FTPolygonFont *> PolygonFonts;
-static std::unordered_map<std::string, FTGLOutlineFont *> OutlineFonts;
+static tlp_hash_map<std::string, FTPolygonFont *> PolygonFonts;
+static tlp_hash_map<std::string, FTGLOutlineFont *> OutlineFonts;
 
 static FTPolygonFont *getPolygonFont(const std::string &name) {
-  std::unordered_map<std::string, FTPolygonFont *>::iterator itf = PolygonFonts.find(name);
+  tlp_hash_map<std::string, FTPolygonFont *>::iterator itf = PolygonFonts.find(name);
 
   if (itf != PolygonFonts.end())
     return itf->second;
@@ -63,7 +52,7 @@ static FTPolygonFont *getPolygonFont(const std::string &name) {
 }
 
 static FTGLOutlineFont *getOutlineFont(const std::string &name) {
-  std::unordered_map<std::string, FTGLOutlineFont *>::iterator itf = OutlineFonts.find(name);
+  tlp_hash_map<std::string, FTGLOutlineFont *>::iterator itf = OutlineFonts.find(name);
 
   if (itf != OutlineFonts.end())
     return itf->second;
