@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -26,8 +26,6 @@
 #include <tulip/Glyph.h>
 #include <tulip/Camera.h>
 
-#include <tulip/OpenGlIncludes.h>
-
 using namespace std;
 
 namespace tlp {
