@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -24,7 +24,6 @@
 #include <tulip/QuadTree.h>
 #include <tulip/GlGraphInputData.h>
 #include <tulip/Camera.h>
-#include <tulip/GlEntity.h>
 #include <tulip/GlTools.h>
 #include <tulip/GlScene.h>
 #include <tulip/GlNode.h>
@@ -36,7 +35,7 @@ using namespace std;
 
 namespace tlp {
 
-BoundingBox computeNewBoundingBox(const BoundingBox &box, const Coord &centerScene, double aX,
+/*BoundingBox computeNewBoundingBox(const BoundingBox &box, const Coord &centerScene, double aX,
                                   double aY) {
   // compute a new bounding box : this bounding box is the rotation of the old bounding box
   Coord &&size = (box[1] - box[0]) / 2.f;
@@ -47,7 +46,7 @@ BoundingBox computeNewBoundingBox(const BoundingBox &box, const Coord &centerSce
   center[1] = centerScene[1] + (cos(aX) * (center[1] - centerScene[1]));
 
   return BoundingBox(center - size, center + size);
-}
+  }*/
 
 GlQuadTreeLODCalculator::GlQuadTreeLODCalculator()
     : haveToCompute(true), haveToInitObservers(true),
@@ -567,8 +566,8 @@ void GlQuadTreeLODCalculator::treatEvent(const Event &ev) {
     switch (graphEvent->getType()) {
     case GraphEvent::TLP_ADD_NODE:
     case GraphEvent::TLP_ADD_EDGE:
-    case GraphEvent::TLP_DEL_NODE:
-    case GraphEvent::TLP_DEL_EDGE:
+    case GraphEvent::TLP_AFTER_DEL_NODE:
+    case GraphEvent::TLP_AFTER_DEL_EDGE:
       setHaveToCompute();
       break;
 
