@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -18,7 +18,6 @@
  */
 
 #include <tulip/GlLine.h>
-#include <tulip/GlPolygon.h>
 #include <tulip/GlTriangle.h>
 
 #include <sstream>
@@ -77,9 +76,11 @@ void GlQuantitativeAxis::setAxisParameters(const long long minV, const long long
   min = minV;
   long long maxVCp = maxV;
 
-  if (incrementStepV)
-    while (((maxVCp - minV) % incrementStepV) != 0)
-      ++maxVCp;
+  if (incrementStepV) {
+    auto r = (maxVCp - minV) % incrementStepV;
+    if (r > 0)
+      maxVCp += incrementStepV - r;
+  }
 
   max = maxVCp;
   incrementStep = incrementStepV;
