@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -16,13 +16,6 @@
  * See the GNU General Public License for more details.
  *
  */
-#include <GL/glew.h>
-
-#include <algorithm>
-#include <cstdlib>
-#include <climits>
-#include <cstdio>
-
 #include <tulip/OpenGlConfigManager.h>
 #include <tulip/GlScene.h>
 #include <tulip/GlTools.h>
@@ -67,8 +60,8 @@ struct entityWithDistanceCompare {
     if (e1.distance < e2.distance)
       return false;
 
-    BoundingBox &bb1 = e1.entity->boundingBox;
-    BoundingBox &bb2 = e2.entity->boundingBox;
+    const BoundingBox &bb1 = e1.entity->boundingBox;
+    const BoundingBox &bb2 = e2.entity->boundingBox;
 
     if (bb1[1][0] - bb1[0][0] > bb2[1][0] - bb2[0][0])
       return false;
@@ -241,7 +234,7 @@ GlLayer *GlScene::createLayer(const std::string &name) {
 
   if (oldLayer != nullptr) {
     tlp::warning()
-        << "Warning : You have a layer in the scene with same name : old layer will be deleted"
+        << "Warning: You have a layer in the scene with same name, old layer will be deleted"
         << endl;
     removeLayer(oldLayer);
   }
@@ -273,7 +266,7 @@ GlLayer *GlScene::createLayerBefore(const std::string &layerName,
       if (oldLayer != nullptr) {
         removeLayer(oldLayer);
         tlp::warning()
-            << "Warning : You have a layer in the scene with same name : old layer will be deleted"
+            << "Warning: You have a layer in the scene with same name, old layer will be deleted"
             << endl;
       }
 
@@ -301,7 +294,7 @@ GlLayer *GlScene::createLayerAfter(const std::string &layerName,
 
       if (oldLayer != nullptr) {
         tlp::warning()
-            << "Warning : You have a layer in the scene with same name : old layer will be deleted"
+            << "Warning: You have a layer in the scene with same name, old layer will be deleted"
             << endl;
         removeLayer(oldLayer);
       }
@@ -318,7 +311,7 @@ void GlScene::addExistingLayer(GlLayer *layer) {
 
   if (oldLayer != nullptr) {
     tlp::warning()
-        << "Warning : You have a layer in the scene with same name : old layer will be deleted"
+        << "Warning: You have a layer in the scene with same name, old layer will be deleted"
         << endl;
     removeLayer(oldLayer);
   }
@@ -344,7 +337,7 @@ bool GlScene::addExistingLayerBefore(GlLayer *layer, const std::string &beforeLa
 
       if (oldLayer != nullptr) {
         tlp::warning()
-            << "Warning : You have a layer in the scene with same name : old layer will be deleted"
+            << "Warning: You have a layer in the scene with same name, old layer will be deleted"
             << endl;
         removeLayer(oldLayer);
       }
@@ -372,7 +365,7 @@ bool GlScene::addExistingLayerAfter(GlLayer *layer, const std::string &afterLaye
 
       if (oldLayer != nullptr) {
         tlp::warning()
-            << "Warning : You have a layer in the scene with same name : old layer will be deleted"
+            << "Warning: You have a layer in the scene with same name, old layer will be deleted"
             << endl;
         removeLayer(oldLayer);
       }
@@ -783,7 +776,7 @@ bool GlScene::selectEntities(RenderingEntitiesFlag type, int x, int y, int w, in
     glDisable(GL_BLEND);
     glDisable(GL_STENCIL_TEST);
 
-    unordered_map<unsigned int, SelectedEntity> idToEntity;
+    tlp_hash_map<unsigned int, SelectedEntity> idToEntity;
 
     if (type & RenderingSimpleEntities) {
       unsigned int id = 1;
