@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -506,8 +506,6 @@ bool GlTextureManager::existsTexture(const string &filename) {
 }
 //====================================================================
 bool GlTextureManager::loadTexture(const string &filename) {
-  glEnable(GL_TEXTURE_2D);
-
   if (texturesMap.find(filename) != texturesMap.end())
     return true;
 
@@ -563,19 +561,13 @@ bool GlTextureManager::activateTexture(const string &filename, unsigned int fram
   if (texturesWithError.count(filename) != 0)
     return false;
 
-  bool loadOk = true;
-
-  if (texturesMap.find(filename) == texturesMap.end())
-    loadOk = loadTexture(filename);
-  else
-    glEnable(GL_TEXTURE_2D);
-
-  if (!loadOk) {
+  if (!loadTexture(filename)) {
     texturesWithError.insert(filename);
-    glDisable(GL_TEXTURE_2D);
     return false;
   }
 
+  glEnable(GL_TEXTURE_2D);
+
   unsigned int spriteNumber = texturesMap[filename].spriteNumber;
   frame = frame - (frame / spriteNumber) * spriteNumber;
   glBindTexture(GL_TEXTURE_2D, texturesMap[filename].id[frame]);
