@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -28,15 +28,25 @@
 #endif
 #endif
 
+#include <GL/glew.h>
+#ifdef __GNUC__
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wold-style-cast"
+#endif
+#include <FTVectoriser.h>
+#include <FTLibrary.h>
+#ifdef __GNUC__
+#pragma GCC diagnostic pop
+#endif
+
 #include <tulip/Rectangle.h>
 #include <tulip/GlTools.h>
-#include <tulip/Matrix.h>
-#include <tulip/BoundingBox.h>
+
+#ifndef NDEBUG
 #include <tulip/TulipException.h>
-#include <iostream>
-#include <string>
-#include <sstream>
-#include <climits>
+#endif
+
+#include <tulip/tuliphash.h>
 
 using namespace std;
 namespace tlp {
@@ -125,7 +135,7 @@ void glTest(const string &message, int line, bool throwException) {
   unsigned int i = 1;
   GLenum error = glGetError();
 
-  stringstream errorStream;
+  string errorMsg;
   bool haveError = false, throwNeeded = false;
 
   while (error != GL_NO_ERROR) {
@@ -135,19 +145,19 @@ void glTest(const string &message, int line, bool throwException) {
       throwNeeded = true;
 
     if (i == 1) {
-      errorStream << "[OpenGL ERROR] " << message;
+      errorMsg += "[OpenGL ERROR] " + message;
       if (line > -1)
-        errorStream << ':' << line << endl;
+        errorMsg += ':' + std::to_string(line) + "\n";
     }
-    errorStream << "========> " << glGetErrorDescription(error) << endl;
+    errorMsg += "========> " + glGetErrorDescription(error) + "\n";
     error = glGetError();
     ++i;
   }
 
   if (haveError) {
     if (throwNeeded)
-      throw tlp::TulipException(errorStream.str());
-    tlp::warning() << errorStream.str();
+      throw tlp::TulipException(errorMsg);
+    tlp::warning() << errorMsg;
   }
 
 #else
@@ -283,7 +293,7 @@ GLfloat projectSize(const BoundingBox &bb, const MatrixGL &projectionMatrix,
   float width = fabs(x1 - x2);
   float size = pow(2. * width, 2);
 
-  // Test of visibily
+  // Test of visibility
   x2 += viewport[0];
   float y2 = (proj2[1] / proj2[3] * 0.5 + 0.5) * viewport[3] + viewport[1];
   Vector<float, 2> upleft;
@@ -439,4 +449,149 @@ std::vector<Coord> computeNormals(const std::vector<Coord> &vertices,
 
   return normals;
 }
+
+#define ushort_cast(x) static_cast<unsigned short>((x))
+
+#define HRES 64
+#define HRESf 64.f
+#define DPI 72
+
+void tesselateFontIcon(const std::string &fontFile, unsigned int iconCodePoint,
+                       GLuint &renderingDataBuffer, GLuint &indicesBuffer, unsigned int &nbVertices,
+                       unsigned int &nbIndices, unsigned int &nbOutlineIndices,
+                       BoundingBox &boundingBox) {
+
+  const FT_Library *library = FTLibrary::Instance().GetLibrary();
+
+  FT_Face face;
+
+  FT_Error err = FT_New_Face(*library, fontFile.c_str(), 0, &face);
+
+  if (err) {
+    return;
+  }
+
+  err = FT_Select_Charmap(face, FT_ENCODING_UNICODE);
+
+  if (err) {
+    return;
+  }
+
+  float size = 20;
+
+  err = FT_Set_Char_Size(face, int(size * HRES), 0, DPI *HRES, DPI *HRES);
+
+  if (err) {
+    return;
+  }
+
+  FT_UInt glyph_index = FT_Get_Char_Index(face, iconCodePoint);
+
+  err = FT_Load_Glyph(face, glyph_index, FT_LOAD_NO_HINTING);
+
+  if (err) {
+    return;
+  }
+
+  // force glyph outline flags to fix misdrawing of several
+  // font awesome v6 icons (fas-circle-info, fas-circle-user...)
+  face->glyph->outline.flags |= ft_outline_even_odd_fill;
+  FTVectoriser vectoriser(face->glyph);
+
+  vectoriser.MakeMesh(1.0, 1, 0.0);
+
+  const FTMesh *mesh = vectoriser.GetMesh();
+
+  tlp::BoundingBox meshBB;
+
+  vector<Coord> vertices;
+  vector<Vec2f> texCoords;
+  vector<unsigned short> indices;
+  vector<unsigned short> outlineIndices;
+
+  tlp_hash_map<Coord, unsigned int> vertexIdx;
+
+  unsigned int idx = 0;
+
+  for (unsigned int t = 0; t < mesh->TesselationCount(); ++t) {
+    const FTTesselation *subMesh = mesh->Tesselation(t);
+
+    for (unsigned int i = 0; i < subMesh->PointCount(); ++i) {
+      FTPoint point = subMesh->Point(i);
+      tlp::Coord p(point.Xf() / HRESf, point.Yf() / HRESf, 0.0f);
+
+      if (vertexIdx.find(p) == vertexIdx.end()) {
+        meshBB.expand(p);
+        vertices.push_back(p);
+        indices.push_back(idx++);
+        vertexIdx[vertices.back()] = indices.back();
+      } else {
+        indices.push_back(vertexIdx[p]);
+      }
+    }
+  }
+
+  for (unsigned int t = 0; t < vectoriser.ContourCount(); ++t) {
+    const FTContour *contour = vectoriser.Contour(t);
+
+    for (unsigned int i = 0; i < contour->PointCount() - 1; ++i) {
+      FTPoint point = contour->Point(i);
+      tlp::Coord p(point.Xf() / HRESf, point.Yf() / HRESf, 0.0f);
+      outlineIndices.push_back(ushort_cast(vertexIdx[p]));
+      point = contour->Point(i + 1);
+      p = Coord(point.Xf() / HRESf, point.Yf() / HRESf, 0.0f);
+      outlineIndices.push_back(ushort_cast(vertexIdx[p]));
+    }
+
+    FTPoint point = contour->Point(contour->PointCount() - 1);
+    tlp::Coord p(point.Xf() / HRESf, point.Yf() / HRESf, 0.0f);
+    outlineIndices.push_back(ushort_cast(vertexIdx[p]));
+    point = contour->Point(0);
+    p = Coord(point.Xf() / HRESf, point.Yf() / HRESf, 0.0f);
+    outlineIndices.push_back(ushort_cast(vertexIdx[p]));
+  }
+
+  tlp::Coord minC = meshBB[0];
+  tlp::Coord maxC = meshBB[1];
+
+  nbVertices = vertices.size();
+  nbIndices = indices.size();
+  nbOutlineIndices = outlineIndices.size();
+
+  for (size_t i = 0; i < vertices.size(); ++i) {
+    if (meshBB.height() > meshBB.width()) {
+      vertices[i][0] = ((vertices[i][0] - minC[0]) / (maxC[0] - minC[0]) - 0.5) *
+                       (meshBB.width() / float(meshBB.height()));
+      vertices[i][1] = ((vertices[i][1] - minC[1]) / (maxC[1] - minC[1])) - 0.5;
+    } else {
+      vertices[i][0] = ((vertices[i][0] - minC[0]) / (maxC[0] - minC[0])) - 0.5;
+      vertices[i][1] = (((vertices[i][1] - minC[1]) / (maxC[1] - minC[1])) - 0.5) *
+                       (meshBB.height() / float(meshBB.width()));
+    }
+
+    const tlp::Coord &v = vertices[i];
+    boundingBox.expand(v);
+    texCoords.push_back(Vec2f(v[0] + 0.5, v[1] + 0.5));
+  }
+
+  glGenBuffers(1, &renderingDataBuffer);
+  glGenBuffers(1, &indicesBuffer);
+
+  glBindBuffer(GL_ARRAY_BUFFER, renderingDataBuffer);
+  glBufferData(GL_ARRAY_BUFFER, (vertices.size() * 3 + texCoords.size() * 2) * sizeof(float),
+               nullptr, GL_STATIC_DRAW);
+  glBufferSubData(GL_ARRAY_BUFFER, 0, vertices.size() * 3 * sizeof(float), &vertices[0]);
+  glBufferSubData(GL_ARRAY_BUFFER, vertices.size() * 3 * sizeof(float),
+                  texCoords.size() * 2 * sizeof(float), &texCoords[0]);
+  glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, indicesBuffer);
+  glBufferData(GL_ELEMENT_ARRAY_BUFFER,
+               (indices.size() + outlineIndices.size()) * sizeof(unsigned short), nullptr,
+               GL_STATIC_DRAW);
+  glBufferSubData(GL_ELEMENT_ARRAY_BUFFER, 0, indices.size() * sizeof(unsigned short), &indices[0]);
+  glBufferSubData(GL_ELEMENT_ARRAY_BUFFER, indices.size() * sizeof(unsigned short),
+                  outlineIndices.size() * sizeof(unsigned short), &outlineIndices[0]);
+  glBindBuffer(GL_ARRAY_BUFFER, 0);
+  glBindBuffer(GL_ELEMENT_ARRAY_BUFFER, 0);
+}
+
 } // namespace tlp
