@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -24,9 +24,7 @@
 #include <tulip/GlEdge.h>
 #include <tulip/GlNode.h>
 #include <tulip/GlGraphInputData.h>
-#include <tulip/Graph.h>
 #include <tulip/Curves.h>
-#include <tulip/GlShaderProgram.h>
 #include <tulip/GlGraphRenderingParameters.h>
 
 using namespace std;
@@ -47,6 +45,7 @@ GlVertexArrayManager::GlVertexArrayManager(GlGraphInputData *i)
     : inputData(i), graph(inputData->getGraph()), layoutProperty(inputData->getElementLayout()),
       sizeProperty(inputData->getElementSize()), shapeProperty(inputData->getElementShape()),
       rotationProperty(inputData->getElementRotation()),
+      lengthRatioProperty(inputData->getEdgeLengthRatio()),
       colorProperty(inputData->getElementColor()),
       borderColorProperty(inputData->getElementBorderColor()),
       borderWidthProperty(inputData->getElementBorderWidth()),
@@ -92,6 +91,7 @@ void GlVertexArrayManager::setInputData(GlGraphInputData *inputData) {
   sizeProperty = inputData->getElementSize();
   shapeProperty = inputData->getElementShape();
   rotationProperty = inputData->getElementRotation();
+  lengthRatioProperty = inputData->getEdgeLengthRatio();
   colorProperty = inputData->getElementColor();
   borderColorProperty = inputData->getElementBorderColor();
   borderWidthProperty = inputData->getElementBorderWidth();
@@ -175,6 +175,18 @@ bool GlVertexArrayManager::haveToCompute() {
     recompute = true;
   }
 
+  // length ratio property changed
+  if (lengthRatioProperty != inputData->getEdgeLengthRatio()) {
+    if (lengthRatioProperty && layoutObserverActivated)
+      lengthRatioProperty->removeListener(this);
+
+    lengthRatioProperty = inputData->getEdgeLengthRatio();
+    lengthRatioProperty->addListener(this);
+
+    clearLayoutData();
+    recompute = true;
+  }
+
   // Color property changed
   if (colorProperty != inputData->getElementColor()) {
     if (colorProperty && colorObserverActivated)
@@ -665,9 +677,11 @@ void GlVertexArrayManager::visit(GlEdge *glEdge) {
     Coord srcCoord, tgtCoord;
     Size srcSize, tgtSize;
 
+    const vector<Coord> &bends = layoutProperty->getEdgeValue(e);
+    float lengthRatio = bends.size() ? 1 : lengthRatioProperty->getEdgeValue(e);
     vector<Coord> &vertices = eInfos.lineVertices;
-    const unsigned int nbLines =
-        glEdge->getVertices(inputData, e, src, tgt, srcCoord, tgtCoord, srcSize, tgtSize, vertices);
+    const unsigned int nbLines = glEdge->getVertices(inputData, e, src, tgt, srcCoord, tgtCoord,
+                                                     srcSize, tgtSize, vertices, lengthRatio);
 
     if (nbLines != 0) {
       pointsCoordsArray[glEdge->pos + nbNodes] = vertices[0];
@@ -686,9 +700,8 @@ void GlVertexArrayManager::visit(GlEdge *glEdge) {
       vector<Coord> &quadVertices = eInfos.quadVertices;
       buildCurvePoints(vertices, edgeSizes, srcCoord, tgtCoord, quadVertices);
 
-      const vector<Coord> &bends = layoutProperty->getEdgeValue(e);
       glEdge->getEdgeAnchor(inputData, src, tgt, bends, srcCoord, tgtCoord, srcSize, tgtSize,
-                            vertices[0], vertices[nbLines - 1]);
+                            vertices[0], vertices[nbLines - 1], lengthRatio);
     }
   }
 
@@ -870,9 +883,9 @@ void GlVertexArrayManager::activatePointNodeDisplay(GlNode *glNode, bool selecte
 
 void GlVertexArrayManager::propertyValueChanged(PropertyInterface *property) {
   if (layoutProperty == property || sizeProperty == property || shapeProperty == property ||
-      rotationProperty == property || srcAnchorShapeProperty == property ||
-      tgtAnchorShapeProperty == property || srcAnchorSizeProperty == property ||
-      tgtAnchorSizeProperty == property) {
+      rotationProperty == property || lengthRatioProperty == property ||
+      srcAnchorShapeProperty == property || tgtAnchorShapeProperty == property ||
+      srcAnchorSizeProperty == property || tgtAnchorSizeProperty == property) {
     setHaveToComputeLayout(true);
     clearLayoutData();
 
@@ -888,11 +901,15 @@ void GlVertexArrayManager::propertyValueChanged(PropertyInterface *property) {
     if (rotationProperty)
       rotationProperty->removeListener(this);
 
+    if (lengthRatioProperty)
+      lengthRatioProperty->removeListener(this);
+
     layoutObserverActivated = false;
   }
 
-  if (edgesModified || layoutProperty == property || colorProperty == property ||
-      borderColorProperty == property || borderWidthProperty == property) {
+  if (edgesModified || layoutProperty == property || lengthRatioProperty == property ||
+      colorProperty == property || borderColorProperty == property ||
+      borderWidthProperty == property) {
     setHaveToComputeColor(true);
     clearColorData();
 
@@ -953,6 +970,7 @@ void GlVertexArrayManager::initObservers() {
     sizeProperty->addListener(this);
     shapeProperty->addListener(this);
     rotationProperty->addListener(this);
+    lengthRatioProperty->addListener(this);
     srcAnchorShapeProperty->addListener(this);
     tgtAnchorShapeProperty->addListener(this);
     srcAnchorSizeProperty->addListener(this);
@@ -988,6 +1006,9 @@ void GlVertexArrayManager::clearObservers(PropertyInterface *deletedProperty) {
     if (deletedProperty != rotationProperty)
       rotationProperty->removeListener(this);
 
+    if (lengthRatioProperty && (deletedProperty != lengthRatioProperty))
+      lengthRatioProperty->removeListener(this);
+
     if (deletedProperty != srcAnchorShapeProperty)
       srcAnchorShapeProperty->removeListener(this);
 
@@ -1025,8 +1046,8 @@ void GlVertexArrayManager::treatEvent(const Event &evt) {
     switch (graphEvent->getType()) {
     case GraphEvent::TLP_ADD_NODE:
     case GraphEvent::TLP_ADD_EDGE:
-    case GraphEvent::TLP_DEL_NODE:
-    case GraphEvent::TLP_DEL_EDGE:
+    case GraphEvent::TLP_AFTER_DEL_NODE:
+    case GraphEvent::TLP_AFTER_DEL_EDGE:
     case GraphEvent::TLP_REVERSE_EDGE:
     case GraphEvent::TLP_AFTER_SET_ENDS:
       clearData();
@@ -1053,6 +1074,9 @@ void GlVertexArrayManager::treatEvent(const Event &evt) {
       } else if (property == rotationProperty) {
         rotationProperty = nullptr;
         clearData();
+      } else if (property == lengthRatioProperty) {
+        lengthRatioProperty = nullptr;
+        clearData();
       } else if (property == borderColorProperty) {
         borderColorProperty = nullptr;
         clearColorData();
@@ -1106,8 +1130,9 @@ void GlVertexArrayManager::treatEvent(const Event &evt) {
     case PropertyEvent::TLP_BEFORE_SET_EDGE_VALUE:
 
       if (layoutProperty == property || shapeProperty == property ||
-          srcAnchorShapeProperty == property || tgtAnchorShapeProperty == property ||
-          srcAnchorSizeProperty == property || tgtAnchorSizeProperty == property) {
+          lengthRatioProperty == property || srcAnchorShapeProperty == property ||
+          tgtAnchorShapeProperty == property || srcAnchorSizeProperty == property ||
+          tgtAnchorSizeProperty == property) {
         edgesModified = true;
       }
 
