@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -47,12 +47,8 @@ public:
 };
 
 class ParenMatcherHighlighter : public QSyntaxHighlighter {
-
-  QVector<char> _leftParensToMatch;
-  QVector<char> _rightParensToMatch;
-
 public:
-  explicit ParenMatcherHighlighter(QTextDocument *parent = nullptr);
+  explicit ParenMatcherHighlighter(QTextDocument *parent = nullptr) : QSyntaxHighlighter(parent) {}
 
 protected:
   void highlightBlock(const QString &text) override;
