@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -111,38 +111,24 @@ public:
   int lineNumberAreaWidth() const;
 
   inline qreal tabWidth() const {
-#if (QT_VERSION < QT_VERSION_CHECK(5, 10, 0))
-    return tabStopWidth();
-#else
+
     return tabStopDistance();
-#endif
   }
 
   inline void setTabWidth(qreal width) {
-#if (QT_VERSION < QT_VERSION_CHECK(5, 10, 0))
-    setTabStopWidth(width);
-#else
     setTabStopDistance(width);
-#endif
   }
 
   inline int charWidth(char c) const {
     if (c == '\t') {
       return textWidth("    ");
     }
-#if (QT_VERSION < QT_VERSION_CHECK(5, 11, 0))
-    return fontMetrics().width(QLatin1Char(c));
-#else
+
     return fontMetrics().horizontalAdvance(QLatin1Char(c));
-#endif
   }
 
   inline int textWidth(const QString &text) const {
-#if (QT_VERSION < QT_VERSION_CHECK(5, 11, 0))
-    return fontMetrics().width(QString(text).replace('\t', "    "));
-#else
     return fontMetrics().horizontalAdvance(QString(text).replace('\t', "    "));
-#endif
   }
   void indicateScriptCurrentError(int lineNumber);
   void clearErrorIndicator();
@@ -254,7 +240,9 @@ public:
 
   static void deleteStaticResources() {
     delete _autoCompletionDb;
+    _autoCompletionDb = nullptr;
     delete _autoCompletionList;
+    _autoCompletionList = nullptr;
   }
 
 protected:
@@ -316,6 +304,7 @@ protected:
   bool _findReplaceActivate;
   bool _commentShortcutsActivate;
   bool _indentShortcutsActivate;
+  bool _darkBackground;
 
   QPoint _toolTipPos;
   QString _toolTipText;
@@ -327,7 +316,7 @@ protected:
   bool _shellWidget;
   bool _moduleEditor;
 
-  QMainWindow *_mainWindow;
+  static QMainWindow *_mainWindow;
 
   QString _indentPattern;
 };
