@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -53,21 +53,19 @@ public:
 
   bool eventFilter(QObject *, QEvent *) override;
 
-  void saveCurrentEditorContentToFile();
-
-  void saveEditorContentToFile(int);
-
   void increaseFontSize();
 
   void decreaseFontSize();
 
   QTabBar *tabBar() const;
 
+  void closeTab(int tab);
+
 signals:
 
   void tabAboutToBeDeleted(int);
 
-  void fileSaved(int);
+  void fileEdited();
 
   void filesReloaded();
 
