@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -25,8 +25,6 @@
 #include "tulip/PythonIncludes.h"
 #include "tulip/PythonInterpreter.h"
 
-#include <QStringList>
-
 using namespace tlp;
 
 QString consoleOuputString = "";
@@ -41,11 +39,7 @@ typedef struct {
 } consoleutils_ConsoleOutput;
 
 static void consoleutils_ConsoleOutput_dealloc(consoleutils_ConsoleOutput *self) {
-#if PY_MAJOR_VERSION >= 3
   Py_TYPE(self)->tp_free(reinterpret_cast<PyObject *>(self));
-#else
-  self->ob_type->tp_free(reinterpret_cast<PyObject *>(self));
-#endif
 }
 
 static PyObject *consoleutils_ConsoleOutput_new(PyTypeObject *type, PyObject *, PyObject *) {
@@ -131,16 +125,14 @@ static PyObject *consoleutils_ConsoleOutput_flush(PyObject *self, PyObject *) {
   Py_RETURN_NONE;
 }
 
-// T_BOOL is not defined for older versions of Python (2.5 for instance)
-// define it as T_INT in that case
-#ifndef T_BOOL
-#define T_BOOL T_INT
+#if PY_MINOR_VERSION < 12
+#define Py_T_BOOL T_BOOL
 #endif
 
 static PyMemberDef consoleutils_ConsoleOutput_members[] = {
-    {const_cast<char *>("stderrflag"), T_BOOL, offsetof(consoleutils_ConsoleOutput, stderrflag), 0,
-     const_cast<char *>("flag for stderr")},
-    {const_cast<char *>("writeToConsole"), T_BOOL,
+    {const_cast<char *>("stderrflag"), Py_T_BOOL, offsetof(consoleutils_ConsoleOutput, stderrflag),
+     0, const_cast<char *>("flag for stderr")},
+    {const_cast<char *>("writeToConsole"), Py_T_BOOL,
      offsetof(consoleutils_ConsoleOutput, writeToConsole), 0,
      const_cast<char *>("flag for enabling/disabling console output")},
     {NULL, 0, 0, 0, NULL} /* Sentinel */
@@ -157,12 +149,7 @@ static PyMethodDef consoleutils_ConsoleOutput_methods[] = {
 };
 
 static PyTypeObject consoleutils_ConsoleOutputType = {
-#if PY_MAJOR_VERSION >= 3
-    PyVarObject_HEAD_INIT(NULL, 0)
-#else
-    PyObject_HEAD_INIT(NULL) 0, /*ob_size*/
-#endif
-        "consoleutils.ConsoleOutput",                                 /*tp_name*/
+    PyVarObject_HEAD_INIT(NULL, 0) "consoleutils.ConsoleOutput",      /*tp_name*/
     sizeof(consoleutils_ConsoleOutput),                               /*tp_basicsize*/
     0,                                                                /*tp_itemsize*/
     reinterpret_cast<destructor>(consoleutils_ConsoleOutput_dealloc), /*tp_dealloc*/
@@ -207,16 +194,21 @@ static PyTypeObject consoleutils_ConsoleOutputType = {
     0,
     0,
     0,
-    0
-#if PY_MAJOR_VERSION >= 3 && PY_MINOR_VERSION >= 4
-    ,
-    0
-#endif
-#if PY_MAJOR_VERSION >= 3 && PY_MINOR_VERSION >= 8
-    ,
+    0,
     0,
     0
+#if PY_MINOR_VERSION >= 12
+    ,
+    0
 #endif
+#if PY_MINOR_VERSION >= 13
+    ,
+    0
+#endif
+#if PY_MINOR_VERSION >= 14
+#error Python version PY_MAJOR_VERSION.PY_MINOR_VERSION not supported
+#endif
+
 };
 
 typedef struct {
@@ -224,11 +216,7 @@ typedef struct {
 } consoleutils_ConsoleInput;
 
 static void consoleutils_ConsoleInput_dealloc(consoleutils_ConsoleInput *self) {
-#if PY_MAJOR_VERSION >= 3
   Py_TYPE(self)->tp_free(reinterpret_cast<PyObject *>(self));
-#else
-  self->ob_type->tp_free(reinterpret_cast<PyObject *>(self));
-#endif
 }
 
 static PyObject *consoleutils_ConsoleInput_new(PyTypeObject *type, PyObject *, PyObject *) {
@@ -242,31 +230,21 @@ static int consoleutils_ConsoleInput_init(consoleutils_ConsoleInput *, PyObject
 /* This redirects stdin from the calling script. */
 static PyObject *consoleutils_ConsoleInput_readline(PyObject *, PyObject *) {
   QString line = PythonInterpreter::getInstance()->readLineFromConsole();
-#if PY_MAJOR_VERSION >= 3
-  PyObject *obj = PyUnicode_FromString(line.toLatin1().data());
-#else
-  PyObject *obj = PyString_FromString(line.toLatin1().data());
-#endif
-  return obj;
+  return PyUnicode_FromString(line.toUtf8().data());
 }
 
 static PyMemberDef consoleutils_ConsoleInput_members[] = {
-    {NULL, 0, 0, 0, NULL} /* Sentinel */
+    {nullptr, 0, 0, 0, nullptr} /* Sentinel */
 };
 
 static PyMethodDef consoleutils_ConsoleInput_methods[] = {
     {"readline", static_cast<PyCFunction>(consoleutils_ConsoleInput_readline), METH_VARARGS,
      "read an input line from the console"},
-    {NULL, NULL, 0, NULL} /* Sentinel */
+    {nullptr, nullptr, 0, nullptr} /* Sentinel */
 };
 
 static PyTypeObject consoleutils_ConsoleInputType = {
-#if PY_MAJOR_VERSION >= 3
-    PyVarObject_HEAD_INIT(NULL, 0)
-#else
-    PyObject_HEAD_INIT(NULL) 0, /*ob_size*/
-#endif
-        "consoleutils.ConsoleInput",                                 /*tp_name*/
+    PyVarObject_HEAD_INIT(nullptr, 0) "consoleutils.ConsoleInput",   /*tp_name*/
     sizeof(consoleutils_ConsoleInput),                               /*tp_basicsize*/
     0,                                                               /*tp_itemsize*/
     reinterpret_cast<destructor>(consoleutils_ConsoleInput_dealloc), /*tp_dealloc*/
@@ -311,31 +289,30 @@ static PyTypeObject consoleutils_ConsoleInputType = {
     0,
     0,
     0,
+    0,
+    0,
     0
-#if PY_MAJOR_VERSION >= 3 && PY_MINOR_VERSION >= 4
+#if PY_MINOR_VERSION >= 12
     ,
     0
 #endif
-#if PY_MAJOR_VERSION >= 3 && PY_MINOR_VERSION >= 8
+#if PY_MINOR_VERSION >= 13
     ,
-    0,
     0
 #endif
 };
 
-#if PY_MAJOR_VERSION >= 3
 static struct PyModuleDef consoleutilsModuleDef = {
     PyModuleDef_HEAD_INIT,
     "consoleutils", /* m_name */
     "",             /* m_doc */
     -1,             /* m_size */
-    NULL,           /* m_methods */
-    NULL,           /* m_reload */
-    NULL,           /* m_traverse */
-    NULL,           /* m_clear */
-    NULL,           /* m_free */
+    nullptr,        /* m_methods */
+    nullptr,        /* m_reload */
+    nullptr,        /* m_traverse */
+    nullptr,        /* m_clear */
+    nullptr,        /* m_free */
 };
-#endif
 
 // This is called via the PyImport_AppendInittab mechanism called
 // during interpreter initialization, to make the built-in consoleutils
@@ -349,20 +326,14 @@ PyMODINIT_FUNC initconsoleutils(void) {
   PyType_Ready(&consoleutils_ConsoleOutputType);
   PyType_Ready(&consoleutils_ConsoleInputType);
 
-#if PY_MAJOR_VERSION >= 3
   m = PyModule_Create(&consoleutilsModuleDef);
-#else
-  m = Py_InitModule("consoleutils", NULL);
-#endif
   PyObject *cot = reinterpret_cast<PyObject *>(&consoleutils_ConsoleOutputType);
   Py_INCREF(cot);
   PyModule_AddObject(m, "ConsoleOutput", cot);
   PyObject *cit = reinterpret_cast<PyObject *>(&consoleutils_ConsoleInputType);
   Py_INCREF(cit);
   PyModule_AddObject(m, "ConsoleInput", cit);
-#if PY_MAJOR_VERSION >= 3
   return m;
-#endif
 }
 
 #ifdef __GNUC__
