@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -21,47 +21,30 @@
 #include "tulip/PythonCodeEditor.h"
 #include "tulip/PythonCodeHighlighter.h"
 #include "tulip/ParenMatcherHighlighter.h"
+#include "tulip/TlpQtTools.h"
 
 #include <tulip/Perspective.h>
+#include <tulip/TulipSettings.h>
 
 #include <QTextStream>
 #include <QPainter>
 #include <QTextBlock>
 #include <QApplication>
-#include <QMainWindow>
 #include <QToolTip>
 #include <QScrollBar>
 #include <QMessageBox>
 #include <QMimeData>
-#include <QDesktopWidget>
 #include <QFileInfo>
+#include <QRegularExpression>
 #include <QScreen>
 #include <QPushButton>
+#include <QWindow>
 
 #include "ui_FindReplaceDialog.h"
 
 using namespace std;
 using namespace tlp;
 
-class GrabKeyboardFocusEventFilter : public QObject {
-public:
-  bool eventFilter(QObject *, QEvent *event) override {
-    if (event->type() == QEvent::ShortcutOverride) {
-      // do not override decrease/increase font size shortcuts
-      QKeyEvent *ke = static_cast<QKeyEvent *>(event);
-      if ((ke->modifiers() & Qt::ControlModifier) &&
-          (ke->key() == Qt::Key_Minus || ke->key() == Qt::Key_Plus))
-        return false;
-      event->accept();
-      return true;
-    }
-
-    return false;
-  }
-};
-
-static GrabKeyboardFocusEventFilter keyboardFocusEventFilter;
-
 static char sepChar[] = {' ', '\t', '=', '(', '[', '{', ',', '*', '+', '/', '^', '-', 0};
 
 namespace tlp {
@@ -95,7 +78,6 @@ AutoCompletionList::AutoCompletionList() : QListWidget(), _codeEditor(nullptr) {
   setAttribute(Qt::WA_StaticContents);
   setFrameShape(StyledPanel);
   setFrameShadow(Plain);
-  installEventFilter(&keyboardFocusEventFilter);
   _activated = false;
   _wasActivated = false;
   setToolTip("Use up and down arrow keys to navigate through the list (or use the mouse wheel).\n"
@@ -257,6 +239,9 @@ FindReplaceDialog::FindReplaceDialog(QPlainTextEdit *editor, QWidget *parent)
                                            Qt::WindowTitleHint | Qt::WindowCloseButtonHint)),
       _ui(new Ui::FindReplaceDialogData), _editor(editor) {
   _ui->setupUi(this);
+  // fix display of QCheckBox and QRadioButton children
+  tlpFixCBRBs(this);
+
   _findButton = _ui->buttonBox->button(QDialogButtonBox::Reset);
   _findButton->setText("Find");
   connect(_findButton, SIGNAL(clicked()), this, SLOT(doFind()));
@@ -348,7 +333,7 @@ bool FindReplaceDialog::doFind() {
   if (!_ui->regexpCB->isChecked()) {
     sel = _editor->document()->find(text, _editor->textCursor(), findFlags);
   } else {
-    sel = _editor->document()->find(QRegExp(text), _editor->textCursor(), findFlags);
+    sel = _editor->document()->find(QRegularExpression(text), _editor->textCursor(), findFlags);
   }
 
   bool ret = !sel.isNull();
@@ -367,7 +352,7 @@ bool FindReplaceDialog::doFind() {
     if (!_ui->regexpCB->isChecked()) {
       sel = _editor->document()->find(text, cursor, findFlags);
     } else {
-      sel = _editor->document()->find(QRegExp(text), cursor, findFlags);
+      sel = _editor->document()->find(QRegularExpression(text), cursor, findFlags);
     }
 
     ret = !sel.isNull();
@@ -444,10 +429,10 @@ void FindReplaceDialog::doReplaceAll() {
 
 AutoCompletionList *PythonCodeEditor::_autoCompletionList = nullptr;
 AutoCompletionDataBase *PythonCodeEditor::_autoCompletionDb = nullptr;
+QMainWindow *PythonCodeEditor::_mainWindow = nullptr;
 
 PythonCodeEditor::PythonCodeEditor(QWidget *parent)
     : QPlainTextEdit(parent), _highlighter(nullptr), _tooltipActive(false), _indentPattern(4, ' ') {
-  installEventFilter(&keyboardFocusEventFilter);
   setAutoIndentation(true);
   setIndentationGuides(true);
   setHighlightEditedLine(true);
@@ -468,9 +453,7 @@ PythonCodeEditor::PythonCodeEditor(QWidget *parent)
   _currentFont.setPointSize(8);
 #endif
 
-  setStyleSheet("QFrame { background-color: white; }"
-                "QPlainTextEdit { selection-background-color: #C0C0C0; }");
-
+  _darkBackground = TulipSettings::isDisplayInDarkMode();
   format.setFont(_currentFont);
   setCurrentCharFormat(format);
 
@@ -481,7 +464,7 @@ PythonCodeEditor::PythonCodeEditor(QWidget *parent)
   updateLineNumberAreaWidth();
 
   _parenHighlighter = new ParenMatcherHighlighter(document());
-  _highlighter = new PythonCodeHighlighter(document());
+  _highlighter = new PythonCodeHighlighter(document(), _darkBackground);
 
   if (_autoCompletionList == nullptr) {
     _autoCompletionList = new AutoCompletionList();
@@ -588,7 +571,7 @@ void PythonCodeEditor::resizeEvent(QResizeEvent *e) {
 
 void PythonCodeEditor::lineNumberAreaPaintEvent(QPaintEvent *event) {
   QPainter painter(_lineNumberArea);
-  painter.fillRect(event->rect(), Qt::lightGray);
+  painter.fillRect(event->rect(), QColor("silver"));
 
   QTextBlock block = firstVisibleBlock();
   int blockNumber = block.blockNumber();
@@ -611,9 +594,7 @@ void PythonCodeEditor::lineNumberAreaPaintEvent(QPaintEvent *event) {
   }
 }
 
-static float clamp(float f, float minV, float maxV) {
-  return std::min(std::max(f, minV), maxV);
-}
+#define CLAMP(f, minV, maxV) std::min(std::max(f, minV), maxV)
 
 void PythonCodeEditor::updateTabWidth() {
   setTabWidth(textWidth(_indentPattern));
@@ -623,7 +604,7 @@ void PythonCodeEditor::zoomIn() {
   QTextCursor cursor = textCursor();
   selectAll();
   QTextCharFormat format = currentCharFormat();
-  _currentFont.setPointSize(clamp(_currentFont.pointSize() + 1, 6, 30));
+  _currentFont.setPointSize(CLAMP(_currentFont.pointSize() + 1, 6, 30));
   format.setFont(_currentFont);
   setCurrentCharFormat(format);
   setTextCursor(cursor);
@@ -634,7 +615,7 @@ void PythonCodeEditor::zoomOut() {
   QTextCursor cursor = textCursor();
   selectAll();
   QTextCharFormat format = currentCharFormat();
-  _currentFont.setPointSize(clamp(_currentFont.pointSize() - 1, 6, 30));
+  _currentFont.setPointSize(CLAMP(_currentFont.pointSize() - 1, 6, 30));
   format.setFont(_currentFont);
   setCurrentCharFormat(format);
   setTextCursor(cursor);
@@ -692,7 +673,8 @@ void PythonCodeEditor::paintEvent(QPaintEvent *event) {
     QRect tooltipRect(tPos, tPos + QPoint(width + 2 * charWidth(' '), height));
 #endif
     painter.drawRect(tooltipRect);
-    painter.fillRect(tooltipRect, QColor(249, 251, 100, 200));
+    painter.fillRect(tooltipRect, QColor("#FFFFD3"));
+    painter.setPen(Qt::black);
 #ifndef __APPLE__
     painter.drawText(tooltipRect, _toolTipText);
 #else
@@ -897,7 +879,7 @@ void PythonCodeEditor::highlightCurrentLine() {
 
   if (highlightEditedLine() && !isReadOnly() && selectedText().isEmpty()) {
     QTextEdit::ExtraSelection selection;
-    QColor lineColor = QColor(Qt::yellow).lighter(160);
+    QColor lineColor(_darkBackground ? "#CECECE" : "#D8D8D8");
     selection.format = textCursor().block().charFormat();
     selection.format.setBackground(lineColor);
     selection.format.setProperty(QTextFormat::FullWidthSelection, true);
@@ -917,10 +899,10 @@ void PythonCodeEditor::highlightSelection() {
     findFlags |= QTextDocument::FindCaseSensitively;
     findFlags |= QTextDocument::FindWholeWords;
     QTextCursor cursor = document()->find(text, QTextCursor(document()->begin()), findFlags);
+    QColor lineColor = QColor(_darkBackground ? "#D0D0D0" : "#D8D8D8").darker(110);
 
     while (!cursor.isNull()) {
       QTextEdit::ExtraSelection selection;
-      QColor lineColor = QColor(Qt::yellow);
       selection.format = cursor.block().charFormat();
       selection.format.setBackground(lineColor);
       selection.cursor = cursor;
@@ -935,7 +917,7 @@ void PythonCodeEditor::highlightSelection() {
 void PythonCodeEditor::createParenSelection(int pos) {
   QList<QTextEdit::ExtraSelection> selections = extraSelections();
   QTextEdit::ExtraSelection selection;
-  selection.format.setForeground(Qt::red);
+  selection.format.setForeground(QColor("#FFAB00"));
   QTextCursor cursor = textCursor();
   cursor.setPosition(pos);
   cursor.movePosition(QTextCursor::NextCharacter, QTextCursor::KeepAnchor);
@@ -952,7 +934,7 @@ void PythonCodeEditor::highlightErrors() {
     QTextBlock block = document()->findBlockByNumber(_currentErrorLines.at(i));
     selection.format = block.charFormat();
     selection.format.setUnderlineStyle(QTextCharFormat::WaveUnderline);
-    selection.format.setUnderlineColor(Qt::red);
+    selection.format.setUnderlineColor(QColor("#D51A1A"));
     selection.cursor = QTextCursor(block);
     selection.cursor.select(QTextCursor::LineUnderCursor);
     selections.append(selection);
@@ -1178,7 +1160,14 @@ void PythonCodeEditor::keyPressEvent(QKeyEvent *e) {
 
 void PythonCodeEditor::wheelEvent(QWheelEvent *event) {
   if (!_autoCompletionList->isVisible()) {
-    QPlainTextEdit::wheelEvent(event);
+    if (event->modifiers() == Qt::ControlModifier) {
+      if (event->angleDelta().y() > 0)
+        zoomIn();
+      else
+        zoomOut();
+      event->accept();
+    } else
+      QPlainTextEdit::wheelEvent(event);
   }
 }
 
@@ -1246,7 +1235,7 @@ void PythonCodeEditor::updateAutoCompletionListPosition() {
   int pos = lineNumberAreaWidth() + left + 1;
   int stop = 0;
 
-  for (int i = textBeforeCursor.length(); i >= 0; --i) {
+  for (int i = textBeforeCursor.length() - 1; i >= 0; --i) {
     if (textBeforeCursor[i] == '\t' || textBeforeCursor[i] == ' ' || textBeforeCursor[i] == '.' ||
         textBeforeCursor[i] == '(' || textBeforeCursor[i] == '[') {
       stop = i + 1;
@@ -1263,12 +1252,7 @@ void PythonCodeEditor::updateAutoCompletionListPosition() {
   }
 
   if (mapToGlobal(QPoint(0, bottom + _autoCompletionList->height())).y() >
-#if (QT_VERSION < QT_VERSION_CHECK(5, 6, 0))
-      QApplication::desktop()->screenGeometry().height()
-#else
-      QApplication::primaryScreen()->geometry().height()
-#endif
-  )
+      _mainWindow->windowHandle()->screen()->geometry().height())
     _autoCompletionList->move(mapToGlobal(QPoint(pos, top - _autoCompletionList->height())));
   else
     _autoCompletionList->move(mapToGlobal(QPoint(pos, bottom)));
@@ -1288,7 +1272,7 @@ void PythonCodeEditor::updateAutoCompletionList(bool dotContext) {
 
   QString textBeforeCursorTrimmed = textBeforeCursor.trimmed();
 
-  // string litteral edition : don't show autocompletion list
+  // string literal edition : don't show autocompletion list
   if (dotContext && (textBeforeCursorTrimmed.count("\"") % 2 == 1 ||
                      textBeforeCursorTrimmed.count("\'") % 2 == 1))
     return;
@@ -1309,8 +1293,8 @@ QString PythonCodeEditor::getEditedFunctionName() const {
 
   QString funcName = "global";
   QString className = "";
-  QRegExp funcRegexp("^def [A-Za-z_][A-Za-z0-9_]*\\(.*\\)[ \t]*:$");
-  QRegExp classRegexp("^class [A-Za-z_][A-Za-z0-9_]*.*:$");
+  QRegularExpression funcRegexp("^def [A-Za-z_][A-Za-z0-9_]*\\(.*\\)[ \t]*:$");
+  QRegularExpression classRegexp("^class [A-Za-z_][A-Za-z0-9_]*.*:$");
 
   QTextBlock block = textCursor().block();
   QString currentLine = block.text();
@@ -1325,7 +1309,7 @@ QString PythonCodeEditor::getEditedFunctionName() const {
       if (currentLine.startsWith('#') || currentLine.isEmpty())
         continue;
 
-      if (funcName == "global" && funcRegexp.indexIn(currentLine.trimmed()) != -1) {
+      if (funcName == "global" && currentLine.trimmed().indexOf(funcRegexp) != -1) {
         funcName = currentLine.trimmed();
         funcName = funcName.mid(4, funcName.indexOf('(') - 4);
 
@@ -1334,7 +1318,7 @@ QString PythonCodeEditor::getEditedFunctionName() const {
         }
       }
 
-      if (classRegexp.indexIn(currentLine.trimmed()) != -1) {
+      if (currentLine.trimmed().indexOf(classRegexp) != -1) {
         className = currentLine.trimmed();
 
         if (className.indexOf('(') != -1)
@@ -1665,11 +1649,11 @@ bool PythonCodeEditor::loadCodeFromFile(const QString &filePath) {
 
   if (filePath == getFileName() && !toPlainText().isEmpty()) {
     if (scriptCode != getCleanCode() &&
-        QMessageBox::question(
-            nullptr, "File changed on disk",
-            QString("The file ") + filePath +
-                " has been modified by another editor. Do you want to reload it ?",
-            QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes) == QMessageBox::Yes) {
+        QMessageBox::question(QApplication::activeWindow(), "File changed on disk",
+                              QString("The file ") + filePath +
+                                  " has been modified by another editor. Do you want to reload it?",
+                              QMessageBox::Yes | QMessageBox::No,
+                              QMessageBox::Yes) == QMessageBox::Yes) {
       setPlainText(scriptCode);
     } else {
       return false;
@@ -1689,7 +1673,6 @@ bool PythonCodeEditor::saveCodeToFile() {
   if (getFileName() == fileInfo.absoluteFilePath() &&
       file.open(QIODevice::WriteOnly | QIODevice::Text)) {
     QTextStream out(&file);
-    out.setCodec("UTF-8");
     out << getCleanCode();
     file.close();
     QFileInfo fileInfo(file);
