@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -25,7 +25,7 @@
 
 using namespace tlp;
 
-PythonCodeHighlighter::PythonCodeHighlighter(QTextDocument *parent)
+PythonCodeHighlighter::PythonCodeHighlighter(QTextDocument *parent, bool /*darkBackground*/)
     : QSyntaxHighlighter(parent), _shellMode(false) {
 
   QTextCharFormat builtinFormat;
@@ -33,31 +33,33 @@ PythonCodeHighlighter::PythonCodeHighlighter(QTextDocument *parent)
 
   HighlightingRule rule;
 
-  _commentFormat.setForeground(Qt::darkGreen);
+  _commentFormat.setForeground(QColor("#388E3C"));
   _functionFormat.setFontWeight(QFont::Bold);
-  _functionFormat.setForeground(Qt::darkCyan);
-  _tlpApiFormat.setForeground(QColor(128, 128, 0));
+  _functionFormat.setForeground(QColor("#0D47F1"));
+  _tlpApiFormat.setForeground(QColor("#E65100"));
   _classFormat.setFontWeight(QFont::Bold);
-  _classFormat.setForeground(Qt::blue);
-  _qtApiFormat.setForeground(QColor(0, 110, 40));
+  _classFormat.setForeground(QColor("#7E57C2"));
+  _qtApiFormat.setForeground(QColor("#00D09A"));
+  _keywordFormat.setForeground(QColor("#00A8FF"));
+  _numberFormat.setForeground(QColor("#00B8D4"));
+  _quotationFormat.setForeground(QColor("#E040FB"));
 
-  rule.pattern = QRegExp("def [A-Za-z_][A-Za-z0-9_]+(?=\\()");
+  rule.pattern = QRegularExpression("def [A-Za-z_][A-Za-z0-9_]+(?=\\()");
   rule.format = _functionFormat;
   _highlightingRules.append(rule);
 
-  rule.pattern = QRegExp("class [A-Za-z_][A-Za-z0-9_]+");
+  rule.pattern = QRegularExpression("class [A-Za-z_][A-Za-z0-9_]+");
   rule.format = _classFormat;
   _highlightingRules.append(rule);
 
-  rule.pattern = QRegExp("tlp.*\\.[A-Za-z0-9_.]+");
+  rule.pattern = QRegularExpression("tlp.*\\.[A-Za-z0-9_.]+");
   rule.format = _tlpApiFormat;
   _highlightingRules.append(rule);
 
-  rule.pattern = QRegExp("^[ \t]*@.*$");
+  rule.pattern = QRegularExpression("^[ \t]*@.*$");
   rule.format = builtinFormat;
   _highlightingRules.append(rule);
 
-  _keywordFormat.setForeground(Qt::darkBlue);
   _keywordFormat.setFontWeight(QFont::Bold);
   QStringList keywordPatterns;
   int i = 0;
@@ -89,11 +91,7 @@ PythonCodeHighlighter::PythonCodeHighlighter(QTextDocument *parent)
                        << "\\^"
                        << "\\|";
 
-  QString builtinModName = "__builtin__";
-
-  if (PythonInterpreter::getInstance()->getPythonVersion() >= 3.0) {
-    builtinModName = "builtins";
-  }
+  QString builtinModName = "builtins";
 
   if (PythonInterpreter::getInstance()->runString(QString("import ") + builtinModName)) {
     QVector<QString> builtinDictContent =
@@ -107,14 +105,14 @@ PythonCodeHighlighter::PythonCodeHighlighter(QTextDocument *parent)
     builtinPatterns << "\\bself\\b";
 
     for (const QString &pattern : builtinPatterns) {
-      rule.pattern = QRegExp(pattern);
+      rule.pattern = QRegularExpression(pattern);
       rule.format = builtinFormat;
       _highlightingRules.append(rule);
     }
   }
 
   for (const QString &pattern : keywordPatterns) {
-    rule.pattern = QRegExp(pattern);
+    rule.pattern = QRegularExpression(pattern);
     rule.format = _keywordFormat;
     _highlightingRules.append(rule);
   }
@@ -123,21 +121,18 @@ PythonCodeHighlighter::PythonCodeHighlighter(QTextDocument *parent)
   format.setFontWeight(QFont::Bold);
 
   for (const QString &pattern : specialCharsPatterns) {
-    rule.pattern = QRegExp(pattern);
+    rule.pattern = QRegularExpression(pattern);
     rule.format = format;
     _highlightingRules.append(rule);
   }
 
-  _numberFormat.setForeground(Qt::darkCyan);
-  rule.pattern = QRegExp("\\b[0-9]+[lL]?\\b");
+  rule.pattern = QRegularExpression("\\b[0-9]+[lL]?\\b");
   rule.format = _numberFormat;
   _highlightingRules.append(rule);
-  rule.pattern = QRegExp("\\b0[xX][0-9A-Fa-f]+[lL]?\\b");
+  rule.pattern = QRegularExpression("\\b0[xX][0-9A-Fa-f]+[lL]?\\b");
   _highlightingRules.append(rule);
-  rule.pattern = QRegExp("\\b[0-9]+(?:\\.[0-9]+)?(?:[eE][+-]?[0-9]+)?\\b");
+  rule.pattern = QRegularExpression("\\b[0-9]+(?:\\.[0-9]+)?(?:[eE][+-]?[0-9]+)?\\b");
   _highlightingRules.append(rule);
-
-  _quotationFormat.setForeground(Qt::darkMagenta);
 }
 
 void PythonCodeHighlighter::highlightBlock(const QString &text) {
@@ -148,14 +143,14 @@ void PythonCodeHighlighter::highlightBlock(const QString &text) {
     }
   }
 
+  QRegularExpressionMatch match;
   for (const HighlightingRule &rule : _highlightingRules) {
-    QRegExp expression(rule.pattern);
-    int index = expression.indexIn(text);
+    int index = text.indexOf(rule.pattern, 0, &match);
 
     while (index >= 0) {
-      int length = expression.matchedLength();
+      int length = match.capturedLength();
       setFormat(index, length, rule.format);
-      index = expression.indexIn(text, index + length);
+      index = text.indexOf(rule.pattern, index + length, &match);
     }
   }
 
@@ -219,11 +214,11 @@ void PythonCodeHighlighter::highlightBlock(const QString &text) {
     }
   }
 
-  QRegExp qtApiRegexp("\\bQ[A-Za-z_.]+\\b");
-  int index = qtApiRegexp.indexIn(text);
+  QRegularExpression qtApiRegexp("\\bQ[A-Za-z_.]+\\b");
+  int index = text.indexOf(qtApiRegexp, 0, &match);
 
   while (index >= 0) {
-    int length = qtApiRegexp.matchedLength();
+    int length = match.capturedLength();
     QString expr = text.mid(index, length);
 
     if (APIDataBase::getInstance()->typeExists(expr) ||
@@ -242,13 +237,13 @@ void PythonCodeHighlighter::highlightBlock(const QString &text) {
       }
     }
 
-    index = qtApiRegexp.indexIn(text, index + length);
+    index = text.indexOf(qtApiRegexp, index + length, &match);
   }
 
   setCurrentBlockState(0);
 
-  static QRegExp triSingleQuote("'''");
-  static QRegExp triDoubleQuote("\"\"\"");
+  static QRegularExpression triSingleQuote("'''");
+  static QRegularExpression triDoubleQuote("\"\"\"");
 
   // highlight multi-line strings
   bool isInMultilne = highlightMultilineString(text, triSingleQuote, 1, _quotationFormat);
@@ -256,8 +251,8 @@ void PythonCodeHighlighter::highlightBlock(const QString &text) {
   if (!isInMultilne)
     highlightMultilineString(text, triDoubleQuote, 2, _quotationFormat);
 
-  QRegExp commentRegexp("#[^\n]*");
-  index = commentRegexp.indexIn(text);
+  QRegularExpression commentRegexp("#[^\n]*");
+  index = text.indexOf(commentRegexp, 0, &match);
 
   while (index >= 0 && currentBlockState() == 0) {
     int nbQuotes = 0;
@@ -276,43 +271,45 @@ void PythonCodeHighlighter::highlightBlock(const QString &text) {
       }
     }
 
-    int length = commentRegexp.matchedLength();
+    int length = match.capturedLength();
 
     if (nbQuotes % 2 == 0 && nbDblQuotes % 2 == 0) {
       if (previousBlockState() <= 0 ||
-          (previousBlockState() == 1 && triSingleQuote.indexIn(text) < index) ||
-          (previousBlockState() == 2 && triDoubleQuote.indexIn(text) < index))
+          (previousBlockState() == 1 && text.indexOf(triSingleQuote) < index) ||
+          (previousBlockState() == 2 && text.indexOf(triDoubleQuote) < index))
         setFormat(index, length, _commentFormat);
     }
 
-    index = commentRegexp.indexIn(text, index + length);
+    index = text.indexOf(commentRegexp, index + length, &match);
   }
 }
 
-bool PythonCodeHighlighter::highlightMultilineString(const QString &text, const QRegExp &delimiter,
+bool PythonCodeHighlighter::highlightMultilineString(const QString &text,
+                                                     const QRegularExpression &delimiter,
                                                      const int inState,
                                                      const QTextCharFormat &style) {
   int start = -1;
   int add = -1;
   int commentPos = -1;
+  QRegularExpressionMatch match;
 
   if (previousBlockState() == inState) {
     start = 0;
     add = 0;
   } else {
-    start = delimiter.indexIn(text);
-    add = delimiter.matchedLength();
+    start = text.indexOf(delimiter, 0, &match);
+    add = match.capturedLength();
     commentPos = text.indexOf('#');
   }
 
   if (commentPos < 0 || commentPos > start) {
 
     while (start >= 0) {
-      int end = delimiter.indexIn(text, start + add);
+      int end = text.indexOf(delimiter, start + add, &match);
       int length;
 
       if (end >= add) {
-        length = end - start + add + delimiter.matchedLength();
+        length = end - start + add + match.capturedLength();
         setCurrentBlockState(0);
       } else {
         setCurrentBlockState(inState);
@@ -320,8 +317,8 @@ bool PythonCodeHighlighter::highlightMultilineString(const QString &text, const
       }
 
       setFormat(start, length, style);
-      start = delimiter.indexIn(text, start + length);
-      add = delimiter.matchedLength();
+      start = text.indexOf(delimiter, start + length, &match);
+      add = match.capturedLength();
     }
   }
 
