@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -89,6 +89,7 @@ void PythonEditorsTabWidget::scriptTextChanged() {
   if (curTabText[curTabText.size() - 1] != '*') {
     curTabText += "*";
     setTabText(currentIndex(), curTabText);
+    emit fileEdited();
   }
 }
 
@@ -113,39 +114,8 @@ void PythonEditorsTabWidget::clearErrorIndicators() {
   }
 }
 
-bool PythonEditorsTabWidget::eventFilter(QObject *obj, QEvent *event) {
-#ifdef __APPLE__
-  Qt::KeyboardModifiers modifier = Qt::MetaModifier;
-#else
-  Qt::KeyboardModifiers modifier = Qt::ControlModifier;
-#endif
-
-  if (event->type() == QEvent::KeyPress) {
-    QKeyEvent *keyEvt = static_cast<QKeyEvent *>(event);
-
-    if (keyEvt->modifiers() == modifier && keyEvt->key() == Qt::Key_S) {
-      if (obj == getCurrentEditor()) {
-        QString moduleFile = tabText(currentIndex());
-
-        // workaround a Qt5 bug on linux
-        moduleFile = moduleFile.replace("&", "");
-
-        if (!moduleFile.contains("no file")) {
-          saveCurrentEditorContentToFile();
-          return true;
-        } else {
-          // when there is no file associated to the Python module, its content will then be saved
-          // in the project file (.tlpx) currently loaded in Tulip
-          if (moduleFile[moduleFile.size() - 1] == '*')
-            moduleFile = moduleFile.mid(0, moduleFile.size() - 1);
-
-          setTabText(currentIndex(), moduleFile);
-          emit fileSaved(currentIndex());
-          return false;
-        }
-      }
-    }
-  } else if (event->type() == QEvent::FocusIn && !_dontTreatFocusIn) {
+bool PythonEditorsTabWidget::eventFilter(QObject *, QEvent *event) {
+  if (event->type() == QEvent::FocusIn && !_dontTreatFocusIn) {
     _dontTreatFocusIn = true;
     reloadCodeInEditorsIfNeeded();
     _dontTreatFocusIn = false;
@@ -187,40 +157,11 @@ bool PythonEditorsTabWidget::reloadCodeInEditorIfNeeded(int index) {
   return false;
 }
 
-void PythonEditorsTabWidget::saveCurrentEditorContentToFile() {
-  saveEditorContentToFile(currentIndex());
-}
-
-void PythonEditorsTabWidget::saveEditorContentToFile(int editorIdx) {
-  if (editorIdx >= 0 && editorIdx < count()) {
-    QString moduleNameExt = tabText(editorIdx);
-    QString moduleName;
-
-    if (!moduleNameExt.contains("no file")) {
-
-      if (moduleNameExt[moduleNameExt.size() - 1] == '*')
-        moduleName = moduleNameExt.mid(0, moduleNameExt.size() - 4);
-      else
-        moduleName = moduleNameExt.mid(0, moduleNameExt.size() - 3);
-
-      // workaround a Qt5 bug on linux
-      moduleName = moduleName.replace("&", "");
-
-      setTabText(editorIdx, moduleName + ".py");
-      QFile file(getEditor(editorIdx)->getFileName());
-      QFileInfo fileInfo(file);
-
-      if (getEditor(editorIdx)->saveCodeToFile()) {
-        setTabToolTip(editorIdx, fileInfo.absoluteFilePath());
-      }
-
-      emit fileSaved(editorIdx);
-    }
-  }
-}
-
 void PythonEditorsTabWidget::closeTabRequested(int tab) {
   emit tabAboutToBeDeleted(tab);
+}
+
+void PythonEditorsTabWidget::closeTab(int tab) {
   QWidget *editorWidget = widget(tab);
   _dontTreatFocusIn = true;
   delete editorWidget;
