@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -39,7 +39,9 @@
 
 #include <tulip/TulipRelease.h>
 #include <tulip/TlpTools.h>
-#include <tulip/PythonVersionChecker.h>
+#ifdef __MINGW32__
+#include <tulip/PythonIDEInterface.h>
+#endif
 #include <tulip/TlpQtTools.h>
 
 #include <cstdio>
@@ -47,6 +49,7 @@
 #include <dlfcn.h>
 #else
 #include <windows.h>
+#include <QProcess>
 #endif
 
 using namespace tlp;
@@ -91,14 +94,9 @@ def printObjectClass(obj):
         print(type)
 )";
 
-#if PY_MAJOR_VERSION >= 3
 static QString convertPythonUnicodeObjectToQString(PyObject *pyUnicodeObj) {
-  PyObject *utf8Str = PyUnicode_AsUTF8String(pyUnicodeObj);
-  QString ret = QString::fromUtf8(PyBytes_AsString(utf8Str));
-  decrefPyObject(utf8Str);
-  return ret;
+  return QString(PyUnicode_AsUTF8(pyUnicodeObj));
 }
-#endif
 
 static bool scriptPaused = false;
 static bool processQtEvents = false;
@@ -209,20 +207,17 @@ PythonInterpreter::PythonInterpreter()
   }
 
   if (!_wasInit) {
+    PyConfig config;
+    PyStatus status;
+    PyConfig_InitPythonConfig(&config);
+    config.install_signal_handlers = 0;
 
-    int argc = 1;
-#if PY_MAJOR_VERSION >= 3
-    static const std::wstring argv0 = L"tulip";
-    wchar_t *argv[1];
-    argv[0] = const_cast<wchar_t *>(argv0.c_str());
-#else
-    static const std::string argv0 = "tulip";
-    char *argv[1];
-    argv[0] = const_cast<char *>(argv0.c_str());
-#endif
-
-    Py_OptimizeFlag = 1;
-    Py_NoSiteFlag = 1;
+    status = PyConfig_SetString(&config, &config.program_name, L"tulip");
+    if (PyStatus_Exception(status)) {
+      Py_ExitStatusException(status);
+    }
+    config.site_import = 0;
+    config.optimization_level = 1;
 
 // Fix for GDB debugging on windows when compiling with MinGW.
 // GDB contains an embedded Python interpreter that messes up Python Home value.
@@ -230,29 +225,35 @@ PythonInterpreter::PythonInterpreter()
 // it crashes at startup when running it through GDB.
 // So reset correct one to be able to debug it.
 #ifdef __MINGW32__
-    QString pythonHome = PythonVersionChecker::getPythonHome();
-
+    QString pythonHome = PythonIDEInterface::getPythonHome();
     if (!pythonHome.isEmpty()) {
-#if PY_MAJOR_VERSION >= 3
       static std::wstring pythonHomeWString = pythonHome.toStdWString();
-      Py_SetPythonHome(const_cast<wchar_t *>(pythonHomeWString.c_str()));
-#else
-      static std::string pythonHomeString = QStringToTlpString(pythonHome);
-      Py_SetPythonHome(const_cast<char *>(pythonHomeString.c_str()));
-#endif
+      config.home = const_cast<wchar_t *>(pythonHomeWString.c_str());
     }
-
 #endif
 
     // register Tulip builtin Python modules
     PyImport_AppendInittab("consoleutils", initconsoleutils);
     PyImport_AppendInittab("tuliputils", inittuliputils);
 
-    Py_InitializeEx(0);
+    status = Py_InitializeFromConfig(&config);
+    if (PyStatus_Exception(status)) {
+      Py_ExitStatusException(status);
+    }
+#ifdef WIN32
+    // crash on windows 10, but not on windows 11
+    // so check for windows 10.
+    // According to https://ss64.com/nt/ver.html
+    // the "Major version.build" of windows 10 versions
+    // always begins with 10.0.1
+    QProcess proc;
+    proc.start("cmd.exe", {"/C", "ver"});
+    proc.waitForFinished();
+    QString version(proc.readAllStandardOutput());
+    if (version.indexOf("windows") > 0 && version.indexOf("10.0.1") == -1)
+#endif
+      PyConfig_Clear(&config);
 
-    PySys_SetArgv(argc, argv);
-
-    PyEval_InitThreads();
     mainThreadState = PyEval_SaveThread();
   }
 
@@ -260,33 +261,19 @@ PythonInterpreter::PythonInterpreter()
 
   importModule("sys");
 
-#if PY_MAJOR_VERSION >= 3
   PyObject *pName = PyUnicode_FromString("__main__");
-#else
-  PyObject *pName = PyString_FromString("__main__");
-#endif
   PyObject *pMainModule = PyImport_Import(pName);
   decrefPyObject(pName);
   PyObject *pMainDict = PyModule_GetDict(pMainModule);
   PyObject *pVersion = PyRun_String("str(sys.version_info[0])+\".\"+str(sys.version_info[1])",
                                     Py_eval_input, pMainDict, pMainDict);
 
-#if PY_MAJOR_VERSION >= 3
   _pythonVersion = convertPythonUnicodeObjectToQString(pVersion);
-#else
-  _pythonVersion = QString(PyString_AsString(pVersion));
-#endif
 
   // checking if a QApplication is instantiated before creating any QWidget
   // allow to avoid segfaults when trying to instantiate a plugin outside the Tulip GUI (for
   // instance, with tulip_check_pl)
   if (QApplication::instance() && !_wasInit) {
-
-#if PY_MAJOR_VERSION < 3
-    reloadModule("sys");
-    runString("sys.setdefaultencoding('utf-8')");
-#endif
-
 // hack for linux in order to be able to load dynamic python modules installed on the system (like
 // numpy, matplotlib and other cool stuffs)
 #ifndef WIN32
@@ -297,28 +284,7 @@ PythonInterpreter::PythonInterpreter()
     libPythonName += QString(".so.1.0");
 #endif
 
-    if (!dlopen(QStringToTlpString(libPythonName).c_str(), RTLD_LAZY | RTLD_GLOBAL)) {
-
-      // for Python 3.2
-      libPythonName = QString("libpython") + _pythonVersion + QString("mu");
-#ifdef __APPLE__
-      libPythonName += QString(".dylib");
-#else
-      libPythonName += QString(".so.1.0");
-#endif
-
-      if (!dlopen(QStringToTlpString(libPythonName).c_str(), RTLD_LAZY | RTLD_GLOBAL)) {
-        // for Python 3.3
-        libPythonName = QString("libpython") + _pythonVersion + QString("m");
-#ifdef __APPLE__
-        libPythonName += QString(".dylib");
-#else
-        libPythonName += QString(".so.1.0");
-#endif
-        dlopen(QStringToTlpString(libPythonName).c_str(), RTLD_LAZY | RTLD_GLOBAL);
-      }
-    }
-
+    dlopen(QStringToTlpString(libPythonName).c_str(), RTLD_LAZY | RTLD_GLOBAL);
 #endif
 
 #if !defined(_MSC_VER)
@@ -340,12 +306,10 @@ PythonInterpreter::PythonInterpreter()
       // otherwise Py_InitializeEx can crash if Py_NoSiteFlag is not set
       // and if the site module is not present on the host system
       // Disable output while trying to import the module to not confuse the user
-      runString("import site");
-#if PY_MAJOR_VERSION == 3 && PY_MINOR_VERSION >= 3
-      runString("site.main()");
-#endif
-      runString("from tulip import tlp");
-      runString("from tulipgui import tlpgui");
+      runString("import site;"
+                "site.main();"
+                "from tulip import tlp;"
+                "from tulipgui import tlpgui\n");
 
       // When importing the tulip module, Tulip Python plugins and
       // startup scripts will be possibly loaded and other Python modules can be loaded as a side
@@ -368,16 +332,10 @@ PythonInterpreter::PythonInterpreter()
 
     PyEval_SetTrace(tracefunc, nullptr);
 
-// disable exit and quit functions
-#if PY_MAJOR_VERSION >= 3
+    // disable exit and quit functions
     runString("import builtins;"
               "builtins.exit = lambda *args: None;"
               "builtins.quit= lambda *args: None;");
-#else
-    runString("import __builtin__;"
-              "__builtin__.exit = lambda *args: None;"
-              "__builtin__.quit = lambda *args: None;");
-#endif
 
     runString("import sys;"
               "sys.exit = lambda *args: None");
@@ -393,14 +351,13 @@ PythonInterpreter::~PythonInterpreter() {
     consoleOuputString = "";
     runString(
         "sys.stdout = sys.__stdout__; sys.stderr = sys.__stderr__; sys.stdin = sys.__stdin__\n");
-    PyEval_ReleaseLock();
     PyEval_RestoreThread(mainThreadState);
 
     holdGIL();
     // avoid display of invalid read/use of uninitialised value
     // when debugging with valgrind
     if (!TulipProgramExiting)
-      Py_Finalize();
+      Py_FinalizeEx();
   }
 
   delete consoleOuputEmitter;
@@ -462,11 +419,7 @@ bool PythonInterpreter::registerNewModuleFromString(const QString &moduleName,
 
 bool PythonInterpreter::functionExists(const QString &moduleName, const QString &functionName) {
   holdGIL();
-#if PY_MAJOR_VERSION >= 3
   PyObject *pName = PyUnicode_FromString(QStringToTlpString(moduleName).c_str());
-#else
-  PyObject *pName = PyString_FromString(QStringToTlpString(moduleName).c_str());
-#endif
   PyObject *pModule = PyImport_Import(pName);
   decrefPyObject(pName);
   PyObject *pDict = PyModule_GetDict(pModule);
@@ -500,11 +453,7 @@ bool PythonInterpreter::runString(const QString &pythonCode, const QString &scri
 
 PyObject *PythonInterpreter::evalPythonStatement(const QString &pythonStatement, bool singleInput) {
   holdGIL();
-#if PY_MAJOR_VERSION >= 3
   PyObject *pName = PyUnicode_FromString("__main__");
-#else
-  PyObject *pName = PyString_FromString("__main__");
-#endif
   PyObject *pMainModule = PyImport_Import(pName);
   decrefPyObject(pName);
   PyObject *pMainDict = PyModule_GetDict(pMainModule);
@@ -526,11 +475,7 @@ PyObject *PythonInterpreter::callPythonFunction(const QString &module, const QSt
                                                 const tlp::DataSet &parameters) {
   holdGIL();
   PyObject *ret = nullptr;
-#if PY_MAJOR_VERSION >= 3
   PyObject *pName = PyUnicode_FromString(QStringToTlpString(module).c_str());
-#else
-  PyObject *pName = PyString_FromString(QStringToTlpString(module).c_str());
-#endif
 
   PyObject *pModule = PyImport_Import(pName);
   decrefPyObject(pName);
@@ -590,12 +535,12 @@ void PythonInterpreter::addModuleSearchPath(const QString &path, const bool befo
   if (_currentImportPaths.find(path) == _currentImportPaths.end()) {
     QString pythonCode;
     QTextStream oss(&pythonCode);
-    oss << "import sys" << endl;
+    oss << "import sys" << Qt::endl;
 
     if (beforeOtherPaths) {
-      oss << "sys.path.insert(0, \"" << path << "\")" << endl;
+      oss << "sys.path.insert(0, \"" << path << "\")" << Qt::endl;
     } else {
-      oss << "sys.path.append(\"" << path << "\")" << endl;
+      oss << "sys.path.append(\"" << path << "\")" << Qt::endl;
     }
 
     runString(pythonCode);
@@ -622,12 +567,8 @@ bool PythonInterpreter::runGraphScript(const QString &module, const QString &fun
   bool ret = true;
   scriptPaused = false;
 
-// Build the name object
-#if PY_MAJOR_VERSION >= 3
+  // Build the name object
   PyObject *pName = PyUnicode_FromString(QStringToTlpString(module).c_str());
-#else
-  PyObject *pName = PyString_FromString(QStringToTlpString(module).c_str());
-#endif
   // Load the module object
   PyObject *pModule = PyImport_Import(pName);
   decrefPyObject(pName);
@@ -650,7 +591,7 @@ bool PythonInterpreter::runGraphScript(const QString &module, const QString &fun
   if (PyCallable_Check(pFunc)) {
 
     if (sipAPI() == nullptr) {
-      QMessageBox::critical(nullptr, "Failed to initialize Python",
+      QMessageBox::critical(QApplication::activeWindow(), "Failed to initialize Python",
                             "SIP could not be initialized (sipApi is null)");
       return false;
     }
@@ -722,20 +663,18 @@ void PythonInterpreter::stopCurrentScript() {
 void PythonInterpreter::deleteModule(const QString &moduleName) {
   QString pythonCode;
   QTextStream oss(&pythonCode);
-  oss << "import sys" << endl;
-  oss << "if \"" << moduleName << "\" in sys.modules:" << endl;
-  oss << "  del sys.modules[\"" << moduleName << "\"]" << endl;
+  oss << "import sys" << Qt::endl;
+  oss << "if \"" << moduleName << "\" in sys.modules:" << Qt::endl;
+  oss << "  del sys.modules[\"" << moduleName << "\"]" << Qt::endl;
   runString(pythonCode);
 }
 
 bool PythonInterpreter::reloadModule(const QString &moduleName) {
   QString pythonCode;
   QTextStream oss(&pythonCode);
-  oss << "import sys" << endl;
-  oss << "if sys.version_info[0] == 3:" << endl;
-  oss << "  from imp import reload" << endl;
-  oss << "import " << moduleName << endl;
-  oss << "reload(" << moduleName << ")" << endl;
+  oss << "from importlib import reload" << Qt::endl;
+  oss << "mod = __import__(\"" << moduleName << "\")" << Qt::endl;
+  oss << "reload(mod)" << Qt::endl;
   return runString(pythonCode);
 }
 
@@ -851,6 +790,20 @@ QString PythonInterpreter::getVariableType(const QString &varName) {
     return "";
 }
 
+QString PythonInterpreter::getSysVariable(const QString &varName) {
+  setOutputEnabled(false);
+  setErrorOutputEnabled(false);
+  consoleOuputString = "";
+  bool ok = runString(QString("import sys; print(sys.") + varName + ')');
+  setOutputEnabled(true);
+  setErrorOutputEnabled(true);
+
+  if (ok)
+    return consoleOuputString.mid(0, consoleOuputString.size() - 1);
+  else
+    return "";
+}
+
 QVector<QString> PythonInterpreter::getObjectDictEntries(const QString &objectName,
                                                          const QString &prefixFilter) {
   QVector<QString> ret;
@@ -896,13 +849,7 @@ QVector<QString> PythonInterpreter::getImportedModulesList() {
   setOutputEnabled(false);
   setErrorOutputEnabled(false);
   consoleOuputString = "";
-#if PY_MAJOR_VERSION >= 3
-
   if (runString("import sys\nfor mod in sorted(sys.modules.keys()): print(mod)")) {
-#else
-
-  if (runString("import sys\nfor mod in sorted(sys.modules.keys()): print mod")) {
-#endif
     QStringList modulesList = consoleOuputString.split("\n");
 
     for (int i = 0; i < modulesList.count(); ++i) {
@@ -938,11 +885,7 @@ QVector<QString> PythonInterpreter::getBaseTypesForType(const QString &typeName)
 
   QString pythonCode;
 
-#if PY_MAJOR_VERSION >= 3
   pythonCode = QString("for base in ") + typeName + ".__bases__ : print(base)";
-#else
-  pythonCode = QString("for base in ") + typeName + ".__bases__ : print base";
-#endif
 
   if (runString(pythonCode)) {
     QStringList basesList = consoleOuputString.split("\n");
@@ -1015,10 +958,6 @@ bool PythonInterpreter::errorOutputEnabled() const {
   return _errorOutputEnabled;
 }
 
-double PythonInterpreter::getPythonVersion() const {
-  return atof(QStringToTlpString(_pythonVersion).c_str());
-}
-
 QString PythonInterpreter::getPythonFullVersionStr() const {
   std::string version(Py_GetVersion());
   auto pos = version.find(' ');
@@ -1077,10 +1016,6 @@ QString PythonInterpreter::readLineFromConsole() {
 
 void PythonInterpreter::clearTracebacks() {
   QString pythonCode = "import sys\n";
-#if PY_MAJOR_VERSION < 3
-  pythonCode += "sys.exc_clear()\n";
-  pythonCode += "sys.exc_traceback = None\n";
-#endif
   pythonCode += "sys.last_traceback = None\n";
   runString(pythonCode);
 }
