@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -19,7 +19,6 @@
 
 #include "tulip/PythonInterpreter.h"
 
-#include <QRegExp>
 #include <QKeyEvent>
 
 #include <tulip/TlpTools.h>
@@ -31,29 +30,25 @@
 
 using namespace tlp;
 
-static QRegExp linesepRegExp = QRegExp("\r\n|\n|\r");
-
 static QString ps1 = ">>> ";
 static QString ps2 = "... ";
 
 static QString rtrim(const QString &s) {
-  int lastNonSpaceIdx = s.length() - 1;
-
-  while (s.at(lastNonSpaceIdx).isSpace()) {
-    --lastNonSpaceIdx;
+  for (int lastNonSpaceIdx = s.length() - 1; lastNonSpaceIdx != -1; --lastNonSpaceIdx) {
+    if (!s.at(lastNonSpaceIdx).isSpace())
+      return s.left(lastNonSpaceIdx + 1);
   }
 
-  return s.mid(0, lastNonSpaceIdx + 1);
+  return "";
 }
 
 static QString ltrim(const QString &s) {
-  int firstNonSpaceIdx = 0;
-
-  while (s.at(firstNonSpaceIdx).isSpace()) {
-    ++firstNonSpaceIdx;
+  for (int firstNonSpaceIdx = 0; firstNonSpaceIdx < s.length(); ++firstNonSpaceIdx) {
+    if (!s.at(firstNonSpaceIdx).isSpace())
+      return s.right(s.length() - firstNonSpaceIdx);
   }
 
-  return s.mid(firstNonSpaceIdx);
+  return "";
 }
 
 PythonShellWidget::PythonShellWidget(QWidget *parent, bool showBanner) : PythonCodeEditor(parent) {
@@ -87,7 +82,7 @@ void PythonShellWidget::insert(const QString &txt, const bool atEnd) {
   }
 
   QTextCharFormat formt = textCursor().charFormat();
-  formt.setForeground(Qt::black);
+  formt.setForeground(_darkBackground ? Qt::white : Qt::black);
   textCursor().insertText(txt, formt);
 }
 
@@ -137,7 +132,7 @@ void PythonShellWidget::keyPressEvent(QKeyEvent *e) {
       setSelection(lines() - 1, 0, lines() - 1, lineLength(lines() - 1));
       removeSelectedText();
 
-      if (_currentHistoryPos < int(_history.size() - 1) && _history.size() > 0) {
+      if (_currentHistoryPos < int(_history.size() - 1) && !_history.empty()) {
         ++_currentHistoryPos;
         insert(_currentPs + _history[_currentHistoryPos]);
       } else {
