@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -36,15 +36,14 @@ static const char *paramHelp[] = {
     // Connected
     "If true, the resulting subgraphs are guaranteed to be connected."};
 
-#define ELT_TYPE "Type"
 #define ELT_TYPES "nodes;edges;"
 #define NODE_ELT 0
 #define EDGE_ELT 1
 //================================================================================
 EqualValueClustering::EqualValueClustering(tlp::PluginContext *context) : Algorithm(context) {
-  addInParameter<PropertyInterface *>("Property", paramHelp[0], "viewMetric");
-  addInParameter<StringCollection>(ELT_TYPE, paramHelp[1], ELT_TYPES, true, "nodes <br> edges");
-  addInParameter<bool>("Connected", paramHelp[2], "false");
+  addInParameter<PropertyInterface *>("property", paramHelp[0], "viewMetric");
+  addInParameter<StringCollection>("type", paramHelp[1], ELT_TYPES, true, "nodes <br> edges");
+  addInParameter<bool>("connected", paramHelp[2], "false");
 }
 //===============================================================================
 bool EqualValueClustering::run() {
@@ -54,9 +53,9 @@ bool EqualValueClustering::run() {
   eltTypes.setCurrent(0);
 
   if (dataSet != nullptr) {
-    dataSet->get("Property", property);
-    dataSet->get(ELT_TYPE, eltTypes);
-    dataSet->get("Connected", connected);
+    dataSet->get("property", property);
+    dataSet->get("type", eltTypes);
+    dataSet->get("connected", connected);
   }
 
   if (property == nullptr)
@@ -75,8 +74,8 @@ bool EqualValueClustering::computeClusters(NumericProperty *prop, bool onNodes,
   unsigned int step = 0;
   unsigned int maxSteps;
 
-  std::unordered_map<double, Graph *> clusters;
-  std::unordered_map<std::string, unsigned int> valuesCount;
+  tlp_hash_map<double, Graph *> clusters;
+  tlp_hash_map<std::string, unsigned int> valuesCount;
   MutableContainer<bool> visited;
   visited.setAll(false);
 
@@ -105,7 +104,7 @@ bool EqualValueClustering::computeClusters(NumericProperty *prop, bool onNodes,
           sstr << curValue;
 
           if (connected) {
-            std::unordered_map<std::string, unsigned int>::iterator itv = valuesCount.find(strVal);
+            tlp_hash_map<std::string, unsigned int>::iterator itv = valuesCount.find(strVal);
 
             if (itv != valuesCount.end()) {
               itv->second += 1;
@@ -199,7 +198,7 @@ bool EqualValueClustering::computeClusters(NumericProperty *prop, bool onNodes,
           sstr << curValue;
 
           if (connected) {
-            std::unordered_map<std::string, unsigned int>::iterator itv = valuesCount.find(strVal);
+            tlp_hash_map<std::string, unsigned int>::iterator itv = valuesCount.find(strVal);
 
             if (itv != valuesCount.end()) {
               itv->second += 1;
@@ -272,8 +271,8 @@ bool EqualValueClustering::computeClusters(PropertyInterface *prop, bool onNodes
   unsigned int step = 0;
   unsigned int maxSteps;
 
-  std::unordered_map<std::string, Graph *> clusters;
-  std::unordered_map<std::string, unsigned int> valuesCount;
+  tlp_hash_map<std::string, Graph *> clusters;
+  tlp_hash_map<std::string, unsigned int> valuesCount;
   MutableContainer<bool> visited;
   visited.setAll(false);
 
@@ -300,8 +299,7 @@ bool EqualValueClustering::computeClusters(PropertyInterface *prop, bool onNodes
           sstr << prop->getName().c_str() << ": " << curValue.c_str();
 
           if (connected) {
-            std::unordered_map<std::string, unsigned int>::iterator itv =
-                valuesCount.find(curValue);
+            tlp_hash_map<std::string, unsigned int>::iterator itv = valuesCount.find(curValue);
 
             if (itv != valuesCount.end()) {
               itv->second += 1;
@@ -393,8 +391,7 @@ bool EqualValueClustering::computeClusters(PropertyInterface *prop, bool onNodes
           sstr << prop->getName().c_str() << ": " << curValue.c_str();
 
           if (connected) {
-            std::unordered_map<std::string, unsigned int>::iterator itv =
-                valuesCount.find(curValue);
+            tlp_hash_map<std::string, unsigned int>::iterator itv = valuesCount.find(curValue);
 
             if (itv != valuesCount.end()) {
               itv->second += 1;
