@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -132,14 +132,14 @@ void StrengthClustering::computeNodePartition(double threshold, vector<unordered
     }
   }
 
-  // Extract connected component
+  // Extract connected components
   DoubleProperty connected(tmpGraph);
   string errMsg;
-  tmpGraph->applyPropertyAlgorithm("Connected Component", &connected, errMsg);
+  tmpGraph->applyPropertyAlgorithm("Connected Components", &connected, errMsg);
 
   // Compute the node partition
   int index = 0;
-  unordered_map<double, int> resultIndex;
+  tlp_hash_map<double, int> resultIndex;
 
   for (auto n : tmpGraph->nodes()) {
     double val = connected.getNodeValue(n);
