@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -24,6 +24,8 @@
 #include <tulip/ColorScale.h>
 
 #ifndef TULIP_BUILD_CORE_ONLY
+#include <QApplication>
+#include <tulip/Perspective.h>
 #include "DoubleStringsListRelationDialog.h"
 #endif
 
@@ -31,20 +33,20 @@ using namespace tlp;
 
 static const char *paramHelp[] = {
     // type
-    "If linear, logarithmic or uniform, the input property must be a <b>numeric</b> property."
+    "If linear, logarithmic or uniform, the property must be a <b>numeric</b> property."
     "<ul><li><b> linear</b>: the minimum value is mapped to one end of the color scale, "
     "the maximum value is mapped to the other end, and a linear interpolation is used between both "
     "to compute the associated color.</li>"
     "<li> <b>logarithmic</b>: graph elements values are first "
     "mapped in the [1, +inf[ range. "
     "Then the log of each mapped value is computed and used to compute the associated color of the "
-    "graph element trough a linear interpolation between 0 and the log of the mapped maximum value "
+    "graph element through a linear interpolation between 0 and the log of the mapped maximum value "
     "of graph elements.</li>"
     "<li><b>uniform</b>: this is the same as logarithmic except for the interpolation: the values "
     "are sorted, numbered, "
     "and a linear interpolation is used on those numbers "
     "(in other words, only the order is taken into account, not the actual values).</li>"
-    "<li><b>enumerated</b>: the input property can be of any type. Each possible value is "
+    "<li><b>enumerated</b>: the property can be of any type. Each possible value is "
     "mapped manually to a distinct color without any specific order.</li></ul>",
 
     // property
@@ -57,14 +59,14 @@ static const char *paramHelp[] = {
     "The color scale used to transform a node/edge property value into a color.",
 
     // override min
-    "If true override the minimum value of the input property to keep coloring consistent across "
+    "If true override the minimum value of the property to keep coloring consistent across "
     "datasets.",
 
     // min
     "That value will be used to override the minimum one of the input property.",
 
     // override max
-    "If true override the maximum value of the input property to keep coloring consistent across "
+    "If true override the maximum value of the property to keep coloring consistent across "
     "datasets.",
 
     // max
@@ -99,29 +101,28 @@ private:
 public:
   PLUGININFORMATION(
       "Color Mapping", "Mathiaut", "16/09/2010",
-      "Colorizes the nodes or edges of a graph according to the values of a given property.", "2.2",
+      "Colorizes the nodes or edges of a graph according to the values of a given property.", "2.3",
       "")
   ColorMapping(const tlp::PluginContext *context)
-      : ColorAlgorithm(context), entryMetric(nullptr), eltTypes(ELT_TYPES),
+      // set second parameter of the constructor below to true because
+      // result needs to be an inout parameter
+      // in order to preserve the original values of non targeted elements
+      // i.e if "target" = "nodes", the values of edges must be preserved
+      // and if "target" = "edges", the values of nodes must be preserved
+      : ColorAlgorithm(context, true), entryMetric(nullptr), eltTypes(ELT_TYPES),
         maxInput(std::numeric_limits<double>::quiet_NaN()),
         minInput(std::numeric_limits<double>::quiet_NaN()), overrideMaxInput(false),
         overrideMinInput(false) {
     addInParameter<StringCollection>(ELT_TYPE, paramHelp[0], ELT_TYPES, true,
                                      "linear <br> uniform <br> enumerated <br> logarithmic");
-    addInParameter<PropertyInterface *>("input property", paramHelp[1], "viewMetric");
+    addInParameter<PropertyInterface *>("property", paramHelp[1], "viewMetric");
     addInParameter<StringCollection>(TARGET_TYPE, paramHelp[2], TARGET_TYPES, true,
                                      "nodes <br> edges");
     addInParameter<ColorScale>("color scale", paramHelp[3], "");
-    addInParameter<bool>("override minimum value", paramHelp[4], "false", false);
-    addInParameter<double>("minimum value", paramHelp[5], "", false);
-    addInParameter<bool>("override maximum value", paramHelp[6], "false", false);
-    addInParameter<double>("maximum value", paramHelp[7], "", false);
-
-    // result needs to be an inout parameter
-    // in order to preserve the original values of non targeted elements
-    // i.e if "target" = "nodes", the values of edges must be preserved
-    // and if "target" = "edges", the values of nodes must be preserved
-    parameters.setDirection("result", INOUT_PARAM);
+    addInParameter<bool>("override min value", paramHelp[4], "false", false);
+    addInParameter<double>("min value", paramHelp[5], "", false);
+    addInParameter<bool>("override max value", paramHelp[6], "false", false);
+    addInParameter<double>("max value", paramHelp[7], "", false);
   }
 
   //=========================================================
@@ -148,13 +149,13 @@ public:
     PropertyInterface *metric = nullptr;
 
     if (dataSet != nullptr) {
-      dataSet->get("input property", metric);
+      dataSet->get("property", metric);
       dataSet->get(ELT_TYPE, eltTypes);
       dataSet->get(TARGET_TYPE, targetType);
-      dataSet->get("override minimum value", overrideMinInput);
-      dataSet->get("minimum value", minInput);
-      dataSet->get("override maximum value", overrideMaxInput);
-      dataSet->get("maximum value", maxInput);
+      dataSet->get("override min value", overrideMinInput);
+      dataSet->get("min value", minInput);
+      dataSet->get("override max value", overrideMaxInput);
+      dataSet->get("max value", maxInput);
 
       /// Do not allow NaN input
       if (overrideMaxInput &&
@@ -296,13 +297,10 @@ public:
     PropertyInterface *metric = nullptr;
 
     if (dataSet != nullptr) {
-      dataSet->get("input property", metric);
+      dataSet->get("property", metric);
       dataSet->get(ELT_TYPE, eltTypes);
       dataSet->get(TARGET_TYPE, targetType);
-
-      if (!dataSet->get("color scale", colorScale))
-        dataSet->get("colorScale", colorScale);
-
+      dataSet->get("color scale", colorScale);
       dataSet->get("maximum value", maxInput);
       dataSet->get("minimum value", minInput);
     }
@@ -361,12 +359,20 @@ public:
                   });
       }
 
-      DoubleStringsListRelationDialog dialog(enumeratedValues, enumeratedColors);
+      DoubleStringsListRelationDialog dialog(enumeratedValues, enumeratedColors,
+                                             Perspective::instance()->mainWindow());
 
+      QWidget *progressWidget = dynamic_cast<QWidget *>(pluginProgress);
+      if (progressWidget)
+        progressWidget->hide();
       if (!dialog.exec()) {
         errorMsg += "Cancelled by user";
         return false;
       }
+      if (progressWidget) {
+        progressWidget->show();
+        QApplication::processEvents();
+      }
 
       dialog.getResult(enumeratedMappingResultVector);
 #else
