@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -50,20 +50,19 @@ void printSize(ostream &os, const Size &v) {
 /**
  * This plugin records a Tulip graph structure using the GML File format.
  * This format is the file format used by Graphlet.
- * See www.infosun.fmi.uni-passau.de/Graphlet/GML/ for details.
+ * See www.infosun.fim.uni-passau.de/Graphlet/GML/ for details.
  */
 class GMLExport : public tlp::ExportModule {
 public:
-  PLUGININFORMATION("GML Export", "Auber David", "31/07/2001",
-                    "<p>Supported extensions: gml</p><p>Exports a Tulip graph in a file using the "
-                    "GML format (used by Graphlet).<br/>See "
-                    "<b>www.infosun.fmi.uni-passau.de/Graphlet/GML/</b> for details.</p>",
-                    "1.0", "File")
-  std::string fileExtension() const override {
-    return "gml";
-  }
+  PLUGININFORMATION(
+      "GML Export", "Auber David", "31/07/2001",
+      "<p>Supported extensions: gml</p><p>Exports a Tulip graph in a file using the "
+      "GML format (used by Graphlet).<br/>See:<br/>"
+      "<a href=\"https://github.com/GunterMueller/UNI_PASSAU_FMI_Graph_Drawing\">https://github.com/GunterMueller/UNI_PASSAU_FMI_Graph_Drawing</a><br/>"
+      "(formerly www.infosun.fim.uni-passau.de/Graphlet/GML/) for details.</p>",
+      "1.0", "File")
 
-  GMLExport(tlp::PluginContext *context) : tlp::ExportModule(context) {}
+  GMLExport(tlp::PluginContext *context) : tlp::ExportModule(context, {"gml"}) {}
 
   ~GMLExport() override {}
 
