@@ -3,7 +3,7 @@
 
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -31,7 +31,6 @@ class ExportSvg : public ExportInterface {
   QXmlStreamWriter _res;
   QByteArray _out;
   std::set<std::string> _base64fontAdded;
-  bool _woff2;
   bool _gloweffectAdded;
   bool createEdge(const tlp::EdgeShape::EdgeShapes &type, const std::vector<tlp::Coord> &bends,
                   const QString &color, const QString &qcolorA, const double width,
@@ -43,7 +42,7 @@ class ExportSvg : public ExportInterface {
   void addGlowEffect();
 
 public:
-  ExportSvg(tlp::PluginProgress *pp, std::ostream &os, const bool autoformatting, const bool woff2);
+  ExportSvg(tlp::PluginProgress *pp, std::ostream &os, const bool autoformatting);
   bool writeHeader(const tlp::BoundingBox &bb) override;
   bool writeGraph(const tlp::BoundingBox &bb, const tlp::Color &background,
                   bool noBackground) override;
