@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -374,14 +374,14 @@ bool ReadGraph::readGraph(Graph *graph, tlp::DataSet *ds, tlp::PluginProgress *p
   bool noBackground = false;
 
   if (ds != nullptr) {
-    ds->get("Edge color interpolation", edge_color_interpolation);
-    ds->get("Edge size interpolation", edge_size_interpolation);
-    ds->get("Edge extremities", edge_extremities);
-    ds->get("Background color", background);
-    ds->get("No background", noBackground);
-    ds->get("Export node labels", node_labels);
-    ds->get("Export edge labels", edge_labels);
-    ds->get("Export metanode labels", metanode_labels);
+    ds->get("edge color interpolation", edge_color_interpolation);
+    ds->get("edge size interpolation", edge_size_interpolation);
+    ds->get("edge extremities", edge_extremities);
+    ds->get("background color", background);
+    ds->get("no background", noBackground);
+    ds->get("export node labels", node_labels);
+    ds->get("export edge labels", edge_labels);
+    ds->get("export metanode labels", metanode_labels);
   }
 
   // Finding graph size
