@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -59,11 +59,7 @@ static const char *paramHelp[] = {
     "Specifies if edge labels have to be exported.",
 
     // metanode labels
-    "Specifies if node and edge labels inside metanodes have to be exported.",
-
-    // woff2
-    "Uses Web Open Font Format version 2 (woff2) to reduce generated file length. This format is "
-    "supported in almost all recent Internet browsers."};
+    "Specifies if node and edge labels inside metanodes have to be exported."};
 
 class SvgExport : public tlp::ExportModule {
 
@@ -71,45 +67,33 @@ public:
   PLUGININFORMATION("SVG Export", "Sami Gasri, Charles-Antoine Lami, Bruno Pinaud", "16/07/2013",
                     "<p>Supported extensions: svg, svgz (compressed svg).</p><p>Exports a graph "
                     "visualization in a SVG formatted file.</p>",
-                    "1.9", "File")
+                    "1.10", "File")
 
   std::string icon() const override {
     return ":/tulip/graphperspective/icons/32/export_svg.png";
   }
 
-  string fileExtension() const override {
-    return "svg";
-  }
-
-  list<string> gzipFileExtensions() const override {
-    list<string> ext;
-    ext.push_back("svgz");
-    return ext;
-  }
-
-  SvgExport(tlp::PluginContext *context) : tlp::ExportModule(context) {
-    addInParameter<bool>("Edge color interpolation", paramHelp[0], "false");
-    addInParameter<bool>("Edge size interpolation", paramHelp[1], "true");
-    addInParameter<bool>("Edge extremities", paramHelp[2], "false");
-    addInParameter<Color>("Background color", paramHelp[3], "(255,255,255,255)");
-    addInParameter<bool>("No background", paramHelp[4], "false");
-    addInParameter<bool>("Makes SVG output human readable", paramHelp[5], "true");
-    addInParameter<bool>("Export node labels", paramHelp[6], "true");
-    addInParameter<bool>("Export edge labels", paramHelp[7], "false");
-    addInParameter<bool>("Export metanode labels", paramHelp[8], "false");
-    addInParameter<bool>("Use Web Open Font Format v2", paramHelp[9], "false");
+  SvgExport(tlp::PluginContext *context) : tlp::ExportModule(context, {"svg", "svgz"}) {
+    addInParameter<bool>("edge color interpolation", paramHelp[0], "false");
+    addInParameter<bool>("edge size interpolation", paramHelp[1], "true");
+    addInParameter<bool>("edge extremities", paramHelp[2], "false");
+    addInParameter<Color>("background color", paramHelp[3], "(255,255,255,255)");
+    addInParameter<bool>("no background", paramHelp[4], "false");
+    addInParameter<bool>("makes SVG output human readable", paramHelp[5], "true");
+    addInParameter<bool>("export node labels", paramHelp[6], "true");
+    addInParameter<bool>("export edge labels", paramHelp[7], "false");
+    addInParameter<bool>("export metanode labels", paramHelp[8], "false");
   }
 
   bool exportGraph(ostream &os) override {
     pluginProgress->showPreview(false);
-    bool autoformatting(true), woff2(false);
+    bool autoformatting(true);
 
     if (dataSet != nullptr) {
-      dataSet->get("Makes SVG output human readable", autoformatting);
-      dataSet->get("Use Web Open Font Format v2", woff2);
+      dataSet->get("makes SVG output human readable", autoformatting);
     }
 
-    ExportSvg svg(pluginProgress, os, autoformatting, woff2); // We call our first concrete builder
+    ExportSvg svg(pluginProgress, os, autoformatting); // We call our first concrete builder
     bool ret = ReadGraph::readGraph(graph, dataSet, pluginProgress, svg);
 
     if (!ret && autoformatting) {
