@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -32,9 +32,6 @@
 //
 // Code was ported from Javascript to C++.
 
-#ifndef CURVEEDGES_H
-#define CURVEEDGES_H
-
 #include <tulip/Algorithm.h>
 #include <tulip/StringCollection.h>
 #include <tulip/LayoutProperty.h>
@@ -43,31 +40,29 @@
 
 #include <climits>
 
-#define CURVE_TYPE "Curve Type"
 #define CURVE_TYPE_LIST                                                                            \
-  "QuadraticContinuous;QuadraticDiscrete;QuadraticDiagonalCross;\
-QuadraticStraightCross;QuadraticHorizontal;QuadraticVertical;CubicContinuous;CubicVertical;\
-CubicDiagonalCross;CubicVerticalDiagonalCross;CubicStraightCrossSource;CubicStraightCrossTarget"
-#define CURVE_TYPE_QUADRATIC_CONTINUOUS 0
-#define CURVE_TYPE_QUADRATIC_DISCRETE 1
-#define CURVE_TYPE_QUADRATIC_DIAGONALCROSS 2
-#define CURVE_TYPE_QUADRATIC_STRAIGHTCROSS 3
-#define CURVE_TYPE_QUADRATIC_HORIZONTAL 4
-#define CURVE_TYPE_QUADRATIC_VERTICAL 5
-#define CURVE_TYPE_CUBIC_CONTINUOUS 6
-#define CURVE_TYPE_CUBIC_VERTICAL 7
-#define CURVE_TYPE_CUBIC_DIAGONALCROSS 8
-#define CURVE_TYPE_CUBIC_VERTICAL_DIAGONALCROSS 9
-#define CURVE_TYPE_CUBIC_STRAIGHTCROSS_SOURCE 10
-#define CURVE_TYPE_CUBIC_STRAIGHTCROSS_TARGET 11
+  "quadratic continuous;quadratic discrete;quadratic diagonal cross;\
+quadratic straight cross;quadratic horizontal;quadratic vertical;cubic continuous;cubic vertical;\
+cubic diagonal cross;cubic vertical diagonal cross;cubic straight cross source;cubic straight cross target"
+#define QUADRATIC_CONTINUOUS 0
+#define QUADRATIC_DISCRETE 1
+#define QUADRATIC_DIAGONALCROSS 2
+#define QUADRATIC_STRAIGHTCROSS 3
+#define QUADRATIC_HORIZONTAL 4
+#define QUADRATIC_VERTICAL 5
+#define CUBIC_CONTINUOUS 6
+#define CUBIC_VERTICAL 7
+#define CUBIC_DIAGONALCROSS 8
+#define CUBIC_VERTICAL_DIAGONALCROSS 9
+#define CUBIC_STRAIGHTCROSS_SOURCE 10
+#define CUBIC_STRAIGHTCROSS_TARGET 11
 
 static const char *paramHelp[] = {
-    // layout
+    // initial layout
     "The input layout of the graph.",
 
     // curve roundness
-    "Parameter for tweaking the curve roundness. The value range is from 0 to 1 with a maximum "
-    "roundness at 0.5.",
+    "Parameter for tweaking the curve roundness. The value range is from 0 to 1 with a maximum roundness at 0.5.",
 
     // curve type
     "The type of curve to compute (12 available: 6 quadratics and 6 cubics).",
@@ -75,29 +70,29 @@ static const char *paramHelp[] = {
     // bezier edges
     "If activated, set all edge shapes to Bezier curves."};
 
-static const char *curveTypeValues = "QuadraticContinuous <br>"
-                                     "QuadraticDiscrete <br>"
-                                     "QuadraticDiagonalCross <br>"
-                                     "QuadraticStraightCross <br>"
-                                     "QuadraticHorizontal <br>"
-                                     "QuadraticVertical <br>"
-                                     "CubicContinuous <br>"
-                                     "CubicVertical <br>"
-                                     "CubicDiagonalCross <br>"
-                                     "CubicVerticalDiagonalCross <br>"
-                                     "CubicStraightCrossSource <br>"
-                                     "CubicStraightCrossTarget";
+static const char *curveTypeValues = "quadratic continuous<br/>"
+                                     "quadratic discrete<br/>"
+                                     "quadratic diagonal cross<br/>"
+                                     "quadratic straight cross<br/>"
+                                     "quadratic horizontal<br/>"
+                                     "quadratic vertical<br/>"
+                                     "cubic continuous<br/>"
+                                     "cubic vertical<br/>"
+                                     "cubic diagonal cross<br/>"
+                                     "cubic vertical diagonal cross<br/>"
+                                     "cubic straight cross source<br/>"
+                                     "cubic straight cross target";
 
 class CurveEdges : public tlp::Algorithm {
 
 public:
   PLUGININFORMATION("Curve edges", "Antoine Lambert", "16/01/2015",
-                    "Computes quadratic or cubic bezier paths for edges", "1.0", "")
+                    "Computes quadratic or cubic bezier paths for edges", "1.1", "")
 
   CurveEdges(tlp::PluginContext *context)
       : tlp::Algorithm(context), curveType(0), curveRoundness(0.5), layout(nullptr),
         bezierEdges(true) {
-    addInParameter<tlp::LayoutProperty>("layout", paramHelp[0], "viewLayout");
+    addInParameter<tlp::LayoutProperty>("initial layout", paramHelp[0], "viewLayout");
     addInParameter<float>("curve roundness", paramHelp[1], "0.5");
     addInParameter<tlp::StringCollection>("curve type", paramHelp[2], CURVE_TYPE_LIST, true,
                                           curveTypeValues);
@@ -115,9 +110,8 @@ public:
     tlp::Coord normal(dir[1], -dir[0]);
     normal *= factor;
 
-    if (curveType == CURVE_TYPE_CUBIC_VERTICAL ||
-        curveType == CURVE_TYPE_CUBIC_VERTICAL_DIAGONALCROSS ||
-        curveType == CURVE_TYPE_CUBIC_STRAIGHTCROSS_SOURCE) {
+    if (curveType == CUBIC_VERTICAL || curveType == CUBIC_VERTICAL_DIAGONALCROSS ||
+        curveType == CUBIC_STRAIGHTCROSS_SOURCE) {
       dir = tlp::Coord(0, 0, 0);
     }
 
@@ -125,11 +119,11 @@ public:
     p1 *= factor;
     p1 += srcCoord;
 
-    if (curveType != CURVE_TYPE_CUBIC_STRAIGHTCROSS_TARGET) {
+    if (curveType != CUBIC_STRAIGHTCROSS_TARGET) {
       p1 += normal;
     }
 
-    if (curveType == CURVE_TYPE_CUBIC_STRAIGHTCROSS_TARGET) {
+    if (curveType == CUBIC_STRAIGHTCROSS_TARGET) {
       dir = tlp::Coord(0, 0, 0);
     }
 
@@ -137,10 +131,9 @@ public:
     p2 *= -factor;
     p2 += tgtCoord;
 
-    if (curveType == CURVE_TYPE_CUBIC_DIAGONALCROSS ||
-        curveType == CURVE_TYPE_CUBIC_VERTICAL_DIAGONALCROSS) {
+    if (curveType == CUBIC_DIAGONALCROSS || curveType == CUBIC_VERTICAL_DIAGONALCROSS) {
       p2 -= normal;
-    } else if (curveType != CURVE_TYPE_CUBIC_STRAIGHTCROSS_SOURCE) {
+    } else if (curveType != CUBIC_STRAIGHTCROSS_SOURCE) {
       p2 += normal;
     }
 
@@ -156,8 +149,7 @@ public:
     float dx = std::abs(srcCoord[0] - tgtCoord[0]);
     float dy = std::abs(srcCoord[1] - tgtCoord[1]);
 
-    if (curveType == CURVE_TYPE_QUADRATIC_DISCRETE ||
-        curveType == CURVE_TYPE_QUADRATIC_DIAGONALCROSS) {
+    if (curveType == QUADRATIC_DISCRETE || curveType == QUADRATIC_DIAGONALCROSS) {
       if (dx < dy) {
         if (srcCoord[1] > tgtCoord[1]) {
           if (srcCoord[0] < tgtCoord[0]) {
@@ -177,7 +169,7 @@ public:
           }
         }
 
-        if (curveType == CURVE_TYPE_QUADRATIC_DISCRETE && dx < factor * dy) {
+        if (curveType == QUADRATIC_DISCRETE && dx < factor * dy) {
           x = srcCoord[0];
         }
       } else if (dx > dy) {
@@ -199,11 +191,11 @@ public:
           }
         }
 
-        if (curveType == CURVE_TYPE_QUADRATIC_DISCRETE && dy < factor * dx) {
+        if (curveType == QUADRATIC_DISCRETE && dy < factor * dx) {
           y = srcCoord[1];
         }
       }
-    } else if (curveType == CURVE_TYPE_QUADRATIC_STRAIGHTCROSS) {
+    } else if (curveType == QUADRATIC_STRAIGHTCROSS) {
       if (dx < dy) {
         x = srcCoord[0];
 
@@ -221,7 +213,7 @@ public:
 
         y = srcCoord[1];
       }
-    } else if (curveType == CURVE_TYPE_QUADRATIC_HORIZONTAL) {
+    } else if (curveType == QUADRATIC_HORIZONTAL) {
       if (srcCoord[0] < tgtCoord[0]) {
         x = tgtCoord[0] - (1 - factor) * dx;
       } else {
@@ -229,7 +221,7 @@ public:
       }
 
       y = srcCoord[1];
-    } else if (curveType == CURVE_TYPE_QUADRATIC_VERTICAL) {
+    } else if (curveType == QUADRATIC_VERTICAL) {
       x = srcCoord[0];
 
       if (srcCoord[1] < tgtCoord[1]) {
@@ -238,7 +230,7 @@ public:
         y = tgtCoord[1] + (1 - factor) * dy;
       }
 
-    } else { // CURVE_TYPE_QUADRATIC_CONTINUOUS
+    } else { // QUADRATIC_CONTINUOUS
       if (dx < dy) {
         if (srcCoord[1] > tgtCoord[1]) {
           if (srcCoord[0] < tgtCoord[0]) {
@@ -313,7 +305,7 @@ public:
       }
 
       dataSet->get("curve roundness", curveRoundness);
-      dataSet->get("layout", layout);
+      dataSet->get("initial layout", layout);
       dataSet->get("bezier edges", bezierEdges);
     }
 
@@ -322,7 +314,7 @@ public:
     }
 
     for (auto e : graph->edges()) {
-      if (curveType >= CURVE_TYPE_CUBIC_CONTINUOUS) {
+      if (curveType >= CUBIC_CONTINUOUS) {
         layout->setEdgeValue(e, computeCubicBezierControlPoints(e));
       } else {
         layout->setEdgeValue(e, computeQuadraticBezierControlPoints(e));
@@ -345,5 +337,3 @@ private:
 };
 
 PLUGIN(CurveEdges)
-
-#endif // CURVEEDGES_H
