@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -20,91 +20,66 @@
 #include <fstream>
 #include <string>
 #include <cctype>
+#include <tulip/tuliphash.h>
 
 #include <tulip/ImportModule.h>
-#include <tulip/TulipPluginHeaders.h>
-#include <tulip/ForEach.h>
 #include <tulip/TulipViewSettings.h>
+#include <tulip/TlpQtTools.h>
+#include <tulip/StableIterator.h>
+#include <tulip/LayoutProperty.h>
+#include <tulip/SizeProperty.h>
+#include <tulip/ColorProperty.h>
+#include <tulip/StringProperty.h>
+#include <tulip/IntegerProperty.h>
+#include <tulip/DoubleProperty.h>
+#include <tulip/BooleanProperty.h>
 
 #include <QXmlStreamReader>
 #include <QFile>
 
-
 using namespace tlp;
 using namespace std;
 
-
 /** \file
  *  \brief - Import GEXF format graph file.
  * This plugin imports a graph from a file in GEXF format,<br/>
- * as it is described in the XML Schema 1.2draft (http://gexf.net/format/schema.html). Dynamic mode is not yet supported.
- *  <b>HISTORY</b>
+ * as it is described in the XML Schema 1.2 specification (https://gexf.net/schema.html). Dynamic
+ * mode is not yet supported. <b>HISTORY</b>
  *
  *  - 04/06/2012 Version 1.0: Initial release
  *
- *  \author Antoine Lambert & Patrick Mary of Tulip Team http://tulip-software.org/
+ *  \author Antoine Lambert & Patrick Mary of Tulip Team https://tulip.labri.fr/
  *
  *
  */
 
-static const char * paramHelp[] = {
-  // filename
-  HTML_HELP_OPEN()            \
-  HTML_HELP_DEF( "type", "pathname" )       \
-  HTML_HELP_BODY()                  \
-  "This parameter defines the file pathname to import."       \
-  HTML_HELP_CLOSE(),
-  // curved edges
-  HTML_HELP_OPEN()            \
-  HTML_HELP_DEF( "type", "bool" )       \
-  HTML_HELP_DEF( "values", "true, false" ) \
-  HTML_HELP_DEF( "default", "false" ) \
-  HTML_HELP_BODY()                  \
-  "Indicates if Bezier curves will be used to draw the edges."       \
-  HTML_HELP_CLOSE(),
-};
+class GEXFImport : public ImportFileModule {
 
-class GEXFImport : public ImportModule {
-
-public :
-
-  PLUGININFORMATION("GEXF","Antoine LAMBERT","05/05/2010",
-                    "Imports a new graph from a file in the GEXF input format<br/>as it is described in the XML Schema 1.2 draft (http://gexf.net/format/schema.html).<br/>Dynamic mode is not yet supported.",
-                    "1.0","File")
-  GEXFImport(const PluginContext*  context):ImportModule(context),
-    viewLayout(NULL), viewSize(NULL), viewColor(NULL), viewLabel(NULL),
-    viewShape(NULL), nodesHaveCoordinates(false) {
-    // add a file parameter for the plugin
-    addInParameter<string>("file::filename", paramHelp[0],"");
-    addInParameter<bool>("Curved edges",paramHelp[1], "false");
+public:
+  PLUGININFORMATION(
+      "GEXF", "Antoine LAMBERT", "05/05/2010",
+      "<p>Supported extensions: gexf</p><p>Imports a new graph from a file in the "
+      "GEXF input format<br/>as it is described in the XML Schema 1.2 specification<br/>"
+      "(<a "
+      "href=\"https://gexf.net/schema.html\">https://gexf.net/"
+      "schema.html</a>).</p><p>Warning: dynamic mode is not supported.</p>",
+      "1.1", "File")
+  GEXFImport(const PluginContext *context)
+      : ImportFileModule(context, {"gexf"}), viewLayout(nullptr), viewSize(nullptr),
+        viewColor(nullptr), viewLabel(nullptr), viewShape(nullptr), nodesHaveCoordinates(false) {
+    addInParameter<bool>("curved edges",
+                         "Indicates if Bézier curves should be used to draw the edges.", "false");
   }
 
-  ~GEXFImport() {}
+  ~GEXFImport() override {}
 
-  std::string icon() const {
+  std::string icon() const override {
     return ":/tulip/graphperspective/icons/32/import_gephi.png";
   }
 
-  std::list<std::string> fileExtensions() const {
-    std::list<std::string> l;
-    l.push_back("gexf");
-    return l;
-  }
-
-  // import plugins must implement bool importGraph()
-  bool importGraph() {
-    string filename;
+  bool importFile() override {
     bool curvedEdges = false;
-    // get the filename choosed by the user
-    dataSet->get<string>("file::filename", filename);
-    dataSet->get<bool>("Curved edges", curvedEdges);
-
-    QString qfilename = QString::fromUtf8(filename.c_str());
-
-    // if wrong extension, abort
-    if (!qfilename.endsWith(".gexf")) {
-      return false;
-    }
+    dataSet->get("curved edges", curvedEdges);
 
     // get Tulip visual attributes properties associated to the empty graph we want to fill
     viewLayout = graph->getProperty<LayoutProperty>("viewLayout");
@@ -115,25 +90,24 @@ public :
 
     nodesHaveCoordinates = false;
 
-    // Open the GEXF file choosed by the user
-    QFile *xmlFile = new QFile(qfilename);
+    // Open the GEXF file chosen by the user
+    QFile xmlFile(filename.c_str());
 
-    if (!xmlFile->open(QIODevice::ReadOnly | QIODevice::Text)) {
+    if (!xmlFile.open(QIODevice::ReadOnly | QIODevice::Text)) {
       // get error
-      pluginProgress->setError(xmlFile->errorString().toUtf8().data());
+      pluginProgress->setError(QStringToTlpString(xmlFile.errorString()));
       return false;
     }
 
     // Instantiate a QXmlStreamReader to parse the file (GEXF is xml)
-    QXmlStreamReader xmlReader(xmlFile);
+    QXmlStreamReader xmlReader(&xmlFile);
 
     // Parse each line of the file
     while (!xmlReader.atEnd()) {
       if (xmlReader.readNextStartElement()) {
         // only static graph are supported
-        if (xmlReader.name() == "graph") {
-          string mode =
-            xmlReader.attributes().value("mode").toString().toStdString();
+        if (xmlReader.name() == QString("graph")) {
+          string mode = QStringToTlpString(xmlReader.attributes().value("mode").toString());
 
           if (mode == "dynamic") {
             pluginProgress->setError("dynamic graph is not yet supported");
@@ -141,25 +115,25 @@ public :
           }
         }
         // create Tulip Properties from Gephi attributes
-        else if (xmlReader.name() == "attributes") {
+        else if (xmlReader.name() == QString("attributes")) {
           createPropertiesFromAttributes(xmlReader);
         }
         // parse graph node data
-        else if (xmlReader.name() == "nodes") {
+        else if (xmlReader.name() == QString("nodes")) {
           createNodes(xmlReader, graph);
         }
         // parse graph edge data
-        else if (xmlReader.name() == "edges") {
+        else if (xmlReader.name() == QString("edges")) {
           createEdges(xmlReader);
         }
       }
     }
 
-    delete xmlFile;
+    xmlFile.close();
 
     // Special case : some GEXF files declare edges before nodes
     // so we have to add edges once nodes have been parsed
-    for (size_t i = 0 ; i < edgesTmp.size() ; ++i) {
+    for (size_t i = 0; i < edgesTmp.size(); ++i) {
       graph->addEdge(nodesMap[edgesTmp[i].first], nodesMap[edgesTmp[i].second]);
     }
 
@@ -167,7 +141,7 @@ public :
     viewShape->setAllNodeValue(NodeShape::Circle);
 
     // add subgraph nodes, edges and meta nodes if needed
-    Graph*quotientGraph = addSubGraphsNodes();
+    Graph *quotientGraph = addSubGraphsNodes();
 
     if (quotientGraph) {
       addSubGraphsEdges();
@@ -187,64 +161,55 @@ public :
   // Create a set of Tulip Properties from the attributes declared in the GEXF file
   // according to data types
   void createPropertiesFromAttributes(QXmlStreamReader &xmlReader) {
-    bool nodeProperties = xmlReader.attributes().value("class") == "node";
-    map<string, PropertyInterface *> *propertiesMap = NULL;
+    bool nodeProperties = xmlReader.attributes().value("class") == QString("node");
+    tlp_hash_map<string, PropertyInterface *> &propertiesMap =
+        nodeProperties ? nodePropertiesMap : edgePropertiesMap;
 
-    if (nodeProperties) {
-      propertiesMap = &nodePropertiesMap;
-    }
-    else {
-      propertiesMap = &edgePropertiesMap;
-    }
-
-    while (!(xmlReader.isEndElement() && xmlReader.name() == "attributes")) {
+    while (!(xmlReader.isEndElement() && xmlReader.name() == QString("attributes"))) {
       xmlReader.readNext();
 
       // create a Tulip property and store mapping between attribute id and property
-      if (xmlReader.isStartElement() && xmlReader.name() == "attribute") {
-        string attributeId = xmlReader.attributes().value("id").toString().toStdString();
-        string attributeName = xmlReader.attributes().value("title").toString().toUtf8().data();
-        string attributeType = xmlReader.attributes().value("type").toString().toStdString();
+      if (xmlReader.isStartElement() && xmlReader.name() == QString("attribute")) {
+        string attributeId = QStringToTlpString(xmlReader.attributes().value("id").toString());
+        string attributeName = QStringToTlpString(xmlReader.attributes().value("title").toString());
+        string attributeType = QStringToTlpString(xmlReader.attributes().value("type").toString());
 
         if (attributeType == "string") {
-          (*propertiesMap)[attributeId] = graph->getProperty<StringProperty>(attributeName);
-        }
-        else if (attributeType == "float" || attributeType == "double") {
-          (*propertiesMap)[attributeId] = graph->getProperty<DoubleProperty>(attributeName);
-        }
-        else if (attributeType == "integer") {
-          (*propertiesMap)[attributeId] = graph->getProperty<IntegerProperty>(attributeName);
-        }
-        else if (attributeType == "boolean") {
-          (*propertiesMap)[attributeId] = graph->getProperty<BooleanProperty>(attributeName);
+          propertiesMap[attributeId] = graph->getProperty<StringProperty>(attributeName);
+        } else if (attributeType == "float" || attributeType == "double") {
+          propertiesMap[attributeId] = graph->getProperty<DoubleProperty>(attributeName);
+        } else if (attributeType == "integer") {
+          propertiesMap[attributeId] = graph->getProperty<IntegerProperty>(attributeName);
+        } else if (attributeType == "boolean") {
+          propertiesMap[attributeId] = graph->getProperty<BooleanProperty>(attributeName);
         }
       }
     }
   }
 
   // create nodes
-  void createNodes(QXmlStreamReader &xmlReader, Graph* g) {
-    while (!(xmlReader.isEndElement() && xmlReader.name() == "nodes")) {
+  void createNodes(QXmlStreamReader &xmlReader, Graph *g) {
+    while (!(xmlReader.isEndElement() && xmlReader.name() == QString("nodes"))) {
       xmlReader.readNext();
 
       // must be a node
-      if (xmlReader.isStartElement() && xmlReader.name() == "node")
+      if (xmlReader.isStartElement() && xmlReader.name() == QString("node"))
         parseNode(xmlReader, g);
     }
   }
 
   // create edges
   void createEdges(QXmlStreamReader &xmlReader) {
-    while (!(xmlReader.isEndElement() && xmlReader.name() == "edges")) {
+    while (!(xmlReader.isEndElement() && xmlReader.name() == QString("edges"))) {
       xmlReader.readNext();
 
       // must be an edge
-      if (xmlReader.isStartElement() && xmlReader.name() == "edge")
+      if (xmlReader.isStartElement() && xmlReader.name() == QString("edge"))
         parseEdge(xmlReader);
     }
   }
 
-  Graph* addInParent(node n, const string& pid) {
+  Graph *addInParent(node n, const string &pid) {
     // get the parent node
     // to find the corresponding sub graph
     // in which the current node must be added
@@ -254,19 +219,18 @@ public :
       // create a fake meta node
       pn = graph->addNode();
       nodesMap[pid] = pn;
-    }
-    else
+    } else
       pn = nodesMap[pid];
 
-    Graph* sg = (Graph*) nodeToSubgraph.get(pn.id);
+    Graph *sg = nodeToSubgraph.get(pn.id);
 
-    if (sg == NULL) {
+    if (sg == nullptr) {
       // add a subgraph for the fake meta node
       sg = graph->addSubGraph();
       // record pn as its fake meta node
       sg->setAttribute<node>("meta-node", pn);
       // and vice-versa
-      nodeToSubgraph.set(pn.id, (size_t) sg);
+      nodeToSubgraph.set(pn.id, sg);
     }
 
     // add n in the subgraph found
@@ -276,42 +240,40 @@ public :
   }
 
   // Parse node data
-  void parseNode(QXmlStreamReader &xmlReader, Graph* g) {
+  void parseNode(QXmlStreamReader &xmlReader, Graph *g) {
     node n;
-    string nodeId = xmlReader.attributes().value("id").toString().toStdString();
+    string nodeId = QStringToTlpString(xmlReader.attributes().value("id").toString());
 
     if (nodesMap.find(nodeId) == nodesMap.end()) {
       // if needed, add a node in the graph we are building
       n = g->addNode();
       // save mapping between gexf node id and created Tulip node
       nodesMap[nodeId] = n;
-    }
-    else
+    } else
       n = nodesMap[nodeId];
 
     // parse node label
     if (xmlReader.attributes().hasAttribute("label")) {
-      string nodeLabel =
-        xmlReader.attributes().value("label").toString().toUtf8().data();
+      string nodeLabel = QStringToTlpString(xmlReader.attributes().value("label").toString());
       viewLabel->setNodeValue(n, nodeLabel);
     }
 
     // parse node pid
     if (xmlReader.attributes().hasAttribute("pid")) {
-      string pid =
-        xmlReader.attributes().value("pid").toString().toStdString();
+      string pid = QStringToTlpString(xmlReader.attributes().value("pid").toString());
 
       if (g == graph)
         g = addInParent(n, pid);
       else
-        cerr << "multiple parents are not supported: " << pid.c_str() << " will be not added as parent of " << nodeId.c_str() << endl;
+        cerr << "multiple parents are not supported: " << pid.c_str()
+             << " will be not added as parent of " << nodeId.c_str() << endl;
     }
 
     xmlReader.readNext();
 
-    while (!(xmlReader.isEndElement() && xmlReader.name() == "node")) {
+    while (!(xmlReader.isEndElement() && xmlReader.name() == QString("node"))) {
       // parse node color
-      if (xmlReader.isStartElement() && xmlReader.qualifiedName() == "viz:color") {
+      if (xmlReader.isStartElement() && xmlReader.qualifiedName() == QString("viz:color")) {
         unsigned int r = xmlReader.attributes().value("r").toString().toUInt();
         unsigned int g = xmlReader.attributes().value("g").toString().toUInt();
         unsigned int b = xmlReader.attributes().value("b").toString().toUInt();
@@ -321,12 +283,10 @@ public :
           a = xmlReader.attributes().value("a").toString().toFloat();
         }
 
-        viewColor->setNodeValue(n, Color((unsigned char) r, (unsigned char) g,
-                                         (unsigned char) b,
-                                         (unsigned char) (a * 255)));
+        viewColor->setNodeValue(n, Color(uchar(r), uchar(g), uchar(b), uchar(a * 255)));
       }
       // parse node coordinates
-      else if (xmlReader.isStartElement() && xmlReader.qualifiedName() == "viz:position") {
+      else if (xmlReader.isStartElement() && xmlReader.qualifiedName() == QString("viz:position")) {
         nodesHaveCoordinates = true;
         float x = xmlReader.attributes().value("x").toString().toFloat();
         float y = xmlReader.attributes().value("y").toString().toFloat();
@@ -334,61 +294,58 @@ public :
         viewLayout->setNodeValue(n, Coord(x, y, z));
       }
       // parse node size
-      else if (xmlReader.isStartElement() && xmlReader.qualifiedName() == "viz:size") {
+      else if (xmlReader.isStartElement() && xmlReader.qualifiedName() == QString("viz:size")) {
         float size = xmlReader.attributes().value("value").toString().toFloat();
         viewSize->setNodeValue(n, Size(size, size, size));
       }
       // parse node attributes
-      else if (xmlReader.isStartElement() && xmlReader.qualifiedName() == "attvalue") {
+      else if (xmlReader.isStartElement() && xmlReader.qualifiedName() == QString("attvalue")) {
         string attributeId = "";
 
         if (xmlReader.attributes().hasAttribute("id")) {
-          attributeId = xmlReader.attributes().value("id").toString().toStdString();
-        }
-        else if (xmlReader.attributes().hasAttribute("for")) {
-          attributeId = xmlReader.attributes().value("for").toString().toStdString();
+          attributeId = QStringToTlpString(xmlReader.attributes().value("id").toString());
+        } else if (xmlReader.attributes().hasAttribute("for")) {
+          attributeId = QStringToTlpString(xmlReader.attributes().value("for").toString());
         }
 
-        string attributeStrValue = xmlReader.attributes().value("value").toString().toUtf8().data();
+        string attributeStrValue =
+            QStringToTlpString(xmlReader.attributes().value("value").toString());
 
         if (nodePropertiesMap.find(attributeId) != nodePropertiesMap.end()) {
           nodePropertiesMap[attributeId]->setNodeStringValue(n, attributeStrValue);
         }
       }
       // check for subgraph
-      else if (xmlReader.isStartElement() && xmlReader.qualifiedName() == "nodes") {
-        Graph* sg = (Graph *) nodeToSubgraph.get(n.id);
+      else if (xmlReader.isStartElement() && xmlReader.qualifiedName() == QString("nodes")) {
+        Graph *sg = nodeToSubgraph.get(n.id);
 
-        if (sg == NULL) {
+        if (sg == nullptr) {
           // add subgraph
           sg = graph->addSubGraph();
           // record the current node as its fake meta node
           sg->setAttribute<node>("meta-node", n);
           // and vice-versa
-          nodeToSubgraph.set(n.id, (size_t) sg);
+          nodeToSubgraph.set(n.id, sg);
         }
 
         // create its nodes
         createNodes(xmlReader, sg);
-      }
-      else if (xmlReader.isStartElement() && xmlReader.qualifiedName() == "edges") {
+      } else if (xmlReader.isStartElement() && xmlReader.qualifiedName() == QString("edges")) {
         // create its edges
         createEdges(xmlReader);
-      }
-      else if (xmlReader.isStartElement() && xmlReader.qualifiedName() == "parents") {
-        while (!(xmlReader.isEndElement() && xmlReader.name() == "parents")) {
+      } else if (xmlReader.isStartElement() && xmlReader.qualifiedName() == QString("parents")) {
+        while (!(xmlReader.isEndElement() && xmlReader.name() == QString("parents"))) {
           xmlReader.readNext();
 
           // must be a parent
-          if (xmlReader.isStartElement() && xmlReader.name() == "parent") {
-            string pid =
-              xmlReader.attributes().value("for").toString().toStdString();
+          if (xmlReader.isStartElement() && xmlReader.name() == QString("parent")) {
+            string pid = QStringToTlpString(xmlReader.attributes().value("for").toString());
 
             if (g == graph) {
               g = addInParent(n, pid);
-            }
-            else
-              cerr << "multiple parents are not supported: " << pid.c_str() << " will be not added as parent of " << nodeId.c_str() << endl;
+            } else
+              cerr << "multiple parents are not supported: " << pid.c_str()
+                   << " will be not added as parent of " << nodeId.c_str() << endl;
           }
         }
       }
@@ -400,8 +357,8 @@ public :
   // Parse edge data
   void parseEdge(QXmlStreamReader &xmlReader) {
     // parse the source node id and target node id
-    string srcId = xmlReader.attributes().value("source").toString().toStdString();
-    string tgtId = xmlReader.attributes().value("target").toString().toStdString();
+    string srcId = QStringToTlpString(xmlReader.attributes().value("source").toString());
+    string tgtId = QStringToTlpString(xmlReader.attributes().value("target").toString());
 
     // Check if nodes have been parsed
     if (!nodesMap.empty()) {
@@ -409,25 +366,25 @@ public :
       edge e = graph->addEdge(nodesMap[srcId], nodesMap[tgtId]);
 
       if (xmlReader.attributes().hasAttribute("label")) {
-        string edgeLabel = xmlReader.attributes().value("label").toString().toUtf8().data();
+        string edgeLabel = QStringToTlpString(xmlReader.attributes().value("label").toString());
         viewLabel->setEdgeValue(e, edgeLabel);
       }
 
       xmlReader.readNext();
 
-      while (!(xmlReader.isEndElement() && xmlReader.name() == "edge")) {
+      while (!(xmlReader.isEndElement() && xmlReader.name() == QString("edge"))) {
         // parse edge attribute
-        if (xmlReader.isStartElement() && xmlReader.qualifiedName() == "attvalue") {
+        if (xmlReader.isStartElement() && xmlReader.qualifiedName() == QString("attvalue")) {
           string attributeId = "";
 
           if (xmlReader.attributes().hasAttribute("id")) {
-            attributeId = xmlReader.attributes().value("id").toString().toStdString();
-          }
-          else if (xmlReader.attributes().hasAttribute("for")) {
-            attributeId = xmlReader.attributes().value("for").toString().toStdString();
+            attributeId = QStringToTlpString(xmlReader.attributes().value("id").toString());
+          } else if (xmlReader.attributes().hasAttribute("for")) {
+            attributeId = QStringToTlpString(xmlReader.attributes().value("for").toString());
           }
 
-          string attributeStrValue = xmlReader.attributes().value("value").toString().toUtf8().data();
+          string attributeStrValue =
+              QStringToTlpString(xmlReader.attributes().value("value").toString());
 
           if (edgePropertiesMap.find(attributeId) != edgePropertiesMap.end()) {
             edgePropertiesMap[attributeId]->setEdgeStringValue(e, attributeStrValue);
@@ -438,37 +395,29 @@ public :
       }
 
       // Store edge extremities information to add them to the graph once nodes will be parsed
-    }
-    else {
-      edgesTmp.push_back(make_pair(srcId, tgtId));
+    } else {
+      edgesTmp.emplace_back(srcId, tgtId);
     }
   }
 
-  Graph* addSubGraphsNodes() {
+  Graph *addSubGraphsNodes() {
     // quotientGraph will be created
     // as soon as there is a subgraph
-    Graph* quotientGraph = NULL;
+    Graph *quotientGraph = nullptr;
     // iterate on each subgraph of graph
     // and add missing nodes
-    StableIterator<Graph*> itg(graph->getSubGraphs());
-
-    while(itg.hasNext()) {
+    for (Graph *sg : stableIterator(graph->getSubGraphs())) {
       if (!quotientGraph)
         quotientGraph = graph->addCloneSubGraph("quotient graph");
 
-      Graph* sg = itg.next();
       // iterate on nodes
-      StableIterator<node> itn(sg->getNodes());
-
-      while(itn.hasNext()) {
-        node n = itn.next();
-        Graph* msg = (Graph*) nodeToSubgraph.get(n.id);
+      for (auto n : stableIterator(sg->getNodes())) {
+        Graph *msg = nodeToSubgraph.get(n.id);
 
         if (msg) {
           // if the current node is a fake meta node
           // add the nodes of the pointed subgraph
-          node msn;
-          forEach(msn, msg->getNodes()) {
+          for (auto msn : msg->nodes()) {
             sg->addNode(msn);
             // the nodes in a pointed subgraph have to be removed
             // from quotientGraph
@@ -484,16 +433,11 @@ public :
   void addSubGraphsEdges() {
     // iterate on each subgraph of graph
     // and add needed edges
-    Iterator<Graph*>* itg = graph->getSubGraphs();
-
-    while(itg->hasNext()) {
-      Graph* sg = itg->next();
-      node n;
+    for (Graph *sg : graph->subGraphs()) {
       // iterate on nodes
-      forEach(n, sg->getNodes()) {
+      for (auto n : sg->nodes()) {
         // add its out edges
-        edge e;
-        forEach(e, graph->getOutEdges(n)) {
+        for (auto e : graph->getOutEdges(n)) {
           if (sg->isElement(graph->target(e)))
             sg->addEdge(e);
         }
@@ -501,21 +445,17 @@ public :
     }
   }
 
-  void computeMetaNodes(Graph* quotientGraph) {
+  void computeMetaNodes(Graph *quotientGraph) {
     // iterate on each subgraph of g
     // and add needed meta nodes
-    Iterator<Graph*>* itg = graph->getSubGraphs();
 
-    while(itg->hasNext()) {
-      Graph* sg = itg->next();
+    for (Graph *sg : graph->subGraphs()) {
       // iterate on nodes
-      StableIterator<node> itn(sg->getNodes());
+      vector<node> sgNodes(sg->nodes());
+      for (auto n : sgNodes) {
+        Graph *msg = nodeToSubgraph.get(n.id);
 
-      while(itn.hasNext()) {
-        node n = itn.next();
-        Graph* msg = (Graph*) nodeToSubgraph.get(n.id);
-
-        if (msg != NULL) {
+        if (msg != nullptr) {
           // n is a fake meta node
           // create the real meta node
           // pointing to msg
@@ -529,8 +469,7 @@ public :
 
           // set meta node properties values to the ones
           // of the fake meta node
-          PropertyInterface* prop;
-          forEach(prop, graph->getObjectProperties()) {
+          for (PropertyInterface *prop : graph->getObjectProperties()) {
             prop->copy(mn, n, prop, true);
           }
 
@@ -539,29 +478,25 @@ public :
             quotientGraph->addNode(mn);
 
           // replace n by mn
-          edge e;
-          forEach(e, graph->getInOutEdges(n)) {
-            pair<node, node> eEnds = graph->ends(e);
+          for (auto e : graph->getInOutEdges(n)) {
+            const pair<node, node> &eEnds = graph->ends(e);
 
             if (eEnds.first == n) {
               graph->setEnds(e, mn, eEnds.second);
 
-              if ((sg != quotientGraph) &&
-                  quotientGraph->isElement(eEnds.second))
+              if ((sg != quotientGraph) && quotientGraph->isElement(eEnds.second))
                 quotientGraph->addEdge(e);
-            }
-            else {
+            } else {
               graph->setEnds(e, eEnds.first, mn);
 
-              if ((sg != quotientGraph) &&
-                  quotientGraph->isElement(eEnds.first))
+              if ((sg != quotientGraph) && quotientGraph->isElement(eEnds.first))
                 quotientGraph->addEdge(e);
             }
           }
           // remove fake meta node
           graph->delNode(n);
           msg->removeAttribute("meta-node");
-          nodeToSubgraph.set(n.id, 0);
+          nodeToSubgraph.set(n.id, nullptr);
         }
       }
     }
@@ -569,17 +504,15 @@ public :
 
   // Methods which compute Cubic Bézier control points for each edge
   void curveGraphEdges() {
-    edge e;
-    forEach(e, graph->getEdges()) {
-      node src = graph->source(e);
-      node tgt = graph->target(e);
-      Coord srcCoord = viewLayout->getNodeValue(src);
-      Coord tgtCoord = viewLayout->getNodeValue(tgt);
-      Coord dir = tgtCoord - srcCoord;
+    for (auto e : graph->edges()) {
+      auto eEnds = graph->ends(e);
+      const Coord &srcCoord = viewLayout->getNodeValue(eEnds.first);
+      const Coord &tgtCoord = viewLayout->getNodeValue(eEnds.second);
+      Coord &&dir = tgtCoord - srcCoord;
       dir /= dir.norm();
       float length = srcCoord.dist(tgtCoord);
       float factor = 0.2f * length;
-      Coord normal = Coord(dir[1], -dir[0]);
+      Coord &&normal = Coord(dir[1], -dir[0]);
       normal *= factor;
 
       Coord p1 = dir;
@@ -587,31 +520,26 @@ public :
       p1 += srcCoord;
       p1 += normal;
 
-      Coord p2 = dir;
+      Coord p2 = std::move(dir);
       p2 *= -factor;
       p2 += tgtCoord;
       p2 += normal;
 
       // Set the second and third Cubic Bézier curve control points as edge bends
-      vector<Coord> bends;
-      bends.push_back(p1);
-      bends.push_back(p2);
-
-      viewLayout->setEdgeValue(e, bends);
+      viewLayout->setEdgeValue(e, vector<Coord>{{p1, p2}});
     }
   }
 
-private :
-
+private:
   // maps associating attribute id to Tulip property
-  map<string, PropertyInterface *> nodePropertiesMap;
-  map<string, PropertyInterface *> edgePropertiesMap;
+  tlp_hash_map<string, PropertyInterface *> nodePropertiesMap;
+  tlp_hash_map<string, PropertyInterface *> edgePropertiesMap;
 
   // map associating GEXF node id to Tulip node
-  map<string, node> nodesMap;
+  tlp_hash_map<string, node> nodesMap;
 
   // vector to store edge information in case edges are declared before nodes in GEXF file
-  vector<pair<string, string> > edgesTmp;
+  vector<pair<string, string>> edgesTmp;
 
   // Visual attributes properties pointers to the graph we are building
   LayoutProperty *viewLayout;
@@ -621,11 +549,11 @@ private :
   IntegerProperty *viewShape;
   // to register the subgraph corresponding
   // to a fake meta node
-  MutableContainer<size_t> nodeToSubgraph;
+  MutableContainer<Graph *> nodeToSubgraph;
 
   bool nodesHaveCoordinates;
-
 };
 
-// Macro for declaring import plugin in Tulip, it will then be accessible since the File -> Import -> File menu entry in Tulip
+// Macro for declaring import plugin in Tulip, it will then be accessible since the File -> Import
+// -> File menu entry in Tulip
 PLUGIN(GEXFImport)
