@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -35,8 +35,7 @@ static const char *paramHelp[] = {
     "Connectivity number of each node.",
 
     // tore
-    "If true, opposite nodes on each side of the grid are connected. In a 4 connectivity the "
-    "resulting object is a torus.",
+    "If true, opposite nodes on each side of the grid are connected. In a 4 connectivity the resulting object is a torus.",
 
     // Line spacing
     "Spacing between nodes."};
@@ -52,13 +51,12 @@ static const char *paramHelp[] = {
 class Grid : public ImportModule {
 public:
   PLUGININFORMATION("Grid", "Jonathan Dubois", "02/12/2003", "Imports a new grid structured graph.",
-                    "2.0", "Graph")
+                    "2.1", "Graph")
   Grid(tlp::PluginContext *context) : ImportModule(context) {
     addInParameter<unsigned int>("width", paramHelp[0], "10");
     addInParameter<unsigned int>("height", paramHelp[1], "10");
-    addInParameter<StringCollection>("connectivity", paramHelp[2], "4;6;8", true,
-                                     "4 <br> 6 <br> 8");
-    addInParameter<bool>("oppositeNodesConnected", paramHelp[3], "false");
+    addInParameter<StringCollection>("connectivity", paramHelp[2], "4;6;8", true, "4<br/>6<br/>8");
+    addInParameter<bool>("opposite nodes connected", paramHelp[3], "false");
     addInParameter<double>("spacing", paramHelp[4], "1.0");
   }
   ~Grid() override {}
@@ -153,28 +151,28 @@ public:
     if (dataSet != nullptr) {
       dataSet->get("width", width);
       dataSet->get("height", height);
-      dataSet->get("oppositeNodesConnected", isTore);
+      dataSet->get("opposite nodes connected", isTore);
       dataSet->get("spacing", spacing);
       dataSet->get("connectivity", connectivity);
     }
 
     if (width == 0) {
       if (pluginProgress)
-        pluginProgress->setError(string("Error: width cannot be null"));
+        pluginProgress->setError(string("Error: \"width\" cannot be null"));
 
       return false;
     }
 
     if (height == 0) {
       if (pluginProgress)
-        pluginProgress->setError(string("Error: height cannot be null"));
+        pluginProgress->setError(string("Error: \"height\" cannot be null"));
 
       return false;
     }
 
-    if (spacing < 0.0) {
+    if (spacing < 0) {
       if (pluginProgress)
-        pluginProgress->setError(string("Error: spacing must be strictly positive"));
+        pluginProgress->setError(string("Error: \"spacing\" must be strictly positive"));
 
       return false;
     }
@@ -187,11 +185,11 @@ public:
       if (isTore && height % 2 == 1) {
         if (pluginProgress)
           pluginProgress->setError(
-              "Error : cannot connect opposite nodes in an hexagonal grid with odd height");
+              "Error: cannot connect opposite nodes in an hexagonal grid with odd height");
         else
           tlp::warning()
               << __PRETTY_FUNCTION__ << ":" << __LINE__
-              << " Error : cannot connect opposite nodes in an hexagonal grid with odd height"
+              << " Error: cannot connect opposite nodes in an hexagonal grid with odd height"
               << std::endl;
 
         return false;
@@ -200,7 +198,8 @@ public:
       conn = 8;
 
     // graph is predimensioned according the parameters
-    graph->addNodes(height * width);
+    vector<node> nodes;
+    graph->addNodes(height * width, nodes);
 
     // compute nb edges
     unsigned int nbEdges = height * (width - 1);
@@ -231,7 +230,6 @@ public:
     ends.reserve(nbEdges);
     graph->reserveEdges(nbEdges);
 
-    const vector<node> &nodes = graph->nodes();
     buildRow(nodes, ends, 0, width, conn, isTore, spacing);
 
     for (unsigned int i = 1; i < height; ++i) {
