@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -36,18 +36,13 @@
  *
  *  - 09/05/2011 Version 1.0: Initial release
  *
- *  \author Patrick Mary of Tulip Team http://tulip.labri.fr/
+ *  \author Patrick Mary of Tulip Team https://tulip.labri.fr/
  *
  *
  */
 using namespace std;
 using namespace tlp;
 
-static const char *paramHelp[] = {
-    // filename
-    "This parameter indicates the pathname of the Pajek file (.net or .paj) to import.",
-};
-
 namespace {
 bool tokenize(const string &str, vector<string> &tokens, const string &delimiters) {
   if (str.empty())
@@ -105,31 +100,24 @@ bool tokenize(const string &str, vector<string> &tokens, const string &delimiter
 }
 } // namespace
 
-class ImportPajek : public ImportModule {
+class ImportPajek : public ImportFileModule {
 
 public:
   PLUGININFORMATION("Pajek", "Patrick Mary", "09/05/2011",
-                    "<p>Supported extensions: net, paj</p><p>Imports a new graph from a file "
-                    "(.net) in Pajek input format<br/>as it is described in the Pajek manual "
-                    "(<b>http://pajek.imfm.si/lib/exe/fetch.php?media=dl:pajekman203.pdf</b>)<br/"
-                    ">from the Pajek wiki page "
-                    "<b>http://pajek.imfm.si/doku.php?id=download</b>.<br/>Warning: the "
-                    "description of the edges with Matrix (adjacency lists)<br/>is not yet "
+                    "<p>File extensions: net, paj</p><p>Imports a new graph from a file "
+                    "(.net) in Pajek NET format<br/>as it is described in the Pajek manual "
+                    "(<a "
+                    "href=\"http://mrvar.fdv.uni-lj.si/pajek/pajekman.pdf\">http://"
+                    "mrvar.fdv.uni-lj.si/pajek/pajekman.pdf</a>)</p>"
+                    "<p>Warning: the "
+                    "description of the edges with Matrix (adjacency lists)is not yet "
                     "supported.</p>",
                     "1.0", "File")
-  std::list<std::string> fileExtensions() const override {
-    std::list<std::string> l;
-    l.push_back("net");
-    l.push_back("paj");
-    return l;
-  }
 
   ImportPajek(const tlp::PluginContext *context)
-      : ImportModule(context), nbNodes(0), weights(nullptr), labels(nullptr), layout(nullptr),
-        sizes(nullptr), expectedLine(NET_UNKNOWN), partition(nullptr), curNodeId(0),
-        vectorProp(nullptr) {
-    addInParameter<string>("file::filename", paramHelp[0], "");
-  }
+      : ImportFileModule(context, {"net", "paj"}), nbNodes(0), weights(nullptr), labels(nullptr),
+        layout(nullptr), sizes(nullptr), expectedLine(NET_UNKNOWN), partition(nullptr),
+        curNodeId(0), vectorProp(nullptr) {}
 
   ~ImportPajek() override {}
 
@@ -479,18 +467,17 @@ public:
     return true;
   }
 
-  bool importGraph() override {
-    string filename;
-
-    dataSet->get<string>("file::filename", filename);
-
-    if (filename.empty()) {
-      pluginProgress->setError("Filename is empty.");
+  bool importFile() override {
+    std::istream *in = tlp::getInputFileStream(filename);
+    // check for open stream failure
+    if (in->fail()) {
+      std::stringstream ess;
+      ess << "Unable to open " << filename << ": " << tlp::getStrError();
+      pluginProgress->setError(ess.str());
+      delete in;
       return false;
     }
 
-    std::istream *in = tlp::getInputFileStream(filename.c_str());
-
     labels = graph->getProperty<StringProperty>("viewLabel");
     weights = graph->getProperty<DoubleProperty>("weights");
     layout = graph->getProperty<LayoutProperty>("viewLayout");
@@ -516,7 +503,7 @@ public:
       ++lineNumber;
 
       if (!treatLine(line)) {
-        errors << "An error occurs while parsing file : " << filename << endl;
+        errors << "An error occurs while parsing file: " << filename << endl;
         errors << "[ERROR] at line " << lineNumber << endl;
 
         if (pluginProgress) {
