@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -23,11 +23,11 @@ using namespace std;
 using namespace tlp;
 
 static const char *paramHelp[] = {
-    // minsize
-    "Minimal number of nodes in the tree.",
+    // min size
+    "Minimum number of nodes in the tree.",
 
-    // maxsize
-    "Maximal number of nodes in the tree.",
+    // max size
+    "Maximum number of nodes in the tree.",
 
     // tree layout
     "If true, the generated tree is drawn with the 'Tree Leaf' layout algorithm."};
@@ -66,12 +66,12 @@ class RandomTree : public ImportModule {
 
 public:
   PLUGININFORMATION("Uniform Random Binary Tree", "Auber", "16/02/2001",
-                    "Imports a new randomly generated uniform binary tree.", "1.1", "Graph")
+                    "Imports a new randomly generated uniform binary tree.", "1.2", "Graph")
   RandomTree(tlp::PluginContext *context) : ImportModule(context) {
-    addInParameter<unsigned int>("Minimum size", paramHelp[0], "50");
-    addInParameter<unsigned int>("Maximum size", paramHelp[1], "60");
+    addInParameter<unsigned int>("min size", paramHelp[0], "50");
+    addInParameter<unsigned int>("max size", paramHelp[1], "60");
     addInParameter<bool>("tree layout", paramHelp[2], "false");
-    addDependency("Tree Leaf", "1.0");
+    addDependency("Tree Leaf", "1.1");
   }
 
   bool importGraph() override {
@@ -83,25 +83,21 @@ public:
     bool needLayout = false;
 
     if (dataSet != nullptr) {
-      if (!dataSet->get("Minimum size", minSize))
-        dataSet->get("minsize", minSize); // keep old name for backward compatibility
-
-      if (!dataSet->get("Maximum size", maxSize))
-        dataSet->get("maxsize", maxSize); // keep old name for backward compatibility
-
+      dataSet->get("min size", minSize);
+      dataSet->get("max size", maxSize);
       dataSet->get("tree layout", needLayout);
     }
 
     if (maxSize < 1) {
       if (pluginProgress)
-        pluginProgress->setError("Error: maximum size must be a strictly positive integer");
+        pluginProgress->setError("Error: \"max size\" must be a strictly positive integer");
 
       return false;
     }
 
     if (maxSize < minSize) {
       if (pluginProgress)
-        pluginProgress->setError("Error: maximum size must be greater than minimum size");
+        pluginProgress->setError("Error: \"max size\" must be greater than \"min size\"");
 
       return false;
     }
