@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -33,7 +33,7 @@ static const char *paramHelp[] = {
     // degree
     "Average degree of the nodes in the final graph.",
 
-    // degree
+    // long edge
     "If true, long distance edges are added in the grid approximation."};
 
 /*
@@ -72,14 +72,14 @@ public:
 
     if (nbNodes == 0) {
       if (pluginProgress)
-        pluginProgress->setError(string("Error: the number of nodes cannot be null"));
+        pluginProgress->setError("Error: \"nodes\" cannot be null");
 
       return false;
     }
 
     if (avgDegree == 0) {
       if (pluginProgress)
-        pluginProgress->setError(string("Error: the average degree cannot be null"));
+        pluginProgress->setError("Error: \"degree\" cannot be null");
 
       return false;
     }
@@ -93,11 +93,10 @@ public:
 
     pluginProgress->showPreview(false);
 
-    graph->addNodes(nbNodes);
+    vector<node> nodes;
+    graph->addNodes(nbNodes, nodes);
     graph->reserveEdges(nbNodes * avgDegree);
 
-    const vector<node> &nodes = graph->nodes();
-
     for (auto n : nodes) {
       newLayout->setNodeValue(n,
                               Coord(float(randomInteger(WIDTH)), float(randomInteger(HEIGHT)), 0));
