@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -21,10 +21,13 @@
 
 #include "ui_FishEyeConfigWidget.h"
 
+#include <tulip/Interactor.h>
+
 using namespace tlp;
 
 FishEyeConfigWidget::FishEyeConfigWidget(QWidget *parent)
     : QWidget(parent), _ui(new Ui::FishEyeConfigWidget) {
+  Interactor::setupConfigWidget(this);
   _ui->setupUi(this);
 }
 
