@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -102,7 +102,7 @@ FishEyeInteractor::~FishEyeInteractor() {
   delete fisheyeConfigWidget;
 }
 
-QWidget *FishEyeInteractor::configurationWidget() const {
+QWidget *FishEyeInteractor::configurationOptionsWidget() const {
   return fisheyeConfigWidget;
 }
 
@@ -149,8 +149,8 @@ bool FishEyeInteractorComponent::eventFilter(QObject *obj, QEvent *e) {
       e->type() == QEvent::MouseButtonRelease) {
     activateFishEye = true;
     QMouseEvent *me = static_cast<QMouseEvent *>(e);
-    float x = glWidget->width() - me->x();
-    float y = me->y();
+    float x = glWidget->width() - me->pos().x();
+    float y = me->pos().y();
     Coord screenCoords(x, y, 0);
     fisheyeCenter = camera->viewportTo3DWorld(glWidget->screenToViewport(screenCoords));
     glWidget->redraw();
@@ -158,31 +158,30 @@ bool FishEyeInteractorComponent::eventFilter(QObject *obj, QEvent *e) {
   } else if (e->type() == QEvent::Wheel) {
     activateFishEye = true;
     QWheelEvent *wheelEvent = static_cast<QWheelEvent *>(e);
-    int numSteps = wheelEvent->delta() / 120;
+    // vertical move
+    int vDelta = wheelEvent->angleDelta().y();
 
-    if (wheelEvent->orientation() == Qt::Vertical &&
-        (wheelEvent->modifiers() == Qt::ControlModifier)) {
+    if (vDelta != 0) {
       activateFishEye = true;
-      configWidget->setFishEyeRadius(configWidget->getFishEyeRadius() +
-                                     configWidget->getFishEyeRadiusIncrementStep() * numSteps);
-      glWidget->redraw();
-      return true;
-    } else if (wheelEvent->orientation() == Qt::Vertical &&
-               (wheelEvent->modifiers() == Qt::ShiftModifier)) {
-      activateFishEye = true;
-      float newHeight = configWidget->getFishEyeHeight() +
-                        configWidget->getFishEyeHeightIncrementStep() * numSteps;
+      if (wheelEvent->modifiers() == Qt::ControlModifier) {
+        configWidget->setFishEyeRadius(configWidget->getFishEyeRadius() +
+                                       configWidget->getFishEyeRadiusIncrementStep() *
+                                           (vDelta / 120));
+        glWidget->redraw();
+        return true;
+      } else if (wheelEvent->modifiers() == Qt::ShiftModifier) {
+        float newHeight = configWidget->getFishEyeHeight() +
+                          configWidget->getFishEyeHeightIncrementStep() * (vDelta / 120);
 
-      if (newHeight < 0) {
-        newHeight = 0;
+        if (newHeight < 0) {
+          newHeight = 0;
+        }
+
+        configWidget->setFishEyeHeight(newHeight);
+        glWidget->redraw();
+        return true;
       }
-
-      configWidget->setFishEyeHeight(newHeight);
-      glWidget->redraw();
-      return true;
     }
-
-    return false;
   }
 
   return false;
