@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -34,6 +34,7 @@
 #include <QOpenGLFramebufferObject>
 #include <QEvent>
 #include <QMouseEvent>
+#include <QLabel>
 
 #include <sstream>
 
@@ -43,9 +44,29 @@ using namespace std;
 using namespace tlp;
 
 MouseMagnifyingGlassInteractor::MouseMagnifyingGlassInteractor(const tlp::PluginContext *)
-    : GLInteractorComposite(QIcon(":/i_magnifying_glass.png"), "Magnifying glass") {}
+    : GLInteractorComposite(QIcon(":/i_magnifying_glass.png"), "Magnifying glass"),
+      doc(new QLabel()) {
+  Interactor::setupConfigWidget(doc);
+  doc->setWordWrap(true);
+  doc->setAlignment(Qt::AlignTop);
+  doc->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+}
+
+MouseMagnifyingGlassInteractor::~MouseMagnifyingGlassInteractor() {
+  delete doc;
+}
 
 void MouseMagnifyingGlassInteractor::construct() {
+  doc->setText(
+      QString("<h3>Magnifying glass</h3>") +
+      "Increase/decrease size:<ul><li><b>Ctrl + Mouse wheel</b> up/down</ul></li></p>"
+      "Increase/decrease magnifying power:<ul><li><b>Shit + Mouse wheel</b> up/down</ul></li>" +
+#if !defined(__APPLE__)
+      "Zoom/Unzoom:<ul><li><b>Mouse wheel</b> up/down</ul></li>"
+#else
+      "Zoom/Unzoom:<ul><li><b>Mouse wheel</b> down/up</ul></li>"
+#endif
+  );
   push_back(new MouseNKeysNavigator(false));
   push_back(new MouseMagnifyingGlassInteractorComponent());
 }
@@ -85,25 +106,23 @@ bool MouseMagnifyingGlassInteractorComponent::eventFilter(QObject *, QEvent *e)
 
   if (e->type() == QEvent::MouseMove) {
     QMouseEvent *me = static_cast<QMouseEvent *>(e);
-    float x = glWidget->width() - me->x();
-    float y = me->y();
+    float x = glWidget->width() - me->pos().x();
+    float y = me->pos().y();
     screenCoords = Coord(x, y, 0);
     boxCenter = camera->viewportTo3DWorld(glWidget->screenToViewport(screenCoords));
 
     updateMagnifyingGlass = true;
   } else if (e->type() == QEvent::Wheel) {
     QWheelEvent *wheelEvent = static_cast<QWheelEvent *>(e);
-    float x = glWidget->width() - wheelEvent->x();
-    float y = wheelEvent->y();
+    float x = glWidget->width() - wheelEvent->position().x();
+    float y = wheelEvent->position().y();
     screenCoords = Coord(x, y, 0);
     boxCenter = camera->viewportTo3DWorld(glWidget->screenToViewport(screenCoords));
-    int numDegrees = wheelEvent->delta() / 8;
-    int numSteps = numDegrees / 15;
+    int vDelta = wheelEvent->angleDelta().y();
 
-    if (wheelEvent->orientation() == Qt::Vertical &&
-        (wheelEvent->modifiers() == Qt::ControlModifier)) {
+    if (vDelta && (wheelEvent->modifiers() == Qt::ControlModifier)) {
       updateMagnifyingGlass = true;
-      radius += numSteps;
+      radius += vDelta / 120;
 
       if (radius < 1)
         radius = 1;
@@ -112,10 +131,9 @@ bool MouseMagnifyingGlassInteractorComponent::eventFilter(QObject *, QEvent *e)
       delete fbo2;
       fbo = nullptr;
       fbo2 = nullptr;
-    } else if (wheelEvent->orientation() == Qt::Vertical &&
-               (wheelEvent->modifiers() == Qt::ShiftModifier)) {
+    } else if (vDelta && (wheelEvent->modifiers() == Qt::ShiftModifier)) {
       updateMagnifyingGlass = true;
-      magnifyPower += numSteps;
+      magnifyPower += vDelta / 120;
 
       if (magnifyPower < 1)
         magnifyPower = 1;
