@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -22,10 +22,10 @@
 
 #include <tulip/GLInteractor.h>
 #include <tulip/GlMainWidget.h>
-
-#include "../../utils/StandardInteractorPriority.h"
+#include <tulip/StandardInteractorPriority.h>
 
 class QOpenGLFramebufferObject;
+class QLabel;
 
 namespace tlp {
 
@@ -74,18 +74,23 @@ private:
 class MouseMagnifyingGlassInteractor : public GLInteractorComposite {
 
 public:
+  QLabel *doc;
+
   PLUGININFORMATION("MouseMagnifyingGlassInteractor", "Antoine Lambert", "19/06/2009",
-                    "Mouse Magnifying Glass Interactor Interactor", "1.0", "Visualization")
+                    "Mouse Magnifying Glass Interactor", "1.1", "Visualization")
 
   MouseMagnifyingGlassInteractor(const tlp::PluginContext *);
 
+  ~MouseMagnifyingGlassInteractor();
+
   void construct() override;
 
   unsigned int priority() const override {
     return StandardInteractorPriority::MagnifyingGlass;
   }
-  QWidget *configurationWidget() const override {
-    return nullptr;
+
+  QLabel *configurationDocWidget() const override {
+    return doc;
   }
 
   bool isCompatible(const std::string &viewName) const override;
