@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -86,26 +86,6 @@ private:
   LayoutProperty *srcLayout, *destLayout, *viewLayout;
 };
 
-class NeighborNodesEdgeLengthOrdering : public binary_function<node, node, bool> {
-
-public:
-  NeighborNodesEdgeLengthOrdering(node centralNode, LayoutProperty *layout)
-      : centralNode(centralNode), layout(layout) {}
-
-  bool operator()(tlp::node n1, tlp::node n2) const {
-    Coord centralNodeCoord = layout->getNodeValue(centralNode);
-    Coord n1Coord = layout->getNodeValue(n1);
-    Coord n2Coord = layout->getNodeValue(n2);
-    float centralToN1Dist = centralNodeCoord.dist(n1Coord);
-    float centralToN2Dist = centralNodeCoord.dist(n2Coord);
-    return centralToN1Dist < centralToN2Dist;
-  }
-
-private:
-  node centralNode;
-  LayoutProperty *layout;
-};
-
 class MouseEventDiscardFilter : public QObject {
 
 public:
@@ -208,11 +188,13 @@ bool NeighborhoodHighlighter::eventFilter(QObject *, QEvent *e) {
 
   if (e->type() == QEvent::Wheel && centralNodeLocked && !circleLayoutSet) {
     QWheelEvent *we = static_cast<QWheelEvent *>(e);
+    auto wePos = we->position();
 
-    if (selectInAugmentedDisplayGraph(we->x(), we->y(), selectedEntity) &&
+    if (selectInAugmentedDisplayGraph(wePos.x(), wePos.y(), selectedEntity) &&
         selectedEntity.getEntityType() == SelectedEntity::NODE_SELECTED) {
       if (selectedEntity.getComplexEntityId() == neighborhoodGraphCentralNode.id) {
-        int numSteps = we->delta() / 120;
+        auto delta = we->angleDelta();
+        int numSteps = (delta.x() ? delta.x() : delta.y()) / 120;
         neighborhoodDist += numSteps;
 
         if (neighborhoodDist < 1) {
@@ -233,7 +215,7 @@ bool NeighborhoodHighlighter::eventFilter(QObject *, QEvent *e) {
     QMouseEvent *qMouseEv = static_cast<QMouseEvent *>(e);
 
     if (!centralNodeLocked) {
-      node tmpNode = selectNodeInOriginalGraph(glWidget, qMouseEv->x(), qMouseEv->y());
+      node tmpNode = selectNodeInOriginalGraph(glWidget, qMouseEv->pos().x(), qMouseEv->pos().y());
 
       if (tmpNode != selectedNode) {
         buildNeighborhoodGraph(tmpNode, originalGraph);
@@ -244,9 +226,9 @@ bool NeighborhoodHighlighter::eventFilter(QObject *, QEvent *e) {
       else
         glWidget->setCursor(QCursor());
     } else {
-      *neighborhoodGraphColors = *neighborhoodGraphBackupColors;
+      neighborhoodGraphColors->copy(neighborhoodGraphBackupColors);
 
-      if (selectInAugmentedDisplayGraph(qMouseEv->x(), qMouseEv->y(), selectedEntity) &&
+      if (selectInAugmentedDisplayGraph(qMouseEv->pos().x(), qMouseEv->pos().y(), selectedEntity) &&
           selectedEntity.getEntityType() == SelectedEntity::NODE_SELECTED) {
         if (selectedEntity.getComplexEntityId() != neighborhoodGraphCentralNode.id) {
           neighborhoodGraphColors->setNodeValue(node(selectedEntity.getComplexEntityId()),
@@ -363,19 +345,11 @@ bool NeighborhoodHighlighter::eventFilter(QObject *, QEvent *e) {
   return false;
 }
 node NeighborhoodHighlighter::selectNodeInOriginalGraph(GlMainWidget *glWidget, int x, int y) {
-  node n;
-  glWidget->makeCurrent();
-  vector<SelectedEntity> selectedElements;
-  glWidget->getScene()->selectEntities(
-      static_cast<RenderingEntitiesFlag>(RenderingNodes | RenderingWithoutRemove),
-      glWidget->screenToViewport(x - 1), glWidget->screenToViewport(y - 1),
-      glWidget->screenToViewport(3), glWidget->screenToViewport(3), nullptr, selectedElements);
-
-  if (!selectedElements.empty()) {
-    n = node(selectedElements[0].getComplexEntityId());
-  }
-
-  return n;
+  SelectedEntity entity;
+  if (glWidget->pickNodesEdges(x, y, entity, nullptr, true, false) &&
+      entity.getEntityType() == SelectedEntity::NODE_SELECTED)
+    return node(entity.getComplexEntityId());
+  return node();
 }
 
 bool NeighborhoodHighlighter::selectInAugmentedDisplayGraph(const int x, const int y,
@@ -407,8 +381,7 @@ void NeighborhoodHighlighter::performZoomAndPan(const BoundingBox &destBB,
 void NeighborhoodHighlighter::cleanupNeighborhoodGraph() {
   delete glNeighborhoodGraph;
   glNeighborhoodGraph = nullptr;
-  delete neighborhoodGraph;
-  neighborhoodGraph = nullptr;
+  // delete properties first
   delete neighborhoodGraphLayout;
   neighborhoodGraphLayout = nullptr;
   delete neighborhoodGraphCircleLayout;
@@ -419,6 +392,9 @@ void NeighborhoodHighlighter::cleanupNeighborhoodGraph() {
   neighborhoodGraphColors = nullptr;
   delete neighborhoodGraphBackupColors;
   neighborhoodGraphBackupColors = nullptr;
+  // last delete neighborhoodGraph
+  delete neighborhoodGraph;
+  neighborhoodGraph = nullptr;
 }
 
 void NeighborhoodHighlighter::buildNeighborhoodGraph(node n, Graph *g) {
@@ -465,8 +441,8 @@ void NeighborhoodHighlighter::updateNeighborhoodGraphLayoutAndColors() {
       neighborhoodGraphBackupColors->setEdgeValue(e, origGraphColors->getEdgeValue(e));
     }
 
-    *neighborhoodGraphLayout = *neighborhoodGraphOriginalLayout;
-    *neighborhoodGraphColors = *neighborhoodGraphBackupColors;
+    neighborhoodGraphLayout->copy(neighborhoodGraphOriginalLayout);
+    neighborhoodGraphColors->copy(neighborhoodGraphBackupColors);
   }
 }
 
@@ -537,8 +513,15 @@ void NeighborhoodHighlighter::computeNeighborhoodGraphCircleLayout() {
     }
   }
 
+  auto layout = neighborhoodGraphLayout;
   sort(neighborsNodes.begin(), neighborsNodes.end(),
-       NeighborNodesEdgeLengthOrdering(neighborhoodGraphCentralNode, neighborhoodGraphLayout));
+       [centralNodeCoord, layout](tlp::node n1, tlp::node n2) {
+         Coord n1Coord = layout->getNodeValue(n1);
+         Coord n2Coord = layout->getNodeValue(n2);
+         float centralToN1Dist = centralNodeCoord.dist(n1Coord);
+         float centralToN2Dist = centralNodeCoord.dist(n2Coord);
+         return centralToN1Dist < centralToN2Dist;
+       });
 
   BoundingBox centralNodeBB(Coord(centralNodeCoord.getX() - centralNodeSize.getW() / 2,
                                   centralNodeCoord.getY() - centralNodeSize.getH() / 2, 0),
@@ -584,14 +567,13 @@ void NeighborhoodHighlighter::computeNeighborhoodGraphCircleLayout() {
   for (auto e : neighborhoodGraph->edges()) {
     const std::pair<node, node> &eEnds = neighborhoodGraph->ends(e);
     node srcNode = eEnds.first;
-    node tgtNode = eEnds.second;
     Coord finalBendsCoord;
 
     if (srcNode != neighborhoodGraphCentralNode) {
       Coord srcNodeCoord = neighborhoodGraphCircleLayout->getNodeValue(srcNode);
       finalBendsCoord = circleCenter + (srcNodeCoord - circleCenter) / 2.f;
     } else {
-      Coord tgtNodeCoord = neighborhoodGraphCircleLayout->getNodeValue(tgtNode);
+      Coord tgtNodeCoord = neighborhoodGraphCircleLayout->getNodeValue(eEnds.second);
       finalBendsCoord = circleCenter + (tgtNodeCoord - circleCenter) / 2.f;
     }
 
@@ -625,10 +607,9 @@ void NeighborhoodHighlighter::morphCircleAlphaAnimStep(int animStep) {
 float NeighborhoodHighlighter::computeNeighborhoodGraphRadius(
     LayoutProperty *neighborhoodGraphLayoutProp) {
   float radius = 0;
-  node n;
   const Coord &centralNodeCoord =
       neighborhoodGraphLayoutProp->getNodeValue(neighborhoodGraphCentralNode);
-  for (auto n : neighborhoodGraph->nodes()) {
+  for (node n : neighborhoodGraph->nodes()) {
     const Coord &nodeCoord = neighborhoodGraphLayoutProp->getNodeValue(n);
     const Size &nodeSize =
         originalGlGraphComposite->getInputData()->getElementSize()->getNodeValue(n);
