@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -34,7 +34,7 @@ using namespace std;
 using namespace tlp;
 
 PathFinderComponent::PathFinderComponent(PathFinder *parent)
-    : parent(parent), graphPopable(false) {}
+    : lastGraph(nullptr), parent(parent), graphPopable(false) {}
 
 PathFinderComponent::~PathFinderComponent() {
   qDeleteAll(highlighters);
@@ -49,7 +49,7 @@ bool PathFinderComponent::eventFilter(QObject *obj, QEvent *event) {
 
   if (event->type() == QEvent::MouseMove) {
     SelectedEntity entity;
-    if (glw->pickNodesEdges(qMouseEv->x(), qMouseEv->y(), entity) &&
+    if (glw->pickNodesEdges(qMouseEv->pos().x(), qMouseEv->pos().y(), entity) &&
         entity.getEntityType() == SelectedEntity::NODE_SELECTED) {
       tmp.id = entity.getComplexEntityId();
       glw->setCursor(Qt::CrossCursor);
@@ -134,6 +134,10 @@ void PathFinderComponent::selectPath(GlMainWidget *glMainWidget, Graph *graph) {
   BooleanProperty *selection = inputData->getElementSelected();
 
   if (src.isValid() && tgt.isValid()) { // We only select a path if source and target are valid
+    // get active window before launching paths computins
+    // as a workaround for uncorrected QMessageBox styling
+    // when paths computing is interrupted on user demand
+    auto w = QApplication::activeWindow();
     Observable::holdObservers();
     DoubleProperty *weights = nullptr;
     string weightsMetricName = parent->getWeightMetricName();
@@ -154,12 +158,14 @@ void PathFinderComponent::selectPath(GlMainWidget *glMainWidget, Graph *graph) {
       selection->setAllNodeValue(false);
       selection->setAllEdgeValue(false);
       selection->setNodeValue(src, true);
-      QMessageBox::warning(nullptr, "Path finder",
-                           "A path between the selected nodes cannot be found.");
+      QMessageBox::warning(w, "Path finder", "A path between the selected nodes cannot be found.");
 
-    } else
+    } else {
+      // register current graph
+      lastGraph = graph;
       // A path has been found: highlight it
       runHighlighters(glMainWidget, selection, src, tgt);
+    }
   } else if (src.isValid()) {
     selection->setNodeValue(src, true);
   }
@@ -171,13 +177,22 @@ void PathFinderComponent::runHighlighters(GlMainWidget *glMainWidget, BooleanPro
   graphPopable = true;
   vector<string> activeHighlighters(parent->getActiveHighlighters());
 
+  bool foundEnclosingCircle = false;
   for (vector<string>::iterator it = activeHighlighters.begin(); it != activeHighlighters.end();
        ++it) {
+    if (*it == "Enclosing circle")
+      foundEnclosingCircle = true;
+
     PathHighlighter *hler = findHighlighter(*it);
 
     if (hler)
       hler->highlight(parent, glMainWidget, selection, src, tgt);
   }
+  if (!foundEnclosingCircle) {
+    // ensure it is cleared
+    PathHighlighter *enclosingCircle = findHighlighter("Enclosing circle");
+    enclosingCircle->clear();
+  }
 }
 
 void PathFinderComponent::clearHighlighters(GlMainWidget *glMainWidget) {
@@ -214,7 +229,35 @@ QSet<PathHighlighter *> PathFinderComponent::getHighlighters() {
   return highlighters;
 }
 
+void PathFinderComponent::init() {
+  // restore enclosing circle if needed
+  auto graph = view()->graph();
+  if (lastGraph != graph) {
+    src = tgt = node();
+    return;
+  }
+  auto hls = parent->getActiveHighlighters();
+  bool needEnclosingCircle = false;
+  for (const std::string &hl : hls) {
+    if ((needEnclosingCircle = (hl == "Enclosing circle")))
+      break;
+  }
+  if (needEnclosingCircle) {
+    PathHighlighter *enclosingCircle = findHighlighter("Enclosing circle");
+    if (src.isValid() && tgt.isValid()) {
+      if (graph->isElement(src) && graph->isElement(tgt)) {
+        auto glw = static_cast<GlMainView *>(view())->getGlMainWidget();
+        BooleanProperty *selection =
+            glw->getScene()->getGlGraphComposite()->getInputData()->getElementSelected();
+        if (selection->getNodeValue(src) && selection->getNodeValue(tgt))
+          enclosingCircle->highlight(parent, glw, selection, src, tgt);
+      }
+    }
+  }
+}
+
 void PathFinderComponent::clear() {
-  GlMainView *glMainView = static_cast<GlMainView *>(view());
-  glMainView->getGlMainWidget()->setCursor(QCursor());
+  auto glw = static_cast<GlMainView *>(view())->getGlMainWidget();
+  glw->setCursor(QCursor());
+  clearHighlighters(glw);
 }
