@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -57,9 +57,11 @@ public:
    */
   QSet<PathHighlighter *> getHighlighters();
 
+  void init() override;
   void clear() override;
 
 private:
+  tlp::Graph *lastGraph;
   tlp::node src;
   tlp::node tgt;
   tlp::node tmp;
