@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -20,18 +20,21 @@
 #include "PathFinderConfigurationWidget.h"
 #include "ui_PathFinderConfiguration.h"
 
+#include <tulip/Interactor.h>
+
 using namespace tlp;
 using namespace std;
 
 PathFinderConfigurationWidget::PathFinderConfigurationWidget(QWidget *parent)
-    : QWidget(parent), _ui(new Ui::PathFinderConfigurationData) {
+    : QWidget(parent), _ui(new Ui::PathFinderConfigWidget) {
+  Interactor::setupConfigWidget(this);
   _ui->setupUi(this);
 
-  connect(_ui->weightCombo, SIGNAL(activated(const QString &)), this,
+  connect(_ui->weightCombo, SIGNAL(textActivated(const QString &)), this,
           SIGNAL(setWeightMetric(const QString &)));
-  connect(_ui->edgeOrientationCombo, SIGNAL(activated(const QString &)), this,
+  connect(_ui->edgeOrientationCombo, SIGNAL(textActivated(const QString &)), this,
           SIGNAL(setEdgeOrientation(const QString &)));
-  connect(_ui->pathsTypeCombo, SIGNAL(activated(const QString &)), this,
+  connect(_ui->pathsTypeCombo, SIGNAL(textActivated(const QString &)), this,
           SIGNAL(setPathsType(const QString &)));
   connect(_ui->toleranceCheck, SIGNAL(clicked(bool)), this, SIGNAL(activateTolerance(bool)));
   connect(_ui->toleranceSpin, SIGNAL(valueChanged(int)), this, SIGNAL(setTolerance(int)));
