@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -25,7 +25,7 @@
 #include <string>
 
 namespace Ui {
-class PathFinderConfigurationData;
+class PathFinderConfigWidget;
 }
 
 class QString;
@@ -34,7 +34,7 @@ namespace tlp {
 class PathFinderConfigurationWidget : public QWidget {
   Q_OBJECT
 
-  Ui::PathFinderConfigurationData *_ui;
+  Ui::PathFinderConfigWidget *_ui;
 
 public:
   PathFinderConfigurationWidget(QWidget *parent = nullptr);
