@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -53,7 +53,7 @@ void PathHighlighter::clear() {
   if (backupScene) {
     GlLayer *layer = getWorkingLayer(backupScene);
 
-    for (unordered_map<string, bool>::iterator it = entities.begin(); it != entities.end(); ++it) {
+    for (tlp_hash_map<string, bool>::iterator it = entities.begin(); it != entities.end(); ++it) {
       string entityName(it->first);
       GlSimpleEntity *entity(layer->findGlEntity(entityName));
 
