@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -21,7 +21,7 @@
 #define PATHHIGHLIGHTER_H_
 
 #include <string>
-#include <unordered_map>
+#include <tulip/tuliphash.h>
 
 #include <tulip/Node.h>
 #include <tulip/Observable.h>
@@ -63,7 +63,7 @@ protected:
 private:
   std::string name;
   tlp::GlScene *backupScene;
-  std::unordered_map<std::string, bool> entities;
+  tlp_hash_map<std::string, bool> entities;
   int entityId;
 };
 } // namespace tlp
