@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -19,6 +19,9 @@
 #include "Circular.h"
 #include "DatasetTools.h"
 
+#include <tulip/ConnectedTest.h>
+#include <tulip/GraphTools.h>
+
 PLUGIN(Circular)
 
 using namespace std;
@@ -36,7 +39,6 @@ Circular::Circular(const tlp::PluginContext *context) : LayoutAlgorithm(context)
 
 //===============================================================================
 static vector<node> extractCycle(node n, deque<node> &st) {
-  // tlp::warning() << __PRETTY_FUNCTION__ << endl;
   vector<node> result;
   auto it = st.rbegin();
 
