@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -19,7 +19,7 @@
 #ifndef _BUBBLE_CIRCULARLAYOUT_H
 #define _BUBBLE_CIRCULARLAYOUT_H
 
-#include <tulip/TulipPluginHeaders.h>
+#include <tulip/LayoutProperty.h>
 
 /** \addtogroup layout */
 
@@ -43,14 +43,14 @@
  *
  * AUTHORS:
  *
- * David Auber and Romain Bourqui University Bordeaux I France: Email:auber@labri.fr
+ * David Auber and Romain Bourqui University of Bordeaux France: Email:auber@labri.fr
  * Daniel Archambault The University of British Columbia:
  * Email:  archam@cs.ubc.ca
  */
 class Circular : public tlp::LayoutAlgorithm {
 public:
   PLUGININFORMATION("Circular", "David Auber/ Daniel Archambault", "25/11/2004",
-                    "Implements a circular layout that takes node size into account.<br/>"
+                    "Implements a circular layout that takes node size into account.<br>"
                     "It manages size of nodes and use a standard dfs for ordering nodes or search "
                     "the maximum length cycle.",
                     "1.1", "Basic")
