@@ -1,6 +1,6 @@
 /*
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -34,7 +34,7 @@ static const char *paramHelp[] = {
     // overlap removal type
     "Overlap removal type.",
 
-    // layout
+    // initial layout
     "The property used for the input layout of nodes and edges.",
 
     // node size
@@ -66,7 +66,7 @@ FastOverlapRemoval::FastOverlapRemoval(const tlp::PluginContext *context)
     : tlp::LayoutAlgorithm(context) {
   addInParameter<StringCollection>("overlap removal type", paramHelp[0], OVERLAP_TYPE, true,
                                    overlapRemovalTypeValuesDescription);
-  addInParameter<LayoutProperty>("layout", paramHelp[1], "viewLayout");
+  addInParameter<LayoutProperty>("initial layout", paramHelp[1], "viewLayout");
   addInParameter<SizeProperty>("bounding box", paramHelp[2], "viewSize");
   addInParameter<DoubleProperty>("rotation", paramHelp[3], "viewRotation");
   addInParameter<int>("number of passes", paramHelp[4], "5");
@@ -86,8 +86,8 @@ bool FastOverlapRemoval::run() {
     pluginProgress->showStops(false);
   }
 
-  tlp::StringCollection stringCollection(OVERLAP_TYPE);
-  stringCollection.setCurrent(0);
+  tlp::StringCollection overlap_type(OVERLAP_TYPE);
+  overlap_type.setCurrent(0);
   LayoutProperty *viewLayout = nullptr;
   SizeProperty *viewSize = nullptr;
   DoubleProperty *viewRot = nullptr;
@@ -96,18 +96,9 @@ bool FastOverlapRemoval::run() {
   int nbPasses = 5;
 
   if (dataSet != nullptr) {
-
-    if (dataSet->exists("overlaps removal type"))
-      dataSet->get("overlaps removal type", stringCollection);
-    else
-      dataSet->get("overlap removal type", stringCollection);
-
-    dataSet->get("layout", viewLayout);
-
-    if (!dataSet->get("bounding box", viewSize))
-      // old name of the parameter
-      dataSet->get("boundingBox", viewSize);
-
+    dataSet->get("overlap removal type", overlap_type);
+    dataSet->get("bounding box", viewSize);
+    dataSet->get("initial layout", viewLayout);
     dataSet->get("rotation", viewRot);
     dataSet->get("number of passes", nbPasses);
     dataSet->get("x border", xBorder);
@@ -153,9 +144,9 @@ bool FastOverlapRemoval::run() {
     });
 
     // actually apply fast overlap removal
-    if (stringCollection.getCurrentString() == "X-Y") {
+    if (overlap_type.getCurrentString() == "X-Y") {
       removeRectangleOverlap(nbNodes, nodeRectangles.data(), xBorder, yBorder);
-    } else if (stringCollection.getCurrentString() == "X") {
+    } else if (overlap_type.getCurrentString() == "X") {
       removeRectangleOverlapX(nbNodes, nodeRectangles.data(), xBorder, yBorder);
     } else {
       removeRectangleOverlapY(nbNodes, nodeRectangles.data(), yBorder);
