@@ -12,6 +12,7 @@
  *
  * Tim Dwyer, Kim Marriot, Peter J. Stuckey,
  * "Fast Node Overlap Removal" in Graph Drawing, Vol. 3843 (2006), pp. 153-164.
+ * doi: <a href=\"https://doi.org/10.1007/11618058_15\">10.1007/11618058_15</a>
  *
  * <b>NOTES</b>
  *
@@ -42,10 +43,12 @@ class FastOverlapRemoval : public tlp::LayoutAlgorithm {
 public:
   PLUGININFORMATION(
       "Fast Overlap Removal", "Daniel Archambault", "08/12/2006",
-      "Implements a layout algorithm removing the nodes overlaps. It was first published as:<br/>"
-      "<b>Fast Node Overlap Removal</b>, Tim Dwyer, Kim Marriot, Peter J. Stuckey, Graph Drawing, "
-      "Vol. 3843 (2006), pp. 153-164.",
-      "1.3", "Misc")
+      "Implements a layout algorithm removing nodes overlap first published as:<br/>"
+      "<b>Fast Node Overlap Removal</b>,<br/>Tim Dwyer, Kim Marriot, Peter J. Stuckey, "
+      "Graph Drawing 2005, "
+      "Vol. 3843 (2006), pp. 153-164,<br/>doi: <a "
+      "href=\"https://doi.org/10.1007/11618058_15\">10.1007/11618058_15</a>",
+      "1.4", "Misc")
 
   FastOverlapRemoval(const tlp::PluginContext *context);
   inline ~FastOverlapRemoval() override {}
