@@ -16,11 +16,10 @@ namespace vpsc {
 class Rectangle;
 }
 
-void removeRectangleOverlap(unsigned n, vpsc::Rectangle *rs[], double& xBorder, double& yBorder);
+void removeRectangleOverlap(unsigned n, vpsc::Rectangle rs[], double &xBorder, double &yBorder);
 
-void removeRectangleOverlapX(unsigned n, vpsc::Rectangle *rs[], double& xBorder, double& yBorder);
-
-void removeRectangleOverlapY(unsigned n, vpsc::Rectangle *rs[], double& yBorder);
+void removeRectangleOverlapX(unsigned n, vpsc::Rectangle rs[], double &xBorder, double &yBorder);
 
+void removeRectangleOverlapY(unsigned n, vpsc::Rectangle rs[], double &yBorder);
 
 #endif /* !REMOVE_RECTANGLE_OVERLAP_H_SEEN */
