@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -20,8 +20,6 @@
 #include "MISFiltering.h"
 #include "Distances.h"
 
-#include <tulip/TulipPluginHeaders.h>
-
 using namespace std;
 using namespace tlp;
 
@@ -34,7 +32,7 @@ Grip::Grip(const tlp::PluginContext *context)
     : LayoutAlgorithm(context), misf(nullptr), edgeLength(0), level(0), currentGraph(nullptr),
       _dim(0) {
   addInParameter<bool>("3D layout", paramHelp[0], "false");
-  addDependency("Connected Component Packing", "1.0");
+  addDependency("Connected Components Packing", "1.1");
 }
 Grip::~Grip() {}
 
@@ -132,9 +130,9 @@ bool Grip::run() {
 
     string err;
     DataSet tmp;
-    tmp.set("coordinates", result);
+    tmp.set("initial layout", result);
     LayoutProperty layout(graph);
-    graph->applyPropertyAlgorithm("Connected Component Packing", &layout, err, &tmp);
+    graph->applyPropertyAlgorithm("Connected Components Packing", &layout, err, &tmp);
 
     for (auto n : graph->nodes()) {
       result->setNodeValue(n, layout.getNodeValue(n));
