@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -17,6 +17,8 @@
  *
  */
 #include <tulip/GraphTools.h>
+#include <tulip/TreeTest.h>
+
 #include "DatasetTools.h"
 #include "Orientation.h"
 #include "ImprovedWalker.h"
@@ -26,9 +28,6 @@ using namespace tlp;
 
 PLUGIN(ImprovedWalker)
 
-//====================================================================
-const node ImprovedWalker::BADNODE;
-
 //====================================================================
 class ImprovedWalkerIterator : public Iterator<node> {
 private:
@@ -148,7 +147,7 @@ int ImprovedWalker::initializeNode(tlp::node n, unsigned int depth) {
   shiftDelta[n] = 0;
 
   ancestor[n] = n;
-  thread[n] = BADNODE;
+  thread[n] = node();
 
   int maxDepth = 0;
   int count = 0;
@@ -188,7 +187,7 @@ void ImprovedWalker::firstWalk(tlp::node v) {
     prelimX[v] = 0;
     node vleftSibling = leftSibling(v);
 
-    if (vleftSibling != BADNODE)
+    if (vleftSibling.isValid())
       prelimX[v] += prelimX[vleftSibling] + nodeSpacing + oriSize->getNodeValue(v).getW() / 2.f +
                     oriSize->getNodeValue(vleftSibling).getW() / 2.f;
   } else {
@@ -205,7 +204,7 @@ void ImprovedWalker::firstWalk(tlp::node v) {
 
     node leftBrother = leftSibling(v);
 
-    if (leftBrother != BADNODE) {
+    if (leftBrother.isValid()) {
       prelimX[v] = prelimX[leftBrother] + nodeSpacing + oriSize->getNodeValue(v).getW() / 2.f +
                    oriSize->getNodeValue(leftBrother).getW() / 2.f;
       modChildX[v] = prelimX[v] - midPoint;
@@ -225,7 +224,7 @@ void ImprovedWalker::secondWalk(tlp::node v, float modifierX, int depth) {
 void ImprovedWalker::combineSubtree(tlp::node v, tlp::node *defaultAncestor) {
   node leftBrother = leftSibling(v);
 
-  if (leftBrother != BADNODE) {
+  if (leftBrother.isValid()) {
     node nodeInsideRight;
     node nodeOutsideRight;
     node nodeInsideLeft;
@@ -246,8 +245,8 @@ void ImprovedWalker::combineSubtree(tlp::node v, tlp::node *defaultAncestor) {
     shiftInsideLeft = modChildX[nodeInsideLeft];
     shiftOutsideLeft = modChildX[nodeOutsideLeft];
 
-    while (nextRightContour(nodeInsideLeft) != BADNODE &&
-           nextLeftContour(nodeInsideRight) != BADNODE) {
+    while (nextRightContour(nodeInsideLeft).isValid() &&
+           nextLeftContour(nodeInsideRight).isValid()) {
 
       nodeInsideLeft = nextRightContour(nodeInsideLeft);
       nodeInsideRight = nextLeftContour(nodeInsideRight);
@@ -278,14 +277,13 @@ void ImprovedWalker::combineSubtree(tlp::node v, tlp::node *defaultAncestor) {
       shiftOutsideLeft += modChildX[nodeOutsideLeft];
     }
 
-    if (nextRightContour(nodeInsideLeft) != BADNODE &&
-        nextRightContour(nodeOutsideRight) == BADNODE) {
+    if (nextRightContour(nodeInsideLeft).isValid() &&
+        !nextRightContour(nodeOutsideRight).isValid()) {
       thread[nodeOutsideRight] = nextRightContour(nodeInsideLeft);
       modChildX[nodeOutsideRight] += shiftInsideLeft - shiftOutsideRight;
     }
 
-    if (nextLeftContour(nodeInsideRight) != BADNODE &&
-        nextLeftContour(nodeOutsideLeft) == BADNODE) {
+    if (nextLeftContour(nodeInsideRight).isValid() && !nextLeftContour(nodeOutsideLeft).isValid()) {
       thread[nodeOutsideLeft] = nextLeftContour(nodeInsideRight);
       modChildX[nodeOutsideLeft] += shiftInsideRight - shiftOutsideLeft;
 
