@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -19,7 +19,7 @@
 #ifndef LinLogAlgorithm_H_
 #define LinLogAlgorithm_H_
 
-/// An implementation of the LinLog layout algorithm
+// An implementation of the LinLog layout algorithm
 /** This plugin is an implementation of the LinLog
  *  algorithm first published as:
  *
@@ -27,7 +27,7 @@
  * "Energy Models for Graph Clustering", \n
  * in Journal of Graph \n
  * Algorithms and Applications 11(2):453-480, 2007
- * http://www-sst.informatik.tu-cottbus.de/~an/Publications/JGAA2007.pdf
+ * doi: <a href=\"https://dx.doi.org/10.7155/jgaa.00154\">10.7155/jgaa.00154</a>,
  *
  * The code of the plugin has been translated and adapted
  * from A. Noack's java implementation of the LinLog algorithm
@@ -37,12 +37,14 @@
 class LinLogAlgorithm : public tlp::LayoutAlgorithm {
 
 public:
-  PLUGININFORMATION("LinLog", "B. Renoust", "11/02/13",
-                    "Implements the LinLog layout algorithm, an energy model layout algorithm, "
-                    "first published as:<br/>"
-                    "<b>Energy Models for Graph Clustering</b>, Andreas Noack., "
-                    "Journal of Graph Algorithms and Applications 11(2):453-480, 2007.",
-                    "1.0", "Force Directed");
+  PLUGININFORMATION(
+      "LinLog", "B. Renoust", "11/02/13",
+      "Implements the LinLog layout algorithm, an energy model layout algorithm, "
+      "first published as:<br/>"
+      "<b>Energy Models for Graph Clustering</b>,<br/>Andreas Noack., "
+      "Journal of Graph Algorithms and Applications 11(2):453-480, 2007, "
+      "<br/>doi: <a href=\"https://dx.doi.org/10.7155/jgaa.00154\">10.7155/jgaa.00154</a>",
+      "1.0", "Force Directed")
 
   LinLogAlgorithm(const tlp::PluginContext *context);
 
