@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -24,7 +24,7 @@
 #include <tulip/DoubleProperty.h>
 #include <vector>
 
-using namespace tlp;
+namespace tlp {
 
 /**
  * Octtree for graph nodes with positions in 3D space.
@@ -99,5 +99,5 @@ public:
   // Prints the tree on a console output
   void printTree(unsigned int);
 };
-
+} // namespace tlp
 #endif // __OCTTREE_H__
