@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -16,18 +16,25 @@
  * See the GNU General Public License for more details.
  *
  */
+#include "MixedModel.h"
+
 #include <algorithm>
-#include <tulip/TulipPluginHeaders.h>
+
 #include <tulip/MapIterator.h>
-#include <tulip/PlanarConMap.h>
 #include <tulip/Ordering.h>
 #include <tulip/MutableContainer.h>
 #include <tulip/Bfs.h>
 #include <tulip/GraphTools.h>
 #include <tulip/StringCollection.h>
 #include <tulip/TulipViewSettings.h>
+#include <tulip/IntegerProperty.h>
+#include <tulip/ConnectedTest.h>
+#include <tulip/PlanarityTest.h>
+#include <tulip/BiconnectedTest.h>
+#include <tulip/BooleanProperty.h>
+#include <tulip/SimpleTest.h>
+#include <tulip/ColorProperty.h>
 
-#include "MixedModel.h"
 #include "DatasetTools.h"
 
 PLUGIN(MixedModel)
@@ -48,8 +55,7 @@ static const char *paramHelp[] = {
     "This parameter defines the minimum y-spacing between any two nodes.",
 
     // x node-node and edge-node spacing
-    "This parameter defines the minimum x-spacing between any two nodes or between a node and an "
-    "edge.",
+    "This parameter defines the minimum x-spacing between any two nodes or between a node and an edge.",
 
     // shape property
     "This parameter defines the property holding edges shapes."};
@@ -63,7 +69,7 @@ MixedModel::MixedModel(const tlp::PluginContext *context) : LayoutAlgorithm(cont
   addInParameter<float>("y node-node spacing", paramHelp[1], "2");
   addInParameter<float>("x node-node and edge-node spacing", paramHelp[2], "2");
   addOutParameter<IntegerProperty>("shape property", paramHelp[3], "viewShape");
-  addDependency("Connected Component Packing", "1.0");
+  addDependency("Connected Components Packing", "1.1");
 }
 //====================================================
 MixedModel::~MixedModel() {}
@@ -277,8 +283,9 @@ bool MixedModel::run() {
   if (components.size() > 1) {
     string err = "";
     DataSet tmp;
-    tmp.set("coordinates", result);
-    graph->applyPropertyAlgorithm("Connected Component Packing", result, err, &tmp, pluginProgress);
+    tmp.set("initial layout", result);
+    graph->applyPropertyAlgorithm("Connected Components Packing", result, err, &tmp,
+                                  pluginProgress);
     if (pluginProgress->state() != TLP_CONTINUE)
       return pluginProgress->state() != TLP_CANCEL;
   }
@@ -828,7 +835,7 @@ void MixedModel::computeCoords() {
     nodeSize.set(n.id, c);
   }
 
-  unordered_map<node, node> father; // permet de connaître le noeud de référence
+  tlp_hash_map<node, node> father; // permet de connaître le noeud de référence
   assert(!V.empty());
 
   vector<node> C; // chemin courant
