@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -19,7 +19,10 @@
 #ifndef _MixedModel_H
 #define _MixedModel_H
 
-#include <unordered_map>
+#include <tulip/LayoutProperty.h>
+#include <tulip/PlanarConMap.h>
+
+#include <tulip/tuliphash.h>
 
 /** \addtogroup layout */
 
@@ -29,9 +32,9 @@
  *  C. Gutwenger and P. Mutzel, \n
  *  "Planar Polyline Drawings with Good Angular Resolution", \n
  *  "Lecture Notes In Computer Science, Vol. 1547" \n
- *  "Proceedings of the 6th International Symposium on Graph Drawing," \n
- *  pages "167--182" \n
- *  1998 \n
+ *  "Proceedings of the 6th International Symposium on Graph Drawing (GD 1998)," \n
+ *  pages "167--182", 1999, doi: <a
+ * href=\"https://doi.org/10.1007/3-540-37623-2_13\">https://doi.org/10.1007/3-540-37623-2_13</a>\n
  *
  *  Let n be the number of nodes, the original algorithm complexity is in O(n).\n
  *  But the implementation of the canonical ordering has not been made in O(n).\n
@@ -49,7 +52,10 @@ public:
                     "Implements the planar polyline graph drawing algorithm, the mixed model "
                     "algorithm, first published as:<br/>"
                     "<b>Planar Polyline Drawings with Good Angular Resolution</b>, C. Gutwenger "
-                    "and P. Mutzel, LNCS, Vol. 1547 pages 167--182 (1998).",
+                    "and P. Mutzel, LNCS, Vol. 1547 pages 167--182 (1999),<br/>"
+                    "doi: <a "
+                    "href=\"https://doi.org/10.1007/3-540-37623-2_13\">https://doi.org/10.1007/"
+                    "3-540-37623-2_13</a>",
                     "1.0", "Planar")
   MixedModel(const tlp::PluginContext *context);
   ~MixedModel() override;
@@ -75,25 +81,25 @@ private:
 
   tlp::PlanarConMap *carte;
   std::vector<std::vector<tlp::node>> V;
-  std::unordered_map<tlp::node, tlp::Coord> NodeCoords;
+  tlp_hash_map<tlp::node, tlp::Coord> NodeCoords;
 
-  std::unordered_map<tlp::node, int> outl;
-  std::unordered_map<tlp::node, int> outr;
-  std::unordered_map<tlp::node, int> inl;
-  std::unordered_map<tlp::node, int> inr;
+  tlp_hash_map<tlp::node, int> outl;
+  tlp_hash_map<tlp::node, int> outr;
+  tlp_hash_map<tlp::node, int> inl;
+  tlp_hash_map<tlp::node, int> inr;
 
-  std::unordered_map<tlp::node, unsigned int> rank;
-  std::unordered_map<tlp::node, std::vector<tlp::edge>> EdgesIN;
-  std::unordered_map<tlp::node, std::vector<tlp::edge>> EdgesOUT;
+  tlp_hash_map<tlp::node, unsigned int> rank;
+  tlp_hash_map<tlp::node, std::vector<tlp::edge>> EdgesIN;
+  tlp_hash_map<tlp::node, std::vector<tlp::edge>> EdgesOUT;
 
-  std::unordered_map<tlp::edge, std::vector<tlp::Coord>> InPoints;
-  std::unordered_map<tlp::edge, tlp::Coord> OutPoints;
+  tlp_hash_map<tlp::edge, std::vector<tlp::Coord>> InPoints;
+  tlp_hash_map<tlp::edge, tlp::Coord> OutPoints;
 
   tlp::Graph *Pere;
   tlp::PlanarConMap *graphMap;
   tlp::Graph *currentGraph;
   std::vector<tlp::edge> dummy;
-  std::unordered_map<tlp::node, std::vector<tlp::Coord>> out_points;
+  tlp_hash_map<tlp::node, std::vector<tlp::Coord>> out_points;
   tlp::MutableContainer<tlp::Coord> nodeSize;
   std::vector<tlp::edge> unplanar_edges;
   bool planar;
