@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -18,53 +18,11 @@
  */
 #include <ogdf/energybased/FastMultipoleEmbedder.h>
 #include <ogdf/packing/ComponentSplitterLayout.h>
-#include <ogdf/basic/simple_graph_alg.h>
 
-#include "tulip2ogdf/OGDFLayoutPluginBase.h"
+#include <tulip2ogdf/OGDFLayoutPluginBase.h>
 
-// comments below have been extracted from OGDF/src/energybased/FastMultipoleEmbedder.cpp
-/** \addtogroup layout */
-
-/**
- * Implementation of class FastMultipoleEmbedder.
- *
- * \author Martin Gronemann
- *
- * \par License:
- * This is part of the Open Graph Drawing Framework (OGDF).
- * Copyright (C) 2005-2009
- *
- * \par
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * Version 2 or 3 as published by the Free Software Foundation
- * and appearing in the files LICENSE_GPL_v2.txt and
- * LICENSE_GPL_v3.txt included in the packaging of this file.
- *
- * \par
- * In addition, as a special exception, you have permission to link
- * this software with the libraries of the COIN-OR Osi project
- * (http://www.coin-or.org/projects/Osi.xml), all libraries required
- * by Osi, and all LP-solver libraries directly supported by the
- * COIN-OR Osi project, and distribute executables, as long as
- * you follow the requirements of the GNU General Public License
- * in regard to all of the software in the executable aside from these
- * third-party libraries.
- *
- * \par
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * \par
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
- * \see  http://www.gnu.org/copyleft/gpl.html
- ***************************************************************/
+using namespace tlp;
+using namespace ogdf;
 
 static const char *paramHelp[] = {
     // number of iterations
@@ -83,7 +41,9 @@ static const char *paramHelp[] = {
     "The default edge length.",
 
     // number of threads
-    "The number of threads to use during the computation of the layout."};
+    "The number of threads to use during the computation of the layout."
+
+};
 
 class OGDFFastMultipoleEmbedder : public OGDFLayoutPluginBase {
 
@@ -94,24 +54,22 @@ public:
                     "modified attractive forces.",
                     "1.0", "Force Directed")
   OGDFFastMultipoleEmbedder(const tlp::PluginContext *context)
-      : OGDFLayoutPluginBase(context, new ogdf::ComponentSplitterLayout()),
-        fme(new ogdf::FastMultipoleEmbedder()) {
+      : OGDFLayoutPluginBase(context, context ? new ogdf::ComponentSplitterLayout() : nullptr) {
     addInParameter<int>("number of iterations", paramHelp[0], "100");
     addInParameter<int>("number of coefficients", paramHelp[1], "5");
     addInParameter<bool>("randomize layout", paramHelp[2], "true");
     addInParameter<double>("default node size", paramHelp[3], "20.0");
     addInParameter<double>("default edge length", paramHelp[4], "1.0");
-    addInParameter<int>("number of threads", paramHelp[5], "3");
-    ogdf::ComponentSplitterLayout *csl =
-        static_cast<ogdf::ComponentSplitterLayout *>(ogdfLayoutAlgo);
-    // ComponentSplitterLayout takes ownership of the FastMultipoleEmbedder instance
-    csl->setLayoutModule(fme);
+    addInParameter<int>("number of threads", paramHelp[5], "2");
   }
 
-  ~OGDFFastMultipoleEmbedder() override {}
-
   void beforeCall() override {
 
+    ComponentSplitterLayout *csl = static_cast<ComponentSplitterLayout *>(ogdfLayoutAlgo);
+    // ComponentSplitterLayout takes ownership of the FastMultipoleEmbedder instance
+    FastMultipoleEmbedder *fme = new FastMultipoleEmbedder();
+    csl->setLayoutModule(fme);
+
     if (dataSet != nullptr) {
       double dval = 0;
       int ival = 0;
@@ -137,11 +95,8 @@ public:
     }
 
     // ensure the input graph is simple as the layout failed in non multi-threaded mode otherwise
-    ogdf::makeSimple(tlpToOGDF->getOGDFGraph());
+    // ogdf::makeSimple(tlpToOGDF->getOGDFGraph());
   }
-
-private:
-  ogdf::FastMultipoleEmbedder *fme;
 };
 
 PLUGIN(OGDFFastMultipoleEmbedder)
