@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -16,53 +16,13 @@
  * See the GNU General Public License for more details.
  *
  */
+
 #include <ogdf/energybased/SpringEmbedderKK.h>
 
-#include "tulip2ogdf/OGDFLayoutPluginBase.h"
+#include <tulip2ogdf/OGDFLayoutPluginBase.h>
 
-// comments below have been extracted from OGDF/src/energybased/SpringEmbedderKK.cpp
-/** \addtogroup layout */
-
-/**
- * Implementation of Kamada-Kaway layout algorithm.
- *
- * \author Karsten Klein
- *
- * \par License:
- * This is part of the Open Graph Drawing Framework (OGDF).
- * Copyright (C) 2005-2009
- *
- * \par
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * Version 2 or 3 as published by the Free Software Foundation
- * and appearing in the files LICENSE_GPL_v2.txt and
- * LICENSE_GPL_v3.txt included in the packaging of this file.
- *
- * \par
- * In addition, as a special exception, you have permission to link
- * this software with the libraries of the COIN-OR Osi project
- * (http://www.coin-or.org/projects/Osi.xml), all libraries required
- * by Osi, and all LP-solver libraries directly supported by the
- * COIN-OR Osi project, and distribute executables, as long as
- * you follow the requirements of the GNU General Public License
- * in regard to all of the software in the executable aside from these
- * third-party libraries.
- *
- * \par
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * \par
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
- * \see  http://www.gnu.org/copyleft/gpl.html
- ***************************************************************/
+using namespace tlp;
+using namespace ogdf;
 
 static const char *paramHelp[] = {
     // stop tolerance
@@ -98,7 +58,7 @@ public:
                     "to their graph theoretic distance. ",
                     "1.0", "Force Directed")
   OGDFKamadaKawai(const tlp::PluginContext *context)
-      : OGDFLayoutPluginBase(context, new ogdf::SpringEmbedderKK()) {
+      : OGDFLayoutPluginBase(context, context ? new ogdf::SpringEmbedderKK() : nullptr) {
     addInParameter<double>("stop tolerance", paramHelp[0], "0.001");
     addInParameter<bool>("used layout", paramHelp[1], "true");
     addInParameter<double>("zero length", paramHelp[2], "0");
