@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -20,81 +20,46 @@
 #include <ogdf/energybased/PivotMDS.h>
 #include <ogdf/packing/ComponentSplitterLayout.h>
 
-#include "tulip2ogdf/OGDFLayoutPluginBase.h"
+#include <tulip2ogdf/OGDFLayoutPluginBase.h>
 
-// comments below have been extracted from OGDF/include/ogdf/energybased/PivotMDS.h
-
-/**
- * Declaration of the pivot MDS. By setting the number of pivots to
- * infinity this algorithm behaves just like classical MDS.
- * See Brandes and Pich: Eigensolver methods for progressive multidi-
- * mensional scaling of large data.
- *
- * \author Mark Ortmann, University of Konstanz
- *
- * \par License:
- * This file is part of the Open Graph Drawing Framework (OGDF).
- *
- * \par
- * Copyright (C)<br>
- * See README.txt in the root directory of the OGDF installation for details.
- *
- * \par
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * Version 2 or 3 as published by the Free Software Foundation;
- * see the file LICENSE.txt included in the packaging of this file
- * for details.
- *
- * \par
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * \par
- * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
- * \see  http://www.gnu.org/copyleft/gpl.html
- ***************************************************************/
+using namespace tlp;
+using namespace ogdf;
 
 static const char *paramHelp[] = {
     // number of pivots
-    "Sets the number of pivots. If the new value is smaller or equal 0 the default value (250) is "
-    "used.",
+    "Sets the number of pivots. If the new value is less than or equal to 0 the default value (250) is used.",
 
     // use edge costs
     "Sets if the edge costs attribute has to be used.",
 
     // edge costs
-    "Sets the desired distance between adjacent nodes. If the new value is smaller or equal 0 the "
-    "default value (100) is used."};
+    "Sets the desired distance between adjacent nodes. If the new value is less than or equal to 0 the default value (100) is used.",
+
+    // 3D layout
+    "If true, the layout is computed in 3D, else it is computed in 2D."};
 
 class OGDFPivotMDS : public OGDFLayoutPluginBase {
 
 public:
   PLUGININFORMATION("Pivot MDS (OGDF)", "Mark Ortmann", "29/05/2015",
-                    "By setting the number of pivots to infinity this algorithm behaves just like "
+                    "The Pivot MDS (multi-dimensional scaling) layout algorithm. By setting the "
+                    "number of pivots to infinity this algorithm behaves just like "
                     "classical MDS. See:<br/><b>Eigensolver methods for progressive "
                     "multidimensional scaling of large data.</b> Brandes and Pich",
                     "1.0", "Force Directed")
   OGDFPivotMDS(const tlp::PluginContext *context)
-      : OGDFLayoutPluginBase(context, new ogdf::ComponentSplitterLayout()),
-        pivotMds(new ogdf::PivotMDS()) {
+      : OGDFLayoutPluginBase(context, context ? new ogdf::ComponentSplitterLayout() : nullptr) {
     addInParameter<int>("number of pivots", paramHelp[0], "250", false);
     addInParameter<bool>("use edge costs", paramHelp[1], "false", false);
     addInParameter<double>("edge costs", paramHelp[2], "100", false);
-
-    ogdf::ComponentSplitterLayout *csl =
-        static_cast<ogdf::ComponentSplitterLayout *>(ogdfLayoutAlgo);
-    csl->setLayoutModule(pivotMds);
+    addInParameter<bool>("3D layout", paramHelp[3], "false");
   }
   ~OGDFPivotMDS() override {}
 
   void beforeCall() override {
+    ComponentSplitterLayout *csl = static_cast<ogdf::ComponentSplitterLayout *>(ogdfLayoutAlgo);
+    PivotMDS *pivotMds(new ogdf::PivotMDS());
+    csl->setLayoutModule(pivotMds);
 
     if (dataSet != nullptr) {
       bool bval = false;
@@ -112,8 +77,20 @@ public:
     }
   }
 
-private:
-  ogdf::PivotMDS *pivotMds;
+  void afterCall() {
+    bool bval = false;
+    dataSet->get("3D layout", bval);
+    if (!bval) {
+      const std::vector<tlp::node> &nodes = graph->nodes();
+      size_t nbElts = nodes.size();
+
+      for (unsigned int i = 0; i < nbElts; ++i) {
+        tlp::Coord nodeCoord = result->getNodeValue(nodes[i]);
+        nodeCoord[2] = 0.0;
+        result->setNodeValue(nodes[i], nodeCoord);
+      }
+    }
+  }
 };
 
 PLUGIN(OGDFPivotMDS)
