@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -21,7 +21,7 @@
 #include <tulip/LayoutProperty.h>
 
 static const char *paramHelp[] = {
-    // layout
+    // initial layout
     "The layout property from which a perfect aspect ratio has to be computed.",
 
     // subgraph only
@@ -30,19 +30,19 @@ static const char *paramHelp[] = {
 class PerfectLayout : public tlp::LayoutAlgorithm {
 public:
   PLUGININFORMATION("Perfect aspect ratio", "Tulip team", "09/19/2010",
-                    "Scales the graph layout to get an aspect ratio of 1.", "1.1", "")
+                    "Scales the graph layout to get an aspect ratio of 1.", "1.3", "")
 
   PerfectLayout(const tlp::PluginContext *context) : LayoutAlgorithm(context) {
-    addInParameter<tlp::LayoutProperty>("layout", paramHelp[0], "viewLayout", false);
-    addInParameter<bool>("Subgraph only", paramHelp[1], "false");
+    addInParameter<tlp::LayoutProperty>("initial layout", paramHelp[0], "viewLayout", false);
+    addInParameter<bool>("subgraph only", paramHelp[1], "false");
   }
   bool run() override {
     tlp::LayoutProperty *layout = nullptr;
     bool subgraphOnly(false);
 
     if (dataSet != nullptr) {
-      dataSet->get("layout", layout);
-      dataSet->get("Subgraph only", subgraphOnly);
+      dataSet->get("initial layout", layout);
+      dataSet->get("subgraph only", subgraphOnly);
     }
 
     if (!layout)
