@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -31,13 +31,16 @@
 #include <algorithm>
 #include <vector>
 #include <set>
-#include <tulip/TulipPluginHeaders.h>
+
+#include <tulip/LayoutProperty.h>
 #include <tulip/Vector.h>
 #include <tulip/BoundingBox.h>
 #include <tulip/DrawingTools.h>
 #include <tulip/ConnectedTest.h>
 #include <tulip/ParametricCurves.h>
 #include <tulip/TulipViewSettings.h>
+#include <tulip/IntegerProperty.h>
+#include <tulip/DoubleProperty.h>
 
 #include "DatasetTools.h"
 
@@ -45,7 +48,7 @@ using namespace std;
 using namespace tlp;
 
 static const char *paramHelp[] = {
-    // coordinates
+    // initial layout
     "Input layout of nodes and edges.",
 
     // rotation
@@ -76,9 +79,11 @@ public:
   PLUGININFORMATION(
       "Connected Component Packing (Polyomino)", "Antoine Lambert", "05/05/11",
       "Implements the connected component packing algorithm published as:<br/>"
-      "<b>Disconnected Graph Layout and the Polyomino Packing Approach</b>, Freivalds Karlis, "
-      "Dogrusoz Ugur and Kikusts Paulis, "
-      "Graph Drawing '01 Revised Papers from the 9th International Symposium on Graph Drawing.",
+      "<b>Disconnected Graph Layout and the Polyomino Packing Approach</b>,<br/>Freivalds Karlis, Dogrusoz Ugur and Kikusts Paulis, "
+      "9th International Symposium on Graph Drawing 2001,"
+      "LNCS Vol. 2265 (2002), pp 378-391,<br/>doi: <a "
+      "href=\"https://doi.org/10.1007/3-540-45848-4_30\">10.1007/3-540-45848-4_30</"
+      "a>",
       "1.0", "Misc")
   PolyominoPacking(const tlp::PluginContext *context);
 
@@ -102,27 +107,17 @@ private:
 
   int gridStepSize;
 
-  std::unordered_map<tlp::Vec2i, bool> pointsSet;
+  tlp_hash_map<tlp::Vec2i, bool> pointsSet;
 
   tlp::IntegerProperty *shape;
 };
 
 #define C 100
 
-class polyPerimOrdering : public binary_function<Polyomino, Polyomino, bool> {
-
-public:
-  polyPerimOrdering() {}
-
-  bool operator()(const Polyomino &ci1, const Polyomino &ci2) const {
-    return ci1.perim > ci2.perim;
-  }
-};
-
 PLUGIN(PolyominoPacking)
 
 PolyominoPacking::PolyominoPacking(const PluginContext *context) : LayoutAlgorithm(context) {
-  addInParameter<LayoutProperty>("coordinates", paramHelp[0], "viewLayout");
+  addInParameter<LayoutProperty>("initial layout", paramHelp[0], "viewLayout");
   addNodeSizePropertyParameter(this);
   addInParameter<DoubleProperty>("rotation", paramHelp[1], "viewRotation");
   addInParameter<unsigned int>("margin", paramHelp[2], "1");
@@ -140,7 +135,7 @@ bool PolyominoPacking::run() {
   bndIncrement = 1;
 
   if (dataSet != nullptr) {
-    dataSet->get("coordinates", layout);
+    dataSet->get("initial layout", layout);
     getNodeSizePropertyParameter(dataSet, size);
     dataSet->get("rotation", rotation);
     dataSet->get("margin", margin);
@@ -154,13 +149,8 @@ bool PolyominoPacking::run() {
   vector<vector<node>> connectedComponents;
   tlp::ConnectedTest::computeConnectedComponents(graph, connectedComponents);
 
-  if (connectedComponents.size() <= 1) {
-    for (auto n : graph->nodes()) {
-      result->setNodeValue(n, layout->getNodeValue(n));
-    }
-    for (auto e : graph->edges()) {
-      result->setEdgeValue(e, layout->getEdgeValue(e));
-    }
+  if (connectedComponents.size() == 1) {
+    result->copy(layout);
     return true;
   }
 
@@ -194,7 +184,7 @@ bool PolyominoPacking::run() {
     return true;
 
   if (pluginProgress) {
-    pluginProgress->setComment("Generating polyominos ...");
+    pluginProgress->setComment("Generating polyominos...");
     if (pluginProgress->progress(0, polyominos.size()) != TLP_CONTINUE)
       return pluginProgress->state() != TLP_CANCEL;
   }
@@ -206,10 +196,11 @@ bool PolyominoPacking::run() {
       return pluginProgress->state() != TLP_CANCEL;
   }
 
-  std::sort(polyominos.begin(), polyominos.end(), polyPerimOrdering());
+  std::sort(polyominos.begin(), polyominos.end(),
+            [](const Polyomino &ci1, const Polyomino &ci2) { return ci1.perim > ci2.perim; });
 
   if (pluginProgress) {
-    pluginProgress->setComment("Packing polyominos ...");
+    pluginProgress->setComment("Packing polyominos...");
     if (pluginProgress->progress(0, polyominos.size()) != TLP_CONTINUE)
       return pluginProgress->state() != TLP_CANCEL;
   }
