@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -56,10 +56,10 @@ static const char *paramHelp[] = {
 SquarifiedTreeMap::SquarifiedTreeMap(const tlp::PluginContext *context) : LayoutAlgorithm(context) {
   aspectRatio = DEFAULT_RATIO;
   addInParameter<NumericProperty *>("metric", paramHelp[0], "viewMetric", false);
-  addInParameter<double>("Aspect Ratio", paramHelp[1], "1.");
-  addInParameter<bool>("Treemap Type", paramHelp[2], "false");
-  addOutParameter<SizeProperty>("Node Size", paramHelp[3], "viewSize");
-  addOutParameter<IntegerProperty>("Node Shape", paramHelp[4], "viewShape");
+  addInParameter<double>("aspect ratio", paramHelp[1], "1.");
+  addInParameter<bool>("treemap type", paramHelp[2], "false");
+  addOutParameter<SizeProperty>("node dize", paramHelp[3], "viewSize");
+  addOutParameter<IntegerProperty>("node shape", paramHelp[4], "viewShape");
 }
 
 //====================================================================
@@ -80,7 +80,7 @@ bool SquarifiedTreeMap::check(std::string &errorMsg) {
   if (!metric && graph->existProperty("viewMetric")) {
     metric = graph->getProperty<DoubleProperty>("viewMetric");
 
-    if (metric->getNodeDoubleMin() < 0.) {
+    if (metric->getNodeDoubleMin(graph) < 0.) {
       errorMsg = "Graph's nodes must have a positive metric.";
       return false;
     }
@@ -103,10 +103,10 @@ bool SquarifiedTreeMap::run() {
   glyphResult = nullptr;
 
   if (dataSet != nullptr) {
-    dataSet->get("Aspect Ratio", aspectRatio);
-    dataSet->get("Treemap Type", shneidermanTreeMap);
-    dataSet->get("Node Size", sizeResult);
-    dataSet->get("Node Shape", glyphResult);
+    dataSet->get("aspect ratio", aspectRatio);
+    dataSet->get("treemap type", shneidermanTreeMap);
+    dataSet->get("node size", sizeResult);
+    dataSet->get("node shape", glyphResult);
   }
 
   if (sizeResult == nullptr)
