@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -21,12 +21,12 @@
 
 #include <vector>
 #include <utility>
-#include <unordered_map>
+#include <tulip/tuliphash.h>
 #include "tulip/TulipPluginHeaders.h"
 #include "tulip/Rectangle.h"
 
 typedef std::vector<tlp::node> VecNode;
-typedef std::unordered_map<tlp::node, double> MapNode;
+typedef tlp_hash_map<tlp::node, double> MapNode;
 typedef std::pair<tlp::node, double> PairNodeF;
 typedef std::vector<PairNodeF> PairVector;
 /** \addtogroup layout */
@@ -69,7 +69,7 @@ public:
                     " For Squarified Treemaps see:<br/> Bruls, M., Huizing, K., & van Wijk, J. J."
                     " Proc. of Joint Eurographics and IEEE TCVG Symp. on Visualization (TCVG 2000) "
                     "IEEE Press, pp. 33-42.",
-                    "2.0", "Tree")
+                    "2.1", "Tree")
   SquarifiedTreeMap(const tlp::PluginContext *context);
   ~SquarifiedTreeMap() override;
 
