@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -17,6 +17,8 @@
  *
  */
 #include <tulip/GraphTools.h>
+#include <tulip/TreeTest.h>
+
 #include "TreeLeaf.h"
 #include "DatasetTools.h"
 #include "Orientation.h"
