@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -18,6 +18,8 @@
  */
 #include <tulip/GraphTools.h>
 #include <tulip/StringCollection.h>
+#include <tulip/IntegerProperty.h>
+#include <tulip/TreeTest.h>
 
 #include "TreeReingoldAndTilfordExtended.h"
 #include "DatasetTools.h"
@@ -189,7 +191,7 @@ list<LR> *TreeReingoldAndTilfordExtended::mergeLRList(std::list<LR> *L, std::lis
 }
 //=============================================================================
 list<LR> *TreeReingoldAndTilfordExtended::TreePlace(tlp::node n,
-                                                    std::unordered_map<tlp::node, double> *p) {
+                                                    tlp_hash_map<tlp::node, double> *p) {
   if (tree->outdeg(n) == 0) {
     list<LR> *result = new list<LR>();
     LR tmpLR;
@@ -279,9 +281,8 @@ list<LR> *TreeReingoldAndTilfordExtended::TreePlace(tlp::node n,
 }
 //=============================================================================
 void TreeReingoldAndTilfordExtended::TreeLevelSizing(tlp::node n,
-                                                     std::unordered_map<int, double> &maxSize,
-                                                     int level,
-                                                     std::unordered_map<tlp::node, int> &levels) {
+                                                     tlp_hash_map<int, double> &maxSize, int level,
+                                                     tlp_hash_map<tlp::node, int> &levels) {
   levels[n] = level;
 
   if (maxSize.find(level) != maxSize.end()) {
@@ -303,10 +304,9 @@ void TreeReingoldAndTilfordExtended::TreeLevelSizing(tlp::node n,
   }
 }
 //=============================================================================
-void TreeReingoldAndTilfordExtended::calcLayout(tlp::node n,
-                                                std::unordered_map<tlp::node, double> *p, double x,
-                                                double y, int level,
-                                                unordered_map<int, double> &maxLevelSize) {
+void TreeReingoldAndTilfordExtended::calcLayout(tlp::node n, tlp_hash_map<tlp::node, double> *p,
+                                                double x, double y, int level,
+                                                tlp_hash_map<int, double> &maxLevelSize) {
   Coord tmpCoord;
 
   if (!compactLayout)
@@ -346,7 +346,7 @@ void TreeReingoldAndTilfordExtended::calcLayout(tlp::node n,
 }
 //===============================================================
 bool TreeReingoldAndTilfordExtended::run() {
-  std::unordered_map<node, double> posRelative;
+  tlp_hash_map<node, double> posRelative;
 
   result->setAllEdgeValue(vector<Coord>(0));
 
@@ -424,8 +424,8 @@ bool TreeReingoldAndTilfordExtended::run() {
   node startNode = tree->getSource();
   assert(startNode.isValid());
 
-  unordered_map<int, double> maxSizeLevel;
-  unordered_map<node, int> levels;
+  tlp_hash_map<int, double> maxSizeLevel;
+  tlp_hash_map<node, int> levels;
   TreeLevelSizing(startNode, maxSizeLevel, 0, levels);
 
   // check if the specified layer spacing is greater
