@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -20,8 +20,8 @@
 #define _TreeReingoldAndTilfordExtended_H
 #include <string>
 #include <cmath>
-#include <unordered_map>
-#include <tulip/TulipPluginHeaders.h>
+#include <tulip/tuliphash.h>
+#include <tulip/LayoutProperty.h>
 
 struct LR {
   double L;
@@ -36,8 +36,8 @@ struct LR {
  *  E.M. Reingold and J.S. Tilford, \n
  *  "Tidier Drawings of Trees", \n
  *  "IEEE Transactions on Software Engineering" \n
- *  pages "223--228" \n
- *  1981 \n
+ *  pages "223--228", 1981 \n
+ *  doi: <a href=\"https://doi.org/10.1109/TSE.1981.234519\">doi.org/10.1109/TSE.1981.234519</a>.
  *
  *  \note This algorithm only works on trees; so if the graph is not a tree
  *  it will be applied on a spanning tree.\n
@@ -53,21 +53,23 @@ public:
   PLUGININFORMATION("Hierarchical Tree (R-T Extended)", "David Auber and Romain Bourqui",
                     "24/09/2010",
                     "Implements the hierarchical tree layout algorithm first published as:<br/>"
-                    "<b>Tidier Drawings of Trees</b>, E.M. Reingold and J.S. Tilford, IEEE "
-                    "Transactions on Software Engineering pages 223--228 (1981).",
+                    "<b>Tidier Drawings of Trees</b>,<br/>E.M. Reingold and J.S. Tilford, IEEE "
+                    "Transactions on Software Engineering pages 223--228 (1981),<br/>"
+                    "doi: <a "
+                    "href=\"https://doi.org/10.1109/TSE.1981.234519\">10.1109/TSE.1981.234519</a>.",
                     "1.1", "Tree")
   TreeReingoldAndTilfordExtended(const tlp::PluginContext *context);
   ~TreeReingoldAndTilfordExtended() override;
   bool run() override;
 
 private:
-  void calcLayout(tlp::node, std::unordered_map<tlp::node, double> *, double, double, int,
-                  std::unordered_map<int, double> &);
+  void calcLayout(tlp::node, tlp_hash_map<tlp::node, double> *, double, double, int,
+                  tlp_hash_map<int, double> &);
   double calcDecal(const std::list<LR> &, const std::list<LR> &);
   std::list<LR> *mergeLRList(std::list<LR> *, std::list<LR> *, double decal);
-  std::list<LR> *TreePlace(tlp::node, std::unordered_map<tlp::node, double> *);
-  void TreeLevelSizing(tlp::node, std::unordered_map<int, double> &, int,
-                       std::unordered_map<tlp::node, int> &levels);
+  std::list<LR> *TreePlace(tlp::node, tlp_hash_map<tlp::node, double> *);
+  void TreeLevelSizing(tlp::node, tlp_hash_map<int, double> &, int,
+                       tlp_hash_map<tlp::node, int> &levels);
 
   tlp::Graph *tree;
   tlp::SizeProperty *sizes;
