@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -19,7 +19,7 @@
 #ifndef _TutteLAYOUT_H
 #define _TutteLAYOUT_H
 
-#include <tulip/TulipPluginHeaders.h>
+#include <tulip/LayoutProperty.h>
 
 /** \addtogroup layout */
 
@@ -38,7 +38,7 @@ public:
   PLUGININFORMATION(
       "3-Connected (Tutte)", "David Auber", "06/11/2002",
       "Implements the Tutte layout for 3-Connected graph algorithm first published as:<br/>"
-      "<b>How to Draw a Graph</b>, W.T. Tutte, Proc. London Math. Soc. pages 743--768 (1963).",
+      "<b>How to Draw a Graph</b>,<br/>W.T. Tutte, Proc. London Math. Soc. pages 743--768 (1963).",
       "1.0", "Planar")
   Tutte(const tlp::PluginContext *context);
   ~Tutte() override;
