@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -185,9 +185,9 @@ int biconnectedComponents(const Graph &graph, MutableContainer<int> &compnum) {
  */
 class BiconnectedComponent : public DoubleAlgorithm {
 public:
-  PLUGININFORMATION("Biconnected Component", "David Auber", "03/01/2005",
-                    "Implements a biconnected component decomposition."
-                    "It assigns the same value to all the edges in the same component.",
+  PLUGININFORMATION("Biconnected Components", "David Auber", "03/01/2005",
+                    "Implements a biconnected components decomposition. "
+                    "It assigns the same value to all the edges of the same component.",
                     "1.0", "Component")
   BiconnectedComponent(const tlp::PluginContext *context) : DoubleAlgorithm(context) {
     addOutParameter<unsigned int>("#biconnected components",
