@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -26,7 +26,7 @@ using namespace tlp;
 ConnectedComponent::ConnectedComponent(const tlp::PluginContext *context)
     : DoubleAlgorithm(context) {
 
-  addOutParameter<unsigned>("#connected components", "Number of components found");
+  addOutParameter<unsigned>("#connected components", "Number of connected components found");
 }
 //======================================================
 bool ConnectedComponent::run() {
@@ -41,14 +41,15 @@ bool ConnectedComponent::run() {
     }
     ++i;
   }
-
-  // propagate nodes computed value to edges
-  for (auto e : graph->edges()) {
-    result->setEdgeValue(e, result->getNodeValue(graph->source(e)));
-  }
-
   if (dataSet != nullptr)
-    dataSet->set<unsigned>("#connected components", components.size());
+    dataSet->set<unsigned>("#connected components", i);
+
+  if (i > 0) {
+    // propagate nodes computed value to edges
+    for (auto e : graph->edges()) {
+      result->setEdgeValue(e, result->getNodeValue(graph->source(e)));
+    }
+  }
 
   return true;
 }
