@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -32,7 +32,7 @@ static const char *paramHelp[] = {
 
 DepthMetric::DepthMetric(const tlp::PluginContext *context)
     : DoubleAlgorithm(context), edgeWeight(nullptr) {
-  addInParameter<NumericProperty *>("edge weight", paramHelp[0], "", false);
+  addInParameter<NumericProperty *>("metric", paramHelp[0], "", false);
 }
 
 // structure below is used to implement dfs loop
@@ -131,7 +131,7 @@ double DepthMetric::getNodeValue(tlp::node current) {
 //====================================================================
 bool DepthMetric::run() {
   if (dataSet != nullptr) {
-    dataSet->get("edge weight", edgeWeight);
+    dataSet->get("metric", edgeWeight);
   }
 
   result->setAllEdgeValue(0);
