@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -37,16 +37,21 @@ static const char *paramHelp[] = {
 
     // norm
     "If true, the returned values are normalized. "
-    "For the closeness centrality, the reciprocal of the sum of distances is returned. "
+    "For the closeness centrality, the reciprocal of the sum of distances is returned."
     "The eccentricity values are divided by the graph diameter. "
-    "<b> Warning : </b> The normalized eccentricity values should be computed on a (strongly) "
+    "<b> Warning: </b> The normalized eccentricity values should be computed on a (strongly) "
     "connected graph.",
 
     // directed
     "If true, the graph is considered directed.",
 
     // weight
-    "An existing edge weight metric property."};
+    "An existing edge weight metric property.",
+
+    // graph diameter
+    "The computed diameter; it is always computed when normalized eccentricity is required."
+    "To force its computation, in non normalized eccentricity case, set its input value to 1."
+    "When not computed its output value will be set to -1."};
 
 EccentricityMetric::EccentricityMetric(const tlp::PluginContext *context)
     : DoubleAlgorithm(context), allPaths(false), norm(true), directed(false) {
@@ -54,15 +59,14 @@ EccentricityMetric::EccentricityMetric(const tlp::PluginContext *context)
   addInParameter<bool>("norm", paramHelp[1], "true");
   addInParameter<bool>("directed", paramHelp[2], "false");
   addInParameter<NumericProperty *>("weight", paramHelp[3], "", false);
-  addOutParameter<double>("graph diameter", "The computed diameter (-1 if not computed)", "-1");
+  addInOutParameter<double>("graph diameter", paramHelp[4], "-1");
 }
 //====================================================================
 EccentricityMetric::~EccentricityMetric() {}
 //====================================================================
 double EccentricityMetric::compute(unsigned int nPos) {
 
-  NodeStaticProperty<double> distance(graph);
-  distance.setAll(0);
+  NodeStaticProperty<double> distance(graph, 0);
   double val = tlp::maxDistance(graph, nPos, distance, weight, directed ? DIRECTED : UNDIRECTED);
 
   if (!allPaths)
@@ -71,9 +75,9 @@ double EccentricityMetric::compute(unsigned int nPos) {
   double nbAcc = 0.;
   val = 0.;
   unsigned int nbNodes = graph->numberOfNodes();
-  double max_d_acc = nbNodes + 0.;
+  double max_d_acc = nbNodes;
   if (weight)
-    max_d_acc = nbNodes * weight->getEdgeDoubleMax();
+    max_d_acc = nbNodes * weight->getEdgeDoubleMax(graph);
 
   for (unsigned int i = 0; i < nbNodes; ++i) {
     double d = distance[i];
@@ -102,46 +106,64 @@ bool EccentricityMetric::run() {
   norm = true;
   directed = false;
   weight = nullptr;
+  double diameter = -1;
 
   if (dataSet != nullptr) {
     dataSet->get("closeness centrality", allPaths);
     dataSet->get("norm", norm);
     dataSet->get("directed", directed);
     dataSet->get("weight", weight);
+    dataSet->get("graph diameter", diameter);
   }
 
-  // Edges weights should be positive
-  if (weight && weight->getEdgeDoubleMin() <= 0) {
-    pluginProgress->setError("Edges weights should be positive.");
+  // Edges weights have to be positive
+  if (weight && weight->getEdgeDoubleMin(graph) <= 0) {
+    pluginProgress->setError("Edges weights have to be strictly positive.");
     return false;
   }
 
   NodeStaticProperty<double> res(graph);
   unsigned int nbNodes = graph->numberOfNodes();
+  bool needDiameter = (!allPaths && norm) || (diameter == 1);
+  // reset diameter before computation
+  diameter = -1;
 
-  double diameter = 1.0;
   std::atomic<bool> stopfor(false);
-  TLP_PARALLEL_MAP_INDICES(nbNodes, [&](unsigned int i) {
-    if (stopfor.load())
-      return;
+  if (needDiameter) {
+    TLP_PARALLEL_MAP_INDICES(nbNodes, [&](unsigned int i) {
+      if (stopfor.load())
+        return;
 
-    if (ThreadManager::getThreadNumber() == 0) {
-      if (pluginProgress->progress(i, nbNodes / ThreadManager::getNumberOfThreads()) !=
-          TLP_CONTINUE) {
-        stopfor = true;
+      if (ThreadManager::getThreadNumber() == 0) {
+        if (pluginProgress->progress(i, nbNodes / ThreadManager::getNumberOfThreads()) !=
+            TLP_CONTINUE) {
+          stopfor = true;
+        }
       }
-    }
 
-    res[i] = compute(i);
+      res[i] = compute(i);
 
-    if (!allPaths && norm) {
       TLP_LOCK_SECTION(DIAMETER) {
         if (diameter < res[i])
           diameter = res[i];
       }
       TLP_UNLOCK_SECTION(DIAMETER);
-    }
-  });
+    });
+  } else {
+    TLP_PARALLEL_MAP_INDICES(nbNodes, [&](unsigned int i) {
+      if (stopfor.load())
+        return;
+
+      if (ThreadManager::getThreadNumber() == 0) {
+        if (pluginProgress->progress(i, nbNodes / ThreadManager::getNumberOfThreads()) !=
+            TLP_CONTINUE) {
+          stopfor = true;
+        }
+      }
+
+      res[i] = compute(i);
+    });
+  }
 
   if (pluginProgress->state() != TLP_CONTINUE)
     return pluginProgress->state() != TLP_CANCEL;
@@ -154,7 +176,7 @@ bool EccentricityMetric::run() {
   });
 
   if (dataSet != nullptr)
-    dataSet->set("graph diameter", (!allPaths && norm) ? diameter : double(-1));
+    dataSet->set("graph diameter", diameter);
 
   return pluginProgress->state() != TLP_CANCEL;
 }
