@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -123,7 +123,7 @@ bool LeafMetric::run() {
 //=======================================================================
 bool LeafMetric::check(std::string &erreurMsg) {
   if (!AcyclicTest::isAcyclic(graph)) {
-    erreurMsg = "The graph must be a acyclic.";
+    erreurMsg = "The graph must be acyclic.";
     return false;
   }
 
