@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -29,7 +29,7 @@ using namespace tlp;
 /** \addtogroup clustering */
 /*@{*/
 /** \file
- * @brief This plugin is an implementation of a fuzzy clustering procedure. First introduced in :
+ * @brief This plugin is an implementation of a fuzzy clustering procedure. First introduced in:
  *
  * Ahn, Y.Y. and Bagrow, J.P. and Lehmann, S., \n
  * "Link communities reveal multiscale complexity in networks", \n
@@ -37,13 +37,14 @@ using namespace tlp;
  * pages 761--764, \n
  * 2010 \n
  *
- * The result of this procedure is saved as an edge metric : two edges share the same value
+ * The result of this procedure is saved as an edge metric: two edges share the same value
  * if they are part of the same group.
  * The result for a node shows the number of groups to which it belongs.
  *
- * @note To create subgraphs using the result of this algortihm use "Equal Value" with parameter
+ * @note To create subgraphs using the result of this algorithm use "Equal Value" with parameter
  *Type="edges".
  *
+
  * @todo Deal with directed graphs.
  *
  **/
@@ -52,10 +53,11 @@ public:
   PLUGININFORMATION(
       "Link Communities", "François Queyroi", "25/02/11",
       "Edges partitioning measure used for community detection.<br>"
-      "It is an implementation of a fuzzy clustering procedure. First introduced in :<br>"
-      " <b>Link communities reveal multiscale complexity in networks</b>, Ahn, Y.Y. and Bagrow, "
-      "J.P. and Lehmann, S., Nature vol:466, 761--764 (2010)",
-      "1.0", "Clustering")
+      "It is an implementation of a fuzzy clustering procedure. First introduced in:<br/>"
+      "<b>Link communities reveal multiscale complexity in networks</b>,<br/>"
+      " Ahn, Y.Y. and Bagrow, J.P. and Lehmann, S., Nature vol:466, 761--764 (2010)<br>"
+      "doi: <a href=\"https://doi.org/10.1038/nature09182\">10.1038/nature09182</a>",
+      "1.1", "Clustering")
 
   LinkCommunities(const tlp::PluginContext *);
   ~LinkCommunities() override;
@@ -121,8 +123,8 @@ static const char *paramHelp[] = {
 LinkCommunities::LinkCommunities(const tlp::PluginContext *context)
     : DoubleAlgorithm(context), metric(nullptr) {
   addInParameter<NumericProperty *>("metric", paramHelp[0], "", false);
-  addInParameter<bool>("Group isthmus", paramHelp[1], "true", true);
-  addInParameter<unsigned int>("Number of steps", paramHelp[2], "200", true);
+  addInParameter<bool>("group isthmus", paramHelp[1], "true", true);
+  addInParameter<unsigned int>("number of steps", paramHelp[2], "200", true);
 }
 //==============================================================================================================
 LinkCommunities::~LinkCommunities() {}
@@ -134,8 +136,8 @@ bool LinkCommunities::run() {
 
   if (dataSet != nullptr) {
     dataSet->get("metric", metric);
-    dataSet->get("Group isthmus", group_isthmus);
-    dataSet->get("Number of steps", nb_steps);
+    dataSet->get("group isthmus", group_isthmus);
+    dataSet->get("number of steps", nb_steps);
   }
 
   const std::vector<edge> &edges = graph->edges();
@@ -359,11 +361,8 @@ double LinkCommunities::computeAverageDensity(double threshold, const std::vecto
       while (!dnToVisit.empty()) {
         dn = dnToVisit.front();
         dnToVisit.pop_front();
-        const std::vector<edge> &curEdges = dual.star(dn);
-        unsigned int eSz = curEdges.size();
-
-        for (unsigned int j = 0; j < eSz; ++j) {
-          edge e = curEdges[j];
+        for (auto &adj : dual.adj(dn)) {
+          edge e = adj.link();
 
           if (similarity[e] > threshold) {
             node neighbour = dual.opposite(e, dn);
@@ -429,11 +428,8 @@ void LinkCommunities::setEdgeValues(double threshold, bool group_isthmus,
       while (!dnToVisit.empty()) {
         dn = dnToVisit.front();
         dnToVisit.pop_front();
-        const std::vector<edge> &curEdges = dual.star(dn);
-        unsigned int eSz = curEdges.size();
-
-        for (unsigned int j = 0; j < eSz; ++j) {
-          edge e = curEdges[j];
+        for (auto &adj : dual.adj(dn)) {
+          edge e = adj.link();
 
           if (similarity[e] > threshold) {
             node neighbour = dual.opposite(e, dn);
