@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -21,7 +21,7 @@
 #define _STRONGCOMPONENT_H
 
 #include <stack>
-#include <unordered_map>
+#include <tulip/tuliphash.h>
 #include <tulip/DoubleProperty.h>
 
 /** This plugin is an implementation of a strongly connected components decomposition.
@@ -34,17 +34,23 @@
  */
 class StrongComponent : public tlp::DoubleAlgorithm {
 public:
-  PLUGININFORMATION("Strongly Connected Component", "David Auber", "12/06/2001",
-                    "Implements a strongly connected components decomposition.", "1.0", "Component")
+  PLUGININFORMATION("Strongly Connected Components", "David Auber", "12/06/2001",
+                    "Implements a strongly connected components decomposition.<br/> \
+                    If two nodes are in the same strongly connected component, they have the same value; if not, they have a different value.<br/> \
+                    Edges between nodes in the same component have the same value as nodes.<br/> \
+                    Those between nodes of different components have a null value.<br/> \
+                    In the undirected case, these later ones are the disconnecting edges (also called bridges) of the graph.",
+                    "1.1", "Component")
   StrongComponent(const tlp::PluginContext *context);
   ~StrongComponent() override;
   bool run() override;
 
 private:
-  unsigned attachNumerotation(tlp::node, std::unordered_map<tlp::node, bool> &,
-                              std::unordered_map<tlp::node, bool> &,
-                              std::unordered_map<tlp::node, unsigned> &, unsigned &,
-                              std::stack<tlp::node> &, unsigned &);
+  unsigned curComponent, curTS;
+  void findSCC(tlp::node, tlp_hash_map<tlp::node, bool> &, tlp_hash_map<tlp::node, unsigned> &,
+               std::stack<tlp::node> &);
+  void findDE(tlp::node, std::vector<tlp::edge> &, tlp_hash_map<tlp::node, unsigned int> &,
+              tlp_hash_map<tlp::node, unsigned int> &);
 };
 
 #endif
