@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -44,6 +44,7 @@ class AlgorithmRunner : public QWidget {
   tlp::Graph *_graph;
   QToolButton *_storeResultAsLocalButton;
   QAction *_resultAsLocalPropAction;
+  bool _darkBackground;
 
   QList<AlgorithmRunnerItem *> _favorites;
 
