@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -51,6 +51,7 @@ protected slots:
 
   void pathChanged(QString s);
   void browseButtonClicked();
+  void helpButtonClicked();
   bool validateCurrentPage() override;
 };
 
