@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -75,6 +75,7 @@ protected slots:
 
 protected:
   void dragEnterEvent(QDragEnterEvent *) override;
+  void dragLeaveEvent(QDragLeaveEvent *) override;
   void dropEvent(QDropEvent *) override;
 };
 
