@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -30,7 +30,6 @@ ExpandableGroupBox::ExpandableGroupBox(QWidget *parent, const QString &title)
 
   QVBoxLayout *lyt = new QVBoxLayout;
   lyt->setContentsMargins(0, 0, 0, 0);
-  lyt->setMargin(0);
   lyt->setSpacing(0);
   setLayout(lyt);
 }
