@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -18,6 +18,7 @@
  */
 #include "ExportWizard.h"
 #include "ui_ExportWizard.h"
+#include "PluginDocDialog.h"
 
 #include <QAbstractButton>
 #include <QFileDialog>
@@ -35,32 +36,50 @@ using namespace std;
 
 ExportWizard::ExportWizard(Graph *g, const QString &exportFile, QWidget *parent)
     : QWizard(parent), _ui(new Ui::ExportWizard), _graph(g) {
+#if !defined(__LINUX)
+  setWizardStyle(QWizard::ClassicStyle);
+#endif
+
   _ui->setupUi(this);
   button(QWizard::FinishButton)->setEnabled(false);
 
+  bool darkBackground =
+      _ui->exportModules->palette().color(backgroundRole()) != QColor(255, 255, 255);
+  // update foreground colors according to background color
+  if (darkBackground) {
+    auto ss = _ui->exportModules->styleSheet();
+    ss.replace("black", "white");
+    _ui->exportModules->setStyleSheet(ss);
+    _ui->parameters->setStyleSheet("QHeaderView::section { color: white }");
+  }
+
   PluginModel<tlp::ExportModule> *model = new PluginModel<tlp::ExportModule>(_ui->exportModules);
 
   _ui->exportModules->setModel(model);
   _ui->exportModules->setRootIndex(model->index(0, 0));
   _ui->exportModules->expandAll();
-  connect(_ui->exportModules->selectionModel(), SIGNAL(currentChanged(QModelIndex, QModelIndex)),
-          this, SLOT(algorithmSelected(QModelIndex)));
+  connect(_ui->exportModules->selectionModel(),
+          SIGNAL(currentChanged(const QModelIndex &, const QModelIndex &)), this,
+          SLOT(algorithmSelected(const QModelIndex &)));
 
-  _ui->parametersList->setItemDelegate(new TulipItemDelegate(_ui->parametersList));
-  _ui->parametersList->verticalHeader()->setSectionResizeMode(QHeaderView::Fixed);
-  connect(_ui->exportModules, SIGNAL(doubleClicked(QModelIndex)), button(QWizard::FinishButton),
-          SLOT(click()));
+  connect(_ui->exportModules, SIGNAL(doubleClicked(const QModelIndex &)),
+          button(QWizard::FinishButton), SLOT(click()));
 
   // display OK instead of Finish
   setButtonText(QWizard::FinishButton, "OK");
   _ui->parametersFrame->hide();
   updateFinishButton();
 
+  // Help button is used to display export plugin doc
+  // as soon as an import plugin is selected
+  button(QWizard::HelpButton)->setVisible(false);
+  connect(this, SIGNAL(helpRequested()), this, SLOT(helpButtonClicked()));
+
   _ui->pathEdit->setText(exportFile);
 }
 
 ExportWizard::~ExportWizard() {
-  delete _ui->parametersList->model();
+  delete _ui->parameters->model();
   delete _ui;
 }
 
@@ -68,20 +87,21 @@ void ExportWizard::algorithmSelected(const QModelIndex &index) {
   QString alg(index.data().toString());
   string algs(tlp::QStringToTlpString(alg));
   _ui->parametersFrame->setVisible(!alg.isEmpty());
-  QAbstractItemModel *oldModel = _ui->parametersList->model();
-  QAbstractItemModel *newModel = nullptr;
 
   if (PluginLister::pluginExists(algs)) {
-    newModel = new ParameterListModel(PluginLister::getPluginParameters(algs), _graph);
-  }
-
-  _ui->parametersList->setModel(newModel);
+    setButtonText(QWizard::HelpButton, QString("%1 documentation").arg(alg));
+    button(QWizard::HelpButton)->setVisible(true);
+    QAbstractItemModel *oldModel = _ui->parameters->model();
+    ParameterListModel::configureTableView(_ui->parameters, PluginLister::getPluginParameters(algs),
+                                           _graph);
+    delete oldModel;
+  } else
+    button(QWizard::HelpButton)->setVisible(false);
 
   QString parametersText("<b>Parameters</b>");
   parametersText += "&nbsp;<font size=-2>[" + alg + "]</font>";
   _ui->parametersLabel->setText(parametersText);
 
-  delete oldModel;
   updateFinishButton();
 }
 
@@ -93,7 +113,7 @@ QString ExportWizard::algorithm() const {
 }
 
 tlp::DataSet ExportWizard::parameters() const {
-  ParameterListModel *model = dynamic_cast<ParameterListModel *>(_ui->parametersList->model());
+  ParameterListModel *model = dynamic_cast<ParameterListModel *>(_ui->parameters->model());
 
   if (model == nullptr)
     return DataSet();
@@ -106,7 +126,7 @@ QString ExportWizard::outputFile() const {
 }
 
 void ExportWizard::updateFinishButton() {
-  button(QWizard::FinishButton)->setEnabled(_ui->parametersList->model() != nullptr);
+  button(QWizard::FinishButton)->setEnabled(_ui->parameters->model() != nullptr);
 }
 
 void ExportWizard::pathChanged(QString s) {
@@ -118,7 +138,7 @@ void ExportWizard::pathChanged(QString s) {
 
   for (std::list<std::string>::iterator itm = modules.begin(); itm != modules.end(); ++itm) {
     ExportModule *p = PluginLister::getPluginObject<ExportModule>(*itm);
-    std::list<std::string> extension = p->allFileExtensions();
+    std::list<std::string> extension = p->fileExtensions();
 
     for (list<string>::const_iterator extit = extension.begin(); extit != extension.end();
          ++extit) {
@@ -133,18 +153,17 @@ void ExportWizard::pathChanged(QString s) {
       break;
   }
 
-  if (selectedExport.isEmpty()) {
-    _ui->exportModules->clearSelection();
-    return;
-  }
-
   PluginModel<tlp::ExportModule> *model =
       static_cast<PluginModel<tlp::ExportModule> *>(_ui->exportModules->model());
   QModelIndexList results = model->match(_ui->exportModules->rootIndex(), Qt::DisplayRole,
                                          selectedExport, 1, Qt::MatchExactly | Qt::MatchRecursive);
 
-  if (results.empty())
+  if (results.empty()) {
+    _ui->exportModules->clearSelection();
+    _ui->parametersFrame->setVisible(false);
+    button(QWizard::HelpButton)->setVisible(false);
     return;
+  }
 
   _ui->exportModules->setCurrentIndex(results[0]);
 }
@@ -156,7 +175,7 @@ void ExportWizard::browseButtonClicked() {
 
   for (std::list<std::string>::const_iterator itm = modules.begin(); itm != modules.end(); ++itm) {
     ExportModule *p = PluginLister::getPluginObject<ExportModule>(*itm);
-    const std::list<std::string> extension = p->allFileExtensions();
+    const std::list<std::string> extension = p->fileExtensions();
     filter += tlpStringToQString(p->name()) + " (";
 
     for (list<string>::const_iterator it = extension.begin(); it != extension.end(); ++it) {
@@ -189,6 +208,14 @@ void ExportWizard::browseButtonClicked() {
   }
 }
 
+void ExportWizard::helpButtonClicked() {
+  // display current import plugin documentation
+  ParameterListModel *model = static_cast<ParameterListModel *>(_ui->parameters->model());
+  auto index = _ui->exportModules->selectionModel()->currentIndex();
+  PluginDocDialog::showDoc(parentWidget(), index.data().toString(),
+                           index.data(Qt::ToolTipRole).toString(), model);
+}
+
 bool ExportWizard::validateCurrentPage() {
   QString exportFile = outputFile();
 
@@ -198,7 +225,7 @@ bool ExportWizard::validateCurrentPage() {
   std::list<std::string> extension;
 
   if (p != nullptr)
-    extension = p->allFileExtensions();
+    extension = p->fileExtensions();
 
   bool extok(false);
   QString ext;
