@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -28,7 +28,6 @@
 #include <QToolButton>
 #include <QSortFilterProxyModel>
 #include <QMessageBox>
-#include <QMainWindow>
 
 #include <tulip/Perspective.h>
 #include <tulip/BooleanProperty.h>
@@ -56,8 +55,14 @@ int CustomTreeView::sizeHintForColumn(int col) const {
 
   while (index.isValid()) {
     if (viewport()->rect().contains(visualRect(index))) {
-      hint = qMax(hint, visualRect(index).x() +
-                            itemDelegate(index)->sizeHint(viewOptions(), index).width());
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+      auto w = itemDelegate(index)->sizeHint(viewOptions(), index).width();
+#else
+      QStyleOptionViewItem option;
+      initViewItemOption(&option);
+      auto w = itemDelegateForIndex(index)->sizeHint(option, index).width();
+#endif
+      hint = qMax(hint, visualRect(index).x() + w);
     }
 
     index = indexBelow(index);
@@ -75,17 +80,6 @@ void CustomTreeView::scrollContentsBy(int dx, int dy) {
 }
 
 void CustomTreeView::setModel(QAbstractItemModel *m) {
-  if (model()) {
-    disconnect(model(), SIGNAL(rowsInserted(const QModelIndex &, int, int)), this,
-               SLOT(resizeFirstColumnToContent()));
-    disconnect(model(), SIGNAL(rowsRemoved(const QModelIndex &, int, int)), this,
-               SLOT(resizeFirstColumnToContent()));
-  }
-
-  connect(m, SIGNAL(rowsInserted(const QModelIndex &, int, int)), this,
-          SLOT(resizeFirstColumnToContent()));
-  connect(m, SIGNAL(rowsRemoved(const QModelIndex &, int, int)), this,
-          SLOT(resizeFirstColumnToContent()));
   QTreeView::setModel(m);
   resizeFirstColumnToContent();
 }
@@ -159,6 +153,10 @@ void GraphHierarchiesEditor::setModel(tlp::GraphHierarchiesModel *model) {
           SLOT(currentGraphChanged(tlp::Graph *)));
 }
 
+Graph *GraphHierarchiesEditor::currentGraph() {
+  return _model->currentGraph();
+}
+
 GraphHierarchiesEditor::~GraphHierarchiesEditor() {
   delete _ui;
 }
@@ -168,6 +166,8 @@ void GraphHierarchiesEditor::contextMenuRequested(const QPoint &p) {
 
   if (_contextIndex.isValid()) {
     _contextGraph = _contextIndex.data(tlp::GraphHierarchiesModel::GraphRole).value<tlp::Graph *>();
+    if (_contextGraph == nullptr)
+      return;
     QMenu menu;
     tlp::Perspective::redirectStatusTipOfMenu(&menu);
     menu.addAction(tlp::Perspective::typedInstance<GraphPerspective>()->createPanelAction());
@@ -286,8 +286,9 @@ void GraphHierarchiesEditor::currentGraphChanged(Graph *graph) {
     if (selection)
       selection->addObserver(this);
     _currentSelection = selection;
-    updateSelectionInfos();
   }
+  GraphPerspective::typedInstance<GraphPerspective>()->resetTitle();
+  updateSelectionInfos();
 }
 
 void GraphHierarchiesEditor::treatEvents(const std::vector<tlp::Event> &evts) {
@@ -364,10 +365,11 @@ void GraphHierarchiesEditor::delGraph() {
     _model->setCurrentGraph(nullptr);
   } else {
     tlp::Graph *sg = _contextGraph->getSuperGraph();
-    _contextGraph->getSuperGraph()->delSubGraph(_contextGraph);
+    sg->delSubGraph(_contextGraph);
     _model->setCurrentGraph(sg);
   }
 
+  _ui->hierarchiesTree->selectionModel()->reset();
   _contextGraph = nullptr;
 }
 
@@ -403,10 +405,11 @@ void GraphHierarchiesEditor::delAllGraph() {
     _contextGraph->push();
     GraphPerspective::typedInstance<GraphPerspective>()->closePanelsForGraph(_contextGraph);
     tlp::Graph *sg = _contextGraph->getSuperGraph();
-    _contextGraph->getSuperGraph()->delAllSubGraphs(_contextGraph);
+    sg->delAllSubGraphs(_contextGraph);
     _model->setCurrentGraph(sg);
   }
 
+  _ui->hierarchiesTree->selectionModel()->reset();
   _contextGraph = nullptr;
 }
 
