@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -17,8 +17,8 @@
  *
  */
 
-#ifndef GEOLOCALISATIONCONFIGWIDGET_H_
-#define GEOLOCALISATIONCONFIGWIDGET_H_
+#ifndef GEOLOCALISATION_CONFIG_WIDGET_H
+#define GEOLOCALISATION_CONFIG_WIDGET_H
 
 #include <QWidget>
 
@@ -30,39 +30,49 @@ namespace tlp {
 
 class Graph;
 
-class GeolocalisationConfigWidget : public QWidget  {
+class GeolocalisationConfigWidget : public QWidget {
 
   Q_OBJECT
-  Ui::GeolocalisationConfigWidgetData* _ui;
+  Ui::GeolocalisationConfigWidgetData *_ui;
 
-public :
-
-  GeolocalisationConfigWidget(QWidget *parent = 0);
-  ~GeolocalisationConfigWidget();
+public:
+  GeolocalisationConfigWidget(QWidget *parent = nullptr);
+  ~GeolocalisationConfigWidget() override;
 
   void setGraph(Graph *graph);
 
-  void setLatLngGeoLocMethod();
+  void setLatLngGeoLocMethod(const std::string &latitudePropertyName,
+                             const std::string &longitudePropertyName);
+
+  void setAddressGeoLocMethod();
+
+  void setEdgesPathsPropertyName(const std::string &edgesPathsPropertyName);
 
   bool geolocateByAddress() const;
 
   bool createLatAndLngProperties() const;
 
+  bool resetLatAndLngValues() const;
+
+  bool automaticChoice() const;
+
   std::string getAddressGraphPropertyName() const;
 
   std::string getLatitudeGraphPropertyName() const;
 
   std::string getLongitudeGraphPropertyName() const;
 
-public slots :
+  bool useEdgesPaths() const;
+
+  std::string getEdgesPathsPropertyName() const;
+
+public slots:
 
   void enableDisableComboBoxes();
 
 signals:
   void computeGeoLayout();
-
-
 };
-}
+} // namespace tlp
 
-#endif /* GOOGLEMAPSVIEWCONFIGWIDGET_H_ */
+#endif // GEOLOCALISATION_CONFIG_WIDGET_H
