@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -17,8 +17,6 @@
  *
  */
 
-#include <QMainWindow>
-
 #include <tulip/Perspective.h>
 
 #include "HistoOptionsWidget.h"
@@ -31,7 +29,6 @@ namespace tlp {
 HistoOptionsWidget::HistoOptionsWidget(QWidget *parent)
     : QWidget(parent), oldValueInitialized(false), _ui(new Ui::HistoOptionsWidgetData) {
   _ui->setupUi(this);
-  _ui->backColorButton->setDialogParent(Perspective::instance()->mainWindow());
   _ui->backColorButton->setDialogTitle("Choose the background color");
   setBackgroundColor(Color(255, 255, 255));
   connect(_ui->useXScaleCheckBox, SIGNAL(toggled(bool)), this, SLOT(pressXScaleCheckBox(bool)));
