@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -20,11 +20,9 @@
 #ifndef HISTOGRAMINTERACTORS_H_
 #define HISTOGRAMINTERACTORS_H_
 
-#include <tulip/NodeLinkDiagramComponentInteractor.h>
+#include <tulip/InteractorViewExplorer.h>
 #include "../../utils/PluginNames.h"
 
-using namespace std;
-
 namespace tlp {
 
 class HistogramStatistics;
@@ -39,17 +37,6 @@ public:
   bool isCompatible(const std::string &viewName) const override;
 };
 
-class HistogramInteractorNavigation : public HistogramInteractor {
-
-public:
-  PLUGININFORMATION(InteractorName::HistogramInteractorNavigation, "Tulip Team", "02/04/2009",
-                    "Histogram Navigation Interactor", "1.0", "Navigation")
-
-  HistogramInteractorNavigation(const PluginContext *);
-
-  void construct() override;
-};
-
 class HistogramInteractorMetricMapping : public HistogramInteractor {
 
 public:
@@ -71,7 +58,7 @@ public:
   ~HistogramInteractorStatistics() override;
 
   void construct() override;
-  QWidget *configurationWidget() const override;
+  QWidget *configurationOptionsWidget() const override;
   void install(QObject *target) override;
 
 private:
@@ -82,20 +69,15 @@ private:
 /**
  *  \brief interactor to get information about an element of the graph
  */
-class HistogramInteractorGetInformation : public NodeLinkDiagramComponentInteractor {
+class HistogramInteractorGetInformation : public InteractorViewExplorer {
 public:
   PLUGININFORMATION("HistogramInteractorGetInformation", "Tulip Team", "18/06/2015",
-                    "Get Information Interactor", "1.0", "Information")
+                    "Explore current view", "2.0", "Information")
   /**
    * Default constructor
    */
   HistogramInteractorGetInformation(const tlp::PluginContext *);
 
-  /**
-   * Construct chain of responsibility
-   */
-  void construct() override;
-
   bool isCompatible(const std::string &viewName) const override;
 };
 } // namespace tlp
