@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -17,24 +17,31 @@
  *
  */
 
+#include <tulip/GraphImpl.h>
 #include <tulip/GlQuantitativeAxis.h>
-#include <tulip/TlpTools.h>
 #include <tulip/Interactor.h>
 #include <tulip/GlMainWidget.h>
 #include <tulip/GlLabel.h>
 #include <tulip/GlRect.h>
-#include <tulip/GlTextureManager.h>
+
+#include <tulip/Perspective.h>
 #include <tulip/TlpQtTools.h>
 #include <tulip/QuickAccessBar.h>
 #include <tulip/TulipViewSettings.h>
+#include <tulip/ViewGraphPropertiesSelectionWidget.h>
+#include <tulip/WorkspacePanel.h>
+#include <tulip/NeedConfigurationMsgBox.h>
 
 #include <QHelpEvent>
 #include <QApplication>
 #include <QToolTip>
+#include <QGraphicsView>
+#include <QGraphicsProxyWidget>
+#include <QPushButton>
+#include <QMessageBox>
 
 #include "HistogramView.h"
 #include "HistogramInteractors.h"
-#include "../utils/ViewGraphPropertiesSelectionWidget.h"
 #include "HistoOptionsWidget.h"
 
 using namespace std;
@@ -62,10 +69,9 @@ HistogramView::HistogramView(const PluginContext *)
       xAxisDetail(nullptr), yAxisDetail(nullptr), _histoGraph(nullptr), emptyGraph(nullptr),
       emptyGlGraphComposite(nullptr), histogramsComposite(nullptr), labelsComposite(nullptr),
       axisComposite(nullptr), smallMultiplesView(true), mainLayer(nullptr),
-      detailedHistogram(nullptr), sceneRadiusBak(0), zoomFactorBak(0), noDimsLabel(nullptr),
-      noDimsLabel1(nullptr), noDimsLabel2(nullptr), emptyRect(nullptr), emptyRect2(nullptr),
-      isConstruct(false), lastNbHistograms(0), dataLocation(NODE), needUpdateHistogram(false),
-      edgeAsNodeGraph(nullptr) {}
+      detailedHistogram(nullptr), sceneRadiusBak(0), zoomFactorBak(0), emptyRect(nullptr),
+      emptyRect2(nullptr), isConstruct(false), lastNbHistograms(0), dataLocation(NODE),
+      needUpdateHistogram(false), edgeAsNodeGraph(nullptr) {}
 
 HistogramView::~HistogramView() {
   if (isConstruct) {
@@ -83,24 +89,22 @@ HistogramView::~HistogramView() {
   }
 }
 
-QList<QWidget *> HistogramView::configurationWidgets() const {
-  return QList<QWidget *>() << propertiesSelectionWidget << histoOptionsWidget;
+std::list<QWidget *> HistogramView::configurationWidgets() const {
+  return std::list<QWidget *>{propertiesSelectionWidget, histoOptionsWidget};
 }
 
-void HistogramView::initGlWidget(Graph *) {
-  GlLayer *layer = getGlMainWidget()->getScene()->getLayer("Main");
+void HistogramView::initGlWidget() {
+  mainLayer = getGlMainWidget()->getScene()->getLayer("Main");
 
-  if (layer == nullptr) {
-    layer = new GlLayer("Main");
-    getGlMainWidget()->getScene()->addExistingLayer(layer);
+  if (mainLayer == nullptr) {
+    mainLayer = new GlLayer("Main");
+    getGlMainWidget()->getScene()->addExistingLayer(mainLayer);
   }
 
-  mainLayer = layer;
-
   cleanupGlScene();
 
   if (emptyGlGraphComposite == nullptr) {
-    emptyGraph = newGraph();
+    emptyGraph = GraphImpl::newGraph();
     emptyGlGraphComposite = new GlGraphComposite(emptyGraph);
   }
 
@@ -151,22 +155,42 @@ QuickAccessBar *HistogramView::getQuickAccessBarImpl() {
   return _bar;
 }
 
-void HistogramView::setState(const DataSet &dataSet) {
+void HistogramView::graphicsViewResized(int w, int h) {
+  if (isConstruct) {
+    noPropertyMsgBox->setPos(w / 2 - noPropertyMsgBox->sceneBoundingRect().width() / 2,
+                             h / 2 - noPropertyMsgBox->sceneBoundingRect().height() / 2);
+  }
+}
 
+void HistogramView::setState(const DataSet &dataSet) {
   GlMainWidget *gl = getGlMainWidget();
 
   if (!isConstruct) {
     isConstruct = true;
     gl->installEventFilter(this);
-    setOverviewVisible(true);
-
     propertiesSelectionWidget = new ViewGraphPropertiesSelectionWidget();
     histoOptionsWidget = new HistoOptionsWidget();
     propertiesSelectionWidget->setWidgetEnabled(true);
     histoOptionsWidget->setWidgetEnabled(false);
-  }
 
-  GlMainView::setState(dataSet);
+    // create box indicating the lack of selected properties
+    QGraphicsRectItem *qgrItem = new QGraphicsRectItem(0, 0, 1, 1);
+    qgrItem->setBrush(Qt::transparent);
+    qgrItem->setPen(QPen(Qt::transparent));
+    graphicsView()->scene()->addItem(qgrItem);
+
+    QPushButton *okButton;
+    QWidget *msgBox =
+        new_NeedConfigurationMsgBox("<b><font size=\"+1\">"
+                                    "No graph properties selected.</font></b><br/><br/>"
+                                    "Open the <b>Properties</b> configuration tab<br/>"
+                                    "to proceed.",
+                                    &okButton);
+    connect(okButton, SIGNAL(released()), this, SLOT(showPropertiesSelectionWidget()));
+    connect(okButton, SIGNAL(released()), msgBox, SLOT(hide()));
+    noPropertyMsgBox = graphicsView()->scene()->addWidget(msgBox);
+    noPropertyMsgBox->setParentItem(qgrItem);
+  }
 
   Graph *lastGraph = _histoGraph;
   _histoGraph = graph();
@@ -183,14 +207,13 @@ void HistogramView::setState(const DataSet &dataSet) {
       lastGraph->getProperty("viewTexture")->removeListener(this);
     }
 
-    initGlWidget(graph());
+    initGlWidget();
     detailedHistogram = nullptr;
 
-    if (edgeAsNodeGraph)
-      delete edgeAsNodeGraph;
+    delete edgeAsNodeGraph;
 
     if (_histoGraph) {
-      edgeAsNodeGraph = tlp::newGraph();
+      edgeAsNodeGraph = GraphImpl::newGraph();
       edgeToNode.clear();
       nodeToEdge.clear();
       for (auto e : _histoGraph->edges()) {
@@ -228,7 +251,7 @@ void HistogramView::setState(const DataSet &dataSet) {
     histoOptionsWidget->setBackgroundColor(backgroundColor);
   }
 
-  unordered_map<string, DataSet> histogramParametersMap;
+  tlp_hash_map<string, DataSet> histogramParametersMap;
   DataSet histogramParameters;
   int i = 0;
   stringstream ss;
@@ -350,13 +373,8 @@ void HistogramView::setState(const DataSet &dataSet) {
     switchFromSmallMultiplesToDetailedView(histo);
   }
 
-  bool quickAccessBarVisible = false;
-
-  if (dataSet.get<bool>("quickAccessBarVisible", quickAccessBarVisible)) {
-    needQuickAccessBar = true;
-    setQuickAccessBarVisible(quickAccessBarVisible);
-  } else
-    setQuickAccessBarVisible(true);
+  setQuickAccessBarVisible(true);
+  GlMainView::setState(dataSet);
 }
 
 DataSet HistogramView::state() const {
@@ -408,19 +426,21 @@ DataSet HistogramView::state() const {
 
   dataSet.set("histo detailed name", histoDetailedNamed);
 
-  if (needQuickAccessBar)
-    dataSet.set("quickAccessBarVisible", quickAccessBarVisible());
-
   return dataSet;
 }
 
+void HistogramView::showPropertiesSelectionWidget() {
+  WorkspacePanel *wp = static_cast<WorkspacePanel *>(graphicsView()->parentWidget());
+  wp->showConfigurationTab("Properties");
+}
+
 bool HistogramView::eventFilter(QObject *object, QEvent *event) {
   if (xAxisDetail != nullptr && event->type() == QEvent::ToolTip &&
       !detailedHistogram->uniformQuantificationHistogram()) {
     GlMainWidget *glw = getGlMainWidget();
     QHelpEvent *he = static_cast<QHelpEvent *>(event);
-    int x = glw->width() - he->x();
-    int y = he->y();
+    int x = glw->width() - he->pos().x();
+    int y = he->pos().y();
     Coord screenCoords(x, y, 0);
     Coord sceneCoords(glw->getScene()->getLayer("Main")->getCamera().viewportTo3DWorld(
         glw->screenToViewport(screenCoords)));
@@ -439,52 +459,6 @@ bool HistogramView::eventFilter(QObject *object, QEvent *event) {
   return GlMainView::eventFilter(object, event);
 }
 
-void HistogramView::addEmptyViewLabel() {
-
-  Color backgroundColor(histoOptionsWidget->getBackgroundColor());
-  getGlMainWidget()->getScene()->setBackgroundColor(backgroundColor);
-
-  Color foregroundColor;
-  int bgV = backgroundColor.getV();
-
-  if (bgV < 128) {
-    foregroundColor = Color(255, 255, 255);
-  } else {
-    foregroundColor = Color(0, 0, 0);
-  }
-
-  if (noDimsLabel == nullptr) {
-    noDimsLabel = new GlLabel(Coord(0, 0, 0), Size(200, 200), foregroundColor);
-    noDimsLabel->setText(ViewName::HistogramViewName);
-    noDimsLabel1 = new GlLabel(Coord(0, -50, 0), Size(400, 200), foregroundColor);
-    noDimsLabel1->setText("No graph properties selected.");
-    noDimsLabel2 = new GlLabel(Coord(0, -100, 0), Size(700, 200), foregroundColor);
-    noDimsLabel2->setText("Go to the \"Properties\" tab in top right corner.");
-  } else {
-    noDimsLabel->setColor(foregroundColor);
-    noDimsLabel1->setColor(foregroundColor);
-    noDimsLabel2->setColor(foregroundColor);
-  }
-
-  mainLayer->addGlEntity(noDimsLabel, "no dimensions label");
-  mainLayer->addGlEntity(noDimsLabel1, "no dimensions label 1");
-  mainLayer->addGlEntity(noDimsLabel2, "no dimensions label 2");
-}
-
-void HistogramView::removeEmptyViewLabel() {
-  if (noDimsLabel != nullptr) {
-    mainLayer->deleteGlEntity(noDimsLabel);
-    delete noDimsLabel;
-    noDimsLabel = nullptr;
-    mainLayer->deleteGlEntity(noDimsLabel1);
-    delete noDimsLabel1;
-    noDimsLabel1 = nullptr;
-    mainLayer->deleteGlEntity(noDimsLabel2);
-    delete noDimsLabel2;
-    noDimsLabel2 = nullptr;
-  }
-}
-
 void HistogramView::viewConfigurationChanged() {
   getGlMainWidget()->getScene()->setBackgroundColor(histoOptionsWidget->getBackgroundColor());
   bool dataLocationChanged = propertiesSelectionWidget->getDataLocation() != dataLocation;
@@ -523,6 +497,13 @@ void HistogramView::viewConfigurationChanged() {
   drawOverview(true);
 }
 
+void HistogramView::propertiesSelected(bool flag) {
+  noPropertyMsgBox->setVisible(!flag);
+  if (quickAccessBarVisible())
+    _quickAccessBar->setEnabled(flag);
+  setOverviewVisible(flag);
+}
+
 void HistogramView::draw() {
   GlMainWidget *gl = getGlMainWidget();
 
@@ -535,18 +516,14 @@ void HistogramView::draw() {
       switchFromDetailedViewToSmallMultiples();
     }
 
-    removeEmptyViewLabel();
-    addEmptyViewLabel();
+    propertiesSelected(false);
     gl->centerScene();
 
-    if (quickAccessBarVisible())
-      _quickAccessBar->setEnabled(false);
-
+    lastNbHistograms = 0;
     return;
   }
 
-  if (quickAccessBarVisible())
-    _quickAccessBar->setEnabled(true);
+  propertiesSelected(true);
 
   if (detailedHistogram != nullptr) {
     needUpdateHistogram = true;
@@ -560,10 +537,6 @@ void HistogramView::draw() {
     switchFromSmallMultiplesToDetailedView(detailedHistogram);
   }
 
-  if (!selectedProperties.empty()) {
-    removeEmptyViewLabel();
-  }
-
   if (!smallMultiplesView &&
       (detailedHistogram == nullptr || (selectedProperties.size() > 1 && lastNbHistograms == 1))) {
     switchFromDetailedViewToSmallMultiples();
@@ -577,27 +550,26 @@ void HistogramView::draw() {
   if (lastNbHistograms != selectedProperties.size()) {
     centerView();
     lastNbHistograms = selectedProperties.size();
-    return;
-  }
-
-  gl->draw();
-  lastNbHistograms = selectedProperties.size();
+  } else
+    gl->draw();
 }
 
 void HistogramView::refresh() {
   getGlMainWidget()->redraw();
 }
 
-void HistogramView::graphChanged(Graph *) {
-  // We copy the value of "Nodes/Edges"
-  // in the new state in order to keep
-  // the user choice when changing graph
-  DataSet oldDs = state();
-  unsigned nodes = NODE;
-  oldDs.get("Nodes/Edges", nodes);
-  DataSet newDs;
-  newDs.set("Nodes/Edges", nodes);
-  setState(newDs);
+void HistogramView::graphChanged(Graph *g) {
+  DataSet ds = getState(g);
+  if (ds.empty()) {
+    // We copy the value of "Nodes/Edges"
+    // in the new state in order to keep
+    // the user choice when changing graph
+    DataSet oldDs = state();
+    unsigned nodes = NODE;
+    oldDs.get("Nodes/Edges", nodes);
+    ds.set("Nodes/Edges", nodes);
+  }
+  setState(ds);
   drawOverview();
 }
 
@@ -922,7 +894,7 @@ void HistogramView::registerTriggers() {
   }
 }
 
-void HistogramView::interactorsInstalled(const QList<tlp::Interactor *> &) {
+void HistogramView::interactorsInstalled(const std::list<tlp::Interactor *> &) {
   toggleInteractors(detailedHistogram != nullptr);
 }
 
@@ -943,10 +915,10 @@ void HistogramView::treatEvent(const Event &message) {
       if (graphEvent->getType() == GraphEvent::TLP_ADD_EDGE)
         addEdge(graphEvent->getGraph(), graphEvent->getEdge());
 
-      if (graphEvent->getType() == GraphEvent::TLP_DEL_NODE)
+      if (graphEvent->getType() == GraphEvent::TLP_AFTER_DEL_NODE)
         delNode(graphEvent->getGraph(), graphEvent->getNode());
 
-      if (graphEvent->getType() == GraphEvent::TLP_DEL_EDGE)
+      if (graphEvent->getType() == GraphEvent::TLP_AFTER_DEL_EDGE)
         delEdge(graphEvent->getGraph(), graphEvent->getEdge());
     }
   }
