@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -23,13 +23,15 @@
 #include <tulip/GlMainView.h>
 
 #include <vector>
-#include <unordered_map>
+#include <tulip/tuliphash.h>
 
 #include "../../utils/PluginNames.h"
 #include "Histogram.h"
 
 #include <tulip/OpenGlIncludes.h>
 
+class QGraphicsProxyWidget;
+
 namespace tlp {
 
 class Graph;
@@ -52,8 +54,8 @@ class QuickAccessBarImpl;
  * to nodes (or edges).
  *
  * This view also allows to map visual properties (colors, sizes, glyphs, ..) of the graph elements
- * with respect to a graph metric in a visual way. These operations can be done with the "Metric
- mapping"
+ * with respect to a graph metric in a visual way. These operations can be performed with the
+ "Metric mapping"
  * interactor. Many interactors are also bundled with the view to perform elements selection,
  statistical analysis, ...
  *
@@ -71,7 +73,7 @@ public:
                     "displayed for values associated to nodes (or edges).</p>"
                     "<p>This view also allows to map visual properties (colors, sizes, glyphs, ..) "
                     "of the graph elements with respect to a graph metric in a visual way. These "
-                    "operations can be done with the \"Metric mapping\" interactor. Many "
+                    "operations can be performed with the \"Metric mapping\" interactor. Many "
                     "interactors are also bundled with the view to perform elements selection, "
                     "statistical analysis, ...</p>",
                     "1.1", "View")
@@ -86,11 +88,12 @@ public:
   void setState(const DataSet &dataSet) override;
   DataSet state() const override;
   void graphChanged(Graph *graph) override;
+  void graphicsViewResized(int w, int h) override;
   Graph *histoGraph() {
     return _histoGraph;
   }
   bool eventFilter(QObject *object, QEvent *event) override;
-  QList<QWidget *> configurationWidgets() const override;
+  std::list<QWidget *> configurationWidgets() const override;
 
   std::vector<Histogram *> getHistograms() const;
   bool smallMultiplesViewSet() const {
@@ -137,20 +140,20 @@ public slots:
   void draw() override;
   void refresh() override;
   void applySettings() override;
+  void showPropertiesSelectionWidget();
 
 protected slots:
 
 private:
-  void interactorsInstalled(const QList<tlp::Interactor *> &) override;
+  void interactorsInstalled(const std::list<tlp::Interactor *> &) override;
   void registerTriggers();
-  void initGlWidget(Graph *graph);
+  void initGlWidget();
   void buildHistograms();
 
   void updateDetailedHistogramAxis();
   void destroyHistogramsIfNeeded();
   void cleanupGlScene();
-  void addEmptyViewLabel();
-  void removeEmptyViewLabel();
+  void propertiesSelected(bool);
 
   void setLayoutUpdateNeeded() {
     if (detailedHistogram)
@@ -170,6 +173,8 @@ private:
   ViewGraphPropertiesSelectionWidget *propertiesSelectionWidget;
   HistoOptionsWidget *histoOptionsWidget;
 
+  QGraphicsProxyWidget *noPropertyMsgBox;
+
   GlQuantitativeAxis *xAxisDetail, *yAxisDetail;
   Graph *_histoGraph, *emptyGraph;
   GlGraphComposite *emptyGlGraphComposite;
@@ -190,8 +195,6 @@ private:
   Coord centerBak;
   Coord upBak;
 
-  GlLabel *noDimsLabel, *noDimsLabel1;
-  GlLabel *noDimsLabel2;
   GlRect *emptyRect;
   GlRect *emptyRect2;
 
@@ -202,8 +205,8 @@ private:
   bool needUpdateHistogram;
 
   Graph *edgeAsNodeGraph;
-  std::unordered_map<edge, node> edgeToNode;
-  std::unordered_map<node, edge> nodeToEdge;
+  tlp_hash_map<edge, node> edgeToNode;
+  tlp_hash_map<node, edge> nodeToEdge;
 };
 } // namespace tlp
 
