@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -17,7 +17,6 @@
  *
  */
 
-#include <tulip/QtGlSceneZoomAndPanAnimator.h>
 #include <tulip/GlMainWidget.h>
 #include <tulip/Camera.h>
 
@@ -57,8 +56,8 @@ bool HistogramViewNavigator::eventFilter(QObject *widget, QEvent *e) {
 
   if (e->type() == QEvent::MouseMove && histoView->smallMultiplesViewSet()) {
     QMouseEvent *me = static_cast<QMouseEvent *>(e);
-    int x = glWidget->width() - me->x();
-    int y = me->y();
+    int x = glWidget->width() - me->pos().x();
+    int y = me->pos().y();
     Coord screenCoords(x, y, 0);
     Coord &&sceneCoords = glWidget->getScene()->getGraphCamera().viewportTo3DWorld(
         glWidget->screenToViewport(Coord(x, y, 0)));
@@ -66,16 +65,12 @@ bool HistogramViewNavigator::eventFilter(QObject *widget, QEvent *e) {
     return true;
   } else if (e->type() == QEvent::MouseButtonDblClick) {
     if (selectedHistoOverview != nullptr && histoView->smallMultiplesViewSet()) {
-      QtGlSceneZoomAndPanAnimator zoomAndPanAnimator(glWidget,
-                                                     selectedHistoOverview->getBoundingBox());
-      zoomAndPanAnimator.animateZoomAndPan();
+      histoView->zoomAndPanAnimation(selectedHistoOverview->getBoundingBox());
       histoView->switchFromSmallMultiplesToDetailedView(selectedHistoOverview);
       selectedHistoOverview = nullptr;
     } else if (!histoView->smallMultiplesViewSet()) {
       histoView->switchFromDetailedViewToSmallMultiples();
-      QtGlSceneZoomAndPanAnimator zoomAndPanAnimator(glWidget,
-                                                     histoView->getSmallMultiplesBoundingBox());
-      zoomAndPanAnimator.animateZoomAndPan();
+      histoView->zoomAndPanAnimation(histoView->getSmallMultiplesBoundingBox());
     }
 
     return true;
