@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -26,10 +26,10 @@
 #include "MatrixViewQuickAccessBar.h"
 
 #include <tulip/Graph.h>
+#include <tulip/GraphImpl.h>
 #include <tulip/IntegerProperty.h>
 #include <tulip/GlMainWidget.h>
 #include <tulip/TlpQtTools.h>
-#include <tulip/GlLabel.h>
 #include <tulip/GlGraphComposite.h>
 #include <tulip/GlyphManager.h>
 #include <tulip/ParametricCurves.h>
@@ -57,7 +57,6 @@ QuickAccessBar *MatrixView::getQuickAccessBarImpl() {
 }
 
 void MatrixView::setState(const DataSet &ds) {
-
   clearRedrawTriggers();
 
   setOverviewVisible(true);
@@ -115,13 +114,8 @@ void MatrixView::setState(const DataSet &ds) {
   enableEdgeColorInterpolation(status);
   _configurationWidget->setEdgeColorInterpolation(status);
 
-  bool quickAccessBarVisible = false;
-
-  if (ds.get<bool>("quickAccessBarVisible", quickAccessBarVisible)) {
-    needQuickAccessBar = true;
-    setQuickAccessBarVisible(quickAccessBarVisible);
-  } else // display quickaccessbar
-    setQuickAccessBarVisible(true);
+  setQuickAccessBarVisible(true);
+  GlMainView::setState(ds);
 }
 
 void MatrixView::showEdges(bool show) {
@@ -183,12 +177,13 @@ void MatrixView::setOriented(bool flag) {
   }
 }
 
-void MatrixView::graphChanged(Graph *) {
-  setState(DataSet());
+void MatrixView::graphChanged(Graph *g) {
+  setState(getState(g));
 }
 
 DataSet MatrixView::state() const {
-  DataSet ds;
+  DataSet ds = GlMainView::state();
+
   ds.set("show Edges", getGlMainWidget()
                            ->getScene()
                            ->getGlGraphComposite()
@@ -210,14 +205,11 @@ DataSet MatrixView::state() const {
   ds.set("ordering", _configurationWidget->orderingProperty());
   ds.set("oriented", _isOriented);
 
-  if (needQuickAccessBar)
-    ds.set("quickAccessBarVisible", quickAccessBarVisible());
-
   return ds;
 }
 
-QList<QWidget *> MatrixView::configurationWidgets() const {
-  return QList<QWidget *>() << _configurationWidget;
+std::list<QWidget *> MatrixView::configurationWidgets() const {
+  return std::list<QWidget *>{_configurationWidget};
 }
 
 void MatrixView::fillContextMenu(QMenu *menu, const QPointF &point) {
@@ -300,7 +292,7 @@ void MatrixView::initDisplayedGraph() {
     return;
   }
 
-  _matrixGraph = newGraph();
+  _matrixGraph = GraphImpl::newGraph();
   _matrixGraph->reserveNodes(2 * (graph()->numberOfNodes() + graph()->numberOfEdges()));
   _matrixGraph->reserveEdges(graph()->numberOfEdges());
 
@@ -446,10 +438,10 @@ void MatrixView::treatEvent(const Event &message) {
     if (graphEvent->getType() == GraphEvent::TLP_ADD_EDGE)
       addEdge(graphEvent->getGraph(), graphEvent->getEdge());
 
-    if (graphEvent->getType() == GraphEvent::TLP_DEL_NODE)
+    if (graphEvent->getType() == GraphEvent::TLP_AFTER_DEL_NODE)
       delNode(graphEvent->getGraph(), graphEvent->getNode());
 
-    if (graphEvent->getType() == GraphEvent::TLP_DEL_EDGE)
+    if (graphEvent->getType() == GraphEvent::TLP_AFTER_DEL_EDGE)
       delEdge(graphEvent->getGraph(), graphEvent->getEdge());
   }
 }
