@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -26,21 +26,23 @@
 #include "ParallelCoordsDrawConfigWidget.h"
 #include "QuantitativeParallelAxis.h"
 
+#include <QActionGroup>
 #include <QMenu>
-#include <QImageWriter>
-#include <QDir>
 #include <QGraphicsView>
+#include <QGraphicsProxyWidget>
+#include <QMessageBox>
 #include <QKeyEvent>
+#include <QPushButton>
 
-#include <tulip/GlTools.h>
+#include <tulip/GraphImpl.h>
 #include <tulip/GlLabel.h>
 #include <tulip/GlMainWidget.h>
 #include <tulip/Interactor.h>
-#include <tulip/GlTextureManager.h>
 #include <tulip/GlGraphComposite.h>
-#include <tulip/PropertyInterface.h>
-
-#include "../utils/ViewGraphPropertiesSelectionWidget.h"
+#include <tulip/Perspective.h>
+#include <tulip/ViewGraphPropertiesSelectionWidget.h>
+#include <tulip/WorkspacePanel.h>
+#include <tulip/NeedConfigurationMsgBox.h>
 
 using namespace std;
 
@@ -65,11 +67,11 @@ static void toggleGraphView(GlGraphComposite *glGraph, bool displayNodes) {
 PLUGIN(ParallelCoordinatesView)
 
 ParallelCoordinatesView::ParallelCoordinatesView(const PluginContext *)
-    : GlMainView(true), mainLayer(nullptr), axisSelectionLayer(nullptr), glGraphComposite(nullptr),
-      axisPointsGraph(nullptr), graphProxy(nullptr), parallelCoordsDrawing(nullptr),
-      dataConfigWidget(nullptr), drawConfigWidget(nullptr), firstSet(true),
-      lastNbSelectedProperties(0), center(false), lastViewWindowWidth(0), lastViewWindowHeight(0),
-      isConstruct(false), dontCenterViewAfterConfLoaded(false), needDraw(false) {}
+    : GlMainView(true), viewSetupMenu(nullptr), mainLayer(nullptr), axisSelectionLayer(nullptr),
+      glGraphComposite(nullptr), axisPointsGraph(nullptr), graphProxy(nullptr),
+      parallelCoordsDrawing(nullptr), dataConfigWidget(nullptr), drawConfigWidget(nullptr),
+      firstSet(true), lastNbSelectedProperties(0), center(false), lastViewWindowWidth(0),
+      lastViewWindowHeight(0), isConstruct(false), dontCenterViewAfterConfLoaded(false) {}
 
 ParallelCoordinatesView::~ParallelCoordinatesView() {
   for (auto obs : triggers()) {
@@ -81,6 +83,7 @@ ParallelCoordinatesView::~ParallelCoordinatesView() {
   graphProxy = nullptr;
   delete dataConfigWidget;
   delete drawConfigWidget;
+  delete viewSetupMenu;
 }
 
 QuickAccessBar *ParallelCoordinatesView::getQuickAccessBarImpl() {
@@ -89,7 +92,7 @@ QuickAccessBar *ParallelCoordinatesView::getQuickAccessBarImpl() {
   return _bar;
 }
 
-void ParallelCoordinatesView::interactorsInstalled(const QList<tlp::Interactor *> &) {
+void ParallelCoordinatesView::interactorsInstalled(const std::list<tlp::Interactor *> &) {
   toggleInteractors(graphProxy && graphProxy->getNumberOfSelectedProperties());
 }
 
@@ -105,7 +108,7 @@ void ParallelCoordinatesView::initGlWidget() {
     scene->addExistingLayer(mainLayer);
   }
 
-  axisPointsGraph = tlp::newGraph();
+  axisPointsGraph = GraphImpl::newGraph();
   glGraphComposite = new GlGraphComposite(axisPointsGraph);
   mainLayer->addGlEntity(glGraphComposite, "graph");
   axisSelectionLayer = new GlLayer("Axis selection layer");
@@ -122,8 +125,15 @@ void ParallelCoordinatesView::initGlWidget() {
   getGlMainWidget()->setMouseTracking(true);
 }
 
-QList<QWidget *> ParallelCoordinatesView::configurationWidgets() const {
-  return QList<QWidget *>() << dataConfigWidget << drawConfigWidget;
+std::list<QWidget *> ParallelCoordinatesView::configurationWidgets() const {
+  return std::list<QWidget *>{dataConfigWidget, drawConfigWidget};
+}
+
+void ParallelCoordinatesView::graphicsViewResized(int w, int h) {
+  if (isConstruct) {
+    noPropertyMsgBox->setPos(w / 2 - noPropertyMsgBox->sceneBoundingRect().width() / 2,
+                             h / 2 - noPropertyMsgBox->sceneBoundingRect().height() / 2);
+  }
 }
 
 void ParallelCoordinatesView::setState(const DataSet &dataSet) {
@@ -131,18 +141,34 @@ void ParallelCoordinatesView::setState(const DataSet &dataSet) {
   if (!isConstruct) {
     initGlWidget();
     buildContextMenu();
-    setOverviewVisible(true);
     getGlMainWidget()->installEventFilter(this);
 
     dataConfigWidget = new ViewGraphPropertiesSelectionWidget();
     drawConfigWidget = new ParallelCoordsDrawConfigWidget();
 
     isConstruct = true;
+
+    // create box indicating the lack of selected properties
+    QGraphicsRectItem *qgrItem = new QGraphicsRectItem(0, 0, 1, 1);
+    qgrItem->setBrush(Qt::transparent);
+    qgrItem->setPen(QPen(Qt::transparent));
+    graphicsView()->scene()->addItem(qgrItem);
+
+    QPushButton *okButton;
+    QWidget *msgBox =
+        new_NeedConfigurationMsgBox("<b><font size=\"+1\">"
+                                    "No graph properties selected.</font></b><br/><br/>"
+                                    "Open the <b>Properties</b> configuration tab<br/>"
+                                    "to proceed.",
+                                    &okButton);
+    connect(okButton, SIGNAL(released()), this, SLOT(showPropertiesSelectionWidget()));
+    connect(okButton, SIGNAL(released()), msgBox, SLOT(hide()));
+    noPropertyMsgBox = graphicsView()->scene()->addWidget(msgBox);
+    noPropertyMsgBox->setParentItem(qgrItem);
   }
 
-  GlMainView::setState(dataSet);
-
   removeTriggers();
+  dontCenterViewAfterConfLoaded = false;
 
   vector<string> selectedPropertiesBak;
 
@@ -309,13 +335,8 @@ void ParallelCoordinatesView::setState(const DataSet &dataSet) {
     dataConfigWidget->setWidgetParameters(nullptr, propertiesTypesFilter);
   }
 
-  bool quickAccessBarVisible = false;
-
-  if (dataSet.get<bool>("quickAccessBarVisible", quickAccessBarVisible)) {
-    needQuickAccessBar = true;
-    setQuickAccessBarVisible(quickAccessBarVisible);
-  } else
-    setQuickAccessBarVisible(true);
+  setQuickAccessBarVisible(true);
+  GlMainView::setState(dataSet);
 
   setupAndDrawView();
 }
@@ -357,15 +378,17 @@ DataSet ParallelCoordinatesView::state() const {
   dataSet.set("lastViewWindowWidth", getGlMainWidget()->width());
   dataSet.set("lastViewWindowHeight", getGlMainWidget()->height());
 
-  if (needQuickAccessBar)
-    dataSet.set("quickAccessBarVisible", quickAccessBarVisible());
-
   return dataSet;
 }
 
-void ParallelCoordinatesView::graphChanged(tlp::Graph *) {
+void ParallelCoordinatesView::showPropertiesSelectionWidget() {
+  WorkspacePanel *wp = static_cast<WorkspacePanel *>(graphicsView()->parentWidget());
+  wp->showConfigurationTab("Properties");
+}
+
+void ParallelCoordinatesView::graphChanged(tlp::Graph *g) {
   if (isConstruct)
-    setState(DataSet());
+    setState(getState(g));
   else if (quickAccessBarVisible()) {
     _quickAccessBar->setEnabled(false);
   }
@@ -389,102 +412,52 @@ void ParallelCoordinatesView::updateWithProgressBar() {
   }
 }
 
-void ParallelCoordinatesView::addEmptyViewLabel() {
-  Color backgroundColor(drawConfigWidget->getBackgroundColor());
-  getGlMainWidget()->getScene()->setBackgroundColor(backgroundColor);
-
-  Color foregroundColor;
-  int bgV = backgroundColor.getV();
-
-  if (bgV < 128) {
-    foregroundColor = Color(255, 255, 255);
-  } else {
-    foregroundColor = Color(0, 0, 0);
-  }
-
-  GlLabel *noDimsLabel = new GlLabel(Coord(0, 0, 0), Size(200, 200), foregroundColor);
-  noDimsLabel->setText(ViewName::ParallelCoordinatesViewName);
-  mainLayer->addGlEntity(noDimsLabel, "no dimensions label");
-  GlLabel *noDimsLabel1 =
-      new GlLabel(Coord(0.0f, -50.0f, 0.0f), Size(400.0f, 200.0f), foregroundColor);
-  noDimsLabel1->setText("No graph properties selected.");
-  mainLayer->addGlEntity(noDimsLabel1, "no dimensions label 1");
-  GlLabel *noDimsLabel2 =
-      new GlLabel(Coord(0.0f, -100.0f, 0.0f), Size(700.0f, 200.0f), foregroundColor);
-  noDimsLabel2->setText("Go to the \"Properties\" tab in top right corner.");
-  mainLayer->addGlEntity(noDimsLabel2, "no dimensions label 2");
-  mainLayer->deleteGlEntity(parallelCoordsDrawing);
-  mainLayer->deleteGlEntity(glGraphComposite);
-}
-
-void ParallelCoordinatesView::removeEmptyViewLabel() {
-  GlSimpleEntity *noDimsLabel = mainLayer->findGlEntity("no dimensions label");
-  GlSimpleEntity *noDimsLabel1 = mainLayer->findGlEntity("no dimensions label 1");
-  GlSimpleEntity *noDimsLabel2 = mainLayer->findGlEntity("no dimensions label 2");
-
-  if (noDimsLabel != nullptr) {
-    mainLayer->deleteGlEntity(noDimsLabel);
-    delete noDimsLabel;
-    mainLayer->deleteGlEntity(noDimsLabel1);
-    delete noDimsLabel1;
-    mainLayer->deleteGlEntity(noDimsLabel2);
-    delete noDimsLabel2;
-
+void ParallelCoordinatesView::propertiesSelected(bool flag) {
+  noPropertyMsgBox->setVisible(!flag);
+  toggleInteractors(flag);
+  if (quickAccessBarVisible())
+    _quickAccessBar->setEnabled(flag);
+  setOverviewVisible(flag);
+  if (flag) {
     if (parallelCoordsDrawing)
       mainLayer->addGlEntity(parallelCoordsDrawing, "Parallel Coordinates");
 
     mainLayer->addGlEntity(glGraphComposite, "graph");
+  } else {
+    mainLayer->deleteGlEntity(parallelCoordsDrawing);
+    mainLayer->deleteGlEntity(glGraphComposite);
   }
 }
 
 void ParallelCoordinatesView::draw() {
-  if (graph()) {
-    if (graphProxy->selectedPropertiesisEmpty()) {
-      removeEmptyViewLabel();
-      addEmptyViewLabel();
-      toggleInteractors(false);
-      if (quickAccessBarVisible())
-        _quickAccessBar->setEnabled(false);
-      getGlMainWidget()->getScene()->centerScene();
-      getGlMainWidget()->draw();
-      return;
-    } else {
-      removeEmptyViewLabel();
-      if (quickAccessBarVisible())
-        _quickAccessBar->setEnabled(true);
-      toggleInteractors(true);
-      if (graphProxy->getDataCount() > PROGRESS_BAR_DISPLAY_NB_DATA_THRESHOLD) {
-        updateWithProgressBar();
-      } else {
-        updateWithoutProgressBar();
-      }
-    }
+  GlMainWidget *gl = getGlMainWidget();
 
-    if (lastNbSelectedProperties != graphProxy->getNumberOfSelectedProperties() || center) {
-      if (!dontCenterViewAfterConfLoaded) {
-        centerView();
-      } else {
-        dontCenterViewAfterConfLoaded = false;
-      }
-
-      center = false;
-    } else {
-      getGlMainWidget()->draw();
-    }
-
-    lastNbSelectedProperties = graphProxy->getNumberOfSelectedProperties();
+  if (graphProxy->selectedPropertiesisEmpty()) {
+    propertiesSelected(false);
+    gl->getScene()->centerScene();
+    gl->draw();
+    lastNbSelectedProperties = 0;
+    return;
+  }
+  propertiesSelected(true);
+  if (graphProxy->getDataCount() > PROGRESS_BAR_DISPLAY_NB_DATA_THRESHOLD) {
+    updateWithProgressBar();
   } else {
-    getGlMainWidget()->draw();
+    updateWithoutProgressBar();
   }
 
-  needDraw = false;
-}
+  if (lastNbSelectedProperties != graphProxy->getNumberOfSelectedProperties() || center) {
+    if (!dontCenterViewAfterConfLoaded) {
+      centerView();
+    } else {
+      dontCenterViewAfterConfLoaded = false;
+    }
 
-void ParallelCoordinatesView::refresh() {
-  if (!needDraw)
-    getGlMainWidget()->redraw();
-  else
-    draw();
+    center = false;
+  } else {
+    gl->draw();
+  }
+  lastNbSelectedProperties = graphProxy->getNumberOfSelectedProperties();
 }
 
 void ParallelCoordinatesView::init() {
@@ -714,7 +687,6 @@ void ParallelCoordinatesView::setupAndDrawView() {
   }
 
   registerTriggers();
-  needDraw = true;
   draw();
   drawOverview(true);
 }
