@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -17,12 +17,10 @@
  *
  */
 
-#include <tulip/TlpTools.h>
 #include <tulip/GlPolygon.h>
 #include <tulip/GlLabel.h>
 #include <tulip/GlQuad.h>
 #include <tulip/GlLines.h>
-#include <tulip/GlSimpleEntity.h>
 #include <tulip/GlMainWidget.h>
 
 #include "ParallelCoordinatesView.h"
@@ -387,12 +385,12 @@ bool ParallelCoordsAxisBoxPlot::eventFilter(QObject *widget, QEvent *e) {
 
   if (e->type() == QEvent::MouseMove) {
     QMouseEvent *me = static_cast<QMouseEvent *>(e);
-    int x = glWidget->width() - me->x();
-    int y = me->y();
+    int x = glWidget->width() - me->pos().x();
+    int y = me->pos().y();
     Coord screenCoords(x, y, 0.0f);
     Coord sceneCoords(glWidget->getScene()->getLayer("Main")->getCamera().viewportTo3DWorld(
         glWidget->screenToViewport(screenCoords)));
-    selectedAxis = parallelView->getAxisUnderPointer(me->x(), me->y());
+    selectedAxis = parallelView->getAxisUnderPointer(me->pos().x(), me->pos().y());
 
     if (selectedAxis != nullptr) {
       QuantitativeParallelAxis *qaxis = dynamic_cast<QuantitativeParallelAxis *>(selectedAxis);
