@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (www.tulip-software.org)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -27,20 +27,18 @@ namespace pocore {
 class FishEyesScreen : public ScreenFunction {
 
 public:
-  FishEyesScreen ();
-  Vec2f  project (const Vec2f& )const ;
-  Vec2f  unproject (const Vec2f& )const ;
-  void   setCenter (double x, double y);
-  void   setRadius (double r);
+  FishEyesScreen();
+  Vec2f project(const Vec2f &) const override;
+  Vec2f unproject(const Vec2f &) const override;
+  void setCenter(double x, double y);
+  void setRadius(double r);
   double getRadius();
-  void   setHeight (double h);
-
+  void setHeight(double h);
 
 private:
   double R;
   double k;
   Vec2f fisheyesCenter;
 };
-}
-#endif //FISHEYESSCREEN_H
-
+} // namespace pocore
+#endif // FISHEYESSCREEN_H
