@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -65,13 +65,8 @@ public:
     return imageSize[1];
   }
 
-  void changeZoom(int i);
-
-  void backupScreenFunctionsParameters();
   void setScreenFunctionsParameters(double zoom, double translationX, double translationY,
                                     double fishEyeRadius);
-  void restoreScreenFunctionsParameters();
-
   unsigned int getCenterItem() const {
     return centerItem;
   }
@@ -79,9 +74,6 @@ public:
     this->centerItem = centerItem;
   }
 
-  void setLastMousePosition(const int x, const int y);
-  void updateFishEyePosition(const int x, const int y, DimensionBase *data);
-  void translateFishEye(const int x, const int y);
   Vec2i getFishEyeTranslationVector() const {
     return fishTranslation;
   }
@@ -104,8 +96,6 @@ private:
   FishEyesScreen *trans1;
   UniformDeformationScreen *trans2;
 
-  double zoomBak, translationXBak, translationYBak, fishEyeRadiusBak;
-
   unsigned int centerItem;
 
   double zoom;
