@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -20,12 +20,8 @@
 #include <fstream>
 #include <cmath>
 
-#include <QTimer>
-
-#include <tulip/TlpTools.h>
 #include <tulip/Graph.h>
 #include <tulip/GlMainWidget.h>
-#include <tulip/GlRect.h>
 #include <tulip/GlGraphComposite.h>
 #include <tulip/GlLayer.h>
 #include <tulip/GlLabel.h>
@@ -38,17 +34,20 @@
 #include <tulip/tulipconf.h>
 #include <tulip/TlpQtTools.h>
 #include <tulip/Perspective.h>
+#include <tulip/ViewGraphPropertiesSelectionWidget.h>
+#include <tulip/WorkspacePanel.h>
+#include <tulip/NeedConfigurationMsgBox.h>
 
 #include "PixelOrientedInteractors.h"
 #include "PixelOrientedView.h"
 #include "PixelOrientedViewQuickAccessBar.h"
 
-#include "../utils/ViewGraphPropertiesSelectionWidget.h"
-
-#include <QApplication>
+#include <QAbstractButton>
 #include <QGraphicsView>
-#include <QMainWindow>
+#include <QGraphicsProxyWidget>
+#include <QMessageBox>
 #include <QProgressDialog>
+#include <QPushButton>
 #include <QTimer>
 
 using namespace std;
@@ -57,7 +56,6 @@ using namespace pocore;
 static void setGraphView(tlp::GlGraphComposite *glGraph, bool displayNodes) {
   tlp::GlGraphRenderingParameters param = glGraph->getRenderingParameters();
   param.setAntialiasing(true);
-  param.setViewNodeLabel(true);
   param.setFontsType(2);
   param.setSelectedNodesStencil(1);
   param.setNodesStencil(0xFFFF);
@@ -102,8 +100,8 @@ PixelOrientedView::~PixelOrientedView() {
   delete graphComposite;
 }
 
-QList<QWidget *> PixelOrientedView::configurationWidgets() const {
-  return QList<QWidget *>() << propertiesSelectionWidget << optionsWidget;
+std::list<QWidget *> PixelOrientedView::configurationWidgets() const {
+  return std::list<QWidget *>{propertiesSelectionWidget, optionsWidget};
 }
 
 void PixelOrientedView::initGlWidget() {
@@ -112,31 +110,25 @@ void PixelOrientedView::initGlWidget() {
   if (mainLayer == nullptr) {
     mainLayer = new GlLayer("Main");
     getGlMainWidget()->getScene()->addExistingLayer(mainLayer);
-  }
-
-  if (mainLayer->findGlEntity("graph")) {
-    GlGraphComposite *lastGraphComposite =
-        static_cast<GlGraphComposite *>(mainLayer->findGlEntity("graph"));
-    Graph *theGraph = lastGraphComposite->getInputData()->getGraph();
-
-    if (theGraph)
-      theGraph->removeListener(lastGraphComposite);
-  }
-
-  if (overviewsComposite != nullptr) {
+  } else {
     overviewsComposite->reset(true);
+    // detailedOverview may have been deleted by previous call
     detailOverview = nullptr;
+    overviewsMap.clear();
+    mainLayer->getComposite()->reset(true);
+    // graphComposite may have been deleted by previous call
+    graphComposite = nullptr;
   }
-
-  mainLayer->getComposite()->reset(true);
-
   overviewsComposite = new GlComposite();
   mainLayer->addGlEntity(overviewsComposite, "overview composite");
 
   detailViewLabel = nullptr;
 
+  GlGraphComposite *lastGraphComposite = graphComposite;
   graphComposite = new GlGraphComposite(pixelOrientedGraph);
   mainLayer->addGlEntity(graphComposite, "graph");
+  delete lastGraphComposite;
+
   setGraphView(graphComposite, false);
 }
 
@@ -148,8 +140,14 @@ void PixelOrientedView::setLayoutFunction(pocore::LayoutFunction *layoutFunction
   pixelOrientedMediator->setLayoutFunction(layoutFunction);
 }
 
-void PixelOrientedView::setState(const DataSet &dataSet) {
+void PixelOrientedView::graphicsViewResized(int w, int h) {
+  if (isConstruct) {
+    noPropertyMsgBox->setPos(w / 2 - noPropertyMsgBox->sceneBoundingRect().width() / 2,
+                             h / 2 - noPropertyMsgBox->sceneBoundingRect().height() / 2);
+  }
+}
 
+void PixelOrientedView::setState(const DataSet &dataSet) {
   if (!isConstruct) {
     isConstruct = true;
     propertiesSelectionWidget = new ViewGraphPropertiesSelectionWidget();
@@ -157,40 +155,31 @@ void PixelOrientedView::setState(const DataSet &dataSet) {
     pixelOrientedMediator = new PixelOrientedMediator(spiralLayout, nullptr);
     optionsWidget = new PixelOrientedOptionsWidget();
     layoutFunctionsMap["Spiral"] = spiralLayout;
-    setOverviewVisible(true);
+
+    // create box indicating the lack of selected properties
+    QGraphicsRectItem *qgrItem = new QGraphicsRectItem(0, 0, 1, 1);
+    qgrItem->setBrush(Qt::transparent);
+    qgrItem->setPen(QPen(Qt::transparent));
+    graphicsView()->scene()->addItem(qgrItem);
+
+    QPushButton *okButton;
+    QWidget *msgBox =
+        new_NeedConfigurationMsgBox("<b><font size=\"+1\">"
+                                    "No graph properties selected.</font></b><br/><br/>"
+                                    "Open the <b>Properties</b> configuration tab<br/>"
+                                    "to proceed.",
+                                    &okButton);
+    connect(okButton, SIGNAL(released()), this, SLOT(showPropertiesSelectionWidget()));
+    connect(okButton, SIGNAL(released()), msgBox, SLOT(hide()));
+    noPropertyMsgBox = graphicsView()->scene()->addWidget(msgBox);
+    noPropertyMsgBox->setParentItem(qgrItem);
   }
+  if (!smallMultiplesView)
+    switchFromDetailViewToSmallMultiples();
 
-  GlMainView::setState(dataSet);
+  Graph *lastGraph = pixelOrientedGraph;
 
-  Graph *lastGraph = this->pixelOrientedGraph;
-
-  if (graph() == nullptr) {
-    this->pixelOrientedGraph = graph();
-    destroyData();
-    initGlWidget();
-    lastNbNodes = 0;
-
-    if (lastGraph != nullptr && lastGraph != pixelOrientedGraph) {
-      overviewsComposite->reset(true);
-      overviewsMap.clear();
-      detailOverview = nullptr;
-      newGraphSet = true;
-    }
-
-    for (auto obs : triggers()) {
-      removeRedrawTrigger(obs);
-    }
-
-    propertiesSelectionWidget->setWidgetParameters(nullptr, propertiesTypesFilter);
-
-    center = true;
-    draw();
-    center = false;
-
-    return;
-  }
-
-  if (tulipNodeColorMapping != nullptr && this->pixelOrientedGraph != graph()) {
+  if (tulipNodeColorMapping != nullptr && pixelOrientedGraph != graph()) {
     delete tulipNodeColorMapping;
     tulipNodeColorMapping = nullptr;
   }
@@ -201,7 +190,7 @@ void PixelOrientedView::setState(const DataSet &dataSet) {
   }
 
   if (lastGraph == nullptr || lastGraph != graph()) {
-    this->pixelOrientedGraph = graph();
+    pixelOrientedGraph = graph();
     initGlWidget();
     destroyData();
     lastNbNodes = pixelOrientedGraph->numberOfNodes();
@@ -234,6 +223,7 @@ void PixelOrientedView::setState(const DataSet &dataSet) {
   DataSet selectedGraphPropertiesDataSet;
 
   if (dataSet.get("selected graph properties", selectedGraphPropertiesDataSet)) {
+    selectedGraphProperties.clear();
     haveSelectedGraphProperties = true;
     int i = 0;
     ostringstream oss;
@@ -263,33 +253,22 @@ void PixelOrientedView::setState(const DataSet &dataSet) {
     }
   }
 
-  string detailOverviewName;
-  dataSet.get("detail overview  name", detailOverviewName);
-
   center = true;
-
   if (haveSelectedGraphProperties) {
     updateOverviews(true);
-    getGlMainWidget()->centerScene();
   }
-
-  bool quickAccessBarVisible = false;
-
-  if (dataSet.get<bool>("quickAccessBarVisible", quickAccessBarVisible)) {
-    needQuickAccessBar = true;
-    setQuickAccessBarVisible(quickAccessBarVisible);
-  } else // display quickaccessbar
-    setQuickAccessBarVisible(true);
-
   draw();
-  center = false;
 
+  registerTriggers();
+
+  string detailOverviewName;
+  dataSet.get("detail overview name", detailOverviewName);
   if (!detailOverviewName.empty()) {
     switchFromSmallMultiplesToDetailView(overviewsMap[detailOverviewName]);
   }
 
-  drawOverview(true);
-  registerTriggers();
+  setQuickAccessBarVisible(true);
+  GlMainView::setState(dataSet);
 }
 
 DataSet PixelOrientedView::state() const {
@@ -308,17 +287,19 @@ DataSet PixelOrientedView::state() const {
   dataSet.set("layout", optionsWidget->getLayoutType());
   dataSet.set("lastViewWindowWidth", getGlMainWidget()->width());
   dataSet.set("lastViewWindowHeight", getGlMainWidget()->height());
-  dataSet.set("detail overview  name", detailOverviewPropertyName);
+  dataSet.set("detail overview name", detailOverviewPropertyName);
   dataSet.set("background color", optionsWidget->getBackgroundColor());
 
-  if (needQuickAccessBar)
-    dataSet.set("quickAccessBarVisible", quickAccessBarVisible());
-
   return dataSet;
 }
 
-void PixelOrientedView::graphChanged(Graph *) {
-  setState(DataSet());
+void PixelOrientedView::showPropertiesSelectionWidget() {
+  WorkspacePanel *wp = static_cast<WorkspacePanel *>(graphicsView()->parentWidget());
+  wp->showConfigurationTab("Properties");
+}
+
+void PixelOrientedView::graphChanged(Graph *g) {
+  setState(getState(g));
 }
 
 void PixelOrientedView::initLayoutFunctions() {
@@ -452,118 +433,82 @@ void PixelOrientedView::destroyData() {
   dataMap.clear();
 }
 
-void PixelOrientedView::addEmptyViewLabel() {
-  Color backgroundColor(optionsWidget->getBackgroundColor());
-  getGlMainWidget()->getScene()->setBackgroundColor(backgroundColor);
-
-  Color textColor = getTextColor();
-
-  GlLabel *noDimsLabel = new GlLabel(Coord(0.0f, 0.0f, 0.0f), Size(200.0f, 200.0f), textColor);
-  noDimsLabel->setText(ViewName::PixelOrientedViewName);
-  mainLayer->addGlEntity(noDimsLabel, "no dimensions label");
-  GlLabel *noDimsLabel1 = new GlLabel(Coord(0.0f, -50.0f, 0.0f), Size(400.0f, 200.0f), textColor);
-  noDimsLabel1->setText("No graph properties selected.");
-  mainLayer->addGlEntity(noDimsLabel1, "no dimensions label 1");
-  GlLabel *noDimsLabel2 = new GlLabel(Coord(0.0f, -100.0f, 0.0f), Size(700.0f, 200.0f), textColor);
-  noDimsLabel2->setText("Go to the \"Properties\" tab in top right corner.");
-  mainLayer->addGlEntity(noDimsLabel2, "no dimensions label 2");
-
-  mainLayer->deleteGlEntity(graphComposite);
-}
-
-void PixelOrientedView::removeEmptyViewLabel() {
-  GlSimpleEntity *noDimsLabel = mainLayer->findGlEntity("no dimensions label");
-  GlSimpleEntity *noDimsLabel1 = mainLayer->findGlEntity("no dimensions label 1");
-  GlSimpleEntity *noDimsLabel2 = mainLayer->findGlEntity("no dimensions label 2");
-
-  if (noDimsLabel != nullptr) {
-    mainLayer->deleteGlEntity(noDimsLabel);
-    delete noDimsLabel;
-    mainLayer->deleteGlEntity(noDimsLabel1);
-    delete noDimsLabel1;
-    mainLayer->deleteGlEntity(noDimsLabel2);
-    delete noDimsLabel2;
-
-    mainLayer->addGlEntity(graphComposite, "graph");
-  }
-}
-
 void PixelOrientedView::generatePixelOverview(PixelOrientedOverview *pixelOverview) {
   pixelOverview->computePixelView();
   overviewGenMap[pixelOverview->getDimensionName()] = true;
 }
 
+void PixelOrientedView::propertiesSelected(bool flag) {
+  noPropertyMsgBox->setVisible(!flag);
+  if (quickAccessBarVisible())
+    _quickAccessBar->setEnabled(flag);
+  setOverviewVisible(flag);
+  if (flag)
+    mainLayer->addGlEntity(graphComposite, "graph");
+  else
+    mainLayer->deleteGlEntity(graphComposite);
+}
+
 void PixelOrientedView::draw() {
   GlMainWidget *glw = getGlMainWidget();
   GlScene *scene = glw->getScene();
 
-  if (pixelOrientedGraph != nullptr) {
-    scene->setBackgroundColor(optionsWidget->getBackgroundColor());
-    unsigned int lastNbDimensionsSelected = selectedGraphProperties.size();
-    destroyOverviewsIfNeeded();
+  scene->setBackgroundColor(optionsWidget->getBackgroundColor());
+  unsigned int lastNbDimensionsSelected = selectedGraphProperties.size();
+  destroyOverviewsIfNeeded();
 
-    if (pixelOrientedGraph->numberOfNodes() >= 2) // We stop the creation of pixel overviews if we
-                                                  // have less than 2 nodes as we need at least two
-                                                  // to compute sizes for overview
-      initPixelView();
-    else
-      selectedGraphProperties.clear();
+  if (pixelOrientedGraph->numberOfNodes() >= 2) // We stop the creation of pixel overviews if we
+    // have less than 2 nodes as we need at least two
+    // to compute sizes for overview
+    initPixelView();
+  else
+    selectedGraphProperties.clear();
 
-    if (selectedGraphProperties.empty()) {
-      if (!smallMultiplesView) {
-        switchFromDetailViewToSmallMultiples();
-      }
-
-      removeEmptyViewLabel();
-      addEmptyViewLabel();
-      if (quickAccessBarVisible())
-        _quickAccessBar->setEnabled(false);
-      scene->centerScene();
-      glw->draw();
-      return;
-    } else {
-      removeEmptyViewLabel();
-      if (quickAccessBarVisible())
-        _quickAccessBar->setEnabled(true);
-    }
-
-    if (lastNbDimensionsSelected != selectedGraphProperties.size()) {
-      center = true;
-    }
-
-    if (!smallMultiplesView && lastNbDimensionsSelected == 1 &&
-        selectedGraphProperties.size() > 1) {
+  if (selectedGraphProperties.empty()) {
+    if (!smallMultiplesView) {
       switchFromDetailViewToSmallMultiples();
-    } else if (selectedGraphProperties.size() == 1) {
-      glw->makeCurrent();
-      overviewsMap[selectedGraphProperties[0]]->computePixelView();
-      overviewGenMap[selectedGraphProperties[0]] = true;
-      switchFromSmallMultiplesToDetailView(overviewsMap[selectedGraphProperties[0]]);
-    } else if (!smallMultiplesView && detailOverview != nullptr) {
-      detailOverview->computePixelView();
-      smallMultiplesNeedUpdate = true;
-
-      if (newGraphSet) {
-        switchFromSmallMultiplesToDetailView(detailOverview);
-        newGraphSet = false;
-      }
-    } else if (!smallMultiplesView && detailOverview == nullptr) {
-      switchFromDetailViewToSmallMultiples();
-    } else {
-      glw->makeCurrent();
-      updateOverviews(true);
     }
 
-    if (!smallMultiplesView && detailViewLabel != nullptr) {
-      detailViewLabel->setColor(getTextColor());
-    }
+    propertiesSelected(false);
+    glw->centerScene();
+    return;
+  }
 
-    if (center) {
-      centerView();
-      center = false;
-    } else {
-      glw->draw();
+  propertiesSelected(true);
+
+  if (lastNbDimensionsSelected != selectedGraphProperties.size()) {
+    center = true;
+  }
+
+  if (!smallMultiplesView && lastNbDimensionsSelected == 1 && selectedGraphProperties.size() > 1) {
+    switchFromDetailViewToSmallMultiples();
+  } else if (selectedGraphProperties.size() == 1) {
+    glw->makeCurrent();
+    overviewsMap[selectedGraphProperties[0]]->computePixelView();
+    overviewGenMap[selectedGraphProperties[0]] = true;
+    switchFromSmallMultiplesToDetailView(overviewsMap[selectedGraphProperties[0]]);
+  } else if (!smallMultiplesView && detailOverview != nullptr) {
+    detailOverview->computePixelView();
+    smallMultiplesNeedUpdate = true;
+
+    if (newGraphSet) {
+      switchFromSmallMultiplesToDetailView(detailOverview);
+      newGraphSet = false;
     }
+  } else if (!smallMultiplesView && detailOverview == nullptr) {
+    switchFromDetailViewToSmallMultiples();
+  } else {
+    glw->makeCurrent();
+    updateOverviews(true);
+  }
+
+  if (!smallMultiplesView && detailViewLabel != nullptr) {
+    detailViewLabel->setColor(getTextColor());
+  }
+
+  if (center) {
+    centerView();
+    center = false;
   } else {
     glw->draw();
   }
@@ -612,24 +557,24 @@ void PixelOrientedView::centerView(bool) {
 }
 
 void PixelOrientedView::updateOverviews(const bool updateAll) {
-
-  if (smallMultiplesView) {
-    mainLayer->deleteGlEntity(overviewsComposite);
-  } else {
-    setGraphView(graphComposite, false);
-    mainLayer->deleteGlEntity(detailViewLabel);
-  }
-
   unsigned int nbOverviews = selectedGraphProperties.size();
-  unsigned currentStep = 0;
-  Camera &cam = getGlMainWidget()->getScene()->getGraphCamera();
-  double sceneRadiusBak = cam.getSceneRadius();
-  double zoomFactorBak = cam.getZoomFactor();
-  Coord eyesBak = cam.getEyes();
-  Coord centerBak = cam.getCenter();
-  Coord upBak = cam.getUp();
 
   if (nbOverviews) {
+    if (smallMultiplesView) {
+      mainLayer->deleteGlEntity(overviewsComposite);
+    } else {
+      setGraphView(graphComposite, false);
+      mainLayer->deleteGlEntity(detailViewLabel);
+    }
+
+    unsigned currentStep = 0;
+    Camera &cam = getGlMainWidget()->getScene()->getGraphCamera();
+    double sceneRadiusBak = cam.getSceneRadius();
+    double zoomFactorBak = cam.getZoomFactor();
+    Coord eyesBak = cam.getEyes();
+    Coord centerBak = cam.getCenter();
+    Coord upBak = cam.getUp();
+
     QProgressDialog progress(Perspective::instance()->mainWindow());
     progress.setCancelButton(nullptr);
     progress.setWindowTitle("Computing pixel oriented view for: ");
@@ -649,22 +594,22 @@ void PixelOrientedView::updateOverviews(const bool updateAll) {
         progress.setValue(++currentStep);
       }
     }
+
+    if (smallMultiplesView) {
+      mainLayer->addGlEntity(overviewsComposite, "overviews composite");
+    } else {
+      setGraphView(graphComposite, true);
+      mainLayer->addGlEntity(detailViewLabel, "dimension label");
+    }
+
+    cam.setSceneRadius(sceneRadiusBak);
+    cam.setZoomFactor(zoomFactorBak);
+    cam.setEyes(eyesBak);
+    cam.setCenter(centerBak);
+    cam.setUp(upBak);
+
+    getGlMainWidget()->draw();
   }
-
-  if (smallMultiplesView) {
-    mainLayer->addGlEntity(overviewsComposite, "overviews composite");
-  } else {
-    setGraphView(graphComposite, true);
-    mainLayer->addGlEntity(detailViewLabel, "dimension label");
-  }
-
-  cam.setSceneRadius(sceneRadiusBak);
-  cam.setZoomFactor(zoomFactorBak);
-  cam.setEyes(eyesBak);
-  cam.setCenter(centerBak);
-  cam.setUp(upBak);
-
-  getGlMainWidget()->draw();
 }
 
 vector<PixelOrientedOverview *> PixelOrientedView::getOverviews() {
@@ -726,11 +671,8 @@ void PixelOrientedView::switchFromSmallMultiplesToDetailView(PixelOrientedOvervi
     propertiesSelectionWidget->setEnabled(false);
   }
 
-  if (tlp::inGuiTestingMode())
-    // sometimes we must wait a bit to ensure an effective centerView
-    QTimer::singleShot(200, this, SLOT(centerView()));
-  else
-    centerView();
+  // sometimes we must wait a bit to ensure an effective centerView
+  QTimer::singleShot(200, this, SLOT(centerView()));
 }
 
 void PixelOrientedView::switchFromDetailViewToSmallMultiples() {
@@ -761,7 +703,7 @@ BoundingBox PixelOrientedView::getSmallMultiplesViewBoundingBox() {
   return glBBSV.getBoundingBox();
 }
 
-void PixelOrientedView::interactorsInstalled(const QList<tlp::Interactor *> &) {
+void PixelOrientedView::interactorsInstalled(const std::list<tlp::Interactor *> &) {
   toggleInteractors(detailOverview != nullptr);
 }
 
@@ -805,6 +747,7 @@ void PixelOrientedView::applySettings() {
       mainLayer->addGlEntity(detailViewLabel, "dimension label");
       centerView();
     }
+    drawOverview(true);
   }
 }
 } // namespace tlp
