@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -40,6 +40,8 @@
 #include "PixelOrientedOverview.h"
 #include "PixelOrientedOptionsWidget.h"
 
+class QGraphicsProxyWidget;
+
 namespace tlp {
 
 class ViewGraphPropertiesSelectionWidget;
@@ -94,11 +96,12 @@ public:
   QuickAccessBar *getQuickAccessBarImpl() override;
   void setState(const DataSet &dataSet) override;
   DataSet state() const override;
+  void graphicsViewResized(int w, int h) override;
   Graph *getPixelOrientedGraph() {
     return pixelOrientedGraph;
   }
-  QList<QWidget *> configurationWidgets() const override;
-  void interactorsInstalled(const QList<tlp::Interactor *> &) override;
+  std::list<QWidget *> configurationWidgets() const override;
+  void interactorsInstalled(const std::list<tlp::Interactor *> &) override;
 
   void toggleInteractors(const bool activate);
 
@@ -116,19 +119,21 @@ public:
 
 public slots:
 
+  // inherited from View
   void graphChanged(Graph *graph) override;
-  void init();
   void applySettings() override;
   // inherited from GlMainView
   void centerView(bool = false) override;
 
+  void init();
+  void showPropertiesSelectionWidget();
+
 private:
   void initPixelView();
   void destroyData();
   void destroyOverviewsIfNeeded();
   void updateOverviews(const bool updateAll = false);
-  void addEmptyViewLabel();
-  void removeEmptyViewLabel();
+  void propertiesSelected(bool);
   Color getTextColor() const;
 
   Graph *pixelOrientedGraph;
@@ -155,6 +160,8 @@ private:
   std::map<std::string, bool> overviewGenMap;
   std::map<std::string, pocore::TulipGraphDimension *> dataMap;
 
+  QGraphicsProxyWidget *noPropertyMsgBox;
+
   unsigned int overviewWidth;
   unsigned int overviewHeight;
   unsigned int minWidth;
