@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -20,7 +20,6 @@
 #include <tulip/GlRect.h>
 #include <tulip/BoundingBox.h>
 #include <tulip/TulipPluginHeaders.h>
-#include <tulip/QtGlSceneZoomAndPanAnimator.h>
 
 #include "PixelOrientedViewNavigator.h"
 
@@ -61,8 +60,8 @@ bool PixelOrientedViewNavigator::eventFilter(QObject *widget, QEvent *e) {
 
   if (e->type() == QEvent::MouseMove && pixelView->smallMultiplesViewSet()) {
     QMouseEvent *me = static_cast<QMouseEvent *>(e);
-    int x = glWidget->width() - me->x();
-    int y = me->y();
+    int x = glWidget->width() - me->pos().x();
+    int y = me->pos().y();
     Coord screenCoords(x, y, 0);
     Coord &&sceneCoords = glWidget->getScene()->getGraphCamera().viewportTo3DWorld(
         glWidget->screenToViewport(screenCoords));
@@ -78,15 +77,12 @@ bool PixelOrientedViewNavigator::eventFilter(QObject *widget, QEvent *e) {
       pixelView->generatePixelOverview(selectedOverview);
       glWidget->draw();
     } else if (selectedOverview != nullptr && pixelView->smallMultiplesViewSet()) {
-      QtGlSceneZoomAndPanAnimator zoomAndPanAnimator(glWidget, selectedOverview->getBoundingBox());
-      zoomAndPanAnimator.animateZoomAndPan();
+      pixelView->zoomAndPanAnimation(selectedOverview->getBoundingBox());
       pixelView->switchFromSmallMultiplesToDetailView(selectedOverview);
       selectedOverview = nullptr;
     } else if (!pixelView->smallMultiplesViewSet() && pixelView->getOverviews().size() > 1) {
       pixelView->switchFromDetailViewToSmallMultiples();
-      QtGlSceneZoomAndPanAnimator zoomAndPanAnimator(glWidget,
-                                                     pixelView->getSmallMultiplesViewBoundingBox());
-      zoomAndPanAnimator.animateZoomAndPan();
+      pixelView->zoomAndPanAnimation(pixelView->getSmallMultiplesViewBoundingBox());
       pixelView->centerView();
     }
 
