@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -18,9 +18,8 @@
  */
 
 #include <algorithm>
+#include <random>
 #include "InputSample.h"
-#include <tulip/Iterator.h>
-#include <tulip/StlIterator.h>
 
 using namespace std;
 using namespace tlp;
@@ -297,7 +296,11 @@ tlp::Iterator<tlp::node> *InputSample::getNodes() {
 tlp::Iterator<tlp::node> *InputSample::getRandomNodeOrder() {
   if (rootGraph) {
     randomVector = rootGraph->nodes();
-    random_shuffle(randomVector.begin(), randomVector.end());
+    std::random_device rd;
+    // gui testing mode needs reproductibility
+    std::mt19937 g(tlp::inGuiTestingMode() ? 0 : rd());
+
+    std::shuffle(randomVector.begin(), randomVector.end(), g);
 
     return new StlIterator<node, vector<node>::iterator>(randomVector.begin(), randomVector.end());
   } else
