@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -18,6 +18,7 @@
  */
 
 #include "SOMMap.h"
+#include <tulip/GraphImpl.h>
 #include <tulip/DoubleProperty.h>
 #include <tulip/IntegerProperty.h>
 #include <tulip/GlyphManager.h>
@@ -40,8 +41,8 @@ SOMMap::SOMMap(Graph *root, unsigned int width, unsigned int height,
 }
 SOMMap::SOMMap(unsigned int width, unsigned int height, SOMMapConnectivity connectivity,
                bool oppositeConnected)
-    : tlp::GraphDecorator(newGraph()), width(width), height(height), connectivity(connectivity),
-      oppositeConnected(oppositeConnected), graphCreated(true) {
+    : tlp::GraphDecorator(GraphImpl::newGraph()), width(width), height(height),
+      connectivity(connectivity), oppositeConnected(oppositeConnected), graphCreated(true) {
   initMap();
 }
 
@@ -78,9 +79,10 @@ void SOMMap::initMap() {
     }
 
     gridDataSet.set("connectivity", connectivityCollection);
-    gridDataSet.set("oppositeNodesConnected", oppositeConnected);
+    gridDataSet.set("opposite nodes connected", oppositeConnected);
     // Suppress spacing
     gridDataSet.set("spacing", 0.0);
+    graph_component = GraphImpl::newGraph();
     graph_component = importGraph("Grid", gridDataSet, nullptr, graph_component);
   }
 
