@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -28,7 +28,6 @@
 #include <QPushButton>
 #include <QButtonGroup>
 
-#include <tulip/GraphPropertiesSelectionWidget.h>
 #include <tulip/ColorScalesManager.h>
 #include <tulip/PropertyTypes.h>
 #include <tulip/TlpQtTools.h>
@@ -39,16 +38,15 @@ using namespace tlp;
 SOMPropertiesWidget::SOMPropertiesWidget(SOMView *view, QWidget *parent)
     : QWidget(parent), _ui(new Ui::SOMPropertiesWidget), view(view) {
   _ui->setupUi(this);
-  dimensionConfigurationWidget = new tlp::ComputeSOMWidget(parent);
+  dimensionConfigurationWidget = new tlp::ComputeSOMWidget();
 
   defaultScale = new ColorScale(ColorScalesManager::getLatestColorScale());
 
-  defaultScale->addObserver(this);
-
-  QVBoxLayout *sizeMappingLayout = new QVBoxLayout(_ui->nodeSizeMappingGroupBox);
-  sizeMappingLayout->setMargin(0);
+  QVBoxLayout *sizeMappingLayout = new QVBoxLayout(_ui->nodeSizeMappingFrame);
+#ifndef __APPLE__
   sizeMappingLayout->setSpacing(0);
-  sizeMappingLayout->setContentsMargins(0, 5, 0, 0);
+#endif
+  sizeMappingLayout->setContentsMargins(6, 0, 0, 0);
   sizeMappingButtonGroup = new QButtonGroup();
   noNodeSizeMappingRadioButton = new QRadioButton("No size mapping");
   sizeMappingButtonGroup->addButton(noNodeSizeMappingRadioButton);
@@ -61,18 +59,14 @@ SOMPropertiesWidget::SOMPropertiesWidget(SOMView *view, QWidget *parent)
   // Display multiple properties at same time
   multiplePropertiesRepresentation = false;
 
-  dimensionConfigurationWidget->setWindowTitle("Dimensions");
+  dimensionConfigurationWidget->setWindowTitle("Properties");
   setWindowTitle("Options");
 }
 
-QList<QWidget *> SOMPropertiesWidget::configurationWidgets() const {
+std::list<QWidget *> SOMPropertiesWidget::configurationWidgets() const {
 
-  QList<QWidget *> widgets;
-
-  widgets << dimensionConfigurationWidget
-          << const_cast<QWidget *>(static_cast<const QWidget *>(this));
-
-  return widgets;
+  return std::list<QWidget *>{dimensionConfigurationWidget,
+                              const_cast<QWidget *>(static_cast<const QWidget *>(this))};
 }
 
 unsigned int SOMPropertiesWidget::getGridWidth() const {
@@ -158,13 +152,18 @@ void SOMPropertiesWidget::scalingMethodChange(QAbstractButton *button) {
 }
 
 void SOMPropertiesWidget::graphChanged(tlp::Graph *graph) {
+  vector<string> props;
+  // build a vector of double properties
+  for (auto prop : graph->getObjectProperties()) {
+    if (prop->getTypename() == "double") {
+      const string &propName = prop->getName();
+      if ((propName.find("view") != 0) || (propName == "viewMetric"))
+        props.push_back(propName);
+    }
+  }
 
-  vector<string> types;
-  types.push_back("double");
-  tlp::GraphPropertiesSelectionWidget s;
-  s.setWidgetParameters(graph, types);
   // Init the set of colors with all the possible properties.
-  gradientManager.init(s.getCompleteStringsList());
+  gradientManager.init(props);
 }
 
 tlp::ColorScale *SOMPropertiesWidget::getPropertyColorScale(const std::string &) {
@@ -303,7 +302,8 @@ void SOMPropertiesWidget::setData(const DataSet &data) {
     string propertiesString;
     data.get("properties", propertiesString);
     // Use QString split function to parse string.
-    QStringList list = tlpStringToQString(propertiesString).split(";", QString::SkipEmptyParts);
+    auto skipEmpty = Qt::SkipEmptyParts;
+    QStringList list = tlpStringToQString(propertiesString).split(";", skipEmpty);
     vector<string> properties;
 
     for (const QString &s : list) {
