@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -28,22 +28,27 @@
 #include "SOMViewInteractor.h"
 #include "SOMPropertiesWidget.h"
 
+#include <tulip/GraphImpl.h>
 #include <tulip/GlGraphRenderingParameters.h>
 #include <tulip/NumericProperty.h>
 #include <tulip/ColorProperty.h>
 #include <tulip/BooleanProperty.h>
 #include <tulip/GlBoundingBoxSceneVisitor.h>
 #include <tulip/Interactor.h>
-#include <tulip/ImportModule.h>
-#include <tulip/GlLODCalculator.h>
 #include <tulip/GlLabel.h>
 #include <tulip/LayoutProperty.h>
 #include <tulip/GlMainWidget.h>
 #include <tulip/GlGraphComposite.h>
+#include <tulip/Perspective.h>
+#include <tulip/WorkspacePanel.h>
+#include <tulip/NeedConfigurationMsgBox.h>
 
+#include <QPushButton>
 #include <QMenu>
 #include <QTimer>
 #include <QToolTip>
+#include <QGraphicsView>
+#include <QGraphicsProxyWidget>
 #include <QMessageBox>
 #include <QMouseEvent>
 
@@ -117,13 +122,11 @@ void SOMView::construct(QWidget *) {
   mapWidget->installEventFilter(this);
 
   initGlMainViews();
-  mapWidget->installEventFilter(this);
 
   isDetailedMode = false;
 
   // Interactors update
   previewWidget->installEventFilter(&navigator);
-  previewWidget->installEventFilter(this);
 
   // Init var
   graphLayoutProperty = nullptr;
@@ -136,6 +139,28 @@ void SOMView::construct(QWidget *) {
 
   // Init the map to nullptr
   som = nullptr;
+
+  // create box indicating the lack of selected properties
+  QGraphicsRectItem *qgrItem = new QGraphicsRectItem(0, 0, 1, 1);
+  qgrItem->setBrush(Qt::transparent);
+  qgrItem->setPen(QPen(Qt::transparent));
+  graphicsView()->scene()->addItem(qgrItem);
+
+  QPushButton *okButton;
+  QWidget *msgBox = new_NeedConfigurationMsgBox("<b><font size=\"+1\">"
+                                                "No graph properties selected.</font></b><br/><br/>"
+                                                "Open the <b>Properties</b> configuration tab<br/>"
+                                                "to proceed.",
+                                                &okButton);
+  connect(okButton, SIGNAL(released()), this, SLOT(showPropertiesSelectionWidget()));
+  connect(okButton, SIGNAL(released()), msgBox, SLOT(hide()));
+  noPropertyMsgBox = graphicsView()->scene()->addWidget(msgBox);
+  noPropertyMsgBox->setParentItem(qgrItem);
+}
+
+void SOMView::showPropertiesSelectionWidget() {
+  WorkspacePanel *wp = static_cast<WorkspacePanel *>(graphicsView()->parentWidget());
+  wp->showConfigurationTab("Properties");
 }
 
 void SOMView::initGlMainViews() {
@@ -151,7 +176,7 @@ void SOMView::initGlMainViews() {
   }
 
   // No graph to print
-  GlGraphComposite *graphComposite = new GlGraphComposite(tlp::newGraph());
+  GlGraphComposite *graphComposite = new GlGraphComposite(GraphImpl::newGraph());
   mainLayer->addGlEntity(graphComposite, "graph");
   // activate hover
 
@@ -162,7 +187,7 @@ void SOMView::initGlMainViews() {
     mapWidget->getScene()->addExistingLayer(mainLayer);
   }
 
-  graphComposite = new GlGraphComposite(tlp::newGraph());
+  graphComposite = new GlGraphComposite(GraphImpl::newGraph());
   mainLayer->addGlEntity(graphComposite, "graph");
 
   GlGraphRenderingParameters *renderingParameters = graphComposite->getRenderingParametersPointer();
@@ -200,16 +225,27 @@ void SOMView::initMenu() {
   connect(selectNodesInMaskAction, SIGNAL(triggered()), this, SLOT(selectAllNodesInMask()));
 }
 
-void SOMView::setState(const DataSet &dataSet) {
+void SOMView::graphicsViewResized(int w, int h) {
+  if (isConstruct) {
+    noPropertyMsgBox->setPos(w / 2 - noPropertyMsgBox->sceneBoundingRect().width() / 2,
+                             h / 2 - noPropertyMsgBox->sceneBoundingRect().height() / 2);
+  }
+}
 
+void SOMView::setState(const DataSet &dataSet) {
   if (!isConstruct)
     construct(nullptr);
 
-  isDetailedMode = false;
+  if (isDetailedMode) {
+    properties->configurationWidgets().front()->parentWidget()->parentWidget()->setVisible(true);
+    isDetailedMode = false;
+  }
+
   assignNewGlMainWidget(previewWidget, false);
 
   previewWidget->makeCurrent();
 
+  selection.clear();
   //  clearObservers();
   cleanSOMMap();
 
@@ -241,9 +277,9 @@ void SOMView::setState(const DataSet &dataSet) {
 
   computeSOMMap();
 
-  // Display the empty label if no properties are selected.
+  // Display the msg box if no properties are selected.
   if (properties->getSelectedProperties().empty())
-    addEmptyViewLabel();
+    noPropertyMsgBox->show();
 
   registerTriggers();
 
@@ -290,8 +326,8 @@ DataSet SOMView::state() const {
   return dataSet;
 }
 
-void SOMView::graphChanged(Graph *) {
-  setState(DataSet());
+void SOMView::graphChanged(Graph *g) {
+  setState(getState(g));
 }
 
 void SOMView::fillContextMenu(QMenu *menu, const QPointF &point) {
@@ -490,11 +526,7 @@ void SOMView::drawPreviewWidget() {
 }
 
 void SOMView::draw() {
-  removeEmptyViewLabel();
-  previewWidget->getScene()->getLayer("Main");
-
-  if (properties->getSelectedProperties().empty())
-    addEmptyViewLabel();
+  noPropertyMsgBox->setVisible(properties->getSelectedProperties().empty());
 
   getGlMainWidget()->draw(true);
 }
@@ -777,9 +809,7 @@ vector<SOMPreviewComposite *> SOMView::getPreviews() {
 
 void SOMView::getPreviewsAtViewportCoord(int x, int y, std::vector<SOMPreviewComposite *> &result) {
   vector<SelectedEntity> selectedEntities;
-  previewWidget->getScene()->selectEntities(RenderingSimpleEntities, x, y, 0, 0, nullptr,
-                                            selectedEntities);
-
+  previewWidget->pickGlEntities(x, y, selectedEntities);
   for (auto itEntities = selectedEntities.begin(); itEntities != selectedEntities.end();
        ++itEntities) {
     for (auto itSOM = propertyToPreviews.begin(); itSOM != propertyToPreviews.end(); ++itSOM) {
@@ -809,15 +839,14 @@ void SOMView::computeColor(SOMMap *som, tlp::NumericProperty *property, tlp::Col
 
 bool SOMView::eventFilter(QObject *obj, QEvent *event) {
 
-  if (obj == previewWidget) {
-    if (event->type() == QMouseEvent::MouseButtonDblClick) {
+  if (event->type() == QMouseEvent::MouseButtonDblClick) {
+    if (obj == previewWidget) {
       QMouseEvent *me = static_cast<QMouseEvent *>(event);
 
       if (me->button() == Qt::LeftButton) {
         vector<SOMPreviewComposite *> properties;
-        Coord screenCoords(me->x(), me->y(), 0.0f);
-        Coord &&viewportCoords = getGlMainWidget()->screenToViewport(screenCoords);
-        getPreviewsAtViewportCoord(viewportCoords.x(), viewportCoords.y(), properties);
+
+        getPreviewsAtViewportCoord(me->pos().x(), me->pos().y(), properties);
 
         if (!properties.empty()) {
           addPropertyToSelection(properties.front()->getPropertyName());
@@ -825,24 +854,7 @@ bool SOMView::eventFilter(QObject *obj, QEvent *event) {
 
         return true;
       }
-    }
-
-    if (event->type() == QMouseEvent::ToolTip) {
-      QHelpEvent *he = static_cast<QHelpEvent *>(event);
-      vector<SOMPreviewComposite *> properties;
-      Coord screenCoords(he->x(), he->y(), 0.0f);
-      Coord &&viewportCoords = getGlMainWidget()->screenToViewport(screenCoords);
-      getPreviewsAtViewportCoord(viewportCoords.x(), viewportCoords.y(), properties);
-
-      if (!properties.empty()) {
-        QToolTip::showText(he->globalPos(),
-                           QString::fromStdString(properties.front()->getPropertyName()));
-      }
-
-      return true;
-    }
-  } else if (obj == mapWidget) {
-    if (event->type() == QMouseEvent::MouseButtonDblClick) {
+    } else if (obj == mapWidget) {
       switchToPreviewMode();
       return true;
     }
@@ -1032,14 +1044,14 @@ void SOMView::selectAllNodesInMask() {
   }
 }
 
-QList<QWidget *> SOMView::configurationWidgets() const {
+std::list<QWidget *> SOMView::configurationWidgets() const {
   return properties->configurationWidgets();
 }
 
 void SOMView::gridStructurePropertiesUpdated() {
 
   if (!checkGridValidity()) {
-    QMessageBox::critical(nullptr, tr("Bad grid"),
+    QMessageBox::critical(getGlMainWidget(), tr("Bad grid"),
                           tr("Cannot connect opposite nodes in an hexagonal grid with odd height"));
     return;
   }
@@ -1076,13 +1088,13 @@ void SOMView::switchToDetailedMode(SOMPreviewComposite *preview) {
   assert(preview);
   internalSwitchToDetailedMode(preview, properties->useAnimation());
   // hide configuration widgets
-  properties->configurationWidgets()[0]->parentWidget()->parentWidget()->setVisible(false);
+  properties->configurationWidgets().front()->parentWidget()->parentWidget()->setVisible(false);
 }
 
 void SOMView::switchToPreviewMode() {
   internalSwitchToPreviewMode(properties->useAnimation());
   // show configuration widgets
-  properties->configurationWidgets()[0]->parentWidget()->parentWidget()->setVisible(true);
+  properties->configurationWidgets().front()->parentWidget()->parentWidget()->setVisible(true);
 }
 
 void SOMView::copyToGlMainWidget(GlMainWidget *widget) {
@@ -1136,7 +1148,7 @@ void SOMView::internalSwitchToPreviewMode(bool animation) {
   toggleInteractors(false);
 }
 
-void SOMView::interactorsInstalled(const QList<tlp::Interactor *> &) {
+void SOMView::interactorsInstalled(const std::list<tlp::Interactor *> &) {
   toggleInteractors(isDetailedMode);
 }
 
@@ -1145,36 +1157,6 @@ void SOMView::dimensionUpdated() {
   draw();
 }
 
-void SOMView::addEmptyViewLabel() {
-  GlLayer *mainLayer = previewWidget->getScene()->getLayer("Main");
-  GlLabel *noDimsLabel = new GlLabel(Coord(0, 0, 0), Size(200, 100), Color(0, 0, 0));
-  noDimsLabel->setText(ViewName::SOMViewName);
-  GlLabel *noDimsLabel1 = new GlLabel(Coord(0, -50, 0), Size(400, 100), Color(0, 0, 0));
-  noDimsLabel1->setText("No dimension selected.");
-  GlLabel *noDimsLabel2 = new GlLabel(Coord(0, -100, 0), Size(700, 200), Color(0, 0, 0));
-  noDimsLabel2->setText("Go to the \"Dimensions\" tab in top right corner.");
-  mainLayer->addGlEntity(noDimsLabel, "no dimensions label");
-  mainLayer->addGlEntity(noDimsLabel1, "no dimensions label 1");
-  mainLayer->addGlEntity(noDimsLabel2, "no dimensions label 2");
-  BoundingBox bbox(noDimsLabel->getBoundingBox());
-  bbox.expand(noDimsLabel2->getBoundingBox()[0]);
-  bbox.expand(noDimsLabel2->getBoundingBox()[1]);
-  previewWidget->getScene()->centerScene();
-}
-
-void SOMView::removeEmptyViewLabel() {
-  GlLayer *mainLayer = previewWidget->getScene()->getLayer("Main");
-  GlSimpleEntity *noDimsLabel = mainLayer->findGlEntity("no dimensions label");
-  GlSimpleEntity *noDimsLabel1 = mainLayer->findGlEntity("no dimensions label 1");
-  GlSimpleEntity *noDimsLabel2 = mainLayer->findGlEntity("no dimensions label 2");
-
-  if (noDimsLabel) {
-    mainLayer->deleteGlEntity(noDimsLabel);
-    mainLayer->deleteGlEntity(noDimsLabel1);
-    mainLayer->deleteGlEntity(noDimsLabel2);
-  }
-}
-
 void SOMView::registerTriggers() {
   for (auto obs : triggers()) {
     removeRedrawTrigger(obs);
