@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -61,7 +61,6 @@ double ColorScaleSlider::getValue() {
 }
 
 ColorScaleSlider::~ColorScaleSlider() {
-  linkedScale->getGlColorScale()->getColorScale()->removeObserver(this);
   reset(true);
 }
 
@@ -325,8 +324,7 @@ bool ThresholdInteractor::eventFilter(QObject *widget, QEvent *event) {
     // Update Camera for selection
     layer->set2DMode();
     glMainWidget->getScene()->addExistingLayer(layer);
-    glMainWidget->getScene()->selectEntities(RenderingSimpleEntities, me->x(), me->y(), 0, 0, layer,
-                                             selectedEntities);
+    glMainWidget->pickGlEntities(me->pos().x(), me->pos().y(), selectedEntities);
     glMainWidget->getScene()->removeLayer(layer, false);
 
     if (!selectedEntities.empty()) {
@@ -362,13 +360,13 @@ bool ThresholdInteractor::eventFilter(QObject *widget, QEvent *event) {
 
       // assert(!finalSelectedEntities.empty());
 
-      if (!startDrag) {
+      if (!startDrag && mouvingSlider) {
         glMainWidget->setMouseTracking(true);
         startDrag = true;
         // mouvingSlider = *finalSelectedEntities.begin();
         assert(mouvingSlider);
         mouvingSlider->beginShift();
-        XPosCursor = me->x();
+        XPosCursor = me->pos().x();
         glMainWidget->getScene()->getGraphCamera().initGl();
 
         layer->setVisible(false);
@@ -385,8 +383,8 @@ bool ThresholdInteractor::eventFilter(QObject *widget, QEvent *event) {
 
   if (event->type() == QEvent::MouseMove) {
     if (startDrag) {
-      float xShift = me->x() - XPosCursor;
-      XPosCursor = me->x();
+      float xShift = me->pos().x() - XPosCursor;
+      XPosCursor = me->pos().x();
 
       if (xShift == 0) {
         return true;
@@ -401,7 +399,7 @@ bool ThresholdInteractor::eventFilter(QObject *widget, QEvent *event) {
 
   if (event->type() == QEvent::MouseButtonRelease && startDrag) {
     SOMMap *som = somView->getSOM();
-    assert(mouvingSlider != nullptr);
+    assert(mouvingSlider);
     glMainWidget->setMouseTracking(false);
     startDrag = false;
     mouvingSlider->endShift();
@@ -431,7 +429,7 @@ bool ThresholdInteractor::eventFilter(QObject *widget, QEvent *event) {
 void ThresholdInteractor::performSelection(SOMView *view, tlp::Iterator<node> *it) {
   BooleanProperty *selection = view->graph()->getProperty<BooleanProperty>("viewSelection");
   set<node> mask;
-  unordered_map<node, set<node>> &mappingTab = view->getMappingTab();
+  tlp_hash_map<node, set<node>> &mappingTab = view->getMappingTab();
   Observable::holdObservers();
   selection->setAllNodeValue(false);
 
