@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -40,7 +40,7 @@ const std::string backgroundTextureId = ":/background_texture.png";
 class ScatterPlot2D : public GlComposite {
 
 public:
-  ScatterPlot2D(Graph *graph, Graph *edgeGraph, std::unordered_map<node, edge> &nodeMap,
+  ScatterPlot2D(Graph *graph, Graph *edgeGraph, tlp_hash_map<node, edge> &nodeMap,
                 const std::string &xDim, const std::string &yDim, const ElementType &dataLocation,
                 Coord blCorner, unsigned int size, const Color &backgroundColor,
                 const Color &foregroundColor);
@@ -169,7 +169,7 @@ private:
   Color minusOneColor, zeroColor, oneColor;
 
   Graph *edgeAsNodeGraph;
-  std::unordered_map<node, edge> &nodeToEdge;
+  tlp_hash_map<node, edge> &nodeToEdge;
   ElementType dataLocation;
   bool xAxisScaleDefined, yAxisScaleDefined;
   std::pair<double, double> xAxisScale, yAxisScale;
