@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -19,22 +19,15 @@
 
 #include <QPainter>
 #include <QLinearGradient>
-#include <QMainWindow>
 
 #include "ScatterPlot2DOptionsWidget.h"
 #include "ui_ScatterPlot2DOptionsWidget.h"
 
-#include <tulip/Perspective.h>
-
 namespace tlp {
 
 ScatterPlot2DOptionsWidget::ScatterPlot2DOptionsWidget(QWidget *parent)
     : QWidget(parent), oldValuesInitialized(false), _ui(new Ui::ScatterPlot2DOptionsWidgetData) {
   _ui->setupUi(this);
-  _ui->backColorButton->setDialogParent(Perspective::instance()->mainWindow());
-  _ui->minusOneColorButton->setDialogParent(Perspective::instance()->mainWindow());
-  _ui->zeroColorButton->setDialogParent(Perspective::instance()->mainWindow());
-  _ui->oneColorButton->setDialogParent(Perspective::instance()->mainWindow());
   _ui->backColorButton->setDialogTitle("Choose the background color");
   _ui->minusOneColorButton->setDialogTitle("Choose the color for -1");
   _ui->zeroColorButton->setDialogTitle("Choose the color for 0");
@@ -60,8 +53,8 @@ ScatterPlot2DOptionsWidget::~ScatterPlot2DOptionsWidget() {
 }
 
 void ScatterPlot2DOptionsWidget::setWidgetEnabled(const bool enabled) {
-  _ui->xAxisGroupBox->setEnabled(enabled);
-  _ui->yAxisGroupBox->setEnabled(enabled);
+  _ui->xAxisFrame->setEnabled(enabled);
+  _ui->yAxisFrame->setEnabled(enabled);
 }
 
 Color ScatterPlot2DOptionsWidget::getMinusOneColor() const {
