@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -17,6 +17,7 @@
  *
  */
 
+#include <tulip/GraphImpl.h>
 #include <tulip/GlTextureManager.h>
 #include <tulip/GlMainWidget.h>
 #include <tulip/GlGraphComposite.h>
@@ -27,11 +28,15 @@
 #include <tulip/GraphProperty.h>
 #include <tulip/TulipViewSettings.h>
 #include <tulip/Perspective.h>
+#include <tulip/ViewGraphPropertiesSelectionWidget.h>
+#include <tulip/WorkspacePanel.h>
+#include <tulip/NeedConfigurationMsgBox.h>
 
 #include <QGraphicsView>
-#include <QApplication>
-#include <QMainWindow>
+#include <QGraphicsProxyWidget>
+#include <QMessageBox>
 #include <QProgressDialog>
+#include <QPushButton>
 
 #include "ScatterPlot2DView.h"
 #include "ScatterPlot2DOptionsWidget.h"
@@ -39,8 +44,6 @@
 #include "ScatterPlot2DInteractors.h"
 #include "ScatterPlotQuickAccessBar.h"
 
-#include "../utils/ViewGraphPropertiesSelectionWidget.h"
-
 using namespace std;
 
 const unsigned int OVERVIEWS_SIZE = 512;
@@ -50,22 +53,6 @@ namespace tlp {
 
 PLUGIN(ScatterPlot2DView)
 
-class map_pair_string_key_contains
-    : public unary_function<pair<pair<string, string>, ScatterPlot2D *>, bool> {
-
-public:
-  map_pair_string_key_contains(const string &pairValueToFind) : pairValueToFind(pairValueToFind) {}
-
-  bool operator()(const pair<pair<string, string>, ScatterPlot2D *> &elem) const {
-    string pairStringKeyFirst = elem.first.first;
-    string pairStringKeySecond = elem.first.second;
-    return (pairStringKeyFirst == pairValueToFind) || (pairStringKeySecond == pairValueToFind);
-  }
-
-private:
-  string pairValueToFind;
-};
-
 const string propertiesTypes[] = {"double", "int"};
 const unsigned int nbPropertiesTypes = sizeof(propertiesTypes) / sizeof(string);
 const vector<string> propertiesTypesFilter(propertiesTypes, propertiesTypes + nbPropertiesTypes);
@@ -90,24 +77,23 @@ ScatterPlot2DView::~ScatterPlot2DView() {
   delete edgeAsNodeGraph;
 }
 
-void ScatterPlot2DView::initGlWidget(Graph *) {
-  GlLayer *layer = getGlMainWidget()->getScene()->getLayer("Main");
+void ScatterPlot2DView::initGlWidget() {
+  mainLayer = getGlMainWidget()->getScene()->getLayer("Main");
 
-  if (layer == nullptr) {
-    layer = new GlLayer("Main");
-    getGlMainWidget()->getScene()->addExistingLayer(layer);
+  if (mainLayer == nullptr) {
+    mainLayer = new GlLayer("Main");
+    getGlMainWidget()->getScene()->addExistingLayer(mainLayer);
   }
 
-  mainLayer = layer;
-
   cleanupGlScene();
 
   if (emptyGraph == nullptr) {
-    emptyGraph = newGraph();
+    emptyGraph = GraphImpl::newGraph();
     glGraphComposite = new GlGraphComposite(emptyGraph);
-    mainLayer->addGlEntity(glGraphComposite, "graph");
   }
 
+  mainLayer->addGlEntity(glGraphComposite, "graph");
+
   if (matrixComposite == nullptr) {
     matrixComposite = new GlComposite();
     mainLayer->addGlEntity(matrixComposite, "matrix composite");
@@ -144,8 +130,15 @@ void ScatterPlot2DView::cleanupGlScene() {
   }
 }
 
-QList<QWidget *> ScatterPlot2DView::configurationWidgets() const {
-  return QList<QWidget *>() << propertiesSelectionWidget << optionsWidget;
+std::list<QWidget *> ScatterPlot2DView::configurationWidgets() const {
+  return std::list<QWidget *>{propertiesSelectionWidget, optionsWidget};
+}
+
+void ScatterPlot2DView::graphicsViewResized(int w, int h) {
+  if (initialized) {
+    noPropertyMsgBox->setPos(w / 2 - noPropertyMsgBox->sceneBoundingRect().width() / 2,
+                             h / 2 - noPropertyMsgBox->sceneBoundingRect().height() / 2);
+  }
 }
 
 void ScatterPlot2DView::setState(const DataSet &dataSet) {
@@ -156,8 +149,29 @@ void ScatterPlot2DView::setState(const DataSet &dataSet) {
     initialized = true;
     setOverviewVisible(true);
     needQuickAccessBar = true;
+
+    // create box indicating the lack of selected properties
+    QGraphicsRectItem *qgrItem = new QGraphicsRectItem(0, 0, 1, 1);
+    qgrItem->setBrush(Qt::transparent);
+    qgrItem->setPen(QPen(Qt::transparent));
+    graphicsView()->scene()->addItem(qgrItem);
+
+    QPushButton *okButton;
+    QWidget *msgBox =
+        new_NeedConfigurationMsgBox("<b><font size=\"+1\">"
+                                    "Select at least two graph properties.</font></b><br/><br/>"
+                                    "Open the <b>Properties</b> configuration tab<br/>"
+                                    "to proceed.",
+                                    &okButton);
+    connect(okButton, SIGNAL(released()), this, SLOT(showPropertiesSelectionWidget()));
+    connect(okButton, SIGNAL(released()), msgBox, SLOT(hide()));
+    noPropertyMsgBox = graphicsView()->scene()->addWidget(msgBox);
+    noPropertyMsgBox->setParentItem(qgrItem);
   }
 
+  if (!matrixView)
+    switchFromDetailViewToMatrixView();
+
   Graph *lastGraph = scatterPlotGraph;
   scatterPlotGraph = graph();
   propertiesSelectionWidget->setWidgetParameters(scatterPlotGraph, propertiesTypesFilter);
@@ -175,10 +189,13 @@ void ScatterPlot2DView::setState(const DataSet &dataSet) {
       lastGraph->getProperty("viewTexture")->removeListener(this);
     }
 
+    initGlWidget();
+    detailedScatterPlot = nullptr;
+
     delete edgeAsNodeGraph;
 
     if (scatterPlotGraph) {
-      edgeAsNodeGraph = tlp::newGraph();
+      edgeAsNodeGraph = GraphImpl::newGraph();
       ColorProperty *edgeAsNodeGraphColor =
           edgeAsNodeGraph->getProperty<ColorProperty>("viewColor");
       ColorProperty *graphColor = scatterPlotGraph->getProperty<ColorProperty>("viewColor");
@@ -216,8 +233,6 @@ void ScatterPlot2DView::setState(const DataSet &dataSet) {
     } else
       edgeAsNodeGraph = nullptr;
 
-    initGlWidget(scatterPlotGraph);
-    detailedScatterPlot = nullptr;
     destroyOverviews();
   }
 
@@ -230,7 +245,7 @@ void ScatterPlot2DView::setState(const DataSet &dataSet) {
     }
   }
 
-  center = lastGraph ? false : true;
+  center = true;
 
   dataSet.get("lastViewWindowWidth", lastViewWindowWidth);
   dataSet.get("lastViewWindowHeight", lastViewWindowHeight);
@@ -302,9 +317,6 @@ void ScatterPlot2DView::setState(const DataSet &dataSet) {
   propertiesSelectionWidget->setDataLocation(dataLocation);
   viewConfigurationChanged();
 
-  if (overviewVisible())
-    drawOverview(true);
-
   string detailScatterPlotX = "";
   string detailScatterPlotY = "";
   dataSet.get("detailed scatterplot x dim", detailScatterPlotX);
@@ -328,14 +340,7 @@ void ScatterPlot2DView::setState(const DataSet &dataSet) {
 
   registerTriggers();
 
-  bool quickAccessBarVisible = false;
-
-  if (dataSet.get<bool>("quickAccessBarVisible", quickAccessBarVisible)) {
-    needQuickAccessBar = true;
-    setQuickAccessBarVisible(quickAccessBarVisible);
-  } else // display quickaccessbar
-    setQuickAccessBarVisible(true);
-
+  setQuickAccessBarVisible(true);
   GlMainView::setState(dataSet);
 }
 
@@ -369,30 +374,34 @@ DataSet ScatterPlot2DView::state() const {
   dataSet.set("detailed scatterplot y dim", detailedScatterPlotPropertyName.second);
   dataSet.set("Nodes/Edges", static_cast<unsigned>(dataLocation));
 
-  if (needQuickAccessBar)
-    dataSet.set("quickAccessBarVisible", quickAccessBarVisible());
-
   return dataSet;
 }
 
+void ScatterPlot2DView::showPropertiesSelectionWidget() {
+  WorkspacePanel *wp = static_cast<WorkspacePanel *>(graphicsView()->parentWidget());
+  wp->showConfigurationTab("Properties");
+}
+
 Graph *ScatterPlot2DView::getScatterPlotGraph() {
   return scatterPlotGraph;
 }
 
-void ScatterPlot2DView::graphChanged(Graph *) {
+void ScatterPlot2DView::graphChanged(Graph *g) {
   if (!initialized) {
     setState(DataSet());
     return;
   }
-  // We copy the value of "Nodes/Edges"
-  // in the new state in order to keep
-  // the user choice when changing graph
-  DataSet oldDs = state();
-  unsigned nodes = NODE;
-  oldDs.get("Nodes/Edges", nodes);
-  DataSet newDs;
-  newDs.set("Nodes/Edges", nodes);
-  setState(newDs);
+  DataSet ds = getState(g);
+  if (ds.empty()) {
+    // We copy the value of "Nodes/Edges"
+    // in the new state in order to keep
+    // the user choice when changing graph
+    DataSet oldDs = state();
+    unsigned nodes = NODE;
+    oldDs.get("Nodes/Edges", nodes);
+    ds.set("Nodes/Edges", nodes);
+  }
+  setState(ds);
 }
 
 void ScatterPlot2DView::toggleInteractors(const bool activate) {
@@ -561,10 +570,6 @@ void ScatterPlot2DView::buildScatterPlotsMatrix() {
 
         matrixComposite->addGlEntity(scatterOverview,
                                      selectedGraphProperties[i] + "_" + selectedGraphProperties[j]);
-
-        // add some feedback
-        /*if ((i + 1) * (j + 1) % 10 == 0)
-          QApplication::processEvents();*/
       }
     }
   }
@@ -578,46 +583,11 @@ void ScatterPlot2DView::buildScatterPlotsMatrix() {
     centerView();
 }
 
-void ScatterPlot2DView::addEmptyViewLabel() {
-  Color backgroundColor(optionsWidget->getBackgroundColor());
-  getGlMainWidget()->getScene()->setBackgroundColor(backgroundColor);
-
-  Color foregroundColor;
-  int bgV = backgroundColor.getV();
-
-  if (bgV < 128) {
-    foregroundColor = Color(255, 255, 255);
-  } else {
-    foregroundColor = Color(0, 0, 0);
-  }
-
-  GlLabel *noDimsLabel =
-      new GlLabel(Coord(0.0f, 0.0f, 0.0f), Size(200.0f, 200.0f), foregroundColor);
-  noDimsLabel->setText(ViewName::ScatterPlot2DViewName);
-  mainLayer->addGlEntity(noDimsLabel, "no dimensions label");
-  GlLabel *noDimsLabel1 =
-      new GlLabel(Coord(0.0f, -50.0f, 0.0f), Size(400.0f, 200.0f), foregroundColor);
-  noDimsLabel1->setText("Select at least two graph properties.");
-  mainLayer->addGlEntity(noDimsLabel1, "no dimensions label 1");
-  GlLabel *noDimsLabel2 =
-      new GlLabel(Coord(0.0f, -100.0f, 0.0f), Size(700.0f, 200.0f), foregroundColor);
-  noDimsLabel2->setText("Go to the \"Properties\" tab in top right corner.");
-  mainLayer->addGlEntity(noDimsLabel2, "no dimensions label 2");
-}
-
-void ScatterPlot2DView::removeEmptyViewLabel() {
-  GlSimpleEntity *noDimsLabel = mainLayer->findGlEntity("no dimensions label");
-  GlSimpleEntity *noDimsLabel1 = mainLayer->findGlEntity("no dimensions label 1");
-  GlSimpleEntity *noDimsLabel2 = mainLayer->findGlEntity("no dimensions label 2");
-
-  if (noDimsLabel != nullptr) {
-    mainLayer->deleteGlEntity(noDimsLabel);
-    delete noDimsLabel;
-    mainLayer->deleteGlEntity(noDimsLabel1);
-    delete noDimsLabel1;
-    mainLayer->deleteGlEntity(noDimsLabel2);
-    delete noDimsLabel2;
-  }
+void ScatterPlot2DView::propertiesSelected(bool flag) {
+  noPropertyMsgBox->setVisible(!flag);
+  if (quickAccessBarVisible())
+    _quickAccessBar->setEnabled(flag);
+  setOverviewVisible(flag);
 }
 
 void ScatterPlot2DView::viewConfigurationChanged() {
@@ -638,9 +608,11 @@ void ScatterPlot2DView::viewConfigurationChanged() {
   }
 
   draw();
+  drawOverview(true);
 }
 
 void ScatterPlot2DView::draw() {
+  GlMainWidget *gl = getGlMainWidget();
 
   destroyOverviewsIfNeeded();
 
@@ -653,29 +625,20 @@ void ScatterPlot2DView::draw() {
 
   if (selectedGraphProperties.size() < 2) {
     destroyOverviews();
-    removeEmptyViewLabel();
+    propertiesSelected(false);
     matrixUpdateNeeded = false;
     switchFromDetailViewToMatrixView();
-    addEmptyViewLabel();
-    getGlMainWidget()->getScene()->centerScene();
-    getGlMainWidget()->draw();
-
-    if (quickAccessBarVisible())
-      _quickAccessBar->setEnabled(false);
+    gl->centerScene();
 
     return;
-  } else {
-    removeEmptyViewLabel();
   }
 
-  if (quickAccessBarVisible())
-    _quickAccessBar->setEnabled(true);
-
+  propertiesSelected(true);
   computeNodeSizes();
   buildScatterPlotsMatrix();
 
   if (!matrixView && detailedScatterPlot != nullptr) {
-    getGlMainWidget()->makeCurrent();
+    gl->makeCurrent();
     detailedScatterPlot->generateOverview();
     axisComposite->reset(false);
     axisComposite->addGlEntity(detailedScatterPlot->getXAxis(), "x axis");
@@ -687,7 +650,7 @@ void ScatterPlot2DView::draw() {
       newGraphSet = false;
     }
   } else if (matrixView) {
-    getGlMainWidget()->makeCurrent();
+    gl->makeCurrent();
     generateScatterPlots();
   } else if (!matrixView && detailedScatterPlot == nullptr) {
     switchFromDetailViewToMatrixView();
@@ -697,27 +660,28 @@ void ScatterPlot2DView::draw() {
   if (center) {
     centerView();
   } else {
-    getGlMainWidget()->draw();
+    gl->draw();
   }
 }
 
 void ScatterPlot2DView::centerView(bool) {
-  if (!getGlMainWidget()->isVisible()) {
+  GlMainWidget *gl = getGlMainWidget();
+
+  if (!gl->isVisible()) {
     if (lastViewWindowWidth != 0 && lastViewWindowHeight != 0) {
-      getGlMainWidget()->getScene()->adjustSceneToSize(lastViewWindowWidth, lastViewWindowHeight);
+      gl->getScene()->adjustSceneToSize(lastViewWindowWidth, lastViewWindowHeight);
     } else {
-      getGlMainWidget()->getScene()->centerScene();
+      gl->centerScene();
     }
   } else {
-    getGlMainWidget()->getScene()->adjustSceneToSize(getGlMainWidget()->width(),
-                                                     getGlMainWidget()->height());
+    gl->getScene()->adjustSceneToSize(gl->width(), gl->height());
   }
 
   // we apply a zoom factor to preserve a 50 px margin width
   // to ensure the scene will not be drawn under the configuration tabs title
   float glWidth = graphicsView()->width();
-  getGlMainWidget()->getScene()->zoomFactor((glWidth - 50) / glWidth);
-  getGlMainWidget()->draw();
+  gl->getScene()->zoomFactor((glWidth - 50) / glWidth);
+  gl->draw();
   center = false;
 }
 
@@ -743,9 +707,15 @@ void ScatterPlot2DView::destroyOverviewsIfNeeded() {
         detailedScatterPlotPropertyName = make_pair("", "");
       }
 
+      auto current_prop = selectedGraphProperties[i];
+      auto contains_current_prop =
+          [current_prop](const pair<pair<string, string>, ScatterPlot2D *> &map_pair) {
+            return ((map_pair.first.first == current_prop) ||
+                    (map_pair.first.second == current_prop));
+          };
       map<pair<string, string>, ScatterPlot2D *>::iterator overviewToDestroyIt;
-      overviewToDestroyIt = find_if(scatterPlotsMap.begin(), scatterPlotsMap.end(),
-                                    map_pair_string_key_contains(selectedGraphProperties[i]));
+      overviewToDestroyIt =
+          find_if(scatterPlotsMap.begin(), scatterPlotsMap.end(), contains_current_prop);
 
       while (overviewToDestroyIt != scatterPlotsMap.end()) {
         if (overviewToDestroyIt->second == detailedScatterPlot) {
@@ -761,8 +731,8 @@ void ScatterPlot2DView::destroyOverviewsIfNeeded() {
         delete overviewToDestroyIt->second;
         scatterPlotsGenMap.erase(overviewToDestroyIt->first);
         scatterPlotsMap.erase(overviewToDestroyIt);
-        overviewToDestroyIt = find_if(scatterPlotsMap.begin(), scatterPlotsMap.end(),
-                                      map_pair_string_key_contains(selectedGraphProperties[i]));
+        overviewToDestroyIt =
+            find_if(scatterPlotsMap.begin(), scatterPlotsMap.end(), contains_current_prop);
       }
     }
   }
@@ -942,6 +912,10 @@ void ScatterPlot2DView::switchFromDetailViewToMatrixView() {
   optionsWidget->setWidgetEnabled(false);
   optionsWidget->resetAxisScale();
   toggleInteractors(false);
+  // select the navigator interactor
+  // allowing to choose one of the detailed views
+  if (!interactors().empty())
+    setCurrentInteractor(interactors().front());
   getGlMainWidget()->draw();
 }
 
@@ -1000,7 +974,7 @@ std::vector<ScatterPlot2D *> ScatterPlot2DView::getSelectedScatterPlots() const
   return ret;
 }
 
-void ScatterPlot2DView::interactorsInstalled(const QList<tlp::Interactor *> &) {
+void ScatterPlot2DView::interactorsInstalled(const std::list<tlp::Interactor *> &) {
   toggleInteractors(detailedScatterPlot != nullptr);
 }
 
@@ -1024,10 +998,10 @@ void ScatterPlot2DView::treatEvent(const Event &message) {
     if (graphEvent->getType() == GraphEvent::TLP_ADD_EDGE)
       addEdge(graphEvent->getGraph(), graphEvent->getEdge());
 
-    if (graphEvent->getType() == GraphEvent::TLP_DEL_NODE)
+    if (graphEvent->getType() == GraphEvent::TLP_AFTER_DEL_NODE)
       delNode(graphEvent->getGraph(), graphEvent->getNode());
 
-    if (graphEvent->getType() == GraphEvent::TLP_DEL_EDGE)
+    if (graphEvent->getType() == GraphEvent::TLP_AFTER_DEL_EDGE)
       delEdge(graphEvent->getGraph(), graphEvent->getEdge());
   }
 
