@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -20,7 +20,7 @@
 #ifndef SCATTERPLOT2DVIEW_H_
 #define SCATTERPLOT2DVIEW_H_
 
-#include <unordered_map>
+#include <tulip/tuliphash.h>
 
 #include <tulip/Graph.h>
 #include <tulip/GlMainView.h>
@@ -31,6 +31,8 @@
 
 #include "../../utils/PluginNames.h"
 
+class QGraphicsProxyWidget;
+
 namespace tlp {
 
 /*@{*/
@@ -94,13 +96,14 @@ public:
   }
 
   QuickAccessBar *getQuickAccessBarImpl() override;
+  void graphicsViewResized(int w, int h) override;
 
   void setState(const DataSet &dataSet) override;
   DataSet state() const override;
   void graphChanged(Graph *graph) override;
   Graph *getScatterPlotGraph();
 
-  QList<QWidget *> configurationWidgets() const override;
+  std::list<QWidget *> configurationWidgets() const override;
 
   std::vector<ScatterPlot2D *> getSelectedScatterPlots() const;
   bool matrixViewSet() const {
@@ -150,27 +153,30 @@ public:
 
 public slots:
 
-  void init();
-  void viewConfigurationChanged();
-
+  // inherited from View
+  void applySettings() override;
   // inherited from GlMainView
   void centerView(bool graphChanged = false) override;
-  void applySettings() override;
+
+  void init();
+  void viewConfigurationChanged();
+  void showPropertiesSelectionWidget();
 
 private:
-  void interactorsInstalled(const QList<tlp::Interactor *> &) override;
-  void initGlWidget(Graph *graph);
+  void interactorsInstalled(const std::list<tlp::Interactor *> &) override;
+  void initGlWidget();
   void generateScatterPlots();
 
   void destroyOverviewsIfNeeded();
   void destroyOverviews();
   void cleanupGlScene();
-  void addEmptyViewLabel();
-  void removeEmptyViewLabel();
+  void propertiesSelected(bool);
 
   ViewGraphPropertiesSelectionWidget *propertiesSelectionWidget;
   ScatterPlot2DOptionsWidget *optionsWidget;
 
+  QGraphicsProxyWidget *noPropertyMsgBox;
+
   Graph *scatterPlotGraph, *emptyGraph;
   GlLayer *mainLayer;
   GlGraphComposite *glGraphComposite;
@@ -197,8 +203,8 @@ private:
 
   ElementType dataLocation;
   Graph *edgeAsNodeGraph;
-  std::unordered_map<edge, node> edgeToNode;
-  std::unordered_map<node, edge> nodeToEdge;
+  tlp_hash_map<edge, node> edgeToNode;
+  tlp_hash_map<node, edge> nodeToEdge;
 };
 } // namespace tlp
 
