@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -214,8 +214,6 @@ bool ScatterPlotCorrelCoeffSelector::eventFilter(QObject *obj, QEvent *e) {
   GlMainWidget *glWidget = static_cast<GlMainWidget *>(obj);
 
   Camera &camera = glWidget->getScene()->getLayer("Main")->getCamera();
-  Graph *graph = glWidget->getScene()->getGlGraphComposite()->getInputData()->getGraph();
-  BooleanProperty *viewSelection = graph->getProperty<BooleanProperty>("viewSelection");
 
   if (!glWidget->hasMouseTracking()) {
     glWidget->setMouseTracking(true);
@@ -223,8 +221,8 @@ bool ScatterPlotCorrelCoeffSelector::eventFilter(QObject *obj, QEvent *e) {
 
   if (e->type() == QEvent::MouseMove) {
     QMouseEvent *me = static_cast<QMouseEvent *>(e);
-    x = glWidget->screenToViewport(glWidget->width() - me->x());
-    y = glWidget->screenToViewport(me->y());
+    x = glWidget->screenToViewport(glWidget->width() - me->pos().x());
+    y = glWidget->screenToViewport(me->pos().y());
     Coord &&newPointerSceneCoords = camera.viewportTo3DWorld(Coord(x, y, 0));
     Coord &&translationVectorScene = newPointerSceneCoords - currentPointerSceneCoords;
     currentPointerSceneCoords = newPointerSceneCoords;
@@ -256,8 +254,8 @@ bool ScatterPlotCorrelCoeffSelector::eventFilter(QObject *obj, QEvent *e) {
       }
     } else if (polygonEdit.size() > 2) {
       Coord &&startPolygonPointScr = camera.worldTo2DViewport(polygonEdit[0]);
-      Coord pointerGlViewportCoord(glWidget->screenToViewport(me->x()),
-                                   glWidget->screenToViewport(glWidget->height() - me->y()));
+      Coord pointerGlViewportCoord(glWidget->screenToViewport(me->pos().x()),
+                                   glWidget->screenToViewport(glWidget->height() - me->pos().y()));
       bool underFirstPoint =
           (pointerGlViewportCoord.getX() > (startPolygonPointScr.getX() - POINT_RADIUS) &&
            pointerGlViewportCoord.getX() < (startPolygonPointScr.getX() + POINT_RADIUS) &&
@@ -275,8 +273,8 @@ bool ScatterPlotCorrelCoeffSelector::eventFilter(QObject *obj, QEvent *e) {
     return true;
   } else if (e->type() == QEvent::MouseButtonPress) {
     QMouseEvent *me = static_cast<QMouseEvent *>(e);
-    x = glWidget->screenToViewport(glWidget->width() - me->x());
-    y = glWidget->screenToViewport(me->y());
+    x = glWidget->screenToViewport(glWidget->width() - me->pos().x());
+    y = glWidget->screenToViewport(me->pos().y());
     currentPointerSceneCoords = camera.viewportTo3DWorld(Coord(x, y, 0));
 
     if (me->buttons() == Qt::LeftButton) {
@@ -286,8 +284,9 @@ bool ScatterPlotCorrelCoeffSelector::eventFilter(QObject *obj, QEvent *e) {
         polygonEdit.push_back(currentPointerSceneCoords);
       } else {
         Coord &&startPolygonPointScr = camera.worldTo2DViewport(polygonEdit[0]);
-        Coord pointerGlViewportCoord(glWidget->screenToViewport(me->x()),
-                                     glWidget->screenToViewport(glWidget->height() - me->y()));
+        Coord pointerGlViewportCoord(
+            glWidget->screenToViewport(me->pos().x()),
+            glWidget->screenToViewport(glWidget->height() - me->pos().y()));
         bool underFirstPoint =
             (pointerGlViewportCoord.getX() > (startPolygonPointScr.getX() - POINT_RADIUS) &&
              pointerGlViewportCoord.getX() < (startPolygonPointScr.getX() + POINT_RADIUS) &&
@@ -309,46 +308,6 @@ bool ScatterPlotCorrelCoeffSelector::eventFilter(QObject *obj, QEvent *e) {
       if (!polygonEdit.empty()) {
         polygonEdit.clear();
         glWidget->redraw();
-      } else if (selectedPolygon != nullptr) {
-        QMenu contextMenu(glWidget);
-        QAction *deletePoly = contextMenu.addAction("Remove polygon");
-        QAction *selectData = contextMenu.addAction("Select nodes under polygon");
-        QAction *selectedAction = contextMenu.exec(me->globalPos());
-
-        if (selectedAction == deletePoly) {
-          polygons.erase(std::remove(polygons.begin(), polygons.end(), selectedPolygon),
-                         polygons.end());
-          polygonsToNodesSubsetAndCorrelCoeff.erase(selectedPolygon);
-          delete selectedPolygon;
-          selectedPolygon = nullptr;
-          delete selectedPolygonPoint;
-          selectedPolygonPoint = nullptr;
-          glWidget->redraw();
-        } else if (selectedAction == selectData) {
-          Observable::holdObservers();
-
-          for (size_t i = 0; i < polygonsToNodesSubsetAndCorrelCoeff[selectedPolygon].first.size();
-               ++i) {
-            viewSelection->setNodeValue(
-                polygonsToNodesSubsetAndCorrelCoeff[selectedPolygon].first[i], true);
-          }
-
-          for (size_t i = 0; i < polygonsToNodesSubsetAndCorrelCoeff[selectedPolygon].first.size();
-               ++i) {
-            for (size_t j = i + 1;
-                 j < polygonsToNodesSubsetAndCorrelCoeff[selectedPolygon].first.size(); ++j) {
-              edge e = graph->existEdge(
-                  polygonsToNodesSubsetAndCorrelCoeff[selectedPolygon].first[i],
-                  polygonsToNodesSubsetAndCorrelCoeff[selectedPolygon].first[j], false);
-
-              if (e.isValid()) {
-                viewSelection->setEdgeValue(e, true);
-              }
-            }
-          }
-
-          Observable::unholdObservers();
-        }
       }
     }
 
@@ -364,8 +323,8 @@ bool ScatterPlotCorrelCoeffSelector::eventFilter(QObject *obj, QEvent *e) {
     return true;
   } else if (e->type() == QEvent::MouseButtonDblClick) {
     QMouseEvent *me = static_cast<QMouseEvent *>(e);
-    x = glWidget->screenToViewport(glWidget->width() - me->x());
-    y = glWidget->screenToViewport(me->y());
+    x = glWidget->screenToViewport(glWidget->width() - me->pos().x());
+    y = glWidget->screenToViewport(me->pos().y());
     currentPointerSceneCoords = camera.viewportTo3DWorld(Coord(x, y, 0.0f));
 
     if (selectedPolygon != nullptr && selectedPolygonPoint != nullptr) {
@@ -390,6 +349,54 @@ bool ScatterPlotCorrelCoeffSelector::eventFilter(QObject *obj, QEvent *e) {
   return false;
 }
 
+bool ScatterPlotCorrelCoeffSelector::showContextMenu(const QPoint &globalPoint, const QPointF &) {
+  if (selectedPolygon != nullptr) {
+    auto glWidget = scatterView->getGlMainWidget();
+    QMenu contextMenu(glWidget);
+    QAction *deletePoly = contextMenu.addAction("Remove polygon");
+    QAction *selectData = contextMenu.addAction("Select nodes under polygon");
+    QAction *selectedAction = contextMenu.exec(globalPoint);
+
+    if (selectedAction == deletePoly) {
+      polygons.erase(std::remove(polygons.begin(), polygons.end(), selectedPolygon),
+                     polygons.end());
+      polygonsToNodesSubsetAndCorrelCoeff.erase(selectedPolygon);
+      delete selectedPolygon;
+      selectedPolygon = nullptr;
+      delete selectedPolygonPoint;
+      selectedPolygonPoint = nullptr;
+      glWidget->redraw();
+    } else if (selectedAction == selectData) {
+      Graph *graph = glWidget->getScene()->getGlGraphComposite()->getInputData()->getGraph();
+      BooleanProperty *viewSelection = graph->getProperty<BooleanProperty>("viewSelection");
+      Observable::holdObservers();
+
+      for (size_t i = 0; i < polygonsToNodesSubsetAndCorrelCoeff[selectedPolygon].first.size();
+           ++i) {
+        viewSelection->setNodeValue(polygonsToNodesSubsetAndCorrelCoeff[selectedPolygon].first[i],
+                                    true);
+      }
+
+      for (size_t i = 0; i < polygonsToNodesSubsetAndCorrelCoeff[selectedPolygon].first.size();
+           ++i) {
+        for (size_t j = i + 1;
+             j < polygonsToNodesSubsetAndCorrelCoeff[selectedPolygon].first.size(); ++j) {
+          edge e = graph->existEdge(polygonsToNodesSubsetAndCorrelCoeff[selectedPolygon].first[i],
+                                    polygonsToNodesSubsetAndCorrelCoeff[selectedPolygon].first[j],
+                                    false);
+
+          if (e.isValid()) {
+            viewSelection->setEdgeValue(e, true);
+          }
+        }
+      }
+      Observable::unholdObservers();
+    }
+    return true;
+  }
+  return false;
+}
+
 bool ScatterPlotCorrelCoeffSelector::draw(GlMainWidget *glMainWidget) {
   Camera &camera = glMainWidget->getScene()->getLayer("Main")->getCamera();
 
