@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -88,6 +88,7 @@ public:
   bool draw(GlMainWidget *glMainWidget) override;
   bool compute(GlMainWidget *glMainWidget) override;
   void viewChanged(View *view) override;
+  bool showContextMenu(const QPoint &globalPoint, const QPointF &scenePoint) override;
 
 private:
   void getPolygonAndPointUnderPointerIfAny(const Coord &pointerSceneCoord, Camera *camera);
