@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -17,10 +17,10 @@
  *
  */
 
-#include <QColorDialog>
 #include <QPainter>
 #include <QLinearGradient>
 
+#include <tulip/Interactor.h>
 #include "ScatterPlotCorrelCoeffSelectorOptionsWidget.h"
 #include "ui_ScatterPlotCorrelCoeffSelectorOptionsWidget.h"
 
@@ -29,10 +29,8 @@ namespace tlp {
 ScatterPlotCorrelCoeffSelectorOptionsWidget::ScatterPlotCorrelCoeffSelectorOptionsWidget(
     QWidget *parent)
     : QWidget(parent), _ui(new Ui::ScatterPlotCorrelCoeffSelectorOptionsWidgetData) {
+  Interactor::setupConfigWidget(this);
   _ui->setupUi(this);
-  _ui->minusOneColorButton->setDialogParent(parent);
-  _ui->zeroColorButton->setDialogParent(parent);
-  _ui->oneColorButton->setDialogParent(parent);
   _ui->minusOneColorButton->setDialogTitle("Choose the color for -1");
   _ui->zeroColorButton->setDialogTitle("Choose the color for 0");
   _ui->oneColorButton->setDialogTitle("Choose the color for 1");
