@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -22,12 +22,11 @@
 
 #include <QSortFilterProxyModel>
 #include <QMenu>
-#include <QDialogButtonBox>
-#include <QDialog>
 #include <QCursor>
-#include <QMainWindow>
 #include <QMessageBox>
-#include <QTimer>
+#include <QGraphicsView>
+#include <QGraphicsItem>
+#include <QGraphicsProxyWidget>
 
 #include <tulip/Perspective.h>
 #include <tulip/GraphModel.h>
@@ -39,6 +38,7 @@
 #include <tulip/StringProperty.h>
 #include <tulip/BooleanProperty.h>
 #include <tulip/TulipMetaTypes.h>
+#include <tulip/TlpQtTools.h>
 
 Q_DECLARE_METATYPE(Qt::CheckState)
 
@@ -48,8 +48,14 @@ PropertiesEditor::PropertiesEditor(QWidget *parent)
     : QWidget(parent), _ui(new Ui::PropertiesEditor), _contextProperty(nullptr), _graph(nullptr),
       _delegate(new tlp::TulipItemDelegate), _sourceModel(nullptr), filteringProperties(false),
       editorParent(parent), _caseSensitiveSearch(Qt::CaseSensitive) {
+  Perspective::setStyleSheet(this);
   _ui->setupUi(this);
+#ifdef __APPLE__
+  _ui->propMatchCombo->setMinimumContentsLength(9);
+#endif
+
   connect(_ui->newButton, SIGNAL(clicked()), this, SLOT(newProperty()));
+  connect(_ui->propMatchCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(setMatchProperty()));
 }
 
 PropertiesEditor::~PropertiesEditor() {
@@ -65,7 +71,7 @@ void PropertiesEditor::setCaseSensitive(Qt::CaseSensitivity cs) {
 
 void PropertiesEditor::setGraph(tlp::Graph *g) {
   _graph = g;
-  QSortFilterProxyModel *model = new QSortFilterProxyModel(_ui->tableView);
+  QSortFilterProxyModel *model = new QSortFilterProxyModel(_ui->propertiesTableView);
   delete _sourceModel;
   _sourceModel = new GraphPropertiesModel<PropertyInterface>(g, true);
   model->setSourceModel(_sourceModel);
@@ -78,18 +84,40 @@ void PropertiesEditor::setGraph(tlp::Graph *g) {
           SLOT(displayedPropertiesRemoved(const QModelIndex &, int, int)));
   connect(model, SIGNAL(rowsInserted(const QModelIndex &, int, int)), this,
           SLOT(displayedPropertiesInserted(const QModelIndex &, int, int)));
-  _ui->tableView->setModel(model);
+  _ui->propertiesTableView->setModel(model);
   connect(_sourceModel, SIGNAL(checkStateChanged(QModelIndex, Qt::CheckState)), this,
           SLOT(checkStateChanged(QModelIndex, Qt::CheckState)));
-  _ui->tableView->resizeColumnsToContents();
-  _ui->tableView->sortByColumn(0, Qt::AscendingOrder);
+  _ui->propertiesTableView->resizeColumnsToContents();
+  _ui->propertiesTableView->sortByColumn(0, Qt::AscendingOrder);
   _ui->visualPropertiesCheck->setChecked(true);
 }
 
+void PropertiesEditor::setMatchProperty() {
+  _ui->propertiesFilterEdit->setText("");
+  QString tooltip;
+  if (_ui->propMatchCombo->currentText() == "like") {
+    tooltip = QString(
+        "Only show the properties whose name\nis like the given pattern (sql like pattern).");
+    _ui->propertiesFilterEdit->setPlaceholderText("a sql like pattern");
+  } else {
+    tooltip = QString("Only show the properties whose name\nmatches the given regular expression.");
+    _ui->propertiesFilterEdit->setPlaceholderText("a regular expression");
+  }
+  _ui->propMatchLabel->setToolTip(tooltip);
+  _ui->propertiesFilterEdit->setToolTip(tooltip);
+}
+
 void PropertiesEditor::setPropertiesFilter(QString filter) {
   filteringProperties = true;
-  static_cast<QSortFilterProxyModel *>(_ui->tableView->model())
-      ->setFilterRegExp(QRegExp(filter, _caseSensitiveSearch));
+
+  if (_ui->propMatchCombo->currentText() == "like")
+    // convert the sql like filter
+    convertLikeFilter(filter);
+
+  static_cast<QSortFilterProxyModel *>(_ui->propertiesTableView->model())
+      ->setFilterRegularExpression(filter);
+  static_cast<QSortFilterProxyModel *>(_ui->propertiesTableView->model())
+      ->setFilterCaseSensitivity(_caseSensitiveSearch);
   filteringProperties = false;
 }
 
@@ -97,12 +125,21 @@ QLineEdit *PropertiesEditor::getPropertiesFilterEdit() {
   return _ui->propertiesFilterEdit;
 }
 
+QString PropertiesEditor::getPropertiesMatchOp() {
+  return _ui->propMatchCombo->currentText();
+}
+
+void PropertiesEditor::setPropertiesMatchOp(QString op) {
+  return _ui->propMatchCombo->setCurrentText(op);
+}
+
 void PropertiesEditor::showCustomContextMenu(const QPoint &p) {
-  _contextProperty =
-      _ui->tableView->indexAt(p).data(TulipModel::PropertyRole).value<PropertyInterface *>();
+  _contextProperty = _ui->propertiesTableView->indexAt(p)
+                         .data(TulipModel::PropertyRole)
+                         .value<PropertyInterface *>();
   _contextPropertyList.clear();
 
-  for (const QModelIndex &sidx : _ui->tableView->selectionModel()->selectedRows()) {
+  for (const QModelIndex &sidx : _ui->propertiesTableView->selectionModel()->selectedRows()) {
     _contextPropertyList += sidx.data(TulipModel::PropertyRole).value<PropertyInterface *>();
   }
 
@@ -297,7 +334,8 @@ void PropertiesEditor::setPropsVisibility(int state) {
     // reset property name filter
     _ui->propertiesFilterEdit->setText(QString());
     // no filter
-    static_cast<QSortFilterProxyModel *>(_ui->tableView->model())->setFilterFixedString("");
+    static_cast<QSortFilterProxyModel *>(_ui->propertiesTableView->model())
+        ->setFilterFixedString("");
   }
 
   bool showVisualP = _ui->visualPropertiesCheck->isChecked();
@@ -329,7 +367,7 @@ void PropertiesEditor::showVisualProperties(bool f) {
   // reset property name filter
   _ui->propertiesFilterEdit->setText(QString());
 
-  static_cast<QSortFilterProxyModel *>(_ui->tableView->model())->setFilterFixedString("");
+  static_cast<QSortFilterProxyModel *>(_ui->propertiesTableView->model())->setFilterFixedString("");
 
   // ensure all visual properties are shown/hidden
   for (int i = 0; i < _sourceModel->rowCount(); ++i) {
@@ -372,8 +410,8 @@ void PropertiesEditor::displayedPropertiesRemoved(const QModelIndex &parent, int
 
 bool PropertiesEditor::setAllValues(PropertyInterface *prop, bool nodes, bool selectedOnly,
                                     bool graphOnly) {
-  QVariant val = TulipItemDelegate::showEditorDialog(
-      nodes ? NODE : EDGE, prop, _graph, static_cast<TulipItemDelegate *>(_delegate), editorParent);
+  QVariant val = TulipItemDelegate::showEditorDialog(nodes ? NODE : EDGE, prop, _graph, _delegate,
+                                                     editorParent);
 
   // Check if edition has been cancelled
   if (!val.isValid())
@@ -406,8 +444,8 @@ bool PropertiesEditor::setAllValues(PropertyInterface *prop, bool nodes, bool se
 }
 
 void PropertiesEditor::setDefaultValue(tlp::PropertyInterface *prop, bool nodes) {
-  QVariant val = TulipItemDelegate::showEditorDialog(
-      nodes ? NODE : EDGE, prop, _graph, static_cast<TulipItemDelegate *>(_delegate), editorParent);
+  QVariant val = TulipItemDelegate::showEditorDialog(nodes ? NODE : EDGE, prop, _graph, _delegate,
+                                                     editorParent);
 
   // Check if edition has been cancelled
   if (!val.isValid())
@@ -490,14 +528,14 @@ void PropertiesEditor::toLabels(PropertyInterface *prop, bool nodes, bool edges,
   DataSet data;
   data.set("nodes", nodes);
   data.set("edges", edges);
-  data.set("input", prop);
+  data.set("property", prop);
 
   if (selectedOnly)
     data.set("selection", _graph->getProperty<BooleanProperty>("viewSelection"));
 
   std::string msg;
   // _graph->push() must be done outside of this method
-  // to allow call from TabelView.cpp
+  // to allow call from TableView.cpp
   StringProperty *result = _graph->getProperty<StringProperty>("viewLabel");
   _graph->applyPropertyAlgorithm("To labels", result, msg, &data);
 }
