@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -36,7 +36,7 @@ using namespace std;
 
 static std::string TULIP_DUMP_FILE = "";
 
-void CrashHandling::setDumpPath(string s) {
+void CrashHandling::setDumpPath(const string &s) {
   TULIP_DUMP_FILE = s;
 }
 
@@ -84,7 +84,7 @@ static void dumpStackTrace(StackWalker &sw) {
  */
 #if defined(__unix__) || defined(__APPLE__)
 
-#if defined(__i386__) || defined(__amd64__)
+#if defined(__i386__) || defined(__amd64__) || defined(__arm64__)
 
 #include "UnixSignalInterposer.h"
 
@@ -132,8 +132,10 @@ void dumpStack(int sig, siginfo_t *, void *ucontext) {
   ucontext_t *uc = reinterpret_cast<ucontext_t *>(ucontext);
 #if defined(__i386__)
   void *callerAddress = reinterpret_cast<void *>(uc->uc_mcontext->__ss.__eip);
-#else
+#elif defined(__amd64__)
   void *callerAddress = reinterpret_cast<void *>(uc->uc_mcontext->__ss.__rip);
+#elif defined(__arm64__)
+  void *callerAddress = reinterpret_cast<void *>(uc->uc_mcontext->__ss.__lr);
 #endif
 
 #endif
