@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -48,19 +48,20 @@ int backtrace(void **buffer, int size) {
 
 char *getStackFrameDetails(void *address) {
   Dl_info dli;
-  char tmp[1024];
+  std::stringstream tmp;
 
   if (dladdr(address, &dli)) {
     int64_t function_offset =
         reinterpret_cast<int64_t>(address) - reinterpret_cast<int64_t>(dli.dli_saddr);
-    sprintf(tmp, "%s(%s+%p)[%p]", dli.dli_fname, dli.dli_sname,
-            reinterpret_cast<void *>(function_offset), address);
-  } else {
-    sprintf(tmp, "%s(%s+%s)[%p]", "???", "???", "???", address);
-  }
+    tmp << dli.dli_fname << '(' << dli.dli_sname << '+' << reinterpret_cast<void *>(function_offset)
+        << ")[" << address << ']';
+  } else
+    tmp << "???"
+        << "(???+???"
+        << ")[" << address << ']';
 
-  char *ret = new char[strlen(tmp) + 1];
-  strcpy(ret, tmp);
+  char *ret = new char[tmp.gcount() + 1];
+  strcpy(ret, tmp.str().c_str());
   return ret;
 }
 
@@ -281,11 +282,11 @@ void StackWalkerGCC::printCallStack(std::ostream &os, unsigned int maxDepth) {
       if (file_exist("/usr/bin/atos") && file_exist(dsoName)) {
         int64_t exOffset = getOffsetInExecutable(array[i]);
         std::ostringstream oss;
-        oss << "atos -d -o " << dsoName;
+        oss << "atos -o " << dsoName;
 #ifdef X86_64
         oss << " -arch x86_64 ";
 #else
-        oss << " -arch i386 ";
+        oss << " -arch arm64 ";
 #endif
         oss << "0x" << std::hex << exOffset;
         std::string atos = pOpen(oss.str());
