@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -42,6 +42,7 @@ public:
   void testSetGetString();
   void testSetGetStruct();
   void testDataSetSerialization();
+  void testAddDeprecated();
 };
 } // namespace tlp
 #endif
