@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -36,17 +36,12 @@ class PlanarityTestTest : public CppUnit::TestFixture {
   CPPUNIT_TEST_SUITE_END();
 
 public:
-  void setUp() override;
-  void tearDown() override;
   void planarGraphs();
   void notPlanarGraphs();
   void planarGraphsEmbedding();
   void planarMetaGraphsEmbedding();
   void planarEmbeddingFromLayoutGraphs();
   void emptyGraph();
-
-private:
-  tlp::Graph *graph;
 };
 
 #endif
