@@ -1,6 +1,6 @@
 /**
  *
- * This file is part of Tulip (http://tulip.labri.fr)
+ * This file is part of Tulip (https://tulip.labri.fr)
  *
  * Authors: David Auber and the Tulip development Team
  * from LaBRI, University of Bordeaux
@@ -49,7 +49,7 @@ void PushPopTest::testAddDel() {
 
   edge e0 = graph->addEdge(n0, n1);
 
-  graph->push();
+  graph->push(); // e0 = n0 => n1
   node n2 = graph->addNode();
   node n3 = graph->addNode();
 
@@ -143,6 +143,37 @@ void PushPopTest::testAddDel() {
   CPPUNIT_ASSERT(!graph->isElement(e1));
   CPPUNIT_ASSERT(!graph->isElement(n2));
   CPPUNIT_ASSERT(graph->isElement(n3));
+
+  graph->pop();
+  CPPUNIT_ASSERT(!graph->isElement(e1));
+  CPPUNIT_ASSERT(graph->deg(n0) == 1);
+
+  graph->push();
+  e1 = graph->addEdge(n0, n0);
+  CPPUNIT_ASSERT(graph->isElement(e1));
+  CPPUNIT_ASSERT(graph->deg(n0) == 3);
+
+  graph->pop();
+  CPPUNIT_ASSERT(!graph->isElement(e1));
+  CPPUNIT_ASSERT(graph->deg(n0) == 1);
+
+  graph->unpop();
+  CPPUNIT_ASSERT(graph->isElement(e1));
+  CPPUNIT_ASSERT(graph->deg(n0) == 3);
+
+  graph->pop();
+  graph->push();
+  graph->addEdges({{n0, n0}, {n1, n1}});
+  CPPUNIT_ASSERT(graph->deg(n0) == 3);
+  CPPUNIT_ASSERT(graph->deg(n1) == 3);
+
+  graph->pop();
+  CPPUNIT_ASSERT(graph->deg(n0) == 1);
+  CPPUNIT_ASSERT(graph->deg(n1) == 1);
+
+  graph->unpop();
+  CPPUNIT_ASSERT(graph->deg(n0) == 3);
+  CPPUNIT_ASSERT(graph->deg(n1) == 3);
 }
 
 //==========================================================
@@ -847,6 +878,9 @@ void PushPopTest::testPushAddSubgraphsPop() {
   node n1 = g2->addNode();
   edge e1 = g2->addEdge(n1, n1);
   Graph *g3 = g2->addCloneSubGraph();
+  // check validity of g3 id
+  CPPUNIT_ASSERT(g3->getId() != g2->getId());
+
   graph->delEdge(e1);
   graph->pop();
   CPPUNIT_ASSERT(graph->numberOfSubGraphs() == 0);
