@@ -39,7 +39,7 @@
 	handled correctly. */
 
 template <class T> inline void
-CoinCopyN(register const T* from, const int size, register T* to)
+CoinCopyN(const T* from, const int size, T* to)
 {
 	if (size == 0 || from == to)
 	return;
@@ -50,10 +50,10 @@ CoinCopyN(register const T* from, const int size, register T* to)
 			"CoinCopyN", "");
 #endif
 
-	register int n = (size + 7) / 8;
+	int n = (size + 7) / 8;
 	if (to > from) {
-	register const T* downfrom = from + size;
-	register T* downto = to + size;
+	const T* downfrom = from + size;
+	T* downto = to + size;
 	// Use Duff's device to copy
 	switch (size % 8) {
 	case 0: do{     *--downto = *--downfrom;
@@ -97,7 +97,7 @@ CoinCopyN(register const T* from, const int size, register T* to)
 	the difference down to int.  -- lh, 100823 --
 */
 template <class T> inline void
-CoinCopy(register const T* first, register const T* last, register T* to)
+CoinCopy(const T* first, const T* last, T* to)
 {
 	CoinCopyN(first, static_cast<int>(last-first), to);
 }
@@ -107,12 +107,12 @@ CoinCopy(register const T* first, register const T* last, register T* to)
 /** This helper function copies an array to another location. The two arrays
 	must not overlap (otherwise an exception is thrown). For speed 8 entries
 	are copied at a time. The arrays are given by pointers to their first
-	entries and by the size of the source array. 
+	entries and by the size of the source array.
 
-	Note JJF - the speed claim seems to be false on IA32 so I have added 
+	Note JJF - the speed claim seems to be false on IA32 so I have added
 	CoinMemcpyN which can be used for atomic data */
 template <class T> inline void
-CoinDisjointCopyN(register const T* from, const int size, register T* to)
+CoinDisjointCopyN(const T* from, const int size, T* to)
 {
 #ifndef _MSC_VER
 	if (size == 0 || from == to)
@@ -133,7 +133,7 @@ CoinDisjointCopyN(register const T* from, const int size, register T* to)
 	throw CoinError("overlapping arrays", "CoinDisjointCopyN", "");
 #endif
 
-	for (register int n = size / 8; n > 0; --n, from += 8, to += 8) {
+	for (int n = size / 8; n > 0; --n, from += 8, to += 8) {
 	to[0] = from[0];
 	to[1] = from[1];
 	to[2] = from[2];
@@ -165,8 +165,8 @@ CoinDisjointCopyN(register const T* from, const int size, register T* to)
 	are copied at a time. The source array is given by its first and "after
 	last" entry; the target array is given by its first entry. */
 template <class T> inline void
-CoinDisjointCopy(register const T* first, register const T* last,
-		 register T* to)
+CoinDisjointCopy(const T* first, const T* last,
+		 T* to)
 {
 	CoinDisjointCopyN(first, static_cast<int>(last - first), to);
 }
@@ -219,7 +219,7 @@ CoinCopyOfArray( const T * array, const int size, T value)
 		std::memcpy(arrayNew,array,size*sizeof(T));
 	} else {
 	int i;
-	for (i=0;i<size;i++) 
+	for (i=0;i<size;i++)
 		arrayNew[i] = value;
 	}
 	return arrayNew;
@@ -248,13 +248,13 @@ CoinCopyOfArrayOrZero( const T * array , const int size)
 /** This helper function copies an array to another location. The two arrays
 	must not overlap (otherwise an exception is thrown). For speed 8 entries
 	are copied at a time. The arrays are given by pointers to their first
-	entries and by the size of the source array. 
+	entries and by the size of the source array.
 
-	Note JJF - the speed claim seems to be false on IA32 so I have added 
+	Note JJF - the speed claim seems to be false on IA32 so I have added
 	alternative coding if USE_MEMCPY defined*/
 #ifndef COIN_USE_RESTRICT
 template <class T> inline void
-CoinMemcpyN(register const T* from, const int size, register T* to)
+CoinMemcpyN(const T* from, const int size, T* to)
 {
 #ifndef _MSC_VER
 #ifdef USE_MEMCPY
@@ -264,7 +264,7 @@ CoinMemcpyN(register const T* from, const int size, register T* to)
 	if (size < 0)
 	throw CoinError("trying to copy negative number of entries",
 			"CoinMemcpyN", "");
-  
+
 #if 0
 	/* There is no point to do this test. If to and from are from different
 	   blocks then dist is undefined, so this can crash correct code. It's
@@ -294,7 +294,7 @@ CoinMemcpyN(register const T* from, const int size, register T* to)
 	throw CoinError("overlapping arrays", "CoinMemcpyN", "");
 #endif
 
-	for (register int n = size / 8; n > 0; --n, from += 8, to += 8) {
+	for (int n = size / 8; n > 0; --n, from += 8, to += 8) {
 	to[0] = from[0];
 	to[1] = from[1];
 	to[2] = from[2];
@@ -341,8 +341,8 @@ CoinMemcpyN(const T * COIN_RESTRICT from, int size, T* COIN_RESTRICT to)
 	are copied at a time. The source array is given by its first and "after
 	last" entry; the target array is given by its first entry. */
 template <class T> inline void
-CoinMemcpy(register const T* first, register const T* last,
-	   register T* to)
+CoinMemcpy(const T* first, const T* last,
+	   T* to)
 {
 	CoinMemcpyN(first, static_cast<int>(last - first), to);
 }
@@ -351,12 +351,12 @@ CoinMemcpy(register const T* first, register const T* last,
 
 /** This helper function fills an array with a given value. For speed 8 entries
 	are filled at a time. The array is given by a pointer to its first entry
-	and its size. 
+	and its size.
 
-	Note JJF - the speed claim seems to be false on IA32 so I have added 
+	Note JJF - the speed claim seems to be false on IA32 so I have added
 	CoinZero to allow for memset. */
 template <class T> inline void
-CoinFillN(register T* to, const int size, register const T value)
+CoinFillN(T* to, const int size, const T value)
 {
 	if (size == 0)
 	return;
@@ -367,7 +367,7 @@ CoinFillN(register T* to, const int size, register const T value)
 			"CoinFillN", "");
 #endif
 #if 1
-	for (register int n = size / 8; n > 0; --n, to += 8) {
+	for (int n = size / 8; n > 0; --n, to += 8) {
 	to[0] = value;
 	to[1] = value;
 	to[2] = value;
@@ -389,7 +389,7 @@ CoinFillN(register T* to, const int size, register const T value)
 	}
 #else
 	// Use Duff's device to fill
-	register int n = (size + 7) / 8;
+	int n = (size + 7) / 8;
 	--to;
 	switch (size % 8) {
 	case 0: do{     *++to = value;
@@ -411,7 +411,7 @@ CoinFillN(register T* to, const int size, register const T value)
 	entries are filled at a time. The array is given by its first and "after
 	last" entry. */
 template <class T> inline void
-CoinFill(register T* first, register T* last, const T value)
+CoinFill(T* first, T* last, const T value)
 {
 	CoinFillN(first, last - first, value);
 }
@@ -422,10 +422,10 @@ CoinFill(register T* first, register T* last, const T value)
 	are filled at a time. The array is given by a pointer to its first entry
 	and its size.
 
-	Note JJF - the speed claim seems to be false on IA32 so I have allowed 
+	Note JJF - the speed claim seems to be false on IA32 so I have allowed
 	for memset as an alternative */
 template <class T> inline void
-CoinZeroN(register T* to, const int size)
+CoinZeroN(T* to, const int size)
 {
 #ifdef USE_MEMCPY
 	// Use memset - seems faster on Intel with gcc
@@ -446,7 +446,7 @@ CoinZeroN(register T* to, const int size)
 			"CoinZeroN", "");
 #endif
 #if 1
-	for (register int n = size / 8; n > 0; --n, to += 8) {
+	for (int n = size / 8; n > 0; --n, to += 8) {
 	to[0] = 0;
 	to[1] = 0;
 	to[2] = 0;
@@ -468,7 +468,7 @@ CoinZeroN(register T* to, const int size)
 	}
 #else
 	// Use Duff's device to fill
-	register int n = (size + 7) / 8;
+	int n = (size + 7) / 8;
 	--to;
 	switch (size % 8) {
 	case 0: do{     *++to = 0;
@@ -490,7 +490,7 @@ CoinCheckDoubleZero(double * to, const int size)
 {
 	int n=0;
 	for (int j=0;j<size;j++) {
-	if (to[j]) 
+	if (to[j])
 		n++;
 	}
 	if (n) {
@@ -503,7 +503,7 @@ CoinCheckIntZero(int * to, const int size)
 {
 	int n=0;
 	for (int j=0;j<size;j++) {
-	if (to[j]) 
+	if (to[j])
 		n++;
 	}
 	if (n) {
@@ -517,7 +517,7 @@ CoinCheckIntZero(int * to, const int size)
 	entries are filled at a time. The array is given by its first and "after
 	last" entry. */
 template <class T> inline void
-CoinZero(register T* first, register T* last)
+CoinZero(T* first, T* last)
 {
 	CoinZeroN(first, last - first);
 }
@@ -527,7 +527,7 @@ CoinZero(register T* first, register T* last)
 /** Returns strdup or NULL if original NULL */
 inline char * CoinStrdup(const char * name)
 {
-  char* dup = NULL;
+  char* dup = nullptr;
   if (name) {
 	const int len = static_cast<int>(strlen(name));
 	dup = static_cast<char*>(malloc(len+1));
@@ -543,7 +543,7 @@ inline char * CoinStrdup(const char * name)
 	This function was introduced because for some reason compiler tend to
 	handle the <code>max()</code> function differently. */
 template <class T> inline T
-CoinMax(register const T x1, register const T x2)
+CoinMax(const T x1, const T x2)
 {
 	return (x1 > x2) ? x1 : x2;
 }
@@ -554,7 +554,7 @@ CoinMax(register const T x1, register const T x2)
 	This function was introduced because for some reason compiler tend to
 	handle the min() function differently. */
 template <class T> inline T
-CoinMin(register const T x1, register const T x2)
+CoinMin(const T x1, const T x2)
 {
 	return (x1 < x2) ? x1 : x2;
 }
@@ -576,7 +576,7 @@ CoinAbs(const T value)
 	according to operator<. The array is given by a pointer to its first entry
 	and by its size. */
 template <class T> inline bool
-CoinIsSorted(register const T* first, const int size)
+CoinIsSorted(const T* first, const int size)
 {
 	if (size == 0)
 	return true;
@@ -588,7 +588,7 @@ CoinIsSorted(register const T* first, const int size)
 #if 1
 	// size1 is the number of comparisons to be made
 	const int size1 = size  - 1;
-	for (register int n = size1 / 8; n > 0; --n, first += 8) {
+	for (int n = size1 / 8; n > 0; --n, first += 8) {
 	if (first[8] < first[7]) return false;
 	if (first[7] < first[6]) return false;
 	if (first[6] < first[5]) return false;
@@ -610,12 +610,12 @@ CoinIsSorted(register const T* first, const int size)
 	case 0: break;
 	}
 #else
-	register const T* next = first;
-	register const T* last = first + size;
+	const T* next = first;
+	const T* last = first + size;
 	for (++next; next != last; first = next, ++next)
 	if (*next < *first)
 		return false;
-#endif   
+#endif
 	return true;
 }
 
@@ -625,7 +625,7 @@ CoinIsSorted(register const T* first, const int size)
 	according to operator<. The array is given by its first and "after
 	last" entry. */
 template <class T> inline bool
-CoinIsSorted(register const T* first, register const T* last)
+CoinIsSorted(const T* first, const T* last)
 {
 	return CoinIsSorted(first, static_cast<int>(last - first));
 }
@@ -636,7 +636,7 @@ CoinIsSorted(register const T* first, register const T* last)
 	etc. For speed 8 entries are filled at a time. The array is given by a
 	pointer to its first entry and its size. */
 template <class T> inline void
-CoinIotaN(register T* first, const int size, register T init)
+CoinIotaN(T* first, const int size, T init)
 {
 	if (size == 0)
 	return;
@@ -646,7 +646,7 @@ CoinIotaN(register T* first, const int size, register T init)
 	throw CoinError("negative number of entries", "CoinIotaN", "");
 #endif
 #if 1
-	for (register int n = size / 8; n > 0; --n, first += 8, init += 8) {
+	for (int n = size / 8; n > 0; --n, first += 8, init += 8) {
 	first[0] = init;
 	first[1] = init + 1;
 	first[2] = init + 2;
@@ -668,7 +668,7 @@ CoinIotaN(register T* first, const int size, register T init)
 	}
 #else
 	// Use Duff's device to fill
-	register int n = (size + 7) / 8;
+	int n = (size + 7) / 8;
 	--first;
 	--init;
 	switch (size % 8) {
@@ -704,7 +704,7 @@ CoinIota(T* first, const T* last, T init)
 	integer array specified by the last two arguments (again, first and "after
 	last" entry). */
 template <class T> inline T *
-CoinDeleteEntriesFromArray(register T * arrayFirst, register T * arrayLast,
+CoinDeleteEntriesFromArray(T * arrayFirst, T * arrayLast,
 			   const int * firstDelPos, const int * lastDelPos)
 {
 	int delNum = static_cast<int>(lastDelPos - firstDelPos);
@@ -715,7 +715,7 @@ CoinDeleteEntriesFromArray(register T * arrayFirst, register T * arrayLast,
 	throw CoinError("trying to delete negative number of entries",
 			"CoinDeleteEntriesFromArray", "");
 
-	int * delSortedPos = NULL;
+	int * delSortedPos = nullptr;
 	if (! (CoinIsSorted(firstDelPos, lastDelPos) &&
 	   std::adjacent_find(firstDelPos, lastDelPos) == lastDelPos)) {
 	// the positions of the to be deleted is either not sorted or not unique
@@ -771,7 +771,7 @@ CoinDeleteEntriesFromArray(register T * arrayFirst, register T * arrayLast,
 inline double CoinDrand48 (bool isSeed = false, unsigned int seed = 1)
 {
   static unsigned int last = 123456;
-  if (isSeed) { 
+  if (isSeed) {
 	last = seed;
   } else {
 	last = 1664525*last+1013904223;
@@ -808,21 +808,21 @@ inline void CoinSeedRandom(int iseed) { srand48(iseed + 69822); }
 
 //#############################################################################
 
-/** This function figures out whether file names should contain slashes or 
+/** This function figures out whether file names should contain slashes or
 	backslashes as directory separator */
 inline char CoinFindDirSeparator()
 {
 	int size = 1000;
-	char* buf = 0;
+	char* buf = nullptr;
 	while (true) {
 		buf = new char[size];
 		if (getcwd(buf, size))
 			break;
 		delete[] buf;
-		buf = 0;
+		buf = nullptr;
 		size = 2*size;
 	}
-	// if first char is '/' then it's unix and the dirsep is '/'. otherwise we 
+	// if first char is '/' then it's unix and the dirsep is '/'. otherwise we
 	// assume it's dos and the dirsep is '\'
 	char dirsep = buf[0] == '/' ? '/' : '\\';
 	delete[] buf;
@@ -862,7 +862,7 @@ template <class T> inline void CoinSwap (T &x, T &y)
 
 //#############################################################################
 
-/** This helper function copies an array to file 
+/** This helper function copies an array to file
 	Returns 0 if OK, 1 if bad write.
 */
 
@@ -881,7 +881,7 @@ CoinToFile( const T* array, CoinBigIndex size, FILE * fp)
 		return 1;
 	} else {
 	size = 0;
-	numberWritten = 
+	numberWritten =
 		static_cast<CoinBigIndex>(fwrite(&size,sizeof(int),1,fp));
 	if (numberWritten!=1)
 		return 1;
@@ -926,7 +926,7 @@ CoinFromFile( T* &array, CoinBigIndex size, FILE * fp, CoinBigIndex & newSize)
 #if 0
 inline double CoinCbrt(double x)
 {
-#if defined(_MSC_VER) 
+#if defined(_MSC_VER)
 	return pow(x,(1./3.));
 #else
 	return cbrt(x);
@@ -936,9 +936,9 @@ inline double CoinCbrt(double x)
 
 //-----------------------------------------------------------------------------
 
-/// This helper returns "sizeof" as an int 
+/// This helper returns "sizeof" as an int
 #define CoinSizeofAsInt(type) (static_cast<int>(sizeof(type)))
-/// This helper returns "strlen" as an int 
+/// This helper returns "strlen" as an int
 inline int
 CoinStrlenAsInt(const char * string)
 {
@@ -958,7 +958,7 @@ public:
   { seed_=12345678;}
   /** Constructor wih seed. */
   CoinThreadRandom(int seed)
-  { 
+  {
 	seed_ = seed;
   }
   /** Destructor */
@@ -976,18 +976,18 @@ public:
   }
 
   //@}
-  
+
   /**@name Sets/gets */
 
   //@{
   /** Set seed. */
   inline void setSeed(int seed)
-  { 
+  {
 	seed_ = seed;
   }
   /** Get seed. */
   inline unsigned int getSeed() const
-  { 
+  {
 	return seed_;
   }
   /// return a random number
@@ -999,8 +999,8 @@ public:
 	return retVal;
   }
   //@}
-  
-  
+
+
 protected:
   /**@name Data members
 	 The data members are protected to allow access for derived classes. */
@@ -1023,7 +1023,7 @@ public:
   { memcpy(seed_,seed,3*sizeof(unsigned short));}
   /** Constructor wih seed. */
   CoinThreadRandom(int seed)
-  { 
+  {
 	union { int i[2]; unsigned short int s[4];} put;
 	put.i[0]=seed;
 	put.i[1]=seed;
@@ -1044,7 +1044,7 @@ public:
   }
 
   //@}
-  
+
   /**@name Sets/gets */
 
   //@{
@@ -1053,7 +1053,7 @@ public:
   { memcpy(seed_,seed,3*sizeof(unsigned short));}
   /** Set seed. */
   inline void setSeed(int seed)
-  { 
+  {
 	union { int i[2]; unsigned short int s[4];} put;
 	put.i[0]=seed;
 	put.i[1]=seed;
@@ -1072,8 +1072,8 @@ public:
 	return retVal;
   }
   //@}
-  
-  
+
+
 protected:
   /**@name Data members
 	 The data members are protected to allow access for derived classes. */
