@@ -15,27 +15,6 @@
 
 //#############################################################################
 
-//taken in basic/config.h
-//---------------------------------------------------------
-// C++ standard
-//---------------------------------------------------------
-
-#if __cplusplus >= 201103
-#define OGDF_HAVE_CPP11
-
-#elif defined(_MSC_VER)
-#if _MSC_VER >= 1600
-#define OGDF_HAVE_CPP11
-#endif
-
-#elif defined(__GNUC__)
-#ifdef __GXX_EXPERIMENTAL_CXX0X__
-#define OGDF_HAVE_CPP11
-#endif
-
-#endif
-//////////////////////////
-
 #if defined(_MSC_VER)
    typedef void (__cdecl *CoinSighandler_t) (int);
 #  define CoinSighandler_t_defined
@@ -51,32 +30,28 @@
 //-----------------------------------------------------------------------------
 
 #if defined(__CYGWIN__) && defined(__GNUC__)
-   typedef typeof(SIG_DFL) CoinSighandler_t;
+   typedef decltype(SIG_DFL) CoinSighandler_t;
 #  define CoinSighandler_t_defined
 #endif
 
 //-----------------------------------------------------------------------------
 
 #if defined(__MINGW32__) && defined(__GNUC__)
-#ifdef OGDF_HAVE_CPP11
-typedef decltype(SIG_DFL) CoinSighandler_t;
-#else
-typedef typeof(SIG_DFL) CoinSighandler_t;
-#endif
+   typedef decltype(SIG_DFL) CoinSighandler_t;
 #  define CoinSighandler_t_defined
 #endif
 
 //-----------------------------------------------------------------------------
 
 #if defined(__FreeBSD__) && defined(__GNUC__)
-   typedef void(*CoinSighandler_t)(int);
+   typedef decltype(SIG_DFL) CoinSighandler_t;
 #  define CoinSighandler_t_defined
 #endif
 
 //-----------------------------------------------------------------------------
 
 #if defined(__NetBSD__) && defined(__GNUC__)
-   typedef typeof(SIG_DFL) CoinSighandler_t;
+   typedef decltype(SIG_DFL) CoinSighandler_t;
 #  define CoinSighandler_t_defined
 #endif
 
@@ -84,7 +59,7 @@ typedef typeof(SIG_DFL) CoinSighandler_t;
 
 #if defined(_AIX)
 #  if defined(__GNUC__)
-      typedef typeof(SIG_DFL) CoinSighandler_t;
+      typedef decltype(SIG_DFL) CoinSighandler_t;
 #     define CoinSighandler_t_defined
 #  endif
 #endif
@@ -94,7 +69,7 @@ typedef typeof(SIG_DFL) CoinSighandler_t;
 #if defined (__hpux)
 #  define CoinSighandler_t_defined
 #  if defined(__GNUC__)
-      typedef typeof(SIG_DFL) CoinSighandler_t;
+      typedef decltype(SIG_DFL) CoinSighandler_t;
 #  else
       extern "C" {
          typedef void (*CoinSighandler_t) (int);
@@ -113,7 +88,7 @@ typedef typeof(SIG_DFL) CoinSighandler_t;
 #     define CoinSighandler_t_defined
 #  endif
 #  if defined(__GNUC__)
-      typedef typeof(SIG_DFL) CoinSighandler_t;
+      typedef decltype(SIG_DFL) CoinSighandler_t;
 #     define CoinSighandler_t_defined
 #  endif
 #endif
@@ -124,7 +99,7 @@ typedef typeof(SIG_DFL) CoinSighandler_t;
 #if defined(__clang__)
 	  typedef void(*CoinSighandler_t)(int);
 #else
-	  typedef typeof(SIG_DFL) CoinSighandler_t;
+	  typedef decltype(SIG_DFL) CoinSighandler_t;
 #endif
 #define CoinSighandler_t_defined
 #endif
@@ -132,10 +107,10 @@ typedef typeof(SIG_DFL) CoinSighandler_t;
 //#############################################################################
 
 #ifndef CoinSighandler_t_defined
-#  warning("OS and/or compiler is not recognized. Defaulting to:");
-#  warning("extern "C" {")
-#  warning("   typedef void (*CoinSighandler_t) (int);")
-#  warning("}")
+#warning("OS and/or compiler is not recognized. Defaulting to:");
+#warning("extern \"C\" {")
+#warning("   typedef void (*CoinSighandler_t) (int);")
+#warning("}")
    extern "C" {
       typedef void (*CoinSighandler_t) (int);
    }
