@@ -1,11 +1,3 @@
-/*
- * $Revision: 3837 $
- *
- * last checkin:
- *   $Author: gutwenger $
- *   $Date: 2013-11-13 15:19:30 +0100 (Wed, 13 Nov 2013) $
- ***************************************************************/
-
 /** \file
  * \brief GEXF related enums and string conversion functions.
  *
@@ -16,7 +8,7 @@
  *
  * \par
  * Copyright (C)<br>
- * See README.txt in the root directory of the OGDF installation for details.
+ * See README.md in the OGDF root directory for details.
  *
  * \par
  * This program is free software; you can redistribute it and/or
@@ -33,20 +25,11 @@
  *
  * \par
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
- * \see  http://www.gnu.org/copyleft/gpl.html
- ***************************************************************/
+ * License along with this program; if not, see
+ * http://www.gnu.org/copyleft/gpl.html
+ */
 
-#ifdef _MSC_VER
 #pragma once
-#endif
-
-#ifndef OGDF_GEXF_H
-#define OGDF_GEXF_H
-
 
 #include <ogdf/basic/Graph.h>
 #include <ogdf/basic/GraphAttributes.h>
@@ -54,17 +37,14 @@
 
 #include <string>
 
-
 namespace ogdf {
-
 namespace gexf {
 
-	std::string toString(const Shape &shape);
-	Shape toShape(const std::string &str);
+std::string toString(const Shape& shape);
+Shape toShape(const std::string& str);
 
-} // end namespace gexf
+std::string toGEXFStrokeType(const StrokeType& type);
+StrokeType toStrokeType(const std::string& str);
 
-} // end namespace ogdf
-
-
-#endif
+}
+}
