@@ -1,11 +1,3 @@
-/*
- * $Revision: 3837 $
- *
- * last checkin:
- *   $Author: gutwenger $
- *   $Date: 2013-11-13 15:19:30 +0100 (Wed, 13 Nov 2013) $
- ***************************************************************/
-
 /** \file
  * \brief Declaration of TLP string conversion functions.
  *
@@ -16,7 +8,7 @@
  *
  * \par
  * Copyright (C)<br>
- * See README.txt in the root directory of the OGDF installation for details.
+ * See README.md in the OGDF root directory for details.
  *
  * \par
  * This program is free software; you can redistribute it and/or
@@ -33,47 +25,35 @@
  *
  * \par
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
- * \see  http://www.gnu.org/copyleft/gpl.html
- ***************************************************************/
+ * License along with this program; if not, see
+ * http://www.gnu.org/copyleft/gpl.html
+ */
 
-#ifdef _MSC_VER
 #pragma once
-#endif
-
-
-#ifndef OGDF_TLP_H
-#define OGDF_TLP_H
-
 
 #include <string>
 
-
 namespace ogdf {
 
 namespace tlp {
 
 
-enum Attribute {
-	a_label,
-	a_color,
-	a_position,
-	a_size,
-	a_shape,
-	a_unknown
+enum class Attribute {
+	label,
+	color,
+	strokeColor,
+	strokeWidth,
+	strokeType,
+	fillPattern,
+	fillBackground,
+	position,
+	size,
+	shape,
+	unknown
 };
 
+std::string toString(const Attribute& attr);
+Attribute toAttribute(const std::string& str);
 
-std::string toString(const Attribute &attr);
-Attribute toAttribute(const std::string &str);
-
-
-} // end namespace tlp
-
-} // end namespace ogdf
-
-
-#endif
+}
+}
