@@ -1,11 +1,3 @@
-/*
- * $Revision: 2564 $
- *
- * last checkin:
- *   $Author: gutwenger $
- *   $Date: 2012-07-07 00:03:48 +0200 (Sat, 07 Jul 2012) $
- ***************************************************************/
-
 /** \file
  * \brief Declaration of class ELabelPosSimple which represents
  *        a simple labeling algorithm.
@@ -17,7 +9,7 @@
  *
  * \par
  * Copyright (C)<br>
- * See README.txt in the root directory of the OGDF installation for details.
+ * See README.md in the OGDF root directory for details.
  *
  * \par
  * This program is free software; you can redistribute it and/or
@@ -34,48 +26,31 @@
  *
  * \par
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
- * \see  http://www.gnu.org/copyleft/gpl.html
- ***************************************************************/
+ * License along with this program; if not, see
+ * http://www.gnu.org/copyleft/gpl.html
+ */
 
-
-#ifdef _MSC_VER
 #pragma once
-#endif
-
-
-#ifndef OGDF_E_LABEL_POS_SIMPLE_H
-#define OGDF_E_LABEL_POS_SIMPLE_H
 
 #include <ogdf/labeling/ELabelInterface.h>
 
-
 namespace ogdf {
 
 class OGDF_EXPORT ELabelPosSimple {
-
 public:
-
 	ELabelPosSimple();
 	~ELabelPosSimple();
 
 	void call(GraphAttributes& ug, ELabelInterface<double>& eli); //double
 
-	bool   m_absolut;
+	bool m_absolut;
 	double m_marginDistance;
 	double m_edgeDistance;
 
-	bool   m_midOnEdge;
+	bool m_midOnEdge;
 
 private:
-
-
 };
 
 
 }
-
-#endif
