@@ -1,11 +1,3 @@
-/*
- * $Revision: 2523 $
- *
- * last checkin:
- *   $Author: gutwenger $
- *   $Date: 2012-07-02 20:59:27 +0200 (Mon, 02 Jul 2012) $
- ***************************************************************/
-
 /** \file
  * \brief Declaration of a Mixed-Model crossings beautifier
  * that local stretching.
@@ -17,7 +9,7 @@
  *
  * \par
  * Copyright (C)<br>
- * See README.txt in the root directory of the OGDF installation for details.
+ * See README.md in the OGDF root directory for details.
  *
  * \par
  * This program is free software; you can redistribute it and/or
@@ -34,33 +26,21 @@
  *
  * \par
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
- * \see  http://www.gnu.org/copyleft/gpl.html
- ***************************************************************/
+ * License along with this program; if not, see
+ * http://www.gnu.org/copyleft/gpl.html
+ */
 
-#ifdef _MSC_VER
 #pragma once
-#endif
-
-#ifndef OGDF_MMCB_LOCAL_STRETCH_H
-#define OGDF_MMCB_LOCAL_STRETCH_H
-
-
 
 #include <ogdf/planarlayout/MMCBBase.h>
 
-
 namespace ogdf {
 
 
 /**
  * \brief Crossings beautifier using a local stretch strategy.
  */
-class OGDF_EXPORT MMCBLocalStretch : public MMCBBase
-{
+class OGDF_EXPORT MMCBLocalStretch : public MMCBBase {
 public:
 	//! Creates an instance of the crossings beautifier.
 	MMCBLocalStretch() { }
@@ -69,10 +49,7 @@ public:
 
 protected:
 	//! Implements the module call.
-	void doCall(const PlanRep &PG, GridLayout &gl, const List<node> &L);
+	virtual void doCall(const PlanRep& PG, GridLayout& gl, const List<node>& L) override;
 };
 
-
-} // end namespace ogdf
-
-#endif
+}
