@@ -374,7 +374,9 @@ CoinMessageHandler::internalPrint()
 int
 CoinMessageHandler::print()
 {
+#ifndef NDEBUG
   fprintf(fp_,"%s\n",messageBuffer_);
+#endif
   return 0;
 }
 // Check severity
@@ -761,7 +763,7 @@ CoinMessageHandler::operator<< (double doublevalue)
 	  sprintf(messageOut_,g_format_,doublevalue);
 	  if (next != format_+2) {
 	    messageOut_+=strlen(messageOut_);
-	    sprintf(messageOut_,format_+2);
+	    strcpy(messageOut_,format_ + 2);
 	  }
 	}
 	messageOut_+=strlen(messageOut_);
