@@ -5,6 +5,7 @@
 
   This code is licensed under the terms of the Eclipse Public License (EPL).
 */
+#include <climits>
 #include "CoinOslFactorization.hpp"
 #include "CoinOslC.h"
 #include "CoinFinite.hpp"
@@ -1384,7 +1385,7 @@ static void c_ekkmltf(const EKKfactinfo *fact,double *dluval, int *hcoli,
     }
   }
 } /* c_ekkmltf */
-int c_ekklfct( register EKKfactinfo *fact)
+int c_ekklfct(EKKfactinfo *fact)
 {
   const int nrow	= fact->nrow;
   int ninbas = fact->xcsadr[nrow+1]-1;
@@ -1912,10 +1913,7 @@ static void c_ekk_sort2(int * key , double * array2,int number)
   double it;
   int j;
   /*check already sorted  */
-#ifndef LONG_MAX
-#define LONG_MAX 0x7fffffff;
-#endif
-  int last=-LONG_MAX;
+  int last=INT_MIN;
   for (j=0;j<number;j++) {
     if (key[j]>=last) {
       last=key[j];
@@ -2621,7 +2619,7 @@ inline void c_ekkclcp2(const int *hcol, const double *dels, const int * mrstrt,
     }
   }
 } /* c_ekkclcp */
-int c_ekkslcf( register const EKKfactinfo *fact)
+int c_ekkslcf(const EKKfactinfo *fact)
 {
   int * hrow = fact->xeradr;
   int * hcol = fact->xecadr;
