@@ -2435,12 +2435,12 @@ int CoinSimpFactorization::LUupdate(int newBasicCol)
     // increase Eta by (lastRowInU-posNewCol) elements
     newEta(rowInU, lastRowInU-posNewCol );
     assert(!EtaLengths_[lastEtaRow_]);
-    int saveSize = EtaSize_;;
+    int saveSize = EtaSize_;
     for ( int i=posNewCol; i<lastRowInU; ++i ){
 	const int row=secRowOfU_[i];
 	const int column=colOfU_[i];
 	if ( denseVector_[column]==0.0 ) continue;
-	register const double multiplier=denseVector_[column]*invOfPivots_[row];
+	const double multiplier=denseVector_[column]*invOfPivots_[row];
 	denseVector_[column]=0.0;
 	const int rowBeg=UrowStarts_[row];
 	const int rowEnd=rowBeg+UrowLengths_[row];
@@ -2663,4 +2663,3 @@ void CoinSimpFactorization::btran(double *b, double *sol) const
     xHeqb(sol);
     xLeqb(sol);
 }
-
