@@ -1549,7 +1549,7 @@ CoinPresolveMatrix::CoinPresolveMatrix(int ncols0_in,
     sol_ = new double[ncols_];
     const double *presol ;
     presol = si->getColSolution() ;
-    memcpy(sol_,presol,ncols_*sizeof(double));;
+    memcpy(sol_,presol,ncols_*sizeof(double));
     acts_ = new double [nrows_];
     memcpy(acts_,si->getRowActivity(),nrows_*sizeof(double));
     CoinWarmStartBasis * basis  =
@@ -1811,5 +1811,3 @@ CoinPostsolveMatrix::CoinPostsolveMatrix(OsiSolverInterface*  si,
   CoinZeroN(rdone_+nrows1,nrows0_in-nrows1) ;
 # endif
 }
-
-
