@@ -1,11 +1,3 @@
-/*
- * $Revision: 2523 $
- *
- * last checkin:
- *   $Author: gutwenger $
- *   $Date: 2012-07-02 20:59:27 +0200 (Mon, 02 Jul 2012) $
- ***************************************************************/
-
 /** \file
  * \brief Implements a simple, dfs-based algorithm for
  * biconnectivity augmentation.
@@ -17,7 +9,7 @@
  *
  * \par
  * Copyright (C)<br>
- * See README.txt in the root directory of the OGDF installation for details.
+ * See README.md in the OGDF root directory for details.
  *
  * \par
  * This program is free software; you can redistribute it and/or
@@ -34,25 +26,17 @@
  *
  * \par
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
- * \see  http://www.gnu.org/copyleft/gpl.html
- ***************************************************************/
+ * License along with this program; if not, see
+ * http://www.gnu.org/copyleft/gpl.html
+ */
 
 
 #include <ogdf/augmentation/DfsMakeBiconnected.h>
 #include <ogdf/basic/simple_graph_alg.h>
 
-
 namespace ogdf {
 
 
-void DfsMakeBiconnected::doCall(Graph &G, List<edge> &L)
-{
-	makeBiconnected(G,L);
+void DfsMakeBiconnected::doCall(Graph& G, List<edge>& L) { makeBiconnected(G, L); }
+
 }
-
-
-} // end namespace ogdf
