@@ -1,11 +1,3 @@
-/*
- * $Revision: 3977 $
- *
- * last checkin:
- *   $Author: gutwenger $
- *   $Date: 2014-03-25 13:59:42 +0100 (Tue, 25 Mar 2014) $
- ***************************************************************/
-
 /** \file
  * \brief Computes an embedding of a graph with minimum depth.
  * See paper "Graph Embedding with Minimum Depth and Maximum External
@@ -18,7 +10,7 @@
  *
  * \par
  * Copyright (C)<br>
- * See README.txt in the root directory of the OGDF installation for details.
+ * See README.md in the OGDF root directory for details.
  *
  * \par
  * This program is free software; you can redistribute it and/or
@@ -35,66 +27,28 @@
  *
  * \par
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
- * \see  http://www.gnu.org/copyleft/gpl.html
- ***************************************************************/
+ * License along with this program; if not, see
+ * http://www.gnu.org/copyleft/gpl.html
+ */
 
 #include <ogdf/planarity/EmbedderMinDepth.h>
-#include <ogdf/internal/planarity/EmbedderMaxFaceBiconnectedGraphs.h>
-#include <ogdf/internal/planarity/ConnectedSubgraph.h>
+#include <ogdf/planarity/embedder/ConnectedSubgraph.h>
+#include <ogdf/planarity/embedder/EmbedderMaxFaceBiconnectedGraphs.h>
+
+#include <limits>
 
 namespace ogdf {
 
-void EmbedderMinDepth::call(Graph& G, adjEntry& adjExternal)
-{
-	adjExternal = 0;
+void EmbedderMinDepth::doCall(Graph& G, adjEntry& adjExternal) {
+	adjExternal = nullptr;
 	pAdjExternal = &adjExternal;
+	node rootBlockNode = initBCTree(G);
 
-	//simple base cases:
-	if (G.numberOfNodes() <= 1)
-		return;
-
-	if (G.numberOfEdges() == 1)
-	{
-		edge e = G.firstEdge();
-		adjExternal = e->adjSource();
+	if (rootBlockNode == nullptr) {
 		return;
 	}
 
-	//HINT: Edges are directed from child to parent in BC-trees
-	pBCTree = new BCTree(G);
-
-	//base case of biconnected graph:
-	if (pBCTree->bcTree().numberOfNodes() == 1)
-	{
-		NodeArray<int> m_nodeLength(G, 0);
-		EdgeArray<int> m_edgeLength(G, 0);
-		adjEntry m_adjExternal;
-		EmbedderMaxFaceBiconnectedGraphs<int>::embed(G, m_adjExternal, m_nodeLength, m_edgeLength);
-		adjExternal = m_adjExternal->twin();
-
-		delete pBCTree;
-		return;
-	}
-
-
-	//***************************************************************************/
 	//First step: calculate min depth and node lengths
-	//***************************************************************************/
-	//Find root Block (only node with out-degree of 0):
-	node rootBlockNode = 0;
-	node n;
-	forall_nodes(n, pBCTree->bcTree())
-	{
-		if (n->outdeg() == 0) {
-			rootBlockNode = n;
-			break;
-		}
-	}
-	OGDF_ASSERT(rootBlockNode != 0);
 
 	//compute block graphs:
 	blockG.init(pBCTree->bcTree());
@@ -103,26 +57,25 @@ void EmbedderMinDepth::call(Graph& G, adjEntry& adjExternal)
 	nH_to_nBlockEmbedding.init(pBCTree->bcTree());
 	eH_to_eBlockEmbedding.init(pBCTree->bcTree());
 	nodeLength.init(pBCTree->bcTree());
-	spqrTrees.init(pBCTree->bcTree(),0);
-	computeBlockGraphs(rootBlockNode, 0);
+	spqrTrees.init(pBCTree->bcTree(), nullptr);
+	computeBlockGraphs(rootBlockNode, nullptr);
 
 	//Edge lengths of BC-tree, values m_{c, B} for all (c, B) \in bcTree:
 	m_cB.init(pBCTree->bcTree(), 0);
 
 	//Bottom-up traversal: (set m_cB for all {c, B} \in bcTree)
 	nodeLength[rootBlockNode].init(blockG[rootBlockNode], 0);
-	edge e;
-	forall_adj_edges(e, rootBlockNode)
-	{
+	for (adjEntry adj : rootBlockNode->adjEntries) {
+		edge e = adj->theEdge();
 		node cT = e->source();
 		//node cH = pBCTree->cutVertex(cT, rootBlockNode);
 
 		//set length of c in block graph of root block node:
-		edge e2;
-		forall_adj_edges(e2, cT)
-		{
-			if (e2->target() != cT)
+		for (adjEntry adjCT : cT->adjEntries) {
+			edge e2 = adjCT->theEdge();
+			if (e2->target() != cT) {
 				continue;
+			}
 
 			node blockNode = e2->source();
 			node cutVertex = pBCTree->cutVertex(cT, blockNode);
@@ -134,7 +87,7 @@ void EmbedderMinDepth::call(Graph& G, adjEntry& adjExternal)
 
 	//Top-down traversal: (set m_cB for all {B, c} \in bcTree and get min depth
 	//for each block)
-	int maxint = 2147483647;
+	int maxint = std::numeric_limits<int>::max();
 	minDepth.init(pBCTree->bcTree(), maxint);
 	M_B.init(pBCTree->bcTree());
 	M2.init(pBCTree->bcTree());
@@ -142,50 +95,48 @@ void EmbedderMinDepth::call(Graph& G, adjEntry& adjExternal)
 
 	//compute bT_opt:
 	int depth = maxint;
-	node bT_opt;
-	forall_nodes(n, pBCTree->bcTree())
-	{
-		if (pBCTree->typeOfBNode(n) != BCTree::BComp)
+	node bT_opt = nullptr;
+	for (node n : pBCTree->bcTree().nodes) {
+		if (pBCTree->typeOfBNode(n) != BCTree::BNodeType::BComp) {
 			continue;
-		if (minDepth[n] < depth)
-		{
+		}
+		if (minDepth[n] < depth) {
 			depth = minDepth[n];
 			bT_opt = n;
 		}
 	}
+	OGDF_ASSERT(bT_opt != nullptr);
 
-	//****************************************************************************
 	//Second step: Embed G by expanding a maximum face in bT_opt
-	//****************************************************************************
 	newOrder.init(G);
 	treeNodeTreated.init(pBCTree->bcTree(), false);
 	embedBlock(bT_opt);
 
-	forall_nodes(n, G)
+	for (node n : G.nodes) {
 		G.sort(n, newOrder[n]);
+	}
 
-	forall_nodes(n, pBCTree->bcTree())
+	for (node n : pBCTree->bcTree().nodes) {
 		delete spqrTrees[n];
+	}
 
 	delete pBCTree;
 }
 
-
-void EmbedderMinDepth::computeBlockGraphs(const node& bT, const node& cH)
-{
+void EmbedderMinDepth::computeBlockGraphs(const node& bT, const node& cH) {
 	//recursion:
-	edge e;
-	forall_adj_edges(e, bT)
-	{
-		if (e->source() == bT)
+	for (adjEntry adj : bT->adjEntries) {
+		edge e = adj->theEdge();
+		if (e->source() == bT) {
 			continue;
+		}
 
 		node cT = e->source();
-		edge e2;
-		forall_adj_edges(e2, cT)
-		{
-			if (e2->source() == cT)
+		for (adjEntry adjCT : cT->adjEntries) {
+			edge e2 = adjCT->theEdge();
+			if (e2->source() == cT) {
 				continue;
+			}
 			node cH2 = pBCTree->cutVertex(cT, e2->source());
 			computeBlockGraphs(e2->source(), cH2);
 		}
@@ -193,128 +144,114 @@ void EmbedderMinDepth::computeBlockGraphs(const node& bT, const node& cH)
 
 	//embed block bT:
 	node m_cH = cH;
-	if (m_cH == 0)
+	if (m_cH == nullptr) {
 		m_cH = pBCTree->cutVertex(bT->firstAdj()->twinNode(), bT);
-	ConnectedSubgraph<int>::call(pBCTree->auxiliaryGraph(), blockG[bT], m_cH,
-		nBlockEmbedding_to_nH[bT], eBlockEmbedding_to_eH[bT],
-		nH_to_nBlockEmbedding[bT], eH_to_eBlockEmbedding[bT]);
+	}
+	embedder::ConnectedSubgraph<int>::call(pBCTree->auxiliaryGraph(), blockG[bT], m_cH,
+			nBlockEmbedding_to_nH[bT], eBlockEmbedding_to_eH[bT], nH_to_nBlockEmbedding[bT],
+			eH_to_eBlockEmbedding[bT]);
 
-	if (!blockG[bT].empty()
-		&& blockG[bT].numberOfNodes() != 1
-		&& blockG[bT].numberOfEdges() > 2)
-	{
+	if (!blockG[bT].empty() && blockG[bT].numberOfNodes() != 1 && blockG[bT].numberOfEdges() > 2) {
 		spqrTrees[bT] = new StaticSPQRTree(blockG[bT]);
 	}
 }
 
-
-int EmbedderMinDepth::bottomUpTraversal(const node& bT, const node& cH)
-{
+int EmbedderMinDepth::bottomUpTraversal(const node& bT, const node& cH) {
 	int m_B = 0; //max_{c \in B} m_B(c)
-	List<node> M_B; //{c \in B | m_B(c) = m_B}
+	List<node> cInBWithProperty; //{c \in B | m_B(c) = m_B}
 
 	//Recursion:
-	edge e;
-	forall_adj_edges(e, bT)
-	{
-		if (e->target() != bT)
+	for (adjEntry adj : bT->adjEntries) {
+		edge e = adj->theEdge();
+		if (e->target() != bT) {
 			continue;
+		}
 		node cT = e->source();
 		//node c_in_bT = pBCTree->cutVertex(cT, bT);
 
 		//set length of c in block graph of root block node:
-		edge e_cT_bT2;
-		forall_adj_edges(e_cT_bT2, cT)
-		{
-			if (e == e_cT_bT2)
+		for (adjEntry adjCT : cT->adjEntries) {
+			edge e_cT_bT2 = adjCT->theEdge();
+			if (e == e_cT_bT2) {
 				continue;
+			}
 
 			node bT2 = e_cT_bT2->source();
 			node c_in_bT2 = pBCTree->cutVertex(cT, bT2);
 			m_cB[e_cT_bT2] = bottomUpTraversal(bT2, c_in_bT2);
 
-			//update m_B and M_B:
-			if (m_B < m_cB[e_cT_bT2])
-			{
+			//update m_B and cInBWithProperty:
+			if (m_B < m_cB[e_cT_bT2]) {
 				node cV_in_bT = pBCTree->cutVertex(cT, bT);
 				m_B = m_cB[e_cT_bT2];
-				M_B.clear();
-				M_B.pushBack(cV_in_bT);
-			}
-			else if (m_B == m_cB[e_cT_bT2] && !M_B.search(pBCTree->cutVertex(cT, bT)).valid())
-			{
+				cInBWithProperty.clear();
+				cInBWithProperty.pushBack(cV_in_bT);
+			} else if (m_B == m_cB[e_cT_bT2]
+					&& !cInBWithProperty.search(pBCTree->cutVertex(cT, bT)).valid()) {
 				node cV_in_bT = pBCTree->cutVertex(cT, bT);
-				M_B.pushBack(cV_in_bT);
+				cInBWithProperty.pushBack(cV_in_bT);
 			}
 		}
 	}
 
-	//set vertex length for all vertices in bH to 1 if vertex is in M_B:
+	//set vertex length for all vertices in bH to 1 if vertex is in cInBWithProperty:
 	nodeLength[bT].init(blockG[bT], 0);
-	for (ListIterator<node> iterator = M_B.begin(); iterator.valid(); iterator++)
+	for (ListIterator<node> iterator = cInBWithProperty.begin(); iterator.valid(); ++iterator) {
 		nodeLength[bT][nH_to_nBlockEmbedding[bT][*iterator]] = 1;
+	}
 
 	//leafs of BC-tree:
-	if (M_B.size() == 0)
+	if (cInBWithProperty.size() == 0) {
 		return 1;
+	}
 
 	//set edge length for all edges in block graph to 0:
 	EdgeArray<int> edgeLength(blockG[bT], 0);
 
 	//compute maximum external face of block graph and get its size:
-	int cstrLength_B_c = EmbedderMaxFaceBiconnectedGraphs<int>::computeSize(
-		blockG[bT],
-		nH_to_nBlockEmbedding[bT][cH],
-		nodeLength[bT],
-		edgeLength,
-		spqrTrees[bT]);
+	int cstrLength_B_c = EmbedderMaxFaceBiconnectedGraphs<int>::computeSize(blockG[bT],
+			nH_to_nBlockEmbedding[bT][cH], nodeLength[bT], edgeLength, spqrTrees[bT]);
 
-	if (cstrLength_B_c == M_B.size())
+	if (cstrLength_B_c == cInBWithProperty.size()) {
 		return m_B;
+	}
 	//else:
 	return m_B + 2;
 }
 
-
-void EmbedderMinDepth::topDownTraversal(const node& bT)
-{
+void EmbedderMinDepth::topDownTraversal(const node& bT) {
 	//m_B(c) = max {0} \cup {m_{c, B'} | c \in B', B' \neq B}
 	int m_B = 0; //max_{c \in B} m_B(c)
 
 	//Compute m_B and M_B:
-	node cT_parent = 0;
-	edge e_bT_cT;
-	{
-		forall_adj_edges(e_bT_cT, bT)
-		{
-			if (e_bT_cT->source() == bT)
-				cT_parent = e_bT_cT->target();
-			node cT = (e_bT_cT->source() == bT) ? e_bT_cT->target() : e_bT_cT->source();
-			edge e_cT_bT2;
-			forall_adj_edges(e_cT_bT2, cT)
-			{
-				if (e_cT_bT2 == e_bT_cT)
-					continue;
+	node cT_parent = nullptr;
 
-				//update m_B and M_B:
-				if (m_B < m_cB[e_cT_bT2])
-				{
-					m_B = m_cB[e_cT_bT2];
-					M_B[bT].clear();
-					M_B[bT].pushBack(pBCTree->cutVertex(cT, bT));
-				}
-				else if (m_B == m_cB[e_cT_bT2] && !M_B[bT].search(pBCTree->cutVertex(cT, bT)).valid())
-				{
-					M_B[bT].pushBack(pBCTree->cutVertex(cT, bT));
-				}
-			}//forall_adj_edges(e_cT_bT2, cT)
-		}//forall_adj_edges(e_bT_cT, bT)
+	for (adjEntry adj : bT->adjEntries) {
+		edge e_bT_cT = adj->theEdge();
+		if (e_bT_cT->source() == bT) {
+			cT_parent = e_bT_cT->target();
+		}
+		node cT = (e_bT_cT->source() == bT) ? e_bT_cT->target() : e_bT_cT->source();
+		for (adjEntry adjCT : cT->adjEntries) {
+			edge e_cT_bT2 = adjCT->theEdge();
+			if (e_cT_bT2 == e_bT_cT) {
+				continue;
+			}
+
+			//update m_B and M_B:
+			if (m_B < m_cB[e_cT_bT2]) {
+				m_B = m_cB[e_cT_bT2];
+				M_B[bT].clear();
+				M_B[bT].pushBack(pBCTree->cutVertex(cT, bT));
+			} else if (m_B == m_cB[e_cT_bT2] && !M_B[bT].search(pBCTree->cutVertex(cT, bT)).valid()) {
+				M_B[bT].pushBack(pBCTree->cutVertex(cT, bT));
+			}
+		}
 	}
 	//set vertex length for all vertices in bH to 1 if vertex is in M_B:
 	nodeLength[bT].fill(0);
 	NodeArray<int> m_nodeLength(blockG[bT], 0);
-	for (ListIterator<node> iterator = M_B[bT].begin(); iterator.valid(); iterator++)
-	{
+	for (ListIterator<node> iterator = M_B[bT].begin(); iterator.valid(); ++iterator) {
 		nodeLength[bT][nH_to_nBlockEmbedding[bT][*iterator]] = 1;
 		m_nodeLength[nH_to_nBlockEmbedding[bT][*iterator]] = 1;
 	}
@@ -323,101 +260,87 @@ void EmbedderMinDepth::topDownTraversal(const node& bT)
 	EdgeArray<int> edgeLengthBlock(blockG[bT], 0);
 
 	//compute size of a maximum external face of block graph:
-	NodeArray< EdgeArray<int> > edgeLengthSkel;
-	int cstrLength_B_c = EmbedderMaxFaceBiconnectedGraphs<int>::computeSize(
-		blockG[bT],
-		m_nodeLength,
-		edgeLengthBlock,
-		spqrTrees[bT],
-		edgeLengthSkel);
+	NodeArray<EdgeArray<int>> edgeLengthSkel;
+	int cstrLength_B_c = EmbedderMaxFaceBiconnectedGraphs<int>::computeSize(blockG[bT],
+			m_nodeLength, edgeLengthBlock, spqrTrees[bT], edgeLengthSkel);
 
 	//Prepare recursion by setting m_{c, B} for all edges {B, c} \in bcTree:
-	if (M_B[bT].size() > 0)
-	{
+	if (M_B[bT].size() > 0) {
 		node cT1 = pBCTree->bcproper(pBCTree->original(*(M_B[bT].begin())));
 		bool calculateNewNodeLengths;
-		if (M_B[bT].size() == 1 && cT1 == cT_parent)
-			calculateNewNodeLengths = true;
-		else
-			calculateNewNodeLengths = false;
-		forall_adj_edges(e_bT_cT, bT)
-		{
-			if (e_bT_cT->target() != bT)
+		calculateNewNodeLengths = M_B[bT].size() == 1 && cT1 == cT_parent;
+		for (adjEntry adj : bT->adjEntries) {
+			edge e_bT_cT = adj->theEdge();
+			if (e_bT_cT->target() != bT) {
 				continue;
+			}
 			node cT = e_bT_cT->source();
 			node cH = pBCTree->cutVertex(cT, bT);
 
-			if (M_B[bT].size() == 1 && cT1 == cT)
-			{
+			if (M_B[bT].size() == 1 && cT1 == cT) {
 				//Compute new vertex lengths according to
 				//m2 = max_{v \in V_B, v != c} m_B(v) and
 				//M2 = {c \in V_B \ {v} | m_B(c) = m2}.
 				int m2 = 0;
 
 				//Compute m2 and M2:
-				edge e_bT_cT2;
-				forall_adj_edges(e_bT_cT2, bT)
-				{
+				for (adjEntry adjBT : bT->adjEntries) {
+					edge e_bT_cT2 = adjBT->theEdge();
 					node cT2 = (e_bT_cT2->source() == bT) ? e_bT_cT2->target() : e_bT_cT2->source();
-					if (cT1 == cT2)
+					if (cT1 == cT2) {
 						continue;
-					edge e_cT2_bT2;
-					forall_adj_edges(e_cT2_bT2, cT2)
-					{
-						if (e_cT2_bT2 == e_bT_cT2)
+					}
+					for (adjEntry adjCT2 : cT2->adjEntries) {
+						edge e_cT2_bT2 = adjCT2->theEdge();
+						if (e_cT2_bT2 == e_bT_cT2) {
 							continue;
+						}
 
 						//update m_B and M_B:
-						if (m2 < m_cB[e_cT2_bT2])
-						{
+						if (m2 < m_cB[e_cT2_bT2]) {
 							m2 = m_cB[e_cT2_bT2];
 							M2[bT].clear();
 							M2[bT].pushBack(pBCTree->cutVertex(cT2, bT));
-						}
-						else if (m2 == m_cB[e_cT2_bT2] && !M2[bT].search(pBCTree->cutVertex(cT2, bT)).valid())
-						{
+						} else if (m2 == m_cB[e_cT2_bT2]
+								&& !M2[bT].search(pBCTree->cutVertex(cT2, bT)).valid()) {
 							M2[bT].pushBack(pBCTree->cutVertex(cT2, bT));
 						}
-					}//forall_adj_edges(e_cT2_bT2, cT2)
-				}//forall_adj_edges(e_bT_cT2, bT)
+					}
+				}
 
 				//set vertex length for all vertices in bH to 1 if vertex is in M2 and
 				//0 otherwise:
 				nodeLength[bT][nH_to_nBlockEmbedding[bT][*(M_B[bT].begin())]] = 0;
-				for (ListIterator<node> iterator = M2[bT].begin(); iterator.valid(); iterator++)
+				for (ListIterator<node> iterator = M2[bT].begin(); iterator.valid(); ++iterator) {
 					nodeLength[bT][nH_to_nBlockEmbedding[bT][*iterator]] = 1;
+				}
 
 				//set edge length for all edges in block graph to 0:
 				EdgeArray<int> edgeLength(blockG[bT], 0);
 
 				//compute a maximum external face size of a face containing c in block graph:
-				int maxFaceSize = EmbedderMaxFaceBiconnectedGraphs<int>::computeSize(
-					blockG[bT],
-					nH_to_nBlockEmbedding[bT][cH],
-					nodeLength[bT],
-					edgeLength,
-					spqrTrees[bT]);
-				if (M2[bT].size() == 0)
+				int maxFaceSize = EmbedderMaxFaceBiconnectedGraphs<int>::computeSize(blockG[bT],
+						nH_to_nBlockEmbedding[bT][cH], nodeLength[bT], edgeLength, spqrTrees[bT]);
+				if (M2[bT].size() == 0) {
 					m_cB[e_bT_cT] = 1;
-				else
-				{
-					if (maxFaceSize == M2[bT].size())
+				} else {
+					if (maxFaceSize == M2[bT].size()) {
 						m_cB[e_bT_cT] = m2;
-					else
+					} else {
 						m_cB[e_bT_cT] = m2 + 2;
+					}
 				}
 
-				if (calculateNewNodeLengths)
+				if (calculateNewNodeLengths) {
 					calculateNewNodeLengths = false;
-				else
-				{
+				} else {
 					//reset node lengths:
-					for (ListIterator<node> iterator = M2[bT].begin(); iterator.valid(); iterator++)
+					for (ListIterator<node> iterator = M2[bT].begin(); iterator.valid(); ++iterator) {
 						nodeLength[bT][nH_to_nBlockEmbedding[bT][*iterator]] = 0;
+					}
 					nodeLength[bT][nH_to_nBlockEmbedding[bT][*(M_B[bT].begin())]] = 1;
 				}
-			}
-			else //M_B.size() != 1
+			} else //M_B.size() != 1
 			{
 				//Compute a maximum face in block B containing c using the vertex lengths
 				//already assigned.
@@ -426,110 +349,101 @@ void EmbedderMinDepth::topDownTraversal(const node& bT)
 				EdgeArray<int> edgeLength(blockG[bT], 0);
 
 				//compute a maximum external face size of a face containing c in block graph:
-				int maxFaceSize = EmbedderMaxFaceBiconnectedGraphs<int>::computeSize(
-					blockG[bT],
-					nH_to_nBlockEmbedding[bT][cH],
-					nodeLength[bT],
-					edgeLength,
-					spqrTrees[bT],
-					edgeLengthSkel);
-				if (M_B[bT].size() == 0)
+				int maxFaceSize = EmbedderMaxFaceBiconnectedGraphs<int>::computeSize(blockG[bT],
+						nH_to_nBlockEmbedding[bT][cH], nodeLength[bT], edgeLength, spqrTrees[bT],
+						edgeLengthSkel);
+				if (M_B[bT].size() == 0) {
 					m_cB[e_bT_cT] = 1;
-				else
-				{
-					if (maxFaceSize == M_B[bT].size())
+				} else {
+					if (maxFaceSize == M_B[bT].size()) {
 						m_cB[e_bT_cT] = m_B;
-					else
+					} else {
 						m_cB[e_bT_cT] = m_B + 2;
+					}
 				}
 			}
-		}//forall_adj_edges(e_bT_cT, bT)
+		}
 
-		if (calculateNewNodeLengths)
-		{
+		if (calculateNewNodeLengths) {
 			//Compute new vertex lengths according to
 			//m2 = max_{v \in V_B, v != c} m_B(v) and
 			//M2 = {c \in V_B \ {v} | m_B(c) = m2}.
 			int m2 = 0;
 
 			//Compute m2 and M2:
-			edge e_bT_cT2;
-			forall_adj_edges(e_bT_cT2, bT)
-			{
+			for (adjEntry adj : bT->adjEntries) {
+				edge e_bT_cT2 = adj->theEdge();
 				node cT2 = (e_bT_cT2->source() == bT) ? e_bT_cT2->target() : e_bT_cT2->source();
-				if (cT1 == cT2)
+				if (cT1 == cT2) {
 					continue;
-				edge e_cT2_bT2;
-				forall_adj_edges(e_cT2_bT2, cT2)
-				{
-					if (e_cT2_bT2 == e_bT_cT2)
+				}
+				for (adjEntry adjCT2 : cT2->adjEntries) {
+					edge e_cT2_bT2 = adjCT2->theEdge();
+					if (e_cT2_bT2 == e_bT_cT2) {
 						continue;
+					}
 
 					//update m_B and M_B:
-					if (m2 < m_cB[e_cT2_bT2])
-					{
+					if (m2 < m_cB[e_cT2_bT2]) {
 						m2 = m_cB[e_cT2_bT2];
 						M2[bT].clear();
 						M2[bT].pushBack(pBCTree->cutVertex(cT2, bT));
-					}
-					else if (m2 == m_cB[e_cT2_bT2] && !M2[bT].search(pBCTree->cutVertex(cT2, bT)).valid())
-					{
+					} else if (m2 == m_cB[e_cT2_bT2]
+							&& !M2[bT].search(pBCTree->cutVertex(cT2, bT)).valid()) {
 						M2[bT].pushBack(pBCTree->cutVertex(cT2, bT));
 					}
-				}//forall_adj_edges(e_cT2_bT2, cT2)
-			}//forall_adj_edges(e_bT_cT2, bT)
+				}
+			}
 
 			//set vertex length for all vertices in bH to 1 if vertex is in M2 and
 			//0 otherwise:
 			nodeLength[bT][nH_to_nBlockEmbedding[bT][*(M_B[bT].begin())]] = 0;
-			for (ListIterator<node> iterator = M2[bT].begin(); iterator.valid(); iterator++)
+			for (ListIterator<node> iterator = M2[bT].begin(); iterator.valid(); ++iterator) {
 				nodeLength[bT][nH_to_nBlockEmbedding[bT][*iterator]] = 1;
-		} //if (calculateNewNodeLengths
-		else if (M_B[bT].size() == 1)
-		{
+			}
+		} else if (M_B[bT].size() == 1) {
 			//Compute M2 = {c \in V_B \ {v} | m_B(c) = m2} with
 			//m2 = max_{v \in V_B, v != c} m_B(v).
 			int m2 = 0;
-			edge e_bT_cT2;
-			forall_adj_edges(e_bT_cT2, bT)
-			{
+			for (adjEntry adj : bT->adjEntries) {
+				edge e_bT_cT2 = adj->theEdge();
 				node cT2 = (e_bT_cT2->source() == bT) ? e_bT_cT2->target() : e_bT_cT2->source();
-				if (cT1 == cT2)
+				if (cT1 == cT2) {
 					continue;
-				edge e_cT2_bT2;
-				forall_adj_edges(e_cT2_bT2, cT2)
-				{
-					if (e_cT2_bT2 == e_bT_cT2)
+				}
+				for (adjEntry adjCT2 : cT2->adjEntries) {
+					edge e_cT2_bT2 = adjCT2->theEdge();
+					if (e_cT2_bT2 == e_bT_cT2) {
 						continue;
+					}
 
 					//update m_B and M_B:
-					if (m2 < m_cB[e_cT2_bT2])
-					{
+					if (m2 < m_cB[e_cT2_bT2]) {
 						m2 = m_cB[e_cT2_bT2];
 						M2[bT].clear();
 						M2[bT].pushBack(pBCTree->cutVertex(cT2, bT));
-					}
-					else if (m2 == m_cB[e_cT2_bT2] && !M2[bT].search(pBCTree->cutVertex(cT2, bT)).valid())
-					{
+					} else if (m2 == m_cB[e_cT2_bT2]
+							&& !M2[bT].search(pBCTree->cutVertex(cT2, bT)).valid()) {
 						M2[bT].pushBack(pBCTree->cutVertex(cT2, bT));
 					}
-				}//forall_adj_edges(e_cT2_bT2, cT2)
-			}//forall_adj_edges(e_bT_cT2, bT)
+				}
+			}
 		}
 	}
 
 	//Recursion:
-	forall_adj_edges(e_bT_cT, bT)
-	{
-		if (e_bT_cT->target() != bT)
+	for (adjEntry adj : bT->adjEntries) {
+		edge e_bT_cT = adj->theEdge();
+		if (e_bT_cT->target() != bT) {
 			continue;
+		}
 
 		node cT = e_bT_cT->source();
-		edge e_cT_bT2;
-		forall_adj_edges(e_cT_bT2, cT)
-		{
-			if (e_cT_bT2 == e_bT_cT)
+		for (adjEntry adjCT : cT->adjEntries) {
+			edge e_cT_bT2 = adjCT->theEdge();
+			if (e_cT_bT2 == e_bT_cT) {
 				continue;
+			}
 
 			topDownTraversal(e_cT_bT2->source());
 		}
@@ -540,272 +454,255 @@ void EmbedderMinDepth::topDownTraversal(const node& bT)
 		M_B[bT].clear();
 		M2[bT].clear();
 		m_B = 0;
-		int m2 = 0;
-		forall_adj_edges(e_bT_cT, bT)
-		{
+		for (adjEntry adj : bT->adjEntries) {
+			edge e_bT_cT = adj->theEdge();
 			node cT = (e_bT_cT->source() == bT) ? e_bT_cT->target() : e_bT_cT->source();
-			edge e_cT_bT2;
-			forall_adj_edges(e_cT_bT2, cT)
-			{
-				if (e_bT_cT == e_cT_bT2)
+			for (adjEntry adjCT : cT->adjEntries) {
+				edge e_cT_bT2 = adjCT->theEdge();
+				if (e_bT_cT == e_cT_bT2) {
 					continue;
+				}
 
 				//update m_B and M_B:
-				if (m_B < m_cB[e_cT_bT2])
-				{
+				if (m_B < m_cB[e_cT_bT2]) {
 					m_B = m_cB[e_cT_bT2];
 					M_B[bT].clear();
 					M_B[bT].pushBack(pBCTree->cutVertex(cT, bT));
-				}
-				else if (m_B == m_cB[e_cT_bT2] && !M_B[bT].search(pBCTree->cutVertex(cT, bT)).valid())
-				{
+				} else if (m_B == m_cB[e_cT_bT2]
+						&& !M_B[bT].search(pBCTree->cutVertex(cT, bT)).valid()) {
 					M_B[bT].pushBack(pBCTree->cutVertex(cT, bT));
 				}
-			}//forall_adj_edges(e_cT_bT2, cT)
-		}//forall_adj_edges(e_bT_cT, bT)
+			}
+		}
 
-		if (M_B[bT].size() == 1)
-		{
+		if (M_B[bT].size() == 1) {
+			int m2 = 0;
 			node cT1 = pBCTree->bcproper(pBCTree->original(*(M_B[bT].begin())));
-			forall_adj_edges(e_bT_cT, bT)
-			{
+			for (adjEntry adj : bT->adjEntries) {
+				edge e_bT_cT = adj->theEdge();
 				node cT2 = (e_bT_cT->source() == bT) ? e_bT_cT->target() : e_bT_cT->source();
-				if (cT1 == cT2)
+				if (cT1 == cT2) {
 					continue;
+				}
 				node cT = (e_bT_cT->source() == bT) ? e_bT_cT->target() : e_bT_cT->source();
-				edge e_cT_bT2;
-				forall_adj_edges(e_cT_bT2, cT)
-				{
+				for (adjEntry adjCT : cT->adjEntries) {
+					edge e_cT_bT2 = adjCT->theEdge();
 					//update m2 and M2:
-					if (m2 < m_cB[e_cT_bT2])
-					{
+					if (m2 < m_cB[e_cT_bT2]) {
 						m2 = m_cB[e_cT_bT2];
 						M2[bT].clear();
 						M2[bT].pushBack(pBCTree->cutVertex(cT, bT));
-					}
-					else if (m2 == m_cB[e_cT_bT2]
-									 && !M2[bT].search(pBCTree->cutVertex(cT, bT)).valid())
-					{
+					} else if (m2 == m_cB[e_cT_bT2]
+							&& !M2[bT].search(pBCTree->cutVertex(cT, bT)).valid()) {
 						M2[bT].pushBack(pBCTree->cutVertex(cT, bT));
 					}
-				}//forall_adj_edges(e_cT_bT2, cT)
-			}//forall_adj_edges(e_bT_cT, bT)
+				}
+			}
 		}
 	}
 
-	if (cstrLength_B_c == M_B[bT].size())
+	if (cstrLength_B_c == M_B[bT].size()) {
 		minDepth[bT] = m_B;
-	else
+	} else {
 		minDepth[bT] = m_B + 2;
+	}
 }
 
-
-void EmbedderMinDepth::embedBlock(const node& bT)
-{
+void EmbedderMinDepth::embedBlock(const node& bT) {
 	ListIterator<adjEntry> after;
-	node cT = 0;
+	node cT = nullptr;
 	embedBlock(bT, cT, after);
 }
 
-
-void EmbedderMinDepth::embedBlock(
-	const node& bT,
-	const node& cT,
-	ListIterator<adjEntry>& after)
-{
+void EmbedderMinDepth::embedBlock(const node& bT, const node& cT, ListIterator<adjEntry>& after) {
 	treeNodeTreated[bT] = true;
-	node cH = 0;
-	if (!(cT == 0))
+	node cH = nullptr;
+	if (cT != nullptr) {
 		cH = pBCTree->cutVertex(cT, bT);
+	}
 
-	//***************************************************************************
 	// 1. Compute node lengths depending on M_B, M2 and cT
-	//***************************************************************************
 	nodeLength[bT].fill(0);
-	if (!(cT == 0) && M_B[bT].size() == 1 && *(M_B[bT].begin()) == cH)
-	{
+	if (cT != nullptr && M_B[bT].size() == 1 && *(M_B[bT].begin()) == cH) {
 		//set node length to 1 if node is in M2 and 0 otherwise
-		for (ListIterator<node> iterator = M2[bT].begin(); iterator.valid(); iterator++)
+		for (ListIterator<node> iterator = M2[bT].begin(); iterator.valid(); ++iterator) {
 			nodeLength[bT][nH_to_nBlockEmbedding[bT][*iterator]] = 1;
-	}
-	else
-	{
+		}
+	} else {
 		//set node length to 1 if node is in M_B and 0 otherwise
-		for (ListIterator<node> iterator = M_B[bT].begin(); iterator.valid(); iterator++)
+		for (ListIterator<node> iterator = M_B[bT].begin(); iterator.valid(); ++iterator) {
 			nodeLength[bT][nH_to_nBlockEmbedding[bT][*iterator]] = 1;
+		}
 	}
 
-	//***************************************************************************
 	// 2. Compute embedding of block
-	//***************************************************************************
 	EdgeArray<int> edgeLength(blockG[bT], 0);
-	adjEntry m_adjExternal = 0;
-	if (cH == 0)
-		EmbedderMaxFaceBiconnectedGraphs<int>::embed(blockG[bT], m_adjExternal, nodeLength[bT], edgeLength);
-	else
-		EmbedderMaxFaceBiconnectedGraphs<int>::embed(blockG[bT], m_adjExternal, nodeLength[bT], edgeLength,
-			nH_to_nBlockEmbedding[bT][cH]);
+	adjEntry m_adjExternal = nullptr;
+	if (cH == nullptr) {
+		EmbedderMaxFaceBiconnectedGraphs<int>::embed(blockG[bT], m_adjExternal, nodeLength[bT],
+				edgeLength);
+	} else {
+		EmbedderMaxFaceBiconnectedGraphs<int>::embed(blockG[bT], m_adjExternal, nodeLength[bT],
+				edgeLength, nH_to_nBlockEmbedding[bT][cH]);
+	}
 
-	//***************************************************************************
 	// 3. Copy block embedding into graph embedding and call recursively
 	//    embedBlock for all cut vertices in bT
-	//***************************************************************************
 	CombinatorialEmbedding CE(blockG[bT]);
 	face f = CE.leftFace(m_adjExternal);
 
-	if (*pAdjExternal == 0)
-	{
+	if (*pAdjExternal == nullptr) {
 		node on = pBCTree->original(nBlockEmbedding_to_nH[bT][m_adjExternal->theNode()]);
 		adjEntry ae1 = on->firstAdj();
-		for (adjEntry ae = ae1; ae; ae = ae->succ())
-		{
-			if (ae->theEdge() == pBCTree->original(eBlockEmbedding_to_eH[bT][m_adjExternal->theEdge()]))
-			{
+		for (adjEntry ae = ae1; ae; ae = ae->succ()) {
+			if (ae->theEdge()
+					== pBCTree->original(eBlockEmbedding_to_eH[bT][m_adjExternal->theEdge()])) {
 				*pAdjExternal = ae->twin();
 				break;
 			}
 		}
 	}
 
-	node nSG;
-	forall_nodes(nSG, blockG[bT])
-	{
+	for (node nSG : blockG[bT].nodes) {
 		node nH = nBlockEmbedding_to_nH[bT][nSG];
 		node nG = pBCTree->original(nH);
 		adjEntry ae = nSG->firstAdj();
 		ListIterator<adjEntry>* pAfter;
-		if (pBCTree->bcproper(nG) == cT)
+		if (pBCTree->bcproper(nG) == cT) {
 			pAfter = &after;
-		else
-			pAfter = OGDF_NEW ListIterator<adjEntry>();
+		} else {
+			pAfter = new ListIterator<adjEntry>();
+		}
 
-		if (pBCTree->typeOfGNode(nG) == BCTree::CutVertex)
-		{
+		if (pBCTree->typeOfGNode(nG) == BCTree::GNodeType::CutVertex) {
 			node cT2 = pBCTree->bcproper(nG);
+			OGDF_ASSERT(cT2 != nullptr);
 			bool no_recursion = false;
-			if (cT2 == cT)
-			{
-				node parent_bT_of_cT2 = 0;
-				edge e_cT2_to_bT2;
-				forall_adj_edges(e_cT2_to_bT2, cT2)
-				{
-					if (e_cT2_to_bT2->source() == cT2)
-					{
+			if (cT2 == cT) {
+				node parent_bT_of_cT2 = nullptr;
+				for (adjEntry adj : cT2->adjEntries) {
+					edge e_cT2_to_bT2 = adj->theEdge();
+					if (e_cT2_to_bT2->source() == cT2) {
 						parent_bT_of_cT2 = e_cT2_to_bT2->target();
 						break;
 					}
 				}
-				OGDF_ASSERT(parent_bT_of_cT2 != 0);
-				if (treeNodeTreated[parent_bT_of_cT2])
+				OGDF_ASSERT(parent_bT_of_cT2 != nullptr);
+				if (treeNodeTreated[parent_bT_of_cT2]) {
 					no_recursion = true;
+				}
 			}
 
-			if (no_recursion)
-			{
+			if (no_recursion) {
 				//find adjacency entry of nSG which lies on external face f:
 				adjEntry aeFace = f->firstAdj();
-				do
-				{
-					if (aeFace->theNode() == nSG)
-					{
-						if (aeFace->succ())
+				do {
+					if (aeFace->theNode() == nSG) {
+						if (aeFace->succ()) {
 							ae = aeFace->succ();
-						else
+						} else {
 							ae = nSG->firstAdj();
+						}
 						break;
 					}
 					aeFace = aeFace->faceCycleSucc();
-				} while(aeFace != f->firstAdj());
-			}
-			else //!no_recursion
+				} while (aeFace != f->firstAdj());
+			} else //!no_recursion
 			{
-				//(if exists) find adjacency entry of nSG which lies on external face f:
-				//bool aeExtExists = false;
+				// (if exists) find adjacency entry of nSG which lies on external face f:
+#if 0
+				bool aeExtExists = false;
+				List<edge> extFaceEdges;
+#endif
 				adjEntry aeFace = f->firstAdj();
-				//List<edge> extFaceEdges;
-				do
-				{
-					//extFaceEdges.pushBack(aeFace->theEdge());
-					if (aeFace->theNode() == nSG)
-					{
-						if (aeFace->succ())
+				do {
+#if 0
+					extFaceEdges.pushBack(aeFace->theEdge());
+#endif
+					if (aeFace->theNode() == nSG) {
+						if (aeFace->succ()) {
 							ae = aeFace->succ();
-						else
+						} else {
 							ae = nSG->firstAdj();
-						//aeExtExists = true;
+						}
+#if 0
+						aeExtExists = true;
+#endif
 						break;
 					}
 					aeFace = aeFace->faceCycleSucc();
-				} while(aeFace != f->firstAdj());
+				} while (aeFace != f->firstAdj());
 
-				//if (aeExtExists)
-				//{
-					edge e_cT2_to_bT2;
-					forall_adj_edges(e_cT2_to_bT2, cT2)
-					{
+				// if (aeExtExists)
+				{
+					for (adjEntry adj : cT2->adjEntries) {
+						edge e_cT2_to_bT2 = adj->theEdge();
 						node bT2;
-						if (e_cT2_to_bT2->source() == cT2)
+						if (e_cT2_to_bT2->source() == cT2) {
 							bT2 = e_cT2_to_bT2->target();
-						else
+						} else {
 							bT2 = e_cT2_to_bT2->source();
-						if (!treeNodeTreated[bT2])
+						}
+						if (!treeNodeTreated[bT2]) {
 							embedBlock(bT2, cT2, *pAfter);
+						}
 					}
-				//}
-				//else
-				//{
-				//	//cannot embed block into external face, so find a face with an adjacent
-				//	//edge of the external face:
-				//	bool foundIt = false;
-				//	edge adjEdge;
-				//	forall_adj_edges(adjEdge, nSG)
-				//	{
-				//		face m_f = CE.leftFace(adjEdge->adjSource());
-				//		adjEntry aeF = m_f->firstAdj();
-				//		do
-				//		{
-				//			if (extFaceEdges.search(aeF->theEdge()).valid())
-				//			{
-				//				ae = adjEdge->adjSource();
-				//				foundIt = true;
-				//				break;
-				//			}
-				//			aeF = aeF->faceCycleSucc();
-				//		} while(aeF != m_f->firstAdj());
-				//		if (foundIt)
-				//			break;
-				//	}
-				//}
+				}
+#if 0
+				else
+				{
+					//cannot embed block into external face, so find a face with an adjacent
+					//edge of the external face:
+					bool foundIt = false;
+					edge adjEdge;
+					forall_adj_edges(adjEdge, nSG)
+					{
+						face m_f = CE.leftFace(adjEdge->adjSource());
+						adjEntry aeF = m_f->firstAdj();
+						do
+						{
+							if (extFaceEdges.search(aeF->theEdge()).valid())
+							{
+								ae = adjEdge->adjSource();
+								foundIt = true;
+								break;
+							}
+							aeF = aeF->faceCycleSucc();
+						} while(aeF != m_f->firstAdj());
+						if (foundIt) {
+							break;
+						}
+					}
+				}
+#endif
 			}
 		}
 
 		//embed all edges of block bT:
 		bool after_ae = true;
-		for (adjEntry aeNode = ae;
-			after_ae || aeNode != ae;
-			after_ae = (!after_ae || !aeNode->succ()) ? false : true,
-			aeNode = aeNode->succ() ? aeNode->succ() : nSG->firstAdj())
-		{
+		for (adjEntry aeNode = ae; after_ae || aeNode != ae; after_ae = after_ae && aeNode->succ(),
+					  aeNode = aeNode->succ() ? aeNode->succ() : nSG->firstAdj()) {
 			edge eG = pBCTree->original(eBlockEmbedding_to_eH[bT][aeNode->theEdge()]);
-			if (nG == eG->source())
-			{
-				if (!pAfter->valid())
+			if (nG == eG->source()) {
+				if (!pAfter->valid()) {
 					*pAfter = newOrder[nG].pushBack(eG->adjSource());
-				else
+				} else {
 					*pAfter = newOrder[nG].insertAfter(eG->adjSource(), *pAfter);
-			}
-			else //!(nG == eG->source())
+				}
+			} else //!(nG == eG->source())
 			{
-				if (!pAfter->valid())
+				if (!pAfter->valid()) {
 					*pAfter = newOrder[nG].pushBack(eG->adjTarget());
-				else
+				} else {
 					*pAfter = newOrder[nG].insertAfter(eG->adjTarget(), *pAfter);
+				}
 			}
-		} //for (adjEntry aeNode = ae; aeNode; aeNode = aeNode->succ())
+		}
 
-		if (!(*pAfter == after))
+		if (!(*pAfter == after)) {
 			delete pAfter;
-	} //forall_nodes(nSG, blockG[bT])
+		}
+	}
 }
 
-} // end namespace ogdf
+}
