@@ -1,11 +1,3 @@
-/*
- * $Revision: 2554 $
- *
- * last checkin:
- *   $Author: gutwenger $
- *   $Date: 2012-07-06 11:39:38 +0200 (Fri, 06 Jul 2012) $
- ***************************************************************/
-
 /** \file
  * \brief The interface for mixed-model crossings beautifier
  * algorithms
@@ -17,7 +9,7 @@
  *
  * \par
  * Copyright (C)<br>
- * See README.txt in the root directory of the OGDF installation for details.
+ * See README.md in the OGDF root directory for details.
  *
  * \par
  * This program is free software; you can redistribute it and/or
@@ -34,34 +26,27 @@
  *
  * \par
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
- * \see  http://www.gnu.org/copyleft/gpl.html
- ***************************************************************/
-
-
-#include <ogdf/module/MixedModelCrossingsBeautifierModule.h>
+ * License along with this program; if not, see
+ * http://www.gnu.org/copyleft/gpl.html
+ */
 
+#include <ogdf/planarlayout/MixedModelCrossingsBeautifierModule.h>
 
 namespace ogdf {
 
 
-void MixedModelCrossingsBeautifierModule::call (const PlanRep &PG, GridLayout &gl)
-{
-	node v;
+void MixedModelCrossingsBeautifierModule::call(const PlanRep& PG, GridLayout& gl) {
 	List<node> crossings;
-	forall_nodes(v,PG) {
-		if (PG.isDummy(v))
+	for (node v : PG.nodes) {
+		if (PG.isDummy(v)) {
 			crossings.pushBack(v);
+		}
 	}
 
 	gl.compactAllBends();
-	doCall(PG,gl,crossings);
+	doCall(PG, gl, crossings);
 	m_nCrossings = crossings.size();
 	gl.compactAllBends();
 }
 
-
-} // end namespace ogdf
+}
