@@ -1,11 +1,3 @@
-/*
- * $Revision: 2554 $
- *
- * last checkin:
- *   $Author: gutwenger $
- *   $Date: 2012-07-06 11:39:38 +0200 (Fri, 06 Jul 2012) $
- ***************************************************************/
-
 /** \file
  * \brief Implements class ShellingOrderModule.
  *
@@ -16,7 +8,7 @@
  *
  * \par
  * Copyright (C)<br>
- * See README.txt in the root directory of the OGDF installation for details.
+ * See README.md in the OGDF root directory for details.
  *
  * \par
  * This program is free software; you can redistribute it and/or
@@ -33,41 +25,27 @@
  *
  * \par
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
- * \see  http://www.gnu.org/copyleft/gpl.html
- ***************************************************************/
-
-
-#include <ogdf/module/ShellingOrderModule.h>
+ * License along with this program; if not, see
+ * http://www.gnu.org/copyleft/gpl.html
+ */
 
+#include <ogdf/planarlayout/ShellingOrderModule.h>
 
 namespace ogdf {
 
 
-void ShellingOrderModule::call(const Graph &G,
-	ShellingOrder &order,
-	adjEntry adj)
-{
+void ShellingOrderModule::call(const Graph& G, ShellingOrder& order, adjEntry adj) {
 	List<ShellingOrderSet> partition;
-	doCall(G,adj,partition);
+	doCall(G, adj, partition);
 
-	order.init(G,partition);
+	order.init(G, partition);
 }
 
-
-void ShellingOrderModule::callLeftmost(const Graph &G,
-	ShellingOrder &order,
-	adjEntry adj)
-{
+void ShellingOrderModule::callLeftmost(const Graph& G, ShellingOrder& order, adjEntry adj) {
 	List<ShellingOrderSet> partition;
-	doCall(G,adj,partition);
+	doCall(G, adj, partition);
 
-	order.initLeftmost(G,partition);
+	order.initLeftmost(G, partition);
 }
 
-
-} // end namespace ogdf
-
+}
