@@ -1,11 +1,3 @@
-/*
- * $Revision: 2554 $
- *
- * last checkin:
- *   $Author: gutwenger $
- *   $Date: 2012-07-06 11:39:38 +0200 (Fri, 06 Jul 2012) $
- ***************************************************************/
-
 /** \file
  * \brief Module for simdraw manipulator classes
  *
@@ -16,7 +8,7 @@
  *
  * \par
  * Copyright (C)<br>
- * See README.txt in the root directory of the OGDF installation for details.
+ * See README.md in the OGDF root directory for details.
  *
  * \par
  * This program is free software; you can redistribute it and/or
@@ -33,38 +25,27 @@
  *
  * \par
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
- * \see  http://www.gnu.org/copyleft/gpl.html
- ***************************************************************/
+ * License along with this program; if not, see
+ * http://www.gnu.org/copyleft/gpl.html
+ */
 
-#include<ogdf/simultaneous/SimDrawManipulatorModule.h>
+#include <ogdf/simultaneous/SimDrawManipulatorModule.h>
 
 namespace ogdf {
 
-//*************************************************************
 // default constructor
-//
-SimDrawManipulatorModule::SimDrawManipulatorModule()
-{
+SimDrawManipulatorModule::SimDrawManipulatorModule() {
 	m_SD = new SimDraw;
 	m_G = &(m_SD->m_G);
 	m_GA = &(m_SD->m_GA);
-} //end default constructor
+}
 
-
-//*************************************************************
 // initializing base instance
-//
-void SimDrawManipulatorModule::init(SimDraw &SD)
-{
+void SimDrawManipulatorModule::init(SimDraw& SD) {
 	m_SD = &SD;
 	m_G = &(SD.m_G);
 	m_GA = &(SD.m_GA);
-	OGDF_ASSERT( &(*m_G) == &(m_GA->constGraph()) );
-} //end constructor
+	OGDF_ASSERT(&(*m_G) == &(m_GA->constGraph()));
+}
 
-
-} // end namespace ogdf
+}
