@@ -1,11 +1,3 @@
-/*
-* $Revision: 3159 $
-*
-* last checkin:
-*   $Author: gutwenger $
-*   $Date: 2012-12-13 09:01:58 +0100 (Thu, 13 Dec 2012) $
-***************************************************************/
-
 /** \file
  * \brief implementation of class PlanarizationLayoutUML.
  *
@@ -23,7 +15,7 @@
  *
  * \par
  * Copyright (C)<br>
- * See README.txt in the root directory of the OGDF installation for details.
+ * See README.md in the OGDF root directory for details.
  *
  * \par
  * This program is free software; you can redistribute it and/or
@@ -40,105 +32,80 @@
  *
  * \par
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
- * \see  http://www.gnu.org/copyleft/gpl.html
- ***************************************************************/
+ * License along with this program; if not, see
+ * http://www.gnu.org/copyleft/gpl.html
+ */
 
 
-#include <ogdf/uml/PlanarizationLayoutUML.h>
-#include <ogdf/uml/OrthoLayoutUML.h>
-#include <ogdf/uml/SubgraphPlanarizerUML.h>
-#include <ogdf/planarity/SimpleEmbedder.h>
-#include <ogdf/packing/TileToRowsCCPacker.h>
-#include <ogdf/basic/TopologyModule.h>
 #include <ogdf/basic/precondition.h>
-#include <ogdf/basic/simple_graph_alg.h>
-
+#include <ogdf/packing/TileToRowsCCPacker.h>
+#include <ogdf/planarity/SimpleEmbedder.h>
+#include <ogdf/uml/OrthoLayoutUML.h>
+#include <ogdf/uml/PlanarizationLayoutUML.h>
+#include <ogdf/uml/SubgraphPlanarizerUML.h>
 
 namespace ogdf {
 
-//-----------------------------------------------------------------------------
 // Constructor:
 // set default values for parameters and set planar layouter, planarization modules
-//-----------------------------------------------------------------------------
-
-PlanarizationLayoutUML::PlanarizationLayoutUML()
-{
+PlanarizationLayoutUML::PlanarizationLayoutUML() {
 	//modules
-	m_crossMin      .set(new SubgraphPlanarizerUML);
-	m_planarLayouter.set(new OrthoLayoutUML);
-	m_packer        .set(new TileToRowsCCPacker);
-	m_embedder      .set(new SimpleEmbedder);
+	m_crossMin.reset(new SubgraphPlanarizerUML);
+	m_planarLayouter.reset(new OrthoLayoutUML);
+	m_packer.reset(new TileToRowsCCPacker);
+	m_embedder.reset(new SimpleEmbedder);
 
 	//parameters
 	m_pageRatio = 1.0;
-	m_fakeTree  = true; //change edge type from generalization to association
+	m_fakeTree = true; //change edge type from generalization to association
 }
 
-
-//-----------------------------------------------------------------------------
 // call function: compute a layout for graph umlGraph without
 // special UML or interactive features, clique processing etc.
-//-----------------------------------------------------------------------------
-
-void PlanarizationLayoutUML::doSimpleCall(GraphAttributes &GA)
-{
+void PlanarizationLayoutUML::doSimpleCall(GraphAttributes& GA) {
 	m_nCrossings = 0;
 
-	if(GA.constGraph().empty())
+	if (GA.constGraph().empty()) {
 		return;
+	}
 
-	PlanRepUML pr =  PlanRepUML(GA);
+	PlanRepUML pr = PlanRepUML(GA);
 	const int numCC = pr.numberOfCCs();
 
 	// (width,height) of the layout of each connected component
 	Array<DPoint> boundingBox(numCC);
 
-	//------------------------------------------
 	//now planarize CCs and apply drawing module
-	for(int i = 0; i < numCC; ++i)
-	{
-		//---------------------------------------
+	for (int i = 0; i < numCC; ++i) {
 		// 1. crossing minimization
-		//---------------------------------------
 		int cr;
-		m_crossMin.get().call(pr, i, cr);
+		m_crossMin->call(pr, i, cr);
 		m_nCrossings += cr;
 
-
-		//---------------------------------------
 		// 2. embed resulting planar graph
-		//---------------------------------------
-		adjEntry adjExternal = 0;
-		m_embedder.get().call(pr, adjExternal);
+		adjEntry adjExternal = nullptr;
+		m_embedder->call(pr, adjExternal);
 
-
-		//---------------------------------------------------------
 		// 3. compute layout of planarized representation
-		//---------------------------------------------------------
-
 		Layout drawing(pr);
 
 		//call the Layouter for the CC's UMLGraph
-		m_planarLayouter.get().call(pr,adjExternal,drawing);
+		m_planarLayouter->call(pr, adjExternal, drawing);
 
 		// copy layout into umlGraph
 		// Later, we move nodes and edges in each connected component, such
 		// that no two overlap.
 
-		for(int j = pr.startNode(); j < pr.stopNode(); ++j) {
+		for (int j = pr.startNode(); j < pr.stopNode(); ++j) {
 			node vG = pr.v(j);
 
 			GA.x(vG) = drawing.x(pr.copy(vG));
 			GA.y(vG) = drawing.y(pr.copy(vG));
 
-			adjEntry adj;
-			forall_adj(adj,vG) {
-				if ((adj->index() & 1) == 0)
+			for (adjEntry adj : vG->adjEntries) {
+				if ((adj->index() & 1) == 0) {
 					continue;
+				}
 				edge eG = adj->theEdge();
 				drawing.computePolylineClear(pr, eG, GA.bends(eG));
 			}
@@ -146,32 +113,24 @@ void PlanarizationLayoutUML::doSimpleCall(GraphAttributes &GA)
 
 		// the width/height of the layout has been computed by the planar
 		// layout algorithm; required as input to packing algorithm
-		boundingBox[i] = m_planarLayouter.get().getBoundingBox();
+		boundingBox[i] = m_planarLayouter->getBoundingBox();
 	}
 
-	//----------------------------------------
 	// 4. arrange layouts of connected components
-	//----------------------------------------
-
 	arrangeCCs(pr, GA, boundingBox);
 }
 
-
-
-//-----------------------------------------------------------------------------
 // call function: compute an UML layout for graph umlGraph
-//-----------------------------------------------------------------------------
-void PlanarizationLayoutUML::call(UMLGraph &umlGraph)
-{
+void PlanarizationLayoutUML::call(UMLGraph& umlGraph) {
 	m_nCrossings = 0;
 
-	if(umlGraph.constGraph().empty())
+	if (umlGraph.constGraph().empty()) {
 		return;
+	}
 
 	// check necessary preconditions
 	preProcess(umlGraph);
 
-	//---------------------------------------------------
 	// preprocessing: insert a merger for generalizations
 	umlGraph.insertGenMergers();
 
@@ -187,17 +146,13 @@ void PlanarizationLayoutUML::call(UMLGraph &umlGraph)
 	// with them), move later
 	// we have to distinguish between cc's with and without generalizations
 	// if the alignment option is set
-	int l_layoutOptions = m_planarLayouter.get().getOptions();
-	bool l_align = ((l_layoutOptions & umlOpAlign) > 0);
+	int l_layoutOptions = m_planarLayouter->getOptions();
+	bool l_align = ((l_layoutOptions & UMLOpt::OpAlign) > 0);
 	//end alignment section
 
-	//------------------------------------------
 	//now planarize CCs and apply drawing module
-	for(int i = 0; i < numCC; ++i)
-	{
-		//---------------------------------------
+	for (int i = 0; i < numCC; ++i) {
 		// 1. crossing minimization
-		//---------------------------------------
 
 		// alignment: check wether gens exist, special treatment is necessary
 		bool l_gensExist = false; // set this for all CC's, start with first gen,
@@ -210,34 +165,30 @@ void PlanarizationLayoutUML::call(UMLGraph &umlGraph)
 		//edgearray for reinserter call: which edge may never be crossed?
 		EdgeArray<bool> noCrossingEdge(pr.original(), false);
 
-		edge e;
-		forall_edges(e,pr)
-		{
+		for (edge e : pr.edges) {
 			edge eOrig = pr.original(e);
 
-			if (pr.typeOf(e) == Graph::generalization)
-			{
-				if (l_align) l_gensExist = true;
+			if (pr.typeOf(e) == Graph::EdgeType::generalization) {
+				if (l_align) {
+					l_gensExist = true;
+				}
 				OGDF_ASSERT(!eOrig || !(noCrossingEdge[eOrig]));
 
 				// high cost to allow alignment without crossings
-				if (l_align && (
-					(eOrig && (pr.typeOf(e->target()) == Graph::generalizationMerger))
-						|| pr.alignUpward(e->adjSource())
-					))
-				 costOrig[eOrig] = 10;
-
+				if (l_align
+						&& ((eOrig && (pr.typeOf(e->target()) == Graph::NodeType::generalizationMerger))
+								|| pr.alignUpward(e->adjSource()))) {
+					costOrig[eOrig] = 10;
+				}
 			}
 		}
 
 		int cr;
-		m_crossMin.get().call(pr, i, cr, &costOrig);
+		m_crossMin->call(pr, i, cr, &costOrig);
 		m_nCrossings += cr;
 
 
-		//---------------------------------------
 		// 2. embed resulting planar graph
-		//---------------------------------------
 
 		// We currently compute any embedding and choose the maximal face as external face
 
@@ -245,61 +196,57 @@ void PlanarizationLayoutUML::call(UMLGraph &umlGraph)
 		// embedding, otherwise crossing nodes can turn into "touching points"
 		// of edges (alternatively, we could compute a new embedding and
 		// finally "remove" such unnecessary crossings).
-		if(!pr.representsCombEmbedding())
+		if (!pr.representsCombEmbedding()) {
 			planarEmbed(pr);
+		}
 
-		adjEntry adjExternal = 0;
-		if(pr.numberOfEdges() > 0) {
+		adjEntry adjExternal = nullptr;
+		if (pr.numberOfEdges() > 0) {
 			CombinatorialEmbedding E(pr);
-			face fExternal = findBestExternalFace(pr,E);
+			face fExternal = findBestExternalFace(pr, E);
 			adjExternal = fExternal->firstAdj();
 		}
 
-
-		//---------------------------------------------------------
 		// 3. compute layout of planarized representation
-		//---------------------------------------------------------
-
 		Layout drawing(pr);
 
 		// distinguish between CC's with/without generalizations
 		// this changes the input layout modules options!
-		if (l_gensExist)
-			m_planarLayouter.get().setOptions(l_layoutOptions);
-		else
-			m_planarLayouter.get().setOptions((l_layoutOptions & ~umlOpAlign));
+		if (l_gensExist) {
+			m_planarLayouter->setOptions(l_layoutOptions);
+		} else {
+			m_planarLayouter->setOptions((l_layoutOptions & ~UMLOpt::OpAlign));
+		}
 
 		// call the Layouter for the CC's UMLGraph
-		m_planarLayouter.get().call(pr, adjExternal, drawing);
+		m_planarLayouter->call(pr, adjExternal, drawing);
 
 		// copy layout into umlGraph
 		// Later, we move nodes and edges in each connected component, such
 		// that no two overlap.
 
-		for(int j = pr.startNode(); j < pr.stopNode(); ++j) {
+		for (int j = pr.startNode(); j < pr.stopNode(); ++j) {
 			node vG = pr.v(j);
 
 			umlGraph.x(vG) = drawing.x(pr.copy(vG));
 			umlGraph.y(vG) = drawing.y(pr.copy(vG));
 
-			adjEntry adj;
-			forall_adj(adj,vG) {
-				if ((adj->index() & 1) == 0) continue;
+			for (adjEntry adj : vG->adjEntries) {
+				if ((adj->index() & 1) == 0) {
+					continue;
+				}
 				edge eG = adj->theEdge();
 
-				drawing.computePolylineClear(pr,eG,umlGraph.bends(eG));
+				drawing.computePolylineClear(pr, eG, umlGraph.bends(eG));
 			}
 		}
 
 		// the width/height of the layout has been computed by the planar
 		// layout algorithm; required as input to packing algorithm
-		boundingBox[i] = m_planarLayouter.get().getBoundingBox();
-	}//for cc's
+		boundingBox[i] = m_planarLayouter->getBoundingBox();
+	}
 
-	//----------------------------------------
 	// Arrange layouts of connected components
-	//----------------------------------------
-
 	arrangeCCs(pr, umlGraph, boundingBox);
 
 	umlGraph.undoGenMergers();
@@ -309,165 +256,147 @@ void PlanarizationLayoutUML::call(UMLGraph &umlGraph)
 	postProcess(umlGraph);
 }
 
-
-
-
-
-//-----------------------------------------------------------------------------
 // additional helper functions
-//-----------------------------------------------------------------------------
-
-void PlanarizationLayoutUML::assureDrawability(UMLGraph &UG)
-{
+void PlanarizationLayoutUML::assureDrawability(UMLGraph& UG) {
 	//preliminary
 	//self loops are killed by the caller (e.g., the plugin interface)
 	//should be done here later
 
+#ifdef OGDF_DEBUG
 	const Graph& G = UG.constGraph();
 
 	//check for selfloops and handle them
-	edge e;
-	forall_edges(e, G) {
-		if (e->isSelfLoop())
-			OGDF_THROW_PARAM(PreconditionViolatedException, pvcSelfLoop);
+	for (edge e : G.edges) {
+		OGDF_ASSERT(!e->isSelfLoop());
 	}
+#endif
 
 	// check for generalization - nontrees
 	// if m_fakeTree is set, change type of "back" edges to association
-	m_fakedGens.clear();//?
-	if (!dfsGenTree(UG, m_fakedGens, m_fakeTree))
-		OGDF_THROW_PARAM(PreconditionViolatedException, pvcTreeHierarchies);
+	m_fakedGens.clear(); //?
+#ifdef OGDF_DEBUG
+	bool treeGenerated =
+#endif
+			dfsGenTree(UG, m_fakedGens, m_fakeTree);
+	OGDF_ASSERT(treeGenerated);
 
-	else {
-		ListConstIterator<edge> itE = m_fakedGens.begin();
-		while (itE.valid()) {
-			UG.type(*itE) = Graph::association;
-			itE++;
-		}
+	ListConstIterator<edge> itE = m_fakedGens.begin();
+	while (itE.valid()) {
+		UG.type(*itE) = Graph::EdgeType::association;
+		++itE;
 	}
-}//assureDrawability
+}
 
-
-
-void PlanarizationLayoutUML::preProcess(UMLGraph &UG)
-{
+void PlanarizationLayoutUML::preProcess(UMLGraph& UG) {
 	assureDrawability(UG);
 
-	const SListPure<UMLGraph::AssociationClass*> &acList = UG.assClassList();
+	const SListPure<UMLGraph::AssociationClass*>& acList = UG.assClassList();
 	SListConstIterator<UMLGraph::AssociationClass*> it = acList.begin();
-	while (it.valid())
-	{
+	while (it.valid()) {
 		UG.modelAssociationClass((*it));
-		it++;
+		++it;
 	}
-}//preprocess
+}
 
-
-void PlanarizationLayoutUML::postProcess(UMLGraph& UG)
-{
+void PlanarizationLayoutUML::postProcess(UMLGraph& UG) {
 	//reset the type of faked associations to generalization
-	if (m_fakeTree)
-	{
+	if (m_fakeTree) {
 		ListIterator<edge> itE = m_fakedGens.begin();
-		while (itE.valid())
-		{
-			UG.type(*itE) = Graph::generalization;
-			itE++;
+		while (itE.valid()) {
+			UG.type(*itE) = Graph::EdgeType::generalization;
+			++itE;
 		}
 	}
 
 	UG.undoAssociationClasses();
-}//postProcess
-
+}
 
 // find best suited external face according to certain criteria
-face PlanarizationLayoutUML::findBestExternalFace(
-	const PlanRep &PG,
-	const CombinatorialEmbedding &E)
-{
+face PlanarizationLayoutUML::findBestExternalFace(const PlanRep& PG, const CombinatorialEmbedding& E) {
 	FaceArray<int> weight(E);
 
-	face f;
-	forall_faces(f,E)
+	for (face f : E.faces) {
 		weight[f] = f->size();
+	}
 
-	node v;
-	forall_nodes(v,PG)
-	{
-		if(PG.typeOf(v) != Graph::generalizationMerger)
+	for (node v : PG.nodes) {
+		if (PG.typeOf(v) != Graph::NodeType::generalizationMerger) {
 			continue;
-
-		adjEntry adj;
-		forall_adj(adj,v) {
-			if(adj->theEdge()->source() == v)
-				break;
 		}
 
-		OGDF_ASSERT(adj->theEdge()->source() == v);
+		adjEntry adjOut = nullptr;
+		for (adjEntry adj : v->adjEntries) {
+			if (adj->theEdge()->source() == v) {
+				adjOut = adj;
+				break;
+			}
+		}
 
-		node w = adj->theEdge()->target();
+		OGDF_ASSERT(adjOut != nullptr);
+
+		node w = adjOut->theEdge()->target();
 		bool isBase = true;
 
-		adjEntry adj2;
-		forall_adj(adj2, w) {
+		for (adjEntry adj2 : w->adjEntries) {
 			edge e = adj2->theEdge();
-			if(e->target() != w && PG.typeOf(e) == Graph::generalization) {
+			if (e->target() != w && PG.typeOf(e) == Graph::EdgeType::generalization) {
 				isBase = false;
 				break;
 			}
 		}
 
-		if(isBase == false)
+		if (!isBase) {
 			continue;
+		}
 
-		face f1 = E.leftFace(adj);
-		face f2 = E.rightFace(adj);
+		face f1 = E.leftFace(adjOut);
+		face f2 = E.rightFace(adjOut);
 
 		weight[f1] += v->indeg();
-		if(f2 != f1)
+		if (f2 != f1) {
 			weight[f2] += v->indeg();
+		}
 	}
 
 	face fBest = E.firstFace();
-	forall_faces(f,E)
-		if(weight[f] > weight[fBest])
+	for (face f : E.faces) {
+		if (weight[f] > weight[fBest]) {
 			fBest = f;
+		}
+	}
 
 	return fBest;
 }
 
-
-void PlanarizationLayoutUML::arrangeCCs(PlanRep &PG, GraphAttributes &GA, Array<DPoint> &boundingBox)
-{
+void PlanarizationLayoutUML::arrangeCCs(PlanRep& PG, GraphAttributes& GA, Array<DPoint>& boundingBox) {
 	int numCC = PG.numberOfCCs();
 	Array<DPoint> offset(numCC);
-	m_packer.get().call(boundingBox,offset,m_pageRatio);
+	m_packer->call(boundingBox, offset, m_pageRatio);
 
 	// The arrangement is given by offset to the origin of the coordinate
 	// system. We still have to shift each node and edge by the offset
 	// of its connected component.
 
-	for(int i = 0; i < numCC; ++i) {
-
+	for (int i = 0; i < numCC; ++i) {
 		const double dx = offset[i].m_x;
 		const double dy = offset[i].m_y;
 
 		// iterate over all nodes in ith CC
-		for(int j = PG.startNode(i); j < PG.stopNode(i); ++j)
-		{
+		for (int j = PG.startNode(i); j < PG.stopNode(i); ++j) {
 			node v = PG.v(j);
 
 			GA.x(v) += dx;
 			GA.y(v) += dy;
 
-			adjEntry adj;
-			forall_adj(adj,v) {
-				if ((adj->index() & 1) == 0) continue;
+			for (adjEntry adj : v->adjEntries) {
+				if ((adj->index() & 1) == 0) {
+					continue;
+				}
 				edge e = adj->theEdge();
 
-				DPolyline &dpl = GA.bends(e);
+				DPolyline& dpl = GA.bends(e);
 				ListIterator<DPoint> it;
-				for(it = dpl.begin(); it.valid(); ++it) {
+				for (it = dpl.begin(); it.valid(); ++it) {
 					(*it).m_x += dx;
 					(*it).m_y += dy;
 				}
@@ -476,33 +405,25 @@ void PlanarizationLayoutUML::arrangeCCs(PlanRep &PG, GraphAttributes &GA, Array<
 	}
 }
 
-
-
-//=========================================================
-// removed stuff
-//
-
 #if 0
 
-//---------------------------------------------------------
 //compute a layout with the given embedding, take special
 //care of  crossings (assumes that all crossings are non-ambiguous
 //and can be derived from node/bend positions)
-//---------------------------------------------------------
 void PlanarizationLayoutUML::callFixEmbed(UMLGraph &umlGraph)
 {
 	m_nCrossings = 0;
 
-	if(((const Graph &)umlGraph).empty())
+	if(((const Graph &)umlGraph).empty()) {
 		return;
+	}
 
 	//check necessary preconditions
 	preProcess(umlGraph);
 
-	int l_layoutOptions = m_planarLayouter.get().getOptions();
-	bool l_align = ((l_layoutOptions & umlOpAlign)>0);
+	int l_layoutOptions = m_planarLayouter->getOptions();
+	bool l_align = ((l_layoutOptions & UMLOpt::OpAlign)>0);
 
-	//--------------------------------------------------------
 	//first, we sort all edges around each node corresponding
 	//to the given layout in umlGraph
 	//then we insert the mergers
@@ -510,9 +431,7 @@ void PlanarizationLayoutUML::callFixEmbed(UMLGraph &umlGraph)
 	bool umlMerge = false; //Standard: false
 	int i;
 
-	//*********************************************************
 	// first phase: Compute planarized representation from input
-	//*********************************************************
 
 	//now we derive a planar representation of the input
 	//graph using its layout information
@@ -524,7 +443,6 @@ void PlanarizationLayoutUML::callFixEmbed(UMLGraph &umlGraph)
 	Array<DPoint> boundingBox(numCC);
 
 
-	//******************************************
 	//now planarize CCs and apply drawing module
 	for(i = 0; i < numCC; ++i)
 	{
@@ -539,10 +457,8 @@ void PlanarizationLayoutUML::callFixEmbed(UMLGraph &umlGraph)
 		bool l_gensExist = false; //set this for all CC's, start with first gen,
 		//this setting can be mixed among CC's without problems
 
-		//*********************************************************
 		// we don't need to compute a planar subgraph, because we
 		// use the given embedding
-		//*********************************************************
 
 		adjEntry adjExternal = 0;
 
@@ -553,22 +469,18 @@ void PlanarizationLayoutUML::callFixEmbed(UMLGraph &umlGraph)
 		TopologyModule TM;
 		try {
 			embedded = TM.setEmbeddingFromGraph(PG, umlGraph, adjExternal, umlMerge);
-		}//try
+		}
 		catch (...)
 		{
 			//TODO: check for graph changes that are not undone
 			embedded = false;
 		}
 
-
-		//-------------------------------------------------
 		//if not embedded correctly
 		if (!embedded)
 		{
 			reembed(PG, i, l_align, l_gensExist);
-		}//if !embedded
-
-		//-------------------------------------------------
+		}
 
 		CombinatorialEmbedding E(PG);
 
@@ -592,28 +504,28 @@ void PlanarizationLayoutUML::callFixEmbed(UMLGraph &umlGraph)
 			//face fExternal = E.maximalFace();
 			face fExternal = findBestExternalFace(PG,E);
 			adjExternal = fExternal->firstAdj();
-			//while (PG.sinkConnect(adjExternal->theEdge()))
-			//	adjExternal = adjExternal->faceCycleSucc();
+#	if 0
+			while (PG.sinkConnect(adjExternal->theEdge())) {
+				adjExternal = adjExternal->faceCycleSucc();
+			}
+#	endif
 		}
 
 		m_nCrossings += PG.numberOfNodes() - nOrigVerticesPG;
 
 
-		//*********************************************************
 		// third phase: Compute layout of planarized representation
-		//*********************************************************
 
 		Layout drawing(PG);
 
 		//distinguish between CC's with/without generalizations
 		//this changes the input layout modules options!
 		if (l_gensExist)
-			m_planarLayouter.get().setOptions(l_layoutOptions);
-		else m_planarLayouter.get().setOptions((l_layoutOptions & ~umlOpAlign));
+			m_planarLayouter->setOptions(l_layoutOptions);
+		else m_planarLayouter->setOptions((l_layoutOptions & ~UMLOpt::OpAlign));
 
-		//***************************************
 		//call the Layouter for the CC's UMLGraph
-		m_planarLayouter.get().call(PG,adjExternal,drawing);
+		m_planarLayouter->call(PG,adjExternal,drawing);
 
 		// copy layout into umlGraph
 		// Later, we move nodes and edges in each connected component, such
@@ -628,15 +540,14 @@ void PlanarizationLayoutUML::callFixEmbed(UMLGraph &umlGraph)
 			umlGraph.x(vG) = drawing.x(PG.copy(vG));
 			umlGraph.y(vG) = drawing.y(PG.copy(vG));
 
-			adjEntry adj;
-			forall_adj(adj,vG)
+			for(adjEntry adj : vG->adjEntries)
 			{
 				if ((adj->index() & 1) == 0) continue;
 				edge eG = adj->theEdge();
 
 				drawing.computePolylineClear(PG,eG,umlGraph.bends(eG));
-			}//foralladj
-		}//for orig nodes
+			}
+		}
 
 		if (!umlMerge)
 		{
@@ -661,16 +572,16 @@ void PlanarizationLayoutUML::callFixEmbed(UMLGraph &umlGraph)
 						//because of the node collapse using the original
 						//edges instead of the merger copy edges (should be
 						//fixed for incremental mode) the  degree is 4
-						//if (vConnect->degree() != 3)
+						// if (vConnect->degree() != 3)
 						if (vConnect->degree() != 4)
 						{
 							runAdj = runAdj->faceCycleSucc();
 							continue;
 						}
 						edge eCopy = runAdj->cyclicPred()->theEdge();
-						OGDF_ASSERT(eCopy->target() == runAdj->theNode())
-						OGDF_ASSERT(PG.isGeneralization(eCopy))
-						OGDF_ASSERT(PG.original(eCopy))
+						OGDF_ASSERT(eCopy->target() == runAdj->theNode());
+						OGDF_ASSERT(PG.isGeneralization(eCopy));
+						OGDF_ASSERT(PG.original(eCopy));
 						umlGraph.bends(PG.original(eCopy)).pushBack(
 						DPoint(drawing.x(vMerger), drawing.y(vMerger)));
 						runAdj = runAdj->faceCycleSucc();
@@ -680,42 +591,36 @@ void PlanarizationLayoutUML::callFixEmbed(UMLGraph &umlGraph)
 				}
 				else //currently all nodes are expanded, but this is not guaranteed
 				{
-					forall_adj(adjMerger, vMerger)
+					for(adjEntry adjMerger : vMerger->adjEntries)
 					{
 						if (adjMerger->theEdge()->target() == vMerger)
 						{
 							edge eOrig = PG.original(adjMerger->theEdge());
-							if (eOrig)
+							if (eOrig) {
 								//incoming merger edges always have an original here!
 								umlGraph.bends(eOrig).pushBack(DPoint(drawing.x(vMerger),
 								drawing.y(vMerger)));
-
+							}
 						}
-					}//forall adj
+					}
 				}
 				itMerger++;
-			}//while merger nodes
+			}
 		}
 
 		// the width/height of the layout has been computed by the planar
 		// layout algorithm; required as input to packing algorithm
-		boundingBox[i] = m_planarLayouter.get().getBoundingBox();
-	}//for cc's
+		boundingBox[i] = m_planarLayouter->getBoundingBox();
+	}
 
 	postProcess(umlGraph);
 
-	//----------------------------------------
 	// Arrange layouts of connected components
-	//----------------------------------------
-
 	arrangeCCs(PG, umlGraph, boundingBox);
 
 	umlGraph.undoGenMergers();
 	umlGraph.removeUnnecessaryBendsHV();
-}//callfixembed
-
+}
 #endif
-//=========================================================
 
-
-} // end namespace ogdf
+}
