@@ -1,11 +1,3 @@
-/*
- * $Revision: 2963 $
- *
- * last checkin:
- *   $Author: gutwenger $
- *   $Date: 2012-11-05 14:17:50 +0100 (Mon, 05 Nov 2012) $
- ***************************************************************/
-
 /** \file
  * \brief Implementation of class UpwardPlanarSubgraphModule
  *
@@ -16,7 +8,7 @@
  *
  * \par
  * Copyright (C)<br>
- * See README.txt in the root directory of the OGDF installation for details.
+ * See README.md in the OGDF root directory for details.
  *
  * \par
  * This program is free software; you can redistribute it and/or
@@ -33,30 +25,22 @@
  *
  * \par
  * You should have received a copy of the GNU General Public
- * License along with this program; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
- * \see  http://www.gnu.org/copyleft/gpl.html
- ***************************************************************/
-
-
-#include <ogdf/module/UpwardPlanarSubgraphModule.h>
+ * License along with this program; if not, see
+ * http://www.gnu.org/copyleft/gpl.html
+ */
 
+#include <ogdf/upward/UpwardPlanarSubgraphModule.h>
 
 namespace ogdf {
 
 
-void UpwardPlanarSubgraphModule::callAndDelete(
-	GraphCopy &GC,
-	List<edge> &delOrigEdges)
-{
+void UpwardPlanarSubgraphModule::callAndDelete(GraphCopy& GC, List<edge>& delOrigEdges) {
 	List<edge> delEdges;
 
 	call(GC, delEdges);
 
 	ListConstIterator<edge> it;
-	for(it = delEdges.begin(); it.valid(); ++it) {
+	for (it = delEdges.begin(); it.valid(); ++it) {
 		edge eCopy = *it;
 
 		delOrigEdges.pushBack(GC.original(eCopy));
@@ -64,5 +48,4 @@ void UpwardPlanarSubgraphModule::callAndDelete(
 	}
 }
 
-
-} // end namespace ogdf
+}
